@@ -5,19 +5,18 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 package trace.pingpong;
+import org.simgrid.msg.HostNotFoundException;
 import org.simgrid.msg.Msg;
 import org.simgrid.msg.MsgException;
-import org.simgrid.msg.NativeException;
-import org.simgrid.msg.HostNotFoundException;
-import org.simgrid.msg.Task;
 import org.simgrid.msg.Process;
+import org.simgrid.msg.Task;
 import org.simgrid.trace.Trace;
 
 public class Receiver extends Process {
   private static final double COMM_SIZE_LAT = 1;
   private static final double COMM_SIZE_BW = 100000000;
 
-  public Receiver(String hostname, String name, String[]args) throws HostNotFoundException, NativeException {
+  public Receiver(String hostname, String name, String[]args) throws HostNotFoundException {
     super(hostname,name,args);
   }
 
