@@ -4,7 +4,7 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "simgrid/msg.h"
-#include <xbt/replay.h>
+#include <xbt/replay.hpp>
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(storage_actions, "Messages specific for this example");
 
@@ -28,11 +28,10 @@ static void log_action(const char *const *action, double date)
 
 static msg_file_t get_file_descriptor(const char *file_name){
   char full_name[1024];
-  msg_file_t file = NULL;
 
   snprintf(full_name,1023, "%s:%s", MSG_process_get_name(MSG_process_self()), file_name);
 
-  file = (msg_file_t) xbt_dict_get_or_null(opened_files, full_name);
+  msg_file_t file = (msg_file_t)xbt_dict_get_or_null(opened_files, full_name);
   return file;
 }
 
@@ -92,10 +91,8 @@ static void action_close(const char *const *action) {
 }
 
 int main(int argc, char *argv[]) {
-  msg_error_t res = MSG_OK;
-
   MSG_init(&argc, argv);
-  /* Explicit initialization of the action module is required now*/
+  /* Explicit initialization of the action module is required */
   MSG_action_init();
 
   xbt_assert(argc > 3,"Usage: %s platform_file deployment_file [action_files]\n"
@@ -114,7 +111,7 @@ int main(int argc, char *argv[]) {
   if (opened_files == NULL)
     opened_files = xbt_dict_new_homogeneous(NULL);
   /* Actually do the simulation using MSG_action_trace_run */
-  res = MSG_action_trace_run(argv[3]);  // it's ok to pass a NULL argument here
+  msg_error_t res = MSG_action_trace_run(argv[3]); // it's ok to pass a NULL argument here
 
   XBT_INFO("Simulation time %g", MSG_get_clock());
 
