@@ -43,7 +43,7 @@ typedef struct s_message {
   const char *mailbox;
   const char *issuer_host_name;
   int peer_id;
-  char *bitfield;
+  unsigned int bitfield;
   int index;
   int block_index;
   int block_length;
@@ -57,8 +57,8 @@ msg_task_t task_message_new(e_message_type type, const char *issuer_host_name, c
 msg_task_t task_message_index_new(e_message_type type, const char *issuer_host_name, const char *mailbox, int peer_id,
                                   int index, int varsize);
 /** Builds a new bitfield message */
-msg_task_t task_message_bitfield_new(const char *issuer_host_name, const char *mailbox, int peer_id, char *bitfield,
-                                     int bitfield_size);
+msg_task_t task_message_bitfield_new(const char *issuer_host_name, const char *mailbox, int peer_id,
+                                     unsigned int bitfield, int bitfield_size);
 /** Builds a new "request" message */
 msg_task_t task_message_request_new(const char *issuer_host_name, const char *mailbox, int peer_id, int index,
                                     int block_index, int block_length);
