@@ -1,5 +1,4 @@
-/* Copyright (c) 2010-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -21,7 +20,8 @@ XBT_LOG_NEW_DEFAULT_CATEGORY(bugged3, "this example");
 
 static int server(int argc, char *argv[])
 {
-  msg_task_t task1,task2;
+  msg_task_t task1 = NULL;
+  msg_task_t task2 = NULL;
 
   msg_comm_t comm1 = MSG_task_irecv(&task1, "mymailbox1");
   msg_comm_t comm2 = MSG_task_irecv(&task2, "mymailbox2");
