@@ -7,12 +7,13 @@
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(test, "Property test");
 
-static void test_host(const char*hostname) 
+static void test_host(const char*hostname)
 {
   msg_host_t thehost = MSG_host_by_name(hostname);
   xbt_dict_t props = MSG_host_get_properties(thehost);
   xbt_dict_cursor_t cursor = NULL;
-  char *key, *data;
+  char *key;
+  char *data;
   const char *noexist = "Unknown";
   const char *value;
   char exist[] = "Hdd";
@@ -63,10 +64,18 @@ static int david(int argc, char *argv[]) {/* Dump what we have on a remote host
 
 static int bob(int argc, char *argv[])
 {
+  /* this host also tests the properties of the AS*/
+  msg_as_t root = MSG_zone_get_root();
+  XBT_INFO("== Print the properties of the AS");
+  XBT_INFO("   Process property: filename -> %s", MSG_zone_get_property_value(root, "filename"));
+  XBT_INFO("   Process property: date -> %s", MSG_zone_get_property_value(root, "date"));
+  XBT_INFO("   Process property: author -> %s", MSG_zone_get_property_value(root, "author"));
+
   /* Get the property list of current bob process */
   xbt_dict_t props = MSG_process_get_properties(MSG_process_self());
   xbt_dict_cursor_t cursor = NULL;
-  char *key, *data;
+  char *key;
+  char *data;
   const char *noexist = "UnknownProcessProp";
   XBT_ATTRIB_UNUSED const char *value;
 
