@@ -26,8 +26,6 @@ static int sleeper(int argc, char *argv[])
 
 int main(int argc, char *argv[])
 {
-  msg_error_t res = MSG_OK;
-
   MSG_init(&argc, argv);
   xbt_assert(argc > 2, "Usage: %s platform_file deployment_file\n"
              "\tExample: %s msg_platform.xml msg_deployment.xml\n", argv[0], argv[0]);
@@ -36,7 +34,7 @@ int main(int argc, char *argv[])
   MSG_function_register("sleeper", sleeper);
   MSG_launch_application(argv[2]);   /* - Deploy the sleeper processes with explicit start/kill times */
 
-  res = MSG_main();                  /* - Run the simulation */
+  msg_error_t res = MSG_main(); /* - Run the simulation */
   XBT_INFO("Simulation time %g", MSG_get_clock());
   return res != MSG_OK;
 }
