@@ -11,33 +11,33 @@ XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_test, "a sample log category");
 
 class MyHost {
 public:
-
-  void show_info(boost::unordered_map <std::string, simgrid::s4u::Storage*> const&mounts) {
+  void show_info(std::unordered_map<std::string, simgrid::s4u::Storage*> const& mounts)
+  {
     XBT_INFO("Storage info on %s:", simgrid::s4u::Host::current()->cname());
 
     for (const auto&kv : mounts) {
       const char* mountpoint = kv.first.c_str();
-      simgrid::s4u::Storage &storage = *kv.second;
+      simgrid::s4u::Storage* storage = kv.second;
 
       // Retrieve disk's information
-      sg_size_t free_size = storage.sizeFree();
-      sg_size_t used_size = storage.sizeUsed();
-      sg_size_t size = storage.size();
+      sg_size_t free_size = storage->sizeFree();
+      sg_size_t used_size = storage->sizeUsed();
+      sg_size_t size      = storage->size();
 
-      XBT_INFO("    %s (%s) Used: %llu; Free: %llu; Total: %llu.",
-          storage.name(), mountpoint, used_size, free_size, size);
+      XBT_INFO("    %s (%s) Used: %llu; Free: %llu; Total: %llu.", storage->name(), mountpoint, used_size, free_size,
+               size);
     }
   }
 
   void operator()() {
-    boost::unordered_map <std::string, simgrid::s4u::Storage *> const& mounts =
-      simgrid::s4u::Host::current()->mountedStorages();
+    std::unordered_map<std::string, simgrid::s4u::Storage*> const& mounts =
+        simgrid::s4u::Host::current()->mountedStorages();
 
     show_info(mounts);
 
     // Open an non-existing file to create it
-    const char *filename = "/home/tmp/data.txt";
-    simgrid::s4u::File *file = new simgrid::s4u::File(filename, NULL);
+    const char* filename = "/home/tmp/data.txt";
+    simgrid::s4u::File* file = new simgrid::s4u::File(filename, nullptr);
 
     sg_size_t write = file->write(200000);  // Write 200,000 bytes
     XBT_INFO("Create a %llu bytes file named '%s' on /sd1", write, filename);
@@ -55,7 +55,7 @@ public:
     write = file->write(100000);  // Write 100,000 bytes
     XBT_INFO("Write %llu bytes on %s", write, filename);
 
-    simgrid::s4u::Storage &storage = simgrid::s4u::Storage::byName("Disk4");
+    simgrid::s4u::Storage* storage = simgrid::s4u::Storage::byName("Disk4");
 
     // Now rename file from ./tmp/data.txt to ./tmp/simgrid.readme
     const char *newpath = "/home/tmp/simgrid.readme";
@@ -71,11 +71,13 @@ public:
     delete file;
 
     // Now attach some user data to disk1
-    XBT_INFO("Get/set data for storage element: %s",storage.name());
-    XBT_INFO("    Uninitialized storage data: '%s'", (char*)storage.userdata());
+    XBT_INFO("Get/set data for storage element: %s", storage->name());
+    XBT_INFO("    Uninitialized storage data: '%s'", (char*)storage->userdata());
 
-    storage.setUserdata(xbt_strdup("Some user data"));
-    XBT_INFO("    Set and get data: '%s'", (char*)storage.userdata());
+    storage->setUserdata(xbt_strdup("Some user data"));
+    XBT_INFO("    Set and get data: '%s'", (char*)storage->userdata());
+
+    xbt_free(storage->userdata());
   }
 };
 
