@@ -12,11 +12,13 @@
 
 int main(int argc, char **argv)
 {
-  int recv_buff, err, size, rank, i;
+  int recv_buff;
+  int size;
+  int rank;
   MPI_Status status;
 
   /* Initialize MPI */
-  err = MPI_Init(&argc, &argv);
+  int err = MPI_Init(&argc, &argv);
   if (err != MPI_SUCCESS) {
     printf("MPI initialization failed!\n");
     exit(1);
@@ -33,7 +35,7 @@ int main(int argc, char **argv)
   if (rank == 0) {
     //printf("MPI_ISend / MPI_IRecv Test \n");
 
-    for(i=0; i < size - 1; i++){
+    for (int i = 0; i < size - 1; i++) {
       MPI_Recv(&recv_buff, 1, MPI_INT, MPI_ANY_SOURCE, MPI_ANY_TAG, MPI_COMM_WORLD, &status);
       //printf("Message received from %d\n", recv_buff);
     }
