@@ -7,16 +7,25 @@
 #ifndef MSG_H
 #define MSG_H
 
-#include "xbt.h"
-#include "xbt/lib.h"
 #include "simgrid/forward.h"
 #include "simgrid/simix.h"
 
+#ifdef __cplusplus
+namespace simgrid {
+namespace msg {
+class Comm;
+}
+}
+typedef simgrid::msg::Comm sg_msg_Comm;
+#else
+typedef struct msg_Comm sg_msg_Comm;
+#endif
+
 SG_BEGIN_DECL()
 
 /* *************************** Network Zones ******************************** */
 #define msg_as_t msg_netzone_t /* portability macro */
-typedef simgrid_NetZone* msg_netzone_t;
+typedef s4u_NetZone* msg_netzone_t;
 
 /* ******************************** Host ************************************ */
 
@@ -59,55 +68,16 @@ typedef struct msg_task *msg_task_t;
 typedef msg_host_t msg_vm_t;
 
 /* ******************************** File ************************************ */
-
-/** @brief Opaque object describing a File in MSG.
- *  @ingroup msg_file */
-typedef xbt_dictelm_t msg_file_t;
-
-extern int MSG_FILE_LEVEL;
-typedef struct simdata_file *simdata_file_t;
-
-struct msg_file_priv  {
-  char *fullpath;
-  sg_size_t size;
-  char* mount_point;
-  char* storageId;
-  char* storage_type;
-  char* content_type;
-  int desc_id;
-  void *data;
-  simdata_file_t simdata;
-};
-
-typedef struct msg_file_priv s_msg_file_priv_t;
-typedef struct msg_file_priv* msg_file_priv_t;
-
-static inline msg_file_priv_t MSG_file_priv(msg_file_t file){
-  return (msg_file_priv_t )xbt_lib_get_level(file, MSG_FILE_LEVEL);
-}
+typedef sg_file_t msg_file_t;
 
 /* ******************************** Storage ************************************ */
-/* TODO: PV: to comment */
-
-extern int MSG_STORAGE_LEVEL;
 
 /** @brief Storage datatype.
  *  @ingroup msg_storage_management
  *
  *  You should consider this as an opaque object.
  */
-typedef xbt_dictelm_t msg_storage_t;
-
-struct msg_storage_priv  {
-  const char *hostname;
-  void *data;
-};
-typedef struct msg_storage_priv  s_msg_storage_priv_t;
-typedef struct msg_storage_priv* msg_storage_priv_t;
-
-static inline msg_storage_priv_t MSG_storage_priv(msg_storage_t storage){
-  return (msg_storage_priv_t )xbt_lib_get_level(storage, MSG_STORAGE_LEVEL);
-}
+typedef sg_storage_t msg_storage_t;
 
 /**
  * \brief @brief Communication action.
@@ -115,7 +85,7 @@ static inline msg_storage_priv_t MSG_storage_priv(msg_storage_t storage){
  *
  * Object representing an ongoing communication between processes. Such beast is usually obtained by using #MSG_task_isend, #MSG_task_irecv or friends.
  */
-typedef struct msg_comm *msg_comm_t;
+typedef sg_msg_Comm* msg_comm_t;
 
 /** \brief Default value for an uninitialized #msg_task_t.
     \ingroup m_task_management
@@ -134,7 +104,7 @@ typedef struct msg_comm *msg_comm_t;
     structure, but always use the provided API to interact with
     processes.
  */
-typedef smx_actor_t msg_process_t;
+typedef s4u_Actor* msg_process_t;
 
 /** @brief Return code of most MSG functions
     @ingroup msg_simulation
@@ -184,14 +154,48 @@ XBT_PUBLIC(void) MSG_set_function(const char *host_id,
 XBT_PUBLIC(double) MSG_get_clock();
 XBT_PUBLIC(unsigned long int) MSG_get_sent_msg();
 
-/************************** Environment ***********************************/
-XBT_PUBLIC(msg_netzone_t) MSG_environment_get_routing_root();
-XBT_PUBLIC(const char*) MSG_environment_as_get_name(msg_netzone_t as);
-XBT_PUBLIC(msg_netzone_t) MSG_environment_as_get_by_name(const char* name);
-XBT_PUBLIC(xbt_dict_t) MSG_environment_as_get_routing_sons(msg_netzone_t as);
-XBT_PUBLIC(const char*) MSG_environment_as_get_property_value(msg_netzone_t as, const char* name);
-XBT_PUBLIC(void) MSG_environment_as_set_property_value(msg_netzone_t netzone, const char* name, char* value);
-XBT_PUBLIC(xbt_dynar_t) MSG_environment_as_get_hosts(msg_netzone_t as);
+/************************** Net Zones ***********************************/
+XBT_PUBLIC(msg_netzone_t) MSG_zone_get_root();
+XBT_PUBLIC(const char*) MSG_zone_get_name(msg_netzone_t zone);
+XBT_PUBLIC(msg_netzone_t) MSG_zone_get_by_name(const char* name);
+XBT_PUBLIC(void) MSG_zone_get_sons(msg_netzone_t zone, xbt_dict_t whereto);
+XBT_PUBLIC(const char*) MSG_zone_get_property_value(msg_netzone_t as, const char* name);
+XBT_PUBLIC(void) MSG_zone_set_property_value(msg_netzone_t netzone, const char* name, char* value);
+XBT_PUBLIC(void) MSG_zone_get_hosts(msg_netzone_t zone, xbt_dynar_t whereto);
+
+/* Deprecated forms of the previous functions */
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_root since v3.16")
+    msg_netzone_t MSG_environment_get_routing_root() {
+  return MSG_zone_get_root();
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_name since v3.16")
+    const char* MSG_environment_as_get_name(msg_netzone_t zone) {
+  return MSG_zone_get_name(zone);
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_by_name since v3.16")
+    msg_netzone_t MSG_environment_as_get_by_name(const char* name) {
+  return MSG_zone_get_by_name(name);
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_sons since v3.16")
+    xbt_dict_t MSG_environment_as_get_routing_sons(msg_netzone_t zone) {
+  xbt_dict_t res = xbt_dict_new_homogeneous(NULL);
+  MSG_zone_get_sons(zone, res);
+  return res;
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_property_value since v3.16")
+    const char* MSG_environment_as_get_property_value(msg_netzone_t zone, const char* name) {
+  return MSG_zone_get_property_value(zone, name);
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_set_property_value since v3.16")
+    void MSG_environment_as_set_property_value(msg_netzone_t zone, const char* name, char* value) {
+  MSG_zone_set_property_value(zone, name, value);
+}
+static inline XBT_ATTRIB_DEPRECATED("Please use MSG_zone_get_hosts since v3.16")
+    xbt_dynar_t MSG_environment_as_get_hosts(msg_netzone_t zone) {
+  xbt_dynar_t res = xbt_dynar_new(sizeof(sg_host_t), NULL);
+  MSG_zone_get_hosts(zone, res);
+  return res;
+}
 
 /************************** File handling ***********************************/
 XBT_PUBLIC(sg_size_t) MSG_file_read(msg_file_t fd, sg_size_t size);
@@ -205,8 +209,6 @@ XBT_PUBLIC(void) MSG_file_dump(msg_file_t fd);
 XBT_PUBLIC(msg_error_t) MSG_file_unlink(msg_file_t fd);
 XBT_PUBLIC(msg_error_t) MSG_file_seek(msg_file_t fd, sg_offset_t offset, int origin);
 XBT_PUBLIC(sg_size_t) MSG_file_tell (msg_file_t fd);
-XBT_PUBLIC(void) __MSG_file_get_info(msg_file_t fd);
-XBT_PUBLIC(void) __MSG_file_priv_free(msg_file_priv_t priv);
 XBT_PUBLIC(const char *) MSG_file_get_name(msg_file_t file);
 XBT_PUBLIC(msg_error_t) MSG_file_move(msg_file_t fd, const char* fullpath);
 XBT_PUBLIC(msg_error_t) MSG_file_rcopy(msg_file_t fd, msg_host_t host, const char* fullpath);
@@ -224,7 +226,6 @@ XBT_PUBLIC(msg_error_t) MSG_storage_set_data(msg_storage_t host, void *data);
 XBT_PUBLIC(void *) MSG_storage_get_data(msg_storage_t storage);
 XBT_PUBLIC(xbt_dict_t) MSG_storage_get_content(msg_storage_t storage);
 XBT_PUBLIC(sg_size_t) MSG_storage_get_size(msg_storage_t storage);
-XBT_PUBLIC(msg_error_t) MSG_storage_file_move(msg_file_t fd, msg_host_t dest, char* mount, char* fullname);
 XBT_PUBLIC(const char *) MSG_storage_get_host(msg_storage_t storage);
 
 /************************** Host handling ***********************************/
@@ -241,19 +242,17 @@ XBT_PUBLIC(void) MSG_host_off(msg_host_t host);
 XBT_PUBLIC(msg_host_t) MSG_host_self();
 XBT_PUBLIC(double) MSG_host_get_speed(msg_host_t h);
 XBT_PUBLIC(int) MSG_host_get_core_number(msg_host_t h);
-XBT_PUBLIC(xbt_swag_t) MSG_host_get_process_list(msg_host_t h);
+XBT_PUBLIC(void) MSG_host_get_process_list(msg_host_t h, xbt_dynar_t whereto);
 XBT_PUBLIC(int) MSG_host_is_on(msg_host_t h);
 XBT_PUBLIC(int) MSG_host_is_off(msg_host_t h);
 
-// deprecated
-XBT_PUBLIC(double) MSG_get_host_speed(msg_host_t h);
-
+XBT_PUBLIC(double) MSG_get_host_speed(msg_host_t h); /* deprecated */
 
 XBT_PUBLIC(double) MSG_host_get_power_peak_at(msg_host_t h, int pstate);
-XBT_PUBLIC(double) MSG_host_get_current_power_peak(msg_host_t h);
+#define MSG_host_get_current_power_peak(h) MSG_host_get_speed(h) /* deprecated */
 XBT_PUBLIC(int)    MSG_host_get_nb_pstates(msg_host_t h);
-#define MSG_host_get_pstate(h)         sg_host_get_pstate(h)
-#define MSG_host_set_pstate(h, pstate) sg_host_set_pstate(h, pstate)
+#define MSG_host_get_pstate(h)         sg_host_get_pstate(h)         /* deprecated */
+#define MSG_host_set_pstate(h, pstate) sg_host_set_pstate(h, pstate) /* deprecated */
 XBT_PUBLIC(xbt_dynar_t) MSG_hosts_as_dynar();
 XBT_PUBLIC(int) MSG_get_host_number();
 XBT_PUBLIC(xbt_dict_t) MSG_host_get_mounted_storage_list(msg_host_t host);
@@ -272,30 +271,20 @@ XBT_PUBLIC(void) MSG_create_environment(const char *file);
 XBT_PUBLIC(msg_process_t) MSG_process_create(const char *name,
                                            xbt_main_func_t code,
                                            void *data, msg_host_t host);
-XBT_PUBLIC(msg_process_t) MSG_process_create_with_arguments(const char *name,
-                                                          xbt_main_func_t
-                                                          code, void *data,
-                                                          msg_host_t host,
-                                                          int argc,
-                                                          char **argv);
-XBT_PUBLIC(msg_process_t) MSG_process_create_with_environment(const char
-                                                            *name,
-                                                            xbt_main_func_t
-                                                            code,
-                                                            void *data,
-                                                            msg_host_t host,
-                                                            int argc,
-                                                            char **argv,
-                                                            xbt_dict_t
-                                                            properties);
-XBT_PUBLIC(msg_process_t) MSG_process_attach(
-  const char *name, void *data,
-  msg_host_t host, xbt_dict_t properties);
+XBT_PUBLIC(msg_process_t)
+MSG_process_create_with_arguments(const char* name, xbt_main_func_t code, void* data, msg_host_t host, int argc,
+                                  char** argv);
+XBT_PUBLIC(msg_process_t)
+MSG_process_create_with_environment(const char* name, xbt_main_func_t code, void* data, msg_host_t host, int argc,
+                                    char** argv, xbt_dict_t properties);
+
+XBT_PUBLIC(msg_process_t) MSG_process_attach(const char* name, void* data, msg_host_t host, xbt_dict_t properties);
 XBT_PUBLIC(void) MSG_process_detach();
 
 XBT_PUBLIC(void) MSG_process_kill(msg_process_t process);
 XBT_PUBLIC(int) MSG_process_killall(int reset_PIDs);
 XBT_PUBLIC(msg_error_t) MSG_process_migrate(msg_process_t process, msg_host_t host);
+XBT_PUBLIC(void) MSG_process_yield();
 
 XBT_PUBLIC(void *) MSG_process_get_data(msg_process_t process);
 XBT_PUBLIC(msg_error_t) MSG_process_set_data(msg_process_t process,
@@ -326,7 +315,10 @@ XBT_PUBLIC(int) MSG_process_is_suspended(msg_process_t process);
 XBT_PUBLIC(void) MSG_process_on_exit(int_f_pvoid_pvoid_t fun, void *data);
 XBT_PUBLIC(void) MSG_process_auto_restart_set(msg_process_t process, int auto_restart);
 
+XBT_PUBLIC(void) MSG_process_daemonize(msg_process_t process);
 XBT_PUBLIC(msg_process_t) MSG_process_restart(msg_process_t process);
+XBT_PUBLIC(void) MSG_process_ref(msg_process_t process);
+XBT_PUBLIC(void) MSG_process_unref(msg_process_t process);
 
 /************************** Task handling ************************************/
 XBT_PUBLIC(msg_task_t) MSG_task_create(const char *name,
@@ -478,8 +470,9 @@ XBT_PUBLIC(void) MSG_vm_set_params(msg_vm_t vm, vm_params_t params);
 
 // TODO add VDI later
 XBT_PUBLIC(msg_vm_t) MSG_vm_create_core(msg_host_t location, const char *name);
+XBT_PUBLIC(msg_vm_t) MSG_vm_create_multicore(msg_host_t pm, const char* name, int coreAmount);
 XBT_PUBLIC(msg_vm_t)
-MSG_vm_create(msg_host_t ind_pm, const char* name, int ramsize, int mig_netspeed, int dp_intensity);
+MSG_vm_create(msg_host_t ind_pm, const char* name, int coreAmount, int ramsize, int mig_netspeed, int dp_intensity);
 
 XBT_PUBLIC(void) MSG_vm_destroy(msg_vm_t vm);
 
@@ -510,4 +503,11 @@ XBT_PUBLIC(smx_context_t) MSG_process_get_smx_ctx(msg_process_t process);
 
 
 SG_END_DECL()
+
+#ifdef __cplusplus
+XBT_PUBLIC(msg_process_t)
+MSG_process_create_from_stdfunc(const char* name, std::function<void()> code, void* data, msg_host_t host,
+                                xbt_dict_t properties);
+#endif
+
 #endif
