@@ -7,14 +7,7 @@
 #ifndef SIMGRID_SIMIX_HPP
 #define SIMGRID_SIMIX_HPP
 
-#include <cstddef>
-
-#include <string>
-#include <utility>
-#include <memory>
-#include <functional>
-
-#include <xbt/function_types.h>
+//#include <xbt/function_types.h>
 #include <xbt/future.hpp>
 #include <xbt/functional.hpp>
 #include <xbt/signal.hpp>
@@ -111,21 +104,14 @@ typedef smx_actor_t (*smx_creation_func_t) (
                                       std::function<void()> code,
                                       /* userdata */ void*,
                                       /* hostname */ sg_host_t,
-                                      /* kill_time */ double,
                                       /* props */ xbt_dict_t,
-                                      /* auto_restart */ int,
                                       /* parent_process */ smx_actor_t);
 
 extern "C"
 XBT_PUBLIC(void) SIMIX_function_register_process_create(smx_creation_func_t function);
 
-XBT_PUBLIC(smx_actor_t) simcall_process_create(const char *name,
-                                          std::function<void()> code,
-                                          void *data,
-                                          sg_host_t host,
-                                          double kill_time,
-                                          xbt_dict_t properties,
-                                          int auto_restart);
+XBT_PUBLIC(smx_actor_t)
+simcall_process_create(const char* name, std::function<void()> code, void* data, sg_host_t host, xbt_dict_t properties);
 
 XBT_PUBLIC(smx_timer_t) SIMIX_timer_set(double date, simgrid::xbt::Task<void()> callback);
 
