@@ -1,11 +1,10 @@
-/* Copyright (c) 2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2016-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef _XBT_CONFIG_HPP_
-#define _XBT_CONFIG_HPP_
+#ifndef XBT_CONFIG_HPP
+#define XBT_CONFIG_HPP
 
 #include <xbt/base.h>
 
@@ -169,8 +168,8 @@ typename std::enable_if<std::is_same<
 bindFlag(T& value, const char* name, const char* description,
   F callback)
 {
-  declareFlag(name, description, value, [&value,callback](const T& val) {
-    if (!callback(val))
+  declareFlag(name, description, value, [&value, callback](const T& val) {
+    if (not callback(val))
       throw std::range_error("invalid value");
     value = std::move(val);
   });
