@@ -1,11 +1,10 @@
-/* Copyright (c) 2006-2007, 2009-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef _XBT_GRAPH_H
-#define _XBT_GRAPH_H
+#ifndef XBT_GRAPH_H
+#define XBT_GRAPH_H
 #include "xbt/misc.h"           /* SG_BEGIN_DECL */
 #include "xbt/dynar.h"
 SG_BEGIN_DECL()
@@ -80,9 +79,10 @@ XBT_PUBLIC(xbt_dynar_t) xbt_graph_node_get_outedges(xbt_node_t n);
 XBT_PUBLIC(xbt_node_t) xbt_graph_edge_get_source(xbt_edge_t e);
 XBT_PUBLIC(xbt_node_t) xbt_graph_edge_get_target(xbt_edge_t e);
 
-XBT_PUBLIC(void) xbt_graph_export_graphviz(xbt_graph_t g, const char *filename,
-    const char *(node_name) (xbt_node_t), const char *(edge_name) (xbt_edge_t));
+XBT_PUBLIC(void)
+xbt_graph_export_graphviz(xbt_graph_t g, const char* filename, const char*(node_name)(xbt_node_t n),
+                          const char*(edge_name)(xbt_edge_t e));
 
 SG_END_DECL()
-#endif                          /* _XBT_GRAPH_H */
+#endif /* XBT_GRAPH_H */
 /** @} */
