@@ -1,20 +1,19 @@
 /* Java Wrappers to the MSG API.                                            */
 
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include <locale.h>
 
-#include <simgrid/msg.h>
-#include <simgrid/simix.h>
-#include <simgrid/plugins/energy.h>
+#include "simgrid/msg.h"
+#include "simgrid/plugins/energy.h"
+#include "simgrid/simix.h"
 
-#include <simgrid/s4u/host.hpp>
+#include "simgrid/s4u/Host.hpp"
 
-#include <src/simix/smx_private.h>
+#include "src/simix/smx_private.h"
 
 #include "jmsg_process.h"
 #include "jmsg_as.h"
@@ -26,6 +25,8 @@
 
 #include "JavaContext.hpp"
 
+#include <xbt/ex.hpp>
+
 /* Shut up some errors in eclipse online compiler. I wish such a pimple wouldn't be needed */
 #ifndef JNIEXPORT
 #define JNIEXPORT
@@ -38,9 +39,8 @@
 SG_BEGIN_DECL()
 
 int JAVA_HOST_LEVEL = -1;
-int JAVA_STORAGE_LEVEL = -1;
 
-XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(jmsg);
+XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(java);
 
 JavaVM *__java_vm = nullptr;
 
@@ -51,29 +51,27 @@ JavaVM *get_java_VM()
 
 JNIEnv *get_current_thread_env()
 {
-  JNIEnv *env;
-
-  __java_vm->AttachCurrentThread((void **) &env, nullptr);
-  return env;
+  using simgrid::kernel::context::JavaContext;
+  JavaContext* ctx = static_cast<JavaContext*>(xbt_os_thread_get_extra_data());
+  return ctx->jenv;
 }
 
 void jmsg_throw_status(JNIEnv *env, msg_error_t status) {
   switch (status) {
     case MSG_TIMEOUT:
-        jxbt_throw_time_out_failure(env,nullptr);
-    break;
+      jxbt_throw_time_out_failure(env, "");
+      break;
     case MSG_TRANSFER_FAILURE:
-        jxbt_throw_transfer_failure(env,nullptr);
-    break;
+      jxbt_throw_transfer_failure(env, "");
+      break;
     case MSG_HOST_FAILURE:
-        jxbt_throw_host_failure(env,nullptr);
-    break;
+      jxbt_throw_host_failure(env, "");
+      break;
     case MSG_TASK_CANCELED:
-        jxbt_throw_task_cancelled(env,nullptr);
-    break;
+      jxbt_throw_task_cancelled(env, "");
+      break;
     default:
-        jxbt_throw_native(env,xbt_strdup("undefined message failed "
-          "(please see jmsg_throw_status function in jmsg.cpp)"));
+      xbt_die("undefined message failed (please see jmsg_throw_status function in jmsg.cpp)");
   }
 }
 
@@ -90,19 +88,11 @@ static void __JAVA_host_priv_free(void *host)
 {
 }
 
-static void __JAVA_storage_priv_free(void *storage)
-{
-}
-
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_init(JNIEnv * env, jclass cls, jobjectArray jargs)
 {
-  char **argv = nullptr;
-  int index;
   int argc = 0;
-  jstring jval;
-  const char *tmp;
 
-  XBT_LOG_CONNECT(jmsg);
+  XBT_LOG_CONNECT(java);
   XBT_LOG_CONNECT(jtrace);
 
   env->GetJavaVM(&__java_vm);
@@ -116,15 +106,15 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_init(JNIEnv * env, jclass cls, j
   setlocale(LC_NUMERIC,"C");
 
   if (jargs)
-    argc = (int) env->GetArrayLength(jargs);
+    argc = static_cast<int>(env->GetArrayLength(jargs));
 
   argc++;
-  argv = xbt_new(char *, argc + 1);
+  char** argv = new char*[argc + 1];
   argv[0] = xbt_strdup("java");
 
-  for (index = 0; index < argc - 1; index++) {
-    jval = (jstring) env->GetObjectArrayElement(jargs, index);
-    tmp = env->GetStringUTFChars(jval, 0);
+  for (int index = 0; index < argc - 1; index++) {
+    jstring jval    = (jstring)env->GetObjectArrayElement(jargs, index);
+    const char* tmp = env->GetStringUTFChars(jval, 0);
     argv[index + 1] = xbt_strdup(tmp);
     env->ReleaseStringUTFChars(jval, tmp);
   }
@@ -133,12 +123,13 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_init(JNIEnv * env, jclass cls, j
   MSG_init(&argc, argv);
 
   JAVA_HOST_LEVEL = simgrid::s4u::Host::extension_create(__JAVA_host_priv_free);
-  JAVA_STORAGE_LEVEL = xbt_lib_add_level(storage_lib, __JAVA_storage_priv_free);
 
-  for (index = 0; index < argc; index++)
+  for (int index = 0; index < argc - 1; index++) {
+    env->SetObjectArrayElement(jargs, index, (jstring)env->NewStringUTF(argv[index + 1]));
     free(argv[index]);
-
-  free(argv);
+  }
+  free(argv[argc]);
+  delete[] argv;
 }
 
 JNIEXPORT void JNICALL JNICALL Java_org_simgrid_msg_Msg_run(JNIEnv * env, jclass cls)
@@ -163,15 +154,8 @@ JNIEXPORT void JNICALL JNICALL Java_org_simgrid_msg_Msg_run(JNIEnv * env, jclass
   xbt_dynar_free(&hosts);
 
   /* Cleanup java storages */
-  xbt_dynar_t storages = MSG_storages_as_dynar();
-  if(!xbt_dynar_is_empty(storages)){
-    for (unsigned long index = 0; index < xbt_dynar_length(storages) - 1; index++) {
-      jobject jstorage = (jobject) xbt_lib_get_level(xbt_dynar_get_as(storages,index,msg_storage_t), JAVA_STORAGE_LEVEL);
-      if (jstorage)
-        jstorage_unref(env, jstorage);
-    }
-  }
-  xbt_dynar_free(&storages);
+  for (auto elm : java_storage_map)
+    jstorage_unref(env, elm.second);
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_createEnvironment(JNIEnv * env, jclass cls, jstring jplatformFile)
@@ -185,18 +169,18 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_createEnvironment(JNIEnv * env,
 
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Msg_environmentGetRoutingRoot(JNIEnv * env, jclass cls)
 {
-  msg_netzone_t as = MSG_environment_get_routing_root();
-  jobject jas = jas_new_instance(env);
-  if (!jas) {
+  msg_netzone_t as = MSG_zone_get_root();
+  jobject jas      = jnetzone_new_instance(env);
+  if (not jas) {
     jxbt_throw_jni(env, "java As instantiation failed");
     return nullptr;
   }
-  jas = jas_ref(env, jas);
-  if (!jas) {
+  jas = jnetzone_ref(env, jas);
+  if (not jas) {
     jxbt_throw_jni(env, "new global ref allocation failed");
     return nullptr;
   }
-  jas_bind(jas, as, env);
+  jnetzone_bind(jas, as, env);
 
   return (jobject) jas;
 }
@@ -254,12 +238,12 @@ Java_org_simgrid_msg_Msg_deployApplication(JNIEnv * env, jclass cls, jstring jde
   MSG_launch_application(deploymentFile);
 }
 
-SG_END_DECL()
-
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_energyInit() {
-  sg_energy_plugin_init();
+  sg_host_energy_plugin_init();
 }
 
+SG_END_DECL()
+
 /** Run a Java org.simgrid.msg.Process
  *
  *  If needed, this waits for the process starting time.
@@ -267,16 +251,14 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Msg_energyInit() {
  */
 static void run_jprocess(JNIEnv *env, jobject jprocess)
 {
-  xbt_assert(jprocess != nullptr, "Process not created...");
-  //wait for the process to be able to begin
-  //TODO: Cache it
+  // wait for the process's start time
   jfieldID jprocess_field_Process_startTime = jxbt_get_sfield(env, "org/simgrid/msg/Process", "startTime", "D");
   jdouble startTime = env->GetDoubleField(jprocess, jprocess_field_Process_startTime);
   if (startTime > MSG_get_clock())
     MSG_process_sleep(startTime - MSG_get_clock());
   //Execution of the "run" method.
   jmethodID id = jxbt_get_smethod(env, "org/simgrid/msg/Process", "run", "()V");
-  xbt_assert( (id != nullptr), "Method not found...");
+  xbt_assert((id != nullptr), "Method run() not found...");
   env->CallVoidMethod(jprocess, id);
 }
 
@@ -332,13 +314,8 @@ void java_main_jprocess(jobject jprocess)
   JNIEnv *env = get_current_thread_env();
   simgrid::kernel::context::JavaContext* context = static_cast<simgrid::kernel::context::JavaContext*>(SIMIX_context_self());
   context->jprocess = jprocess;
-  smx_actor_t process = SIMIX_process_self();
-  jprocess_bind(context->jprocess, process, env);
+  jprocess_bind(context->jprocess, MSG_process_self(), env);
 
-  // Adrien, ugly path, just to bypass creation of context at low levels (i.e such as for the VM migration for instance)
-  if (context->jprocess == nullptr)
-    return;
-  else
-    run_jprocess(env, context->jprocess);
+  run_jprocess(env, context->jprocess);
 }
 }}}
