@@ -1,7 +1,6 @@
-/* Functions related to the java file API.                            */
+/* Java bindings of the file API.                                           */
 
-/* Copyright (c) 2012-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2015. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -9,12 +8,14 @@
 #include "jmsg_file.h"
 #include "jxbt_utilities.h"
 
+SG_BEGIN_DECL()
+
 void jfile_bind(JNIEnv *env, jobject jfile, msg_file_t fd) {
   env->SetLongField(jfile, jfile_field_bind, reinterpret_cast<std::intptr_t>(fd));
 }
 
 msg_file_t jfile_get_native(JNIEnv *env, jobject jfile) {
-  return reinterpret_cast<msg_file_t>(static_cast<std::intptr_t>(env->GetLongField(jfile, jfile_field_bind)));
+  return reinterpret_cast<msg_file_t>(env->GetLongField(jfile, jfile_field_bind));
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_File_nativeInit(JNIEnv *env, jclass cls) {
@@ -52,3 +53,5 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_File_close(JNIEnv *env, jobject jfil
   MSG_file_close(file);
   jfile_bind(env, jfile, nullptr);
 }
+
+SG_END_DECL()
