@@ -1,17 +1,11 @@
 /* Functions related to the java task instances.                            */
 
-/* Copyright (c) 2007, 2009-2010, 2013-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <xbt/log.h>
-#include <xbt/str.h>
-#include <xbt/sysdep.h>
-
-#include <simgrid/msg.h>
-#include <simgrid/s4u/host.hpp>
+#include "simgrid/s4u/Host.hpp"
 
 #include "jmsg.h"
 #include "jmsg_host.h"
@@ -19,7 +13,9 @@
 #include "jmsg_process.h"
 #include "jxbt_utilities.h"
 
-XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(jmsg);
+XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(java);
+
+SG_BEGIN_DECL()
 
 static jmethodID jtask_method_Comm_constructor;
 
@@ -35,19 +31,16 @@ void jtask_bind(jobject jtask, msg_task_t task, JNIEnv * env)
   env->SetLongField(jtask, jtask_field_Task_bind, (intptr_t)task);
 }
 
-msg_task_t jtask_to_native_task(jobject jtask, JNIEnv * env)
+msg_task_t jtask_to_native(jobject jtask, JNIEnv* env)
 {
   return (msg_task_t)(intptr_t)env->GetLongField(jtask, jtask_field_Task_bind);
 }
 
-jboolean jtask_is_valid(jobject jtask, JNIEnv * env)
-{
-  return env->GetLongField(jtask, jtask_field_Task_bind) ? JNI_TRUE : JNI_FALSE;
-}
-
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_nativeInit(JNIEnv *env, jclass cls) {
   jclass jtask_class_Comm = env->FindClass("org/simgrid/msg/Comm");
   jclass jtask_class_Task = env->FindClass("org/simgrid/msg/Task");
+  xbt_assert(jtask_class_Comm && jtask_class_Task,
+             "Native initialization of msg/Comm or msg/Task failed. Please report that bug");
 
   jtask_method_Comm_constructor = env->GetMethodID(jtask_class_Comm, "<init>", "()V");
   jtask_field_Task_bind = jxbt_get_jfield(env, jtask_class_Task, "bind", "J");
@@ -56,117 +49,63 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_nativeInit(JNIEnv *env, jclass
   jtask_field_Comm_bind = jxbt_get_jfield(env, jtask_class_Comm, "bind", "J");
   jtask_field_Comm_taskBind = jxbt_get_jfield(env, jtask_class_Comm, "taskBind", "J");
   jtask_field_Comm_receiving = jxbt_get_jfield(env, jtask_class_Comm, "receiving", "Z");
-  if (!jtask_field_Task_bind || !jtask_class_Task || !jtask_field_Comm_bind || !jtask_field_Comm_taskBind ||
-        !jtask_field_Comm_receiving || !jtask_method_Comm_constructor) {
-          jxbt_throw_native(env,bprintf("Can't find some fields in Java class."));
-  }
+  xbt_assert(jtask_field_Task_bind && jtask_field_Comm_bind && jtask_field_Comm_taskBind &&
+                 jtask_field_Comm_receiving && jtask_method_Comm_constructor,
+             "Native initialization of msg/Task failed. Please report that bug");
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_create(JNIEnv * env, jobject jtask, jstring jname,
                                       jdouble jflopsAmount, jdouble jbytesAmount)
 {
-  msg_task_t task;                /* the native task to create                            */
   const char *name = nullptr;      /* the name of the task                                 */
 
-  if (jflopsAmount < 0) {
-    jxbt_throw_illegal(env, bprintf("Task flopsAmount (%f) cannot be negative", (double) jflopsAmount));
-    return;
-  }
-
-  if (jbytesAmount < 0) {
-    jxbt_throw_illegal(env, bprintf("Task bytesAmount (%f) cannot be negative", (double) jbytesAmount));
-    return;
-  }
-
-  if (jname) {
-    /* get the C string from the java string */
+  if (jname)
     name = env->GetStringUTFChars(jname, 0);
-  }
-
-  /* create the task */
-  task = MSG_task_create(name, (double) jflopsAmount, (double) jbytesAmount, nullptr);
+  msg_task_t task = MSG_task_create(name, static_cast<double>(jflopsAmount), static_cast<double>(jbytesAmount), jtask);
   if (jname)
     env->ReleaseStringUTFChars(jname, name);
-  /* sets the task name */
-  env->SetObjectField(jtask, jtask_field_Task_name, jname);
+
   /* bind & store the task */
   jtask_bind(jtask, task, env);
-  MSG_task_set_data(task, jtask);
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_parallelCreate(JNIEnv * env, jobject jtask, jstring jname,
                                          jobjectArray jhosts, jdoubleArray jcomputeDurations_arg,
                                          jdoubleArray jmessageSizes_arg)
 {
-  msg_task_t task;                /* the native parallel task to create           */
-  const char *name;             /* the name of the task                         */
-  int host_count;
-  msg_host_t *hosts;
-  double *computeDurations;
-  double *messageSizes;
-  jdouble *jcomputeDurations;
-  jdouble *jmessageSizes;
-  jobject jhost;
-  int index;
+  int host_count = static_cast<int>(env->GetArrayLength(jhosts));
 
-  if (!jcomputeDurations_arg) {
-    jxbt_throw_null(env, xbt_strdup("Parallel task flops amounts cannot be null"));
-    return;
-  }
-
-  if (!jmessageSizes_arg) {
-    jxbt_throw_null(env, xbt_strdup("Parallel task bytes amounts cannot be null"));
-    return;
-  }
-
-  if (!jname) {
-    jxbt_throw_null(env, xbt_strdup("Parallel task name cannot be null"));
-    return;
-  }
-
-  host_count = (int) env->GetArrayLength(jhosts);
-
-  hosts = xbt_new0(msg_host_t, host_count);
-  computeDurations = xbt_new0(double, host_count);
-  messageSizes = xbt_new0(double, host_count * host_count);
-
-  jcomputeDurations = env->GetDoubleArrayElements(jcomputeDurations_arg, 0);
-  jmessageSizes = env->GetDoubleArrayElements(jmessageSizes_arg, 0);
-
-  for (index = 0; index < host_count; index++) {
-    jhost = env->GetObjectArrayElement(jhosts, index);
+  jdouble* jcomputeDurations = env->GetDoubleArrayElements(jcomputeDurations_arg, 0);
+  msg_host_t* hosts          = xbt_new0(msg_host_t, host_count);
+  double* computeDurations   = xbt_new0(double, host_count);
+  for (int index = 0; index < host_count; index++) {
+    jobject jhost           = env->GetObjectArrayElement(jhosts, index);
     hosts[index] = jhost_get_native(env, jhost);
     computeDurations[index] = jcomputeDurations[index];
   }
-  for (index = 0; index < host_count * host_count; index++) {
+  env->ReleaseDoubleArrayElements(jcomputeDurations_arg, jcomputeDurations, 0);
+
+  jdouble* jmessageSizes = env->GetDoubleArrayElements(jmessageSizes_arg, 0);
+  double* messageSizes   = xbt_new0(double, host_count* host_count);
+  for (int index = 0; index < host_count * host_count; index++) {
     messageSizes[index] = jmessageSizes[index];
   }
-
-  env->ReleaseDoubleArrayElements(jcomputeDurations_arg, jcomputeDurations, 0);
   env->ReleaseDoubleArrayElements(jmessageSizes_arg, jmessageSizes, 0);
 
   /* get the C string from the java string */
-  name = env->GetStringUTFChars(jname, 0);
-
-  task = MSG_parallel_task_create(name, host_count, hosts, computeDurations, messageSizes, nullptr);
-
+  const char* name = env->GetStringUTFChars(jname, 0);
+  msg_task_t task  = MSG_parallel_task_create(name, host_count, hosts, computeDurations, messageSizes, jtask);
   env->ReleaseStringUTFChars(jname, name);
-  /* sets the task name */
-  env->SetObjectField(jtask, jtask_field_Task_name, jname);
+
   /* associate the java task object and the native task */
   jtask_bind(jtask, task, env);
-
-  MSG_task_set_data(task, (void *) jtask);
-
-  if (!MSG_task_get_data(task))
-    jxbt_throw_jni(env, "global ref allocation failed");
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_cancel(JNIEnv * env, jobject jtask)
 {
-  msg_task_t ptask = jtask_to_native_task(jtask, env);
+  msg_task_t ptask = jtask_to_native(jtask, env);
 
-  if (!ptask) {
+  if (not ptask) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
@@ -178,9 +117,9 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_cancel(JNIEnv * env, jobject jt
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_execute(JNIEnv * env, jobject jtask)
 {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
@@ -195,9 +134,9 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_execute(JNIEnv * env, jobject j
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setBound(JNIEnv * env, jobject jtask, jdouble bound)
 {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
@@ -205,9 +144,9 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setBound(JNIEnv * env, jobject
 }
 
 JNIEXPORT jstring JNICALL Java_org_simgrid_msg_Task_getName(JNIEnv * env, jobject jtask) {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return nullptr;
   }
@@ -218,9 +157,9 @@ JNIEXPORT jstring JNICALL Java_org_simgrid_msg_Task_getName(JNIEnv * env, jobjec
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_getSender(JNIEnv * env, jobject jtask) {
   msg_process_t process;
 
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return nullptr;
   }
@@ -229,15 +168,15 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_getSender(JNIEnv * env, jobj
   if (process == nullptr) {
     return nullptr;
   }
-  return (jobject) native_to_java_process(process);
+  return (jobject)jprocess_from_native(process);
 }
 
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_getSource(JNIEnv * env, jobject jtask)
 {
   msg_host_t host;
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return nullptr;
   }
@@ -246,7 +185,7 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_getSource(JNIEnv * env, jobj
   if (host == nullptr) {
     return nullptr;
   }
-  if (!host->extension(JAVA_HOST_LEVEL)) {
+  if (not host->extension(JAVA_HOST_LEVEL)) {
     jxbt_throw_jni(env, "MSG_task_get_source() failed");
     return nullptr;
   }
@@ -256,9 +195,9 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_getSource(JNIEnv * env, jobj
 
 JNIEXPORT jdouble JNICALL Java_org_simgrid_msg_Task_getFlopsAmount(JNIEnv * env, jobject jtask)
 {
-  msg_task_t ptask = jtask_to_native_task(jtask, env);
+  msg_task_t ptask = jtask_to_native(jtask, env);
 
-  if (!ptask) {
+  if (not ptask) {
     jxbt_throw_notbound(env, "task", jtask);
     return -1;
   }
@@ -266,9 +205,9 @@ JNIEXPORT jdouble JNICALL Java_org_simgrid_msg_Task_getFlopsAmount(JNIEnv * env,
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setName(JNIEnv *env, jobject jtask, jobject jname) {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
@@ -282,114 +221,127 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setName(JNIEnv *env, jobject jt
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setPriority(JNIEnv * env, jobject jtask, jdouble priority)
 {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
-  MSG_task_set_priority(task, (double) priority);
+  MSG_task_set_priority(task, static_cast<double>(priority));
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setFlopsAmount (JNIEnv *env, jobject jtask, jdouble computationAmount)
 {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
-  MSG_task_set_flops_amount(task, (double) computationAmount);
+  MSG_task_set_flops_amount(task, static_cast<double>(computationAmount));
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_setBytesAmount (JNIEnv *env, jobject jtask, jdouble dataSize)
 {
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
   env->SetDoubleField(jtask, jtask_field_Task_messageSize, dataSize);
-  MSG_task_set_bytes_amount(task, (double) dataSize);
-}
-
-JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_send(JNIEnv * env,jobject jtask, jstring jalias, jdouble jtimeout)
-{
-  msg_error_t rv;
-  const char *alias = env->GetStringUTFChars(jalias, 0);
-
-  msg_task_t task = jtask_to_native_task(jtask, env);
-
-  if (!task) {
-    env->ReleaseStringUTFChars(jalias, alias);
-    jxbt_throw_notbound(env, "task", jtask);
-    return;
-  }
-
-  /* Pass a global ref to the Jtask into the Ctask so that the receiver can use it */
-  MSG_task_set_data(task, (void *) env->NewGlobalRef(jtask));
-  rv = MSG_task_send_with_timeout(task, alias, (double) jtimeout);
-  env->ReleaseStringUTFChars(jalias, alias);
-
-  if (rv != MSG_OK) {
-    jmsg_throw_status(env, rv);
-  }
+  MSG_task_set_bytes_amount(task, static_cast<double>(dataSize));
 }
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_sendBounded(JNIEnv * env,jobject jtask, jstring jalias,
                                                              jdouble jtimeout,jdouble maxrate)
 {
-  msg_error_t rv;
-  const char *alias = env->GetStringUTFChars(jalias, 0);
-
-  msg_task_t task = jtask_to_native_task(jtask, env);
-
-  if (!task) {
-    env->ReleaseStringUTFChars(jalias, alias);
+  msg_task_t task = jtask_to_native(jtask, env);
+  if (not task) {
     jxbt_throw_notbound(env, "task", jtask);
     return;
   }
 
-  /* Pass a global ref to the Jtask into the Ctask so that the receiver can use it */
+  /* Add a global ref into the Ctask so that the receiver can use it */
   MSG_task_set_data(task, (void *) env->NewGlobalRef(jtask));
-  rv = MSG_task_send_with_timeout_bounded(task, alias, (double) jtimeout, (double) maxrate);
+
+  const char* alias = env->GetStringUTFChars(jalias, 0);
+  msg_error_t res =
+      MSG_task_send_with_timeout_bounded(task, alias, static_cast<double>(jtimeout), static_cast<double>(maxrate));
   env->ReleaseStringUTFChars(jalias, alias);
 
-  if (rv != MSG_OK) {
-    jmsg_throw_status(env, rv);
-  }
+  if (res != MSG_OK)
+    jmsg_throw_status(env, res);
 }
 
-JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_receive(JNIEnv * env, jclass cls, jstring jalias, jdouble jtimeout,
-                                                            jobject jhost)
+JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_receive(JNIEnv* env, jclass cls, jstring jalias, jdouble jtimeout)
 {
   msg_task_t task = nullptr;
 
-  msg_host_t host = nullptr;
-  jobject jtask_global, jtask_local;
-
-  if (jhost) {
-    host = jhost_get_native(env, jhost);
-
-    if (!host) {
-      jxbt_throw_notbound(env, "host", jhost);
-      return nullptr;
-    }
-  }
-
   const char *alias = env->GetStringUTFChars(jalias, 0);
-  msg_error_t rv = MSG_task_receive_ext(&task, alias, (double) jtimeout, host);
+  msg_error_t rv    = MSG_task_receive_ext(&task, alias, (double)jtimeout, /*host*/ nullptr);
+  env->ReleaseStringUTFChars(jalias, alias);
   if (env->ExceptionOccurred())
     return nullptr;
   if (rv != MSG_OK) {
     jmsg_throw_status(env,rv);
     return nullptr;
   }
-  jtask_global = (jobject) MSG_task_get_data(task);
+  jobject jtask_global = (jobject) MSG_task_get_data(task);
 
   /* Convert the global ref into a local ref so that the JVM can free the stuff */
-  jtask_local = env->NewLocalRef(jtask_global);
+  jobject jtask_local = env->NewLocalRef(jtask_global);
+  env->DeleteGlobalRef(jtask_global);
+  MSG_task_set_data(task, nullptr);
+
+  return (jobject) jtask_local;
+}
+
+JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_irecv(JNIEnv * env, jclass cls, jstring jmailbox) {
+  jclass comm_class = env->FindClass("org/simgrid/msg/Comm");
+  if (not comm_class)
+    return nullptr;
+
+  //pointer to store the task object pointer.
+  msg_task_t *task = xbt_new(msg_task_t,1);
+  *task = nullptr;
+  /* There should be a cache here */
+
+  jobject jcomm = env->NewObject(comm_class, jtask_method_Comm_constructor);
+  if (not jcomm) {
+    jxbt_throw_jni(env, "Can't create a Comm object.");
+    return nullptr;
+  }
+
+  const char* mailbox = env->GetStringUTFChars(jmailbox, 0);
+  msg_comm_t comm     = MSG_task_irecv(task, mailbox);
+  env->ReleaseStringUTFChars(jmailbox, mailbox);
+
+  env->SetLongField(jcomm, jtask_field_Comm_bind, (jlong) (uintptr_t)(comm));
+  env->SetLongField(jcomm, jtask_field_Comm_taskBind, (jlong) (uintptr_t)(task));
+  env->SetBooleanField(jcomm, jtask_field_Comm_receiving, JNI_TRUE);
+
+  return jcomm;
+}
+
+JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_receiveBounded(JNIEnv* env, jclass cls, jstring jalias,
+                                                                   jdouble jtimeout, jdouble rate)
+{
+  msg_task_t task = nullptr;
+
+  const char *alias = env->GetStringUTFChars(jalias, 0);
+  msg_error_t res   = MSG_task_receive_ext_bounded(&task, alias, static_cast<double>(jtimeout), /*host*/ nullptr,
+                                                 static_cast<double>(rate));
+  if (env->ExceptionOccurred())
+    return nullptr;
+  if (res != MSG_OK) {
+    jmsg_throw_status(env, res);
+    return nullptr;
+  }
+  jobject jtask_global = (jobject)MSG_task_get_data(task);
+
+  /* Convert the global ref into a local ref so that the JVM can free the stuff */
+  jobject jtask_local = env->NewLocalRef(jtask_global);
   env->DeleteGlobalRef(jtask_global);
   MSG_task_set_data(task, nullptr);
 
@@ -398,136 +350,48 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_receive(JNIEnv * env, jclass
   return (jobject) jtask_local;
 }
 
-JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_irecv(JNIEnv * env, jclass cls, jstring jmailbox) {
-  msg_comm_t comm;
-  const char *mailbox;
-  jclass comm_class;
-  //pointer to store the task object pointer.
-  msg_task_t *task = xbt_new(msg_task_t,1);
-  *task = nullptr;
-  /* There should be a cache here */
-  comm_class = env->FindClass("org/simgrid/msg/Comm");
-
-  if (!comm_class) {
-    jxbt_throw_native(env,bprintf("fieldID or methodID or class not found."));
-    return nullptr;
-  }
-
-  jobject jcomm = env->NewObject(comm_class, jtask_method_Comm_constructor);
-  if (!jcomm) {
-    jxbt_throw_native(env,bprintf("Can't create a Comm object."));
-    return nullptr;
-  }
-
-  mailbox = env->GetStringUTFChars(jmailbox, 0);
-
-  comm = MSG_task_irecv(task,mailbox);
-
-  env->SetLongField(jcomm, jtask_field_Comm_bind, (jlong) (uintptr_t)(comm));
-  env->SetLongField(jcomm, jtask_field_Comm_taskBind, (jlong) (uintptr_t)(task));
-  env->SetBooleanField(jcomm, jtask_field_Comm_receiving, JNI_TRUE);
-
-  env->ReleaseStringUTFChars(jmailbox, mailbox);
-
-  return jcomm;
-}
-
-JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_receiveBounded(JNIEnv * env, jclass cls, jstring jalias,
-                                                                   jdouble jtimeout, jobject jhost, jdouble rate)
-{
-  msg_error_t rv;
-  msg_task_t *task = xbt_new(msg_task_t,1);
-  *task = nullptr;
-
-  msg_host_t host = nullptr;
-  jobject jtask_global, jtask_local;
-  const char *alias;
-
-  if (jhost) {
-    host = jhost_get_native(env, jhost);
-
-    if (!host) {
-      jxbt_throw_notbound(env, "host", jhost);
-      return nullptr;
-    }
-  }
-
-  alias = env->GetStringUTFChars(jalias, 0);
-  rv = MSG_task_receive_ext_bounded(task, alias, (double) jtimeout, host, (double) rate);
-  if (env->ExceptionOccurred())
-    return nullptr;
-  if (rv != MSG_OK) {
-    jmsg_throw_status(env,rv);
-    return nullptr;
-  }
-  jtask_global = (jobject) MSG_task_get_data(*task);
-
-  /* Convert the global ref into a local ref so that the JVM can free the stuff */
-  jtask_local = env->NewLocalRef(jtask_global);
-  env->DeleteGlobalRef(jtask_global);
-  MSG_task_set_data(*task, nullptr);
-
-  env->ReleaseStringUTFChars(jalias, alias);
-
-  xbt_free(task);
-
-  return (jobject) jtask_local;
-}
-
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_irecvBounded(JNIEnv * env, jclass cls, jstring jmailbox,
                                                                  jdouble rate)
 {
-  msg_comm_t comm;
-  const char *mailbox;
-  jclass comm_class;
-  //pointer to store the task object pointer.
-  msg_task_t *task = xbt_new(msg_task_t,1);
-  *task = nullptr;
-  /* There should be a cac hee */
-  comm_class = env->FindClass("org/simgrid/msg/Comm");
-
-  if (!comm_class) {
-    jxbt_throw_native(env,bprintf("fieldID or methodID or class not found."));
+  jclass comm_class = env->FindClass("org/simgrid/msg/Comm");
+  if (not comm_class)
     return nullptr;
-  }
+
+  // pointer to store the task object pointer.
+  msg_task_t* task = xbt_new0(msg_task_t, 1);
 
   jobject jcomm = env->NewObject(comm_class, jtask_method_Comm_constructor);
-  if (!jcomm) {
-    jxbt_throw_native(env,bprintf("Can't create a Comm object."));
+  if (not jcomm) {
+    jxbt_throw_jni(env, "Can't create a Comm object.");
     return nullptr;
   }
 
-  mailbox = env->GetStringUTFChars(jmailbox, 0);
-
-  comm = MSG_task_irecv_bounded(task,mailbox, (double) rate);
+  const char* mailbox = env->GetStringUTFChars(jmailbox, 0);
+  msg_comm_t comm     = MSG_task_irecv_bounded(task, mailbox, static_cast<double>(rate));
+  env->ReleaseStringUTFChars(jmailbox, mailbox);
 
   env->SetLongField(jcomm, jtask_field_Comm_bind, (jlong) (uintptr_t)(comm));
   env->SetLongField(jcomm, jtask_field_Comm_taskBind, (jlong) (uintptr_t)(task));
   env->SetBooleanField(jcomm, jtask_field_Comm_receiving, JNI_TRUE);
 
-  env->ReleaseStringUTFChars(jmailbox, mailbox);
-
   return jcomm;
 }
 
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_isend(JNIEnv *env, jobject jtask, jstring jmailbox)
 {
-  jclass comm_class;
-  msg_task_t task;
-  jobject jcomm;
   msg_comm_t comm;
-  const char *mailbox;
 
-  comm_class = env->FindClass("org/simgrid/msg/Comm");
+  jclass comm_class = env->FindClass("org/simgrid/msg/Comm");
 
-  if (!comm_class) return nullptr;
+  if (not comm_class)
+    return nullptr;
 
-  jcomm = env->NewObject(comm_class, jtask_method_Comm_constructor);
-  mailbox = env->GetStringUTFChars(jmailbox, 0);
+  jobject jcomm       = env->NewObject(comm_class, jtask_method_Comm_constructor);
+  const char* mailbox = env->GetStringUTFChars(jmailbox, 0);
 
-  task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     env->ReleaseStringUTFChars(jmailbox, mailbox);
     env->DeleteLocalRef(jcomm);
     jxbt_throw_notbound(env, "task", jtask);
@@ -549,22 +413,21 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_isend(JNIEnv *env, jobject j
 JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_isendBounded(JNIEnv *env, jobject jtask, jstring jmailbox,
                                                                  jdouble maxrate)
 {
-  jclass comm_class;
   msg_task_t task;
   jobject jcomm;
   msg_comm_t comm;
   const char *mailbox;
 
-  comm_class = env->FindClass("org/simgrid/msg/Comm");
-
-  if (!comm_class) return nullptr;
+  jclass comm_class = env->FindClass("org/simgrid/msg/Comm");
+  if (not comm_class)
+    return nullptr;
 
   jcomm = env->NewObject(comm_class, jtask_method_Comm_constructor);
   mailbox = env->GetStringUTFChars(jmailbox, 0);
 
-  task = jtask_to_native_task(jtask, env);
+  task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     env->ReleaseStringUTFChars(jmailbox, mailbox);
     env->DeleteLocalRef(jcomm);
     jxbt_throw_notbound(env, "task", jtask);
@@ -585,11 +448,11 @@ JNIEXPORT jobject JNICALL Java_org_simgrid_msg_Task_isendBounded(JNIEnv *env, jo
 
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_nativeFinalize(JNIEnv * env, jobject jtask)
 {
-    msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-    if (!task) {
-      jxbt_throw_notbound(env, "task", jtask);
-      return;
+  if (not task) {
+    jxbt_throw_notbound(env, "task", jtask);
+    return;
     }
 
     MSG_task_destroy(task);
@@ -610,9 +473,9 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_dsend(JNIEnv * env, jobject jta
 {
   const char *alias = env->GetStringUTFChars(jalias, 0);
 
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     env->ReleaseStringUTFChars(jalias, alias);
     jxbt_throw_notbound(env, "task", jtask);
     return;
@@ -630,9 +493,9 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_dsendBounded(JNIEnv * env, jobj
 {
   const char *alias = env->GetStringUTFChars(jalias, 0);
 
-  msg_task_t task = jtask_to_native_task(jtask, env);
+  msg_task_t task = jtask_to_native(jtask, env);
 
-  if (!task) {
+  if (not task) {
     env->ReleaseStringUTFChars(jalias, alias);
     jxbt_throw_notbound(env, "task", jtask);
     return;
@@ -640,18 +503,15 @@ JNIEXPORT void JNICALL Java_org_simgrid_msg_Task_dsendBounded(JNIEnv * env, jobj
 
   /* Pass a global ref to the Jtask into the Ctask so that the receiver can use it */
   MSG_task_set_data(task, (void *) env->NewGlobalRef(jtask));
-  MSG_task_dsend_bounded(task, alias, msg_task_cancel_on_failed_dsend,(double)maxrate);
+  MSG_task_dsend_bounded(task, alias, msg_task_cancel_on_failed_dsend,static_cast<double>(maxrate));
 
   env->ReleaseStringUTFChars(jalias, alias);
 }
 
 JNIEXPORT jboolean JNICALL Java_org_simgrid_msg_Task_listen(JNIEnv * env, jclass cls, jstring jalias)
 {
-  const char *alias;
-  int rv;
-
-  alias = env->GetStringUTFChars(jalias, 0);
-  rv = MSG_task_listen(alias);
+  const char *alias = env->GetStringUTFChars(jalias, 0);
+  int rv = MSG_task_listen(alias);
   env->ReleaseStringUTFChars(jalias, alias);
 
   return (jboolean) rv;
@@ -659,10 +519,11 @@ JNIEXPORT jboolean JNICALL Java_org_simgrid_msg_Task_listen(JNIEnv * env, jclass
 
 JNIEXPORT jint JNICALL Java_org_simgrid_msg_Task_listenFrom(JNIEnv * env, jclass cls, jstring jalias)
 {
-  int rv;
   const char *alias = env->GetStringUTFChars(jalias, 0);
-  rv = MSG_task_listen_from(alias);
+  int rv = MSG_task_listen_from(alias);
   env->ReleaseStringUTFChars(jalias, alias);
 
   return (jint) rv;
 }
+
+SG_END_DECL()
