@@ -1,25 +1,23 @@
 /* Various JNI helper functions                                             */
 
-/* Copyright (c) 2007-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <stdlib.h>             /* abort */
-#include "xbt/misc.h"
 #include "xbt/sysdep.h"
-#include "xbt/str.h"
 #include "jxbt_utilities.h"
 
+#include <stdlib.h> /* abort */
+
+SG_BEGIN_DECL()
+
 jclass jxbt_get_class(JNIEnv * env, const char *name)
 {
   jclass cls = env->FindClass(name);
 
-  if (!cls) {
-    char *m = bprintf("Class %s not found", name);
-    jxbt_throw_jni(env, m);
-    free(m);
+  if (not cls) {
+    jxbt_throw_jni(env, std::string("Class ") + name + " not found");
     return nullptr;
   }
 
@@ -30,23 +28,19 @@ jmethodID jxbt_get_jmethod(JNIEnv * env, jclass cls, const char *name, const cha
 {
   jmethodID id;
 
-  if (!cls)
+  if (not cls)
     return 0;
   id = env->GetMethodID(cls, name, signature);
 
-  if (!id) {
+  if (not id) {
 
     jmethodID tostr_id = env->GetMethodID(cls, "getName", "()Ljava/lang/String;");
     jstring jclassname = (jstring) env->CallObjectMethod(cls, tostr_id, nullptr);
     const char *classname = env->GetStringUTFChars(jclassname, 0);
 
-    char *m = bprintf("Cannot find method %s(%s) in %s", name, signature, classname);
-
     env->ReleaseStringUTFChars(jclassname, classname);
 
-    jxbt_throw_jni(env, m);
-
-    free(m);
+    jxbt_throw_jni(env, std::string("Cannot find method") + name + "(" + signature + ") in " + classname);
     return 0;
   }
 
@@ -57,22 +51,18 @@ jmethodID jxbt_get_static_jmethod(JNIEnv * env, jclass cls, const char *name, co
 {
   jmethodID id;
 
-  if (!cls)
+  if (not cls)
     return 0;
   id = env->GetStaticMethodID(cls, name, signature);
 
-  if (!id) {
+  if (not id) {
     jmethodID tostr_id = env->GetMethodID(cls, "getName", "()Ljava/lang/String;");
     jstring jclassname = (jstring) env->CallObjectMethod(cls, tostr_id, nullptr);
     const char *classname = env->GetStringUTFChars(jclassname, 0);
 
-    char *m = bprintf("Cannot find static method %s(%s) in %s", name, signature, classname);
-
     env->ReleaseStringUTFChars(jclassname, classname);
 
-    jxbt_throw_jni(env, m);
-
-    free(m);
+    jxbt_throw_jni(env, std::string("Cannot find static method") + name + "(" + signature + ") in " + classname);
     return 0;
   }
 
@@ -85,17 +75,13 @@ jmethodID jxbt_get_static_smethod(JNIEnv * env, const char *classname, const cha
   jmethodID id;
   cls = jxbt_get_class(env, classname);
 
-  if (!cls)
+  if (not cls)
     return 0;
 
   id = env->GetStaticMethodID(cls, name, signature);
 
-  if (!id) {
-    char *m = bprintf("Cannot find static method %s(%s) in %s", name, signature, classname);
-
-    jxbt_throw_jni(env, m);
-
-    free(m);
+  if (not id) {
+    jxbt_throw_jni(env, std::string("Cannot find static method") + name + "(" + signature + ") in " + classname);
     return 0;
   }
   return id;
@@ -107,17 +93,13 @@ jmethodID jxbt_get_smethod(JNIEnv * env, const char *classname, const char *name
   jmethodID id;
   cls = jxbt_get_class(env, classname);
 
-  if (!cls)
+  if (not cls)
     return 0;
 
   id = env->GetMethodID(cls, name, signature);
 
-  if (!id) {
-    char *m = bprintf("Cannot find method %s(%s) in %s", name, signature, classname);
-
-    jxbt_throw_jni(env, m);
-
-    free(m);
+  if (not id) {
+    jxbt_throw_jni(env, std::string("Cannot find method") + name + "(" + signature + ") in " + classname);
     return 0;
   }
   return id;
@@ -127,22 +109,20 @@ jfieldID jxbt_get_jfield(JNIEnv * env, jclass cls, const char *name, const char
 {
   jfieldID id;
 
-  if (!cls)
+  if (not cls)
     return 0;
 
   id = env->GetFieldID(cls, name, signature);
 
-  if (!id) {
+  if (not id) {
     jmethodID getname_id = env->GetMethodID(cls, "getName", "()Ljava/lang/String;");
     jstring jclassname = (jstring) env->CallObjectMethod(cls, getname_id, nullptr);
     const char *classname = env->GetStringUTFChars(jclassname, 0);
-    char *m = bprintf("Cannot find field %s %s in %s", signature, name, classname);
 
     env->ReleaseStringUTFChars(jclassname, classname);
 
-    jxbt_throw_jni(env, m);
+    jxbt_throw_jni(env, std::string("Cannot find field") + signature + " " + name + " in " + classname);
 
-    free(m);
     return 0;
   }
 
@@ -154,90 +134,82 @@ jfieldID jxbt_get_sfield(JNIEnv * env, const char *classname, const char *name,
   jclass cls = jxbt_get_class(env, classname);
   jfieldID id;
 
-  if (!cls)
+  if (not cls)
     return 0;
 
   id = env->GetFieldID(cls, name, signature);
 
-  if (!id) {
-    char *m = bprintf("Cannot find field %s %s in %s", signature, name, classname);
-
-    jxbt_throw_jni(env, m);
-
-    free(m);
+  if (not id) {
+    jxbt_throw_jni(env, std::string("Cannot find field") + signature + " " + name + " in " + classname);
     return 0;
   }
 
   return id;
 }
 
-void jxbt_throw_by_name(JNIEnv * env, const char *name, char *msg)
+void jxbt_throw_by_name(JNIEnv* env, const char* name, std::string msg)
 {
   jclass cls = env->FindClass(name);
 
-  xbt_assert(cls, "%s (Plus severe error: class %s not found)\n", msg, name);
+  xbt_assert(cls, "%s (Plus severe error: class %s not found)\n", msg.c_str(), name);
 
-  env->ThrowNew(cls, msg);
-
-  free(msg);
+  env->ThrowNew(cls, msg.c_str());
 }
 
-void jxbt_throw_jni(JNIEnv * env, const char *msg)
+void jxbt_throw_jni(JNIEnv* env, std::string msg)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/JniException", bprintf("Internal or JNI error: %s", msg));
+  jxbt_throw_by_name(env, "org/simgrid/msg/JniException", "Internal or JNI error: " + msg);
 }
 
-void jxbt_throw_notbound(JNIEnv * env, const char *kind, void *pointer)
+void jxbt_throw_notbound(JNIEnv* env, std::string kind, void* pointer)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/JniException", bprintf("Internal error: %s %p not bound", kind, pointer));
+  jxbt_throw_by_name(env, "org/simgrid/msg/JniException",
+                     "Internal error: " + kind + " " + static_cast<const char*>(pointer) + " not bound");
 }
 
-void jxbt_throw_native(JNIEnv * env, char *msg)
-{
-  jxbt_throw_by_name(env, "org/simgrid/msg/NativeException", msg);
-}
-
-void jxbt_throw_null(JNIEnv * env, char *msg)
+void jxbt_throw_null(JNIEnv* env, std::string msg)
 {
   jxbt_throw_by_name(env, "java/lang/NullPointerException", msg);
 }
 
-void jxbt_throw_illegal(JNIEnv * env, char *msg)
+void jxbt_throw_illegal(JNIEnv* env, std::string msg)
 {
   jxbt_throw_by_name(env, "java/lang/IllegalArgumentException", msg);
 }
 
-void jxbt_throw_host_not_found(JNIEnv * env, const char *invalid_name)
+void jxbt_throw_host_not_found(JNIEnv* env, std::string invalid_name)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/HostNotFoundException", bprintf("No such host: %s", invalid_name));
+  jxbt_throw_by_name(env, "org/simgrid/msg/HostNotFoundException", "No such host: " + invalid_name);
 }
 
-void jxbt_throw_storage_not_found(JNIEnv * env, const char *invalid_name)
+void jxbt_throw_storage_not_found(JNIEnv* env, std::string invalid_name)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/StorageNotFoundException", bprintf("No such storage: %s", invalid_name));
+  jxbt_throw_by_name(env, "org/simgrid/msg/StorageNotFoundException", "No such storage: " + invalid_name);
 }
 
-void jxbt_throw_process_not_found(JNIEnv * env, const char *invalid_name)
+void jxbt_throw_process_not_found(JNIEnv* env, std::string invalid_name)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/ProcessNotFoundException", bprintf("No such process: %s", invalid_name));
+  jxbt_throw_by_name(env, "org/simgrid/msg/ProcessNotFoundException", "No such process: " + invalid_name);
 }
 
-void jxbt_throw_transfer_failure(JNIEnv * env, char *details)
+void jxbt_throw_transfer_failure(JNIEnv* env, std::string details)
 {
   jxbt_throw_by_name(env, "org/simgrid/msg/TransferFailureException", details);
 }
 
-void jxbt_throw_host_failure(JNIEnv * env, char *details)
+void jxbt_throw_host_failure(JNIEnv* env, std::string details)
 {
-  jxbt_throw_by_name(env, "org/simgrid/msg/HostFailureException", bprintf("Host Failure %s", details));
+  jxbt_throw_by_name(env, "org/simgrid/msg/HostFailureException", "Host Failure " + details);
 }
 
-void jxbt_throw_time_out_failure(JNIEnv * env, char *details)
+void jxbt_throw_time_out_failure(JNIEnv* env, std::string details)
 {
   jxbt_throw_by_name(env, "org/simgrid/msg/TimeoutException", details);
 }
 
-void jxbt_throw_task_cancelled(JNIEnv * env, char *details)
+void jxbt_throw_task_cancelled(JNIEnv* env, std::string details)
 {
   jxbt_throw_by_name(env, "org/simgrid/msg/TaskCancelledException", details);
 }
+
+SG_END_DECL()
