@@ -7,10 +7,9 @@
 /* SimGrid Lua bindings                                                     */
 
 #include "lua_private.h"
-#include "src/kernel/routing/NetCard.hpp"
+#include "src/kernel/routing/NetPoint.hpp"
 #include "src/surf/network_interface.hpp"
 #include "src/surf/xml/platf_private.hpp"
-#include "surf/surf_routing.h"
 #include <ctype.h>
 #include <string.h>
 
@@ -18,8 +17,12 @@ extern "C" {
 #include <lauxlib.h>
 }
 
-#include <simgrid/host.h>
 #include "src/surf/surf_private.h"
+#include <boost/algorithm/string/classification.hpp>
+#include <boost/algorithm/string/split.hpp>
+#include <simgrid/host.h>
+#include <string>
+#include <vector>
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(lua_platf, "Lua bindings (platform module)");
 
@@ -61,16 +64,14 @@ int console_close(lua_State *L) {
 }
 
 int console_add_backbone(lua_State *L) {
-  s_sg_platf_link_cbarg_t link;
-  memset(&link,0,sizeof(link));
-  int type;
+  LinkCreationArgs link;
 
   link.properties = nullptr;
 
   lua_ensure(lua_istable(L, -1),"Bad Arguments to create backbone in Lua. Should be a table with named arguments.");
 
   lua_pushstring(L, "id");
-  type = lua_gettable(L, -2);
+  int type = lua_gettable(L, -2);
   lua_ensure(type == LUA_TSTRING, "Attribute 'id' must be specified for backbone and must be a string.");
   link.id = lua_tostring(L, -1);
   lua_pop(L, 1);
@@ -79,29 +80,29 @@ int console_add_backbone(lua_State *L) {
   type = lua_gettable(L, -2);
   lua_ensure(type == LUA_TSTRING || type == LUA_TNUMBER,
       "Attribute 'bandwidth' must be specified for backbone and must either be a string (in the right format; see docs) or a number.");
-  link.bandwidth = surf_parse_get_bandwidth(lua_tostring(L, -1),"bandwidth of backbone",link.id);
+  link.bandwidth = surf_parse_get_bandwidth(lua_tostring(L, -1), "bandwidth of backbone", link.id.c_str());
   lua_pop(L, 1);
 
   lua_pushstring(L, "lat");
   type = lua_gettable(L, -2);
   lua_ensure(type == LUA_TSTRING || type == LUA_TNUMBER,
       "Attribute 'lat' must be specified for backbone and must either be a string (in the right format; see docs) or a number.");
-  link.latency = surf_parse_get_time(lua_tostring(L, -1),"latency of backbone",link.id);
+  link.latency = surf_parse_get_time(lua_tostring(L, -1), "latency of backbone", link.id.c_str());
   lua_pop(L, 1);
 
   lua_pushstring(L, "sharing_policy");
   type = lua_gettable(L, -2);
   const char* policy = lua_tostring(L, -1);
-  if (policy && !strcmp(policy,"FULLDUPLEX")) {
+  if (policy && not strcmp(policy, "FULLDUPLEX")) {
     link.policy = SURF_LINK_FULLDUPLEX;
-  } else if (policy && !strcmp(policy,"FATPIPE")) {
+  } else if (policy && not strcmp(policy, "FATPIPE")) {
     link.policy = SURF_LINK_FATPIPE;
   } else {
     link.policy = SURF_LINK_SHARED;
   }
 
   sg_platf_new_link(&link);
-  routing_cluster_add_backbone(sg_link_by_name(link.id));
+  routing_cluster_add_backbone(simgrid::surf::LinkImpl::byName(link.id.c_str()));
 
   return 0;
 }
@@ -171,8 +172,8 @@ int console_add_host(lua_State *L) {
   // get core
   lua_pushstring(L, "core");
   lua_gettable(L, -2);
-  if(!lua_isnumber(L,-1))
-      host.core_amount = 1;// Default value
+  if (not lua_isnumber(L, -1))
+    host.core_amount = 1; // Default value
   else
     host.core_amount = lua_tonumber(L, -1);
   if (host.core_amount == 0)
@@ -201,17 +202,15 @@ int console_add_host(lua_State *L) {
 }
 
 int  console_add_link(lua_State *L) {
-  s_sg_platf_link_cbarg_t link;
-  memset(&link,0,sizeof(link));
+  LinkCreationArgs link;
 
-  int type;
   const char* policy;
 
   lua_ensure(lua_istable(L, -1), "Bad Arguments to create link, Should be a table with named arguments");
 
   // get Id Value
   lua_pushstring(L, "id");
-  type = lua_gettable(L, -2);
+  int type = lua_gettable(L, -2);
   lua_ensure(type == LUA_TSTRING || type == LUA_TNUMBER,
       "Attribute 'id' must be specified for any link and must be a string.");
   link.id = lua_tostring(L, -1);
@@ -225,7 +224,7 @@ int  console_add_link(lua_State *L) {
   if (type == LUA_TNUMBER)
     link.bandwidth = lua_tonumber(L, -1);
   else // LUA_TSTRING
-    link.bandwidth = surf_parse_get_bandwidth(lua_tostring(L, -1),"bandwidth of link", link.id);
+    link.bandwidth = surf_parse_get_bandwidth(lua_tostring(L, -1), "bandwidth of link", link.id.c_str());
   lua_pop(L, 1);
 
   //get latency value
@@ -236,7 +235,7 @@ int  console_add_link(lua_State *L) {
   if (type == LUA_TNUMBER)
     link.latency = lua_tonumber(L, -1);
   else // LUA_TSTRING
-    link.latency = surf_parse_get_time(lua_tostring(L, -1),"latency of link", link.id);
+    link.latency = surf_parse_get_time(lua_tostring(L, -1), "latency of link", link.id.c_str());
   lua_pop(L, 1);
 
   /*Optional Arguments  */
@@ -270,9 +269,9 @@ int  console_add_link(lua_State *L) {
   lua_gettable(L, -2);
   policy = lua_tostring(L, -1);
   lua_pop(L, 1);
-  if (policy && !strcmp(policy,"FULLDUPLEX")) {
+  if (policy && not strcmp(policy, "FULLDUPLEX")) {
     link.policy = SURF_LINK_FULLDUPLEX;
-  } else if (policy && !strcmp(policy,"FATPIPE")) {
+  } else if (policy && not strcmp(policy, "FATPIPE")) {
     link.policy = SURF_LINK_FATPIPE;
   } else {
     link.policy = SURF_LINK_SHARED;
@@ -286,25 +285,21 @@ int  console_add_link(lua_State *L) {
  * add Router to AS components
  */
 int console_add_router(lua_State* L) {
-  s_sg_platf_router_cbarg_t router;
-  memset(&router,0,sizeof(router));
-  int type;
-
   lua_ensure(lua_istable(L, -1),
       "Bad Arguments to create router, Should be a table with named arguments");
 
   lua_pushstring(L, "id");
-  type = lua_gettable(L, -2);
+  int type = lua_gettable(L, -2);
   lua_ensure(type == LUA_TSTRING, "Attribute 'id' must be specified for any link and must be a string.");
-  router.id = lua_tostring(L, -1);
+  const char* name = lua_tostring(L, -1);
   lua_pop(L,1);
 
   lua_pushstring(L,"coord");
   lua_gettable(L,-2);
-  router.coord = lua_tostring(L, -1);
+  const char* coords = lua_tostring(L, -1);
   lua_pop(L,1);
 
-  sg_platf_new_router(&router);
+  sg_platf_new_router(name, coords);
 
   return 0;
 }
@@ -315,16 +310,13 @@ int console_add_route(lua_State *L) {
   memset(&route,0,sizeof(route));
   int type;
 
-  /* allocating memory for the buffer, I think 2kB should be enough */
-  surfxml_bufferstack = xbt_new0(char, surfxml_bufferstack_size);
-
   lua_ensure(lua_istable(L, -1), "Bad Arguments to add a route. Should be a table with named arguments");
 
   lua_pushstring(L,"src");
   type = lua_gettable(L,-2);
   lua_ensure(type == LUA_TSTRING, "Attribute 'src' must be specified for any route and must be a string.");
   const char *srcName = lua_tostring(L, -1);
-  route.src = sg_netcard_by_name_or_null(srcName);
+  route.src           = sg_netpoint_by_name_or_null(srcName);
   lua_ensure(route.src != nullptr, "Attribute 'src=%s' of route does not name a node.", srcName);
   lua_pop(L,1);
 
@@ -332,7 +324,7 @@ int console_add_route(lua_State *L) {
   type = lua_gettable(L,-2);
   lua_ensure(type == LUA_TSTRING, "Attribute 'dest' must be specified for any route and must be a string.");
   const char *dstName = lua_tostring(L, -1);
-  route.dst = sg_netcard_by_name_or_null(dstName);
+  route.dst           = sg_netpoint_by_name_or_null(dstName);
   lua_ensure(route.dst != nullptr, "Attribute 'dst=%s' of route does not name a node.", dstName);
   lua_pop(L,1);
 
@@ -340,18 +332,18 @@ int console_add_route(lua_State *L) {
   type = lua_gettable(L,-2);
   lua_ensure(type == LUA_TSTRING,
       "Attribute 'links' must be specified for any route and must be a string (different links separated by commas or single spaces.");
-  route.link_list = new std::vector<Link*>();
-  xbt_dynar_t names = xbt_str_split(lua_tostring(L, -1), ", \t\r\n");
-  if (xbt_dynar_is_empty(names)) {
+  route.link_list   = new std::vector<simgrid::surf::LinkImpl*>();
+  std::vector<std::string> names;
+  const char* str = lua_tostring(L, -1);
+  boost::split(names, str, boost::is_any_of(", \t\r\n"));
+  if (names.empty()) {
     /* unique name */
-    route.link_list->push_back(Link::byName(lua_tostring(L, -1)));
+    route.link_list->push_back(simgrid::surf::LinkImpl::byName(lua_tostring(L, -1)));
   } else {
     // Several names separated by , \t\r\n
-    unsigned int cpt;
-    char *name;
-    xbt_dynar_foreach(names, cpt, name) {
-      if (strlen(name)>0) {
-        Link *link = Link::byName(name);
+    for (auto name : names) {
+      if (name.length() > 0) {
+        simgrid::surf::LinkImpl* link = simgrid::surf::LinkImpl::byName(name.c_str());
         route.link_list->push_back(link);
       }
     }
@@ -382,6 +374,7 @@ int console_add_route(lua_State *L) {
   route.gw_dst = nullptr;
 
   sg_platf_new_route(&route);
+  delete route.link_list;
 
   return 0;
 }
@@ -393,45 +386,45 @@ int console_add_ASroute(lua_State *L) {
   lua_pushstring(L, "src");
   lua_gettable(L, -2);
   const char *srcName = lua_tostring(L, -1);
-  ASroute.src = sg_netcard_by_name_or_null(srcName);
+  ASroute.src         = sg_netpoint_by_name_or_null(srcName);
   lua_ensure(ASroute.src != nullptr, "Attribute 'src=%s' of AS route does not name a node.", srcName);
   lua_pop(L, 1);
 
   lua_pushstring(L, "dst");
   lua_gettable(L, -2);
   const char *dstName = lua_tostring(L, -1);
-  ASroute.dst = sg_netcard_by_name_or_null(dstName);
+  ASroute.dst         = sg_netpoint_by_name_or_null(dstName);
   lua_ensure(ASroute.dst != nullptr, "Attribute 'dst=%s' of AS route does not name a node.", dstName);
   lua_pop(L, 1);
 
   lua_pushstring(L, "gw_src");
   lua_gettable(L, -2);
   const char *name = lua_tostring(L, -1);
-  ASroute.gw_src = sg_netcard_by_name_or_null(name);
+  ASroute.gw_src   = sg_netpoint_by_name_or_null(name);
   lua_ensure(ASroute.gw_src, "Attribute 'gw_src=%s' of AS route does not name a valid node", name);
   lua_pop(L, 1);
 
   lua_pushstring(L, "gw_dst");
   lua_gettable(L, -2);
   name = lua_tostring(L, -1);
-  ASroute.gw_dst = sg_netcard_by_name_or_null(name);
+  ASroute.gw_dst = sg_netpoint_by_name_or_null(name);
   lua_ensure(ASroute.gw_dst, "Attribute 'gw_dst=%s' of AS route does not name a valid node", name);
   lua_pop(L, 1);
 
   lua_pushstring(L,"links");
   lua_gettable(L,-2);
-  ASroute.link_list = new std::vector<Link*>();
-  xbt_dynar_t names = xbt_str_split(lua_tostring(L, -1), ", \t\r\n");
-  if (xbt_dynar_is_empty(names)) {
+  ASroute.link_list = new std::vector<simgrid::surf::LinkImpl*>();
+  std::vector<std::string> names;
+  const char* str = lua_tostring(L, -1);
+  boost::split(names, str, boost::is_any_of(", \t\r\n"));
+  if (names.empty()) {
     /* unique name with no comma */
-    ASroute.link_list->push_back(Link::byName(lua_tostring(L, -1)));
+    ASroute.link_list->push_back(simgrid::surf::LinkImpl::byName(lua_tostring(L, -1)));
   } else {
     // Several names separated by , \t\r\n
-    unsigned int cpt;
-    char *name;
-    xbt_dynar_foreach(names, cpt, name) {
-      if (strlen(name)>0) {
-        Link *link = Link::byName(name);
+    for (auto name : names) {
+      if (name.length() > 0) {
+        simgrid::surf::LinkImpl* link = simgrid::surf::LinkImpl::byName(name.c_str());
         ASroute.link_list->push_back(link);
       }
     }
@@ -453,6 +446,7 @@ int console_add_ASroute(lua_State *L) {
   lua_pop(L,1);
 
   sg_platf_new_route(&ASroute);
+  delete ASroute.link_list;
 
   return 0;
 }
@@ -478,13 +472,20 @@ int console_AS_open(lua_State *L) {
  lua_pop(L, 1);
 
  int mode_int = A_surfxml_AS_routing_None;
- if(!strcmp(mode,"Full")) mode_int = A_surfxml_AS_routing_Full;
- else if(!strcmp(mode,"Floyd")) mode_int = A_surfxml_AS_routing_Floyd;
- else if(!strcmp(mode,"Dijkstra")) mode_int = A_surfxml_AS_routing_Dijkstra;
- else if(!strcmp(mode,"DijkstraCache")) mode_int = A_surfxml_AS_routing_DijkstraCache;
- else if(!strcmp(mode,"Vivaldi")) mode_int = A_surfxml_AS_routing_Vivaldi;
- else if(!strcmp(mode,"Cluster")) mode_int = A_surfxml_AS_routing_Cluster;
- else if(!strcmp(mode,"none")) mode_int = A_surfxml_AS_routing_None;
+ if (not strcmp(mode, "Full"))
+   mode_int = A_surfxml_AS_routing_Full;
+ else if (not strcmp(mode, "Floyd"))
+   mode_int = A_surfxml_AS_routing_Floyd;
+ else if (not strcmp(mode, "Dijkstra"))
+   mode_int = A_surfxml_AS_routing_Dijkstra;
+ else if (not strcmp(mode, "DijkstraCache"))
+   mode_int = A_surfxml_AS_routing_DijkstraCache;
+ else if (not strcmp(mode, "Vivaldi"))
+   mode_int = A_surfxml_AS_routing_Vivaldi;
+ else if (not strcmp(mode, "Cluster"))
+   mode_int = A_surfxml_AS_routing_Cluster;
+ else if (not strcmp(mode, "none"))
+   mode_int = A_surfxml_AS_routing_None;
  else xbt_die("Don't have the model name '%s'",mode);
 
  s_sg_platf_AS_cbarg_t AS;
