@@ -1,9 +1,11 @@
-/* Copyright (c) 2012-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#ifndef SIMGRID_INSTR_INTERFACE_H
+#define SIMGRID_INSTR_INTERFACE_H
+
 #include "xbt.h"
 
 SG_BEGIN_DECL()
@@ -14,7 +16,7 @@ XBT_PUBLIC(void) TRACE_global_init(int *argc, char **argv);
 XBT_PUBLIC(void) TRACE_help(int detailed);
 XBT_PUBLIC(void) TRACE_surf_resource_utilization_alloc();
 XBT_PUBLIC(void) TRACE_surf_resource_utilization_release();
-XBT_PUBLIC(void) TRACE_add_start_function(void (*func)(void));
-XBT_PUBLIC(void) TRACE_add_end_function(void (*func)(void));
 
 SG_END_DECL()
+
+#endif
