@@ -1,9 +1,11 @@
-/* Copyright (c) 2012-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#ifndef SIMGRID_CONFIG_H
+#define SIMGRID_CONFIG_H
+
 #include "xbt/config.h"
 
 /** Config Globals */
@@ -17,3 +19,5 @@ XBT_PUBLIC(void) sg_config_init(int *argc, char **argv);
 XBT_PUBLIC(void) sg_config_finalize();
 
 SG_END_DECL()
+
+#endif
\ No newline at end of file
