@@ -1,5 +1,4 @@
-/* Copyright (c) 2009-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2009-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,13 +6,10 @@
 #ifndef MAXMIN_DATATYPES_H
 #define MAXMIN_DATATYPES_H
 
-typedef struct surf_storage *surf_storage_t;
-typedef struct surf_stat *surf_stat_t;
-
 typedef struct lmm_element *lmm_element_t;
 typedef struct lmm_variable *lmm_variable_t;
 typedef struct lmm_constraint *lmm_constraint_t;
 typedef struct lmm_constraint_light *lmm_constraint_light_t;
 typedef struct lmm_system *lmm_system_t;
 
-#endif                          /* MAXMIN_DATATYPES_H */
+#endif
