@@ -1,18 +1,12 @@
-/* Copyright (c) 2010, 2012-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/s4u/engine.hpp"
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/Host.hpp"
 
-#include <xbt/dict.h>
-#include <xbt/lib.h>
-#include <xbt/log.h>
-
-#include <surf/surf.h>
-#include <surf/surf_routing.h>
+#include "surf/surf.h"
 
 #include "src/instr/instr_private.h"
 
@@ -68,19 +62,19 @@ container_t PJ_container_new (const char *name, e_container_types kind, containe
   //Search for network_element_t
   switch (kind){
     case INSTR_HOST:
-      newContainer->netcard = sg_host->pimpl_netcard;
-      xbt_assert(newContainer->netcard, "Element '%s' not found",name);
+      newContainer->netpoint = sg_host->pimpl_netpoint;
+      xbt_assert(newContainer->netpoint, "Element '%s' not found", name);
       break;
     case INSTR_ROUTER:
-      newContainer->netcard = simgrid::s4u::Engine::instance()->netcardByNameOrNull(name);
-      xbt_assert(newContainer->netcard, "Element '%s' not found",name);
+      newContainer->netpoint = simgrid::s4u::Engine::instance()->netpointByNameOrNull(name);
+      xbt_assert(newContainer->netpoint, "Element '%s' not found", name);
       break;
     case INSTR_AS:
-      newContainer->netcard = simgrid::s4u::Engine::instance()->netcardByNameOrNull(name);
-      xbt_assert(newContainer->netcard, "Element '%s' not found",name);
+      newContainer->netpoint = simgrid::s4u::Engine::instance()->netpointByNameOrNull(name);
+      xbt_assert(newContainer->netpoint, "Element '%s' not found", name);
       break;
     default:
-      newContainer->netcard = nullptr;
+      newContainer->netpoint = nullptr;
       break;
   }
 
@@ -144,7 +138,7 @@ container_t PJ_container_new (const char *name, e_container_types kind, containe
   newContainer->children = xbt_dict_new_homogeneous(nullptr);
   if (newContainer->father){
     xbt_dict_set(newContainer->father->children, newContainer->name, newContainer, nullptr);
-    new_pajeCreateContainer (newContainer);
+    LogContainerCreation(newContainer);
   }
 
   //register all kinds by name
@@ -209,10 +203,10 @@ void PJ_container_free (container_t container)
   TRACE_paje_dump_buffer(1);
 
   //trace my destruction
-  if (!TRACE_disable_destroy() && container != PJ_container_get_root()){
+  if (not TRACE_disable_destroy() && container != PJ_container_get_root()) {
     //do not trace the container destruction if user requests
     //or if the container is root
-    new_pajeDestroyContainer(container);
+    LogContainerDestruction(container);
   }
 
   //remove it from allContainers data structure
@@ -251,7 +245,7 @@ void PJ_container_free_all ()
   rootContainer = nullptr;
 
   //checks
-  if (!xbt_dict_is_empty(allContainers)){
+  if (not xbt_dict_is_empty(allContainers)) {
     THROWF(tracing_error, 0, "some containers still present even after destroying all of them");
   }
 }
