@@ -130,7 +130,7 @@ type_t PJ_type_container_new (const char *name, type_t father)
 
   if(father){
     XBT_DEBUG("ContainerType %s(%s), child of %s(%s)", ret->name, ret->id, father->name, father->id);
-    new_pajeDefineContainerType (ret);
+    DefineContainerEvent(ret);
   }
   return ret;
 }
@@ -143,7 +143,7 @@ type_t PJ_type_event_new (const char *name, type_t father)
 
   type_t ret = newType (name, name, nullptr, TYPE_EVENT, father);
   XBT_DEBUG("EventType %s(%s), child of %s(%s)", ret->name, ret->id, father->name, father->id);
-  new_pajeDefineEventType(ret);
+  LogDefineEventType(ret);
   return ret;
 }
 
@@ -156,13 +156,13 @@ type_t PJ_type_variable_new (const char *name, const char *color, type_t father)
   type_t ret = nullptr;
 
   char white[INSTR_DEFAULT_STR_SIZE] = "1 1 1";
-  if (!color){
+  if (not color) {
     ret = newType (name, name, white, TYPE_VARIABLE, father);
   }else{
     ret = newType (name, name, color, TYPE_VARIABLE, father);
   }
   XBT_DEBUG("VariableType %s(%s), child of %s(%s)", ret->name, ret->id, father->name, father->id);
-  new_pajeDefineVariableType (ret);
+  LogVariableTypeDefinition (ret);
   return ret;
 }
 
@@ -179,7 +179,7 @@ type_t PJ_type_link_new (const char *name, type_t father, type_t source, type_t
   ret = newType (name, key, nullptr, TYPE_LINK, father);
   XBT_DEBUG("LinkType %s(%s), child of %s(%s)  %s(%s)->%s(%s)", ret->name, ret->id, father->name, father->id,
             source->name, source->id, dest->name, dest->id);
-  new_pajeDefineLinkType(ret, source, dest);
+  LogLinkTypeDefinition(ret, source, dest);
   return ret;
 }
 
@@ -193,6 +193,6 @@ type_t PJ_type_state_new (const char *name, type_t father)
 
   ret = newType (name, name, nullptr, TYPE_STATE, father);
   XBT_DEBUG("StateType %s(%s), child of %s(%s)", ret->name, ret->id, father->name, father->id);
-  new_pajeDefineStateType(ret);
+  LogStateTypeDefinition(ret);
   return ret;
 }
