@@ -1,20 +1,15 @@
-/* Copyright (c) 2010-2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "xbt/asserts.h"
-#include "simgrid/jedule/jedule_sd_binding.h"
-
-#include "simgrid/forward.h"
-
-#include "../../simdag/simdag_private.hpp"
 #include "simgrid/jedule/jedule.hpp"
-#include "simgrid/s4u/NetZone.hpp"
-#include "simgrid/s4u/engine.hpp"
+#include "src/simdag/simdag_private.hpp"
 
-#if HAVE_JEDULE
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/NetZone.hpp"
+
+#if SIMGRID_HAVE_JEDULE
 
 XBT_LOG_NEW_CATEGORY(jedule, "Logging specific to Jedule");
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(jed_sd, jedule, "Logging specific to Jedule SD binding");
@@ -33,7 +28,7 @@ void jedule_log_sd_event(SD_task_t task)
 
 void jedule_sd_init()
 {
-  NetZone_t root_comp = simgrid::s4u::Engine::instance()->netRoot();
+  sg_netzone_t root_comp = simgrid::s4u::Engine::instance()->netRoot();
   XBT_DEBUG("root name %s\n", root_comp->name());
 
   my_jedule = new simgrid::jedule::Jedule();
@@ -43,7 +38,7 @@ void jedule_sd_init()
   my_jedule->root_container = root_container;
 }
 
-void jedule_sd_exit(void)
+void jedule_sd_exit()
 {
   delete my_jedule;
 }
@@ -52,7 +47,7 @@ void jedule_sd_dump(const char * filename)
 {
   if (my_jedule) {
     char *fname;
-    if (!filename) {
+    if (not filename) {
       fname = bprintf("%s.jed", xbt_binary_name);
     } else {
       fname = xbt_strdup(filename);
