@@ -26,7 +26,7 @@ public:
   explicit FloydZone(NetZone* father, const char* name);
   ~FloydZone() override;
 
-  void getLocalRoute(NetCard* src, NetCard* dst, sg_platf_route_cbarg_t into, double* latency) override;
+  void getLocalRoute(NetPoint* src, NetPoint* dst, sg_platf_route_cbarg_t into, double* latency) override;
   void addRoute(sg_platf_route_cbarg_t route) override;
   void seal() override;
 
