@@ -9,16 +9,16 @@
 
 #include <functional>
 
-#include <xbt/log.h>
-#include <xbt/system_error.hpp>
-#include <simgrid/sg_config.h>
-#include <simgrid/modelchecker.h>
+#include "xbt/log.h"
+#include "xbt/system_error.hpp"
 #include <mc/mc.h>
+#include <simgrid/modelchecker.h>
+#include <simgrid/sg_config.h>
 
 #include "src/mc/Session.hpp"
 #include "src/mc/mc_state.h"
 #include "src/mc/mc_private.h"
-#include "src/mc/Checker.hpp"
+#include "src/mc/checker/Checker.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_Session, mc, "Model-checker session");
 
@@ -85,8 +85,7 @@ Session::Session(pid_t pid, int socket)
 {
   std::unique_ptr<simgrid::mc::Process> process(new simgrid::mc::Process(pid, socket));
   // TODO, automatic detection of the config from the process
-  process->privatized(
-    xbt_cfg_get_boolean("smpi/privatize-global-variables"));
+  process->privatized(smpi_privatize_global_variables != SMPI_PRIVATIZE_NONE);
   modelChecker_ = std::unique_ptr<ModelChecker>(
     new simgrid::mc::ModelChecker(std::move(process)));
   xbt_assert(mc_model_checker == nullptr);
@@ -132,7 +131,7 @@ void Session::logState()
 }
 
 // static
-Session* Session::fork(std::function<void(void)> code)
+Session* Session::fork(std::function<void()> code)
 {
   // Create a AF_LOCAL socketpair used for exchanging messages
   // bewteen the model-checker process (ourselves) and the model-checked
@@ -143,7 +142,7 @@ Session* Session::fork(std::function<void(void)> code)
   if (res == -1)
     throw simgrid::xbt::errno_error("Could not create socketpair");
 
-  pid_t pid = do_fork([&] {
+  pid_t pid = do_fork([sockets, &code] {
     ::close(sockets[1]);
     setup_child_environment(sockets[0]);
     code();
@@ -159,7 +158,7 @@ Session* Session::fork(std::function<void(void)> code)
 // static
 Session* Session::spawnv(const char *path, char *const argv[])
 {
-  return Session::fork([&] {
+  return Session::fork([path, argv] {
     execv(path, argv);
   });
 }
@@ -167,7 +166,7 @@ Session* Session::spawnv(const char *path, char *const argv[])
 // static
 Session* Session::spawnvp(const char *file, char *const argv[])
 {
-  return Session::fork([&] {
+  return Session::fork([file, argv] {
     execvp(file, argv);
   });
 }
