@@ -1,5 +1,4 @@
-/* Copyright (c) 2011-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2011-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,18 +10,16 @@
 
 #include <boost/range/algorithm.hpp>
 
-#include <xbt/log.h>
-#include <xbt/sysdep.h>
+#include "xbt/log.h"
+#include "xbt/sysdep.h"
 
 #include "src/mc/mc_comm_pattern.h"
-#include "src/mc/mc_safety.h"
 #include "src/mc/mc_private.h"
 #include "src/mc/Process.hpp"
 #include "src/mc/mc_smx.h"
 #include "src/mc/VisitedState.hpp"
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_VisitedState, mc,
-                                "Logging specific to state equaity detection mechanisms");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_VisitedState, mc, "Logging specific to state equality detection mechanisms");
 
 namespace simgrid {
 namespace mc {
@@ -36,10 +33,7 @@ static int snapshot_compare(simgrid::mc::VisitedState* state1, simgrid::mc::Visi
   return snapshot_compare(num1, s1, num2, s2);
 }
 
-/**
- * \brief Save the current state
- * \return Snapshot of the current state.
- */
+/** @brief Save the current state */
 VisitedState::VisitedState(unsigned long state_number)
 {
   simgrid::mc::Process* process = &(mc_model_checker->process());
@@ -47,12 +41,11 @@ VisitedState::VisitedState(unsigned long state_number)
     process->get_heap()->heaplimit,
     process->get_malloc_info());
 
-  this->nb_processes =
-    mc_model_checker->process().simix_processes().size();
+  this->actors_count = mc_model_checker->process().actors().size();
 
   this->system_state = simgrid::mc::take_snapshot(state_number);
   this->num = state_number;
-  this->other_num = -1;
+  this->original_num = -1;
 }
 
 VisitedState::~VisitedState()
@@ -61,7 +54,7 @@ VisitedState::~VisitedState()
 
 void VisitedStates::prune()
 {
-  while (states_.size() > (std::size_t) _sg_mc_visited) {
+  while (states_.size() > (std::size_t)_sg_mc_max_visited_states) {
     XBT_DEBUG("Try to remove visited state (maximum number of stored states reached)");
     auto min_element = boost::range::min_element(states_,
       [](std::unique_ptr<simgrid::mc::VisitedState>& a, std::unique_ptr<simgrid::mc::VisitedState>& b) {
@@ -74,8 +67,7 @@ void VisitedStates::prune()
   }
 }
 
-/**
- * \brief Checks whether a given state has already been visited by the algorithm.
+/** \brief Checks whether a given state has already been visited by the algorithm.
  */
 std::unique_ptr<simgrid::mc::VisitedState> VisitedStates::addVisitedState(
   unsigned long state_number, simgrid::mc::State* graph_state, bool compare_snpashots)
@@ -86,8 +78,8 @@ std::unique_ptr<simgrid::mc::VisitedState> VisitedStates::addVisitedState(
   XBT_DEBUG("Snapshot %p of visited state %d (exploration stack state %d)",
     new_state->system_state.get(), new_state->num, graph_state->num);
 
-  auto range = boost::range::equal_range(states_,
-    new_state.get(), simgrid::mc::DerefAndCompareByNbProcessesAndUsedHeap());
+  auto range =
+      boost::range::equal_range(states_, new_state.get(), simgrid::mc::DerefAndCompareByActorsCountAndUsedHeap());
 
   if (compare_snpashots)
     for (auto i = range.first; i != range.second; ++i) {
@@ -98,18 +90,17 @@ std::unique_ptr<simgrid::mc::VisitedState> VisitedStates::addVisitedState(
         std::unique_ptr<simgrid::mc::VisitedState> old_state =
           std::move(visited_state);
 
-        if (old_state->other_num == -1)
-          new_state->other_num = old_state->num;
-        else
-          new_state->other_num = old_state->other_num;
+        if (old_state->original_num == -1) // I'm the copy of an original process
+          new_state->original_num = old_state->num;
+        else // I'm the copy of a copy
+          new_state->original_num = old_state->original_num;
 
         if (dot_output == nullptr)
           XBT_DEBUG("State %d already visited ! (equal to state %d)",
-            new_state->num, old_state->num);
+                    new_state->num, old_state->num);
         else
-          XBT_DEBUG(
-            "State %d already visited ! (equal to state %d (state %d in dot_output))",
-            new_state->num, old_state->num, new_state->other_num);
+          XBT_DEBUG("State %d already visited ! (equal to state %d (state %d in dot_output))",
+                    new_state->num, old_state->num, new_state->original_num);
 
         /* Replace the old state with the new one (with a bigger num)
            (when the max number of visited states is reached,  the oldest
