@@ -1,20 +1,18 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include <string.h>
 
-#include <xbt/sysdep.h>
-#include <xbt/dynar.h>
+#include "xbt/dynar.h"
+#include "xbt/sysdep.h"
 #include <xbt/dynar.hpp>
 
 #include "src/mc/mc_comm_pattern.h"
 #include "src/mc/mc_smx.h"
 #include "src/mc/mc_xbt.hpp"
-#include "src/mc/Checker.hpp"
-#include "src/mc/CommunicationDeterminismChecker.hpp"
+#include "src/mc/checker/CommunicationDeterminismChecker.hpp"
 
 using simgrid::mc::remote;
 
@@ -87,16 +85,16 @@ void MC_handle_comm_pattern(
   case MC_CALL_TYPE_WAIT:
   case MC_CALL_TYPE_WAITANY:
     {
-      simgrid::mc::RemotePtr<simgrid::kernel::activity::Comm> comm_addr = nullptr;
-      if (call_type == MC_CALL_TYPE_WAIT)
-        comm_addr = remote(static_cast<simgrid::kernel::activity::Comm*>(
-          simcall_comm_wait__get__comm(req)));
-      else {
-        simgrid::kernel::activity::Comm* addr;
-        // comm_addr = REMOTE(xbt_dynar_get_as(simcall_comm_waitany__get__comms(req), value, smx_synchro_t)):
-        simgrid::mc::read_element(mc_model_checker->process(), &addr,
-          remote(simcall_comm_waitany__get__comms(req)), value, sizeof(comm_addr));
-        comm_addr = remote(addr);
+    simgrid::mc::RemotePtr<simgrid::kernel::activity::CommImpl> comm_addr = nullptr;
+    if (call_type == MC_CALL_TYPE_WAIT)
+      comm_addr = remote(static_cast<simgrid::kernel::activity::CommImpl*>(simcall_comm_wait__getraw__comm(req)));
+
+    else {
+      simgrid::kernel::activity::CommImpl* addr;
+      // comm_addr = REMOTE(xbt_dynar_get_as(simcall_comm_waitany__get__comms(req), value, smx_synchro_t)):
+      simgrid::mc::read_element(mc_model_checker->process(), &addr, remote(simcall_comm_waitany__get__comms(req)),
+                                value, sizeof(comm_addr));
+      comm_addr = remote(addr);
       }
       checker->complete_comm_pattern(pattern, comm_addr,
         MC_smx_simcall_get_issuer(req)->pid, backtracking);
