@@ -1,11 +1,11 @@
-/* Copyright (c) 2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2015-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #ifndef SIMGRID_MC_EXIT_HPP
 #define SIMGRID_MC_EXIT_HPP
+#include "xbt/base.h"
 
 #define SIMGRID_MC_EXIT_SUCCESS  0
 #define SIMGRID_MC_EXIT_SAFETY   1
@@ -17,4 +17,12 @@
 
 #define SIMGRID_MC_EXIT_ERROR         63
 
+namespace simgrid {
+namespace mc {
+XBT_PUBLIC_CLASS DeadlockError {};
+XBT_PUBLIC_CLASS TerminationError {};
+XBT_PUBLIC_CLASS LivenessError {};
+}
+}
+
 #endif
