@@ -1,5 +1,4 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,27 +6,15 @@
 #ifndef SIMGRID_MC_SNAPSHOT_H
 #define SIMGRID_MC_SNAPSHOT_H
 
-#include <cstdint>
-#include <cstddef>
-
 #include <vector>
 #include <set>
 #include <string>
 #include <memory>
 
-#include <sys/types.h> // off_t
-
-#include <simgrid_config.h>
-#include "src/xbt/mmalloc/mmprivate.h"
-#include <xbt/asserts.h>
-#include <xbt/base.h>
-
-#include "src/mc/mc_forward.hpp"
 #include "src/mc/ModelChecker.hpp"
-#include "src/mc/PageStore.hpp"
-#include "src/mc/AddressSpace.hpp"
-#include "src/mc/mc_unw.h"
 #include "src/mc/RegionSnapshot.hpp"
+#include "src/mc/mc_forward.hpp"
+#include "src/mc/mc_unw.h"
 
 SG_BEGIN_DECL()
 
@@ -35,8 +22,7 @@ SG_BEGIN_DECL()
 
 XBT_PRIVATE void mc_region_restore_sparse(simgrid::mc::Process* process, mc_mem_region_t reg);
 
-static inline __attribute__((always_inline))
-void* mc_translate_address_region_chunked(uintptr_t addr, mc_mem_region_t region)
+static XBT_ALWAYS_INLINE void* mc_translate_address_region_chunked(uintptr_t addr, mc_mem_region_t region)
 {
   auto split = simgrid::mc::mmu::split(addr - region->start().address());
   auto pageno = split.first;
@@ -45,8 +31,7 @@ void* mc_translate_address_region_chunked(uintptr_t addr, mc_mem_region_t region
   return (char*) snapshot_page + offset;
 }
 
-static inline __attribute__((always_inline))
-void* mc_translate_address_region(uintptr_t addr, mc_mem_region_t region, int process_index)
+static XBT_ALWAYS_INLINE void* mc_translate_address_region(uintptr_t addr, mc_mem_region_t region, int process_index)
 {
   switch (region->storage_type()) {
   case simgrid::mc::StorageType::NoData:
@@ -133,8 +118,8 @@ namespace mc {
 
 class XBT_PRIVATE Snapshot final : public AddressSpace {
 public:
-  Snapshot(Process* process);
-  ~Snapshot();
+  Snapshot(Process* process, int num_state);
+  ~Snapshot() = default;
   const void* read_bytes(void* buffer, std::size_t size,
     RemotePtr<void> address, int process_index = ProcessIndexAny,
     ReadOptions options = ReadOptions::none()) const override;
@@ -157,8 +142,8 @@ public: // To be private
 
 extern "C" {
 
-static inline __attribute__ ((always_inline))
-mc_mem_region_t mc_get_region_hinted(void* addr, simgrid::mc::Snapshot* snapshot, int process_index, mc_mem_region_t region)
+static XBT_ALWAYS_INLINE mc_mem_region_t mc_get_region_hinted(void* addr, simgrid::mc::Snapshot* snapshot,
+                                                              int process_index, mc_mem_region_t region)
 {
   if (region->contain(simgrid::mc::remote(addr)))
     return region;
@@ -199,8 +184,7 @@ XBT_PRIVATE int MC_snapshot_memcmp(
   const void* addr1, simgrid::mc::Snapshot* snapshot1,
   const void* addr2, simgrid::mc::Snapshot* snapshot2, int process_index, std::size_t size);
 
-static inline __attribute__ ((always_inline))
-const void* mc_snapshot_get_heap_end(simgrid::mc::Snapshot* snapshot)
+static XBT_ALWAYS_INLINE const void* mc_snapshot_get_heap_end(simgrid::mc::Snapshot* snapshot)
 {
   if(snapshot==nullptr)
       xbt_die("snapshot is nullptr");
@@ -215,17 +199,14 @@ const void* mc_snapshot_get_heap_end(simgrid::mc::Snapshot* snapshot)
  *  @param size    Size of the data to read in bytes
  *  @return Pointer where the data is located (target buffer of original location)
  */
-static inline __attribute__((always_inline))
-const void* MC_region_read(
-  mc_mem_region_t region, void* target, const void* addr, std::size_t size)
+static XBT_ALWAYS_INLINE const void* MC_region_read(mc_mem_region_t region, void* target, const void* addr,
+                                                    std::size_t size)
 {
   xbt_assert(region);
 
-  std::uintptr_t offset =
-    (std::uintptr_t) addr - (std::uintptr_t) region->start().address();
+  std::uintptr_t offset = (std::uintptr_t)addr - (std::uintptr_t)region->start().address();
 
-  xbt_assert(region->contain(simgrid::mc::remote(addr)),
-    "Trying to read out of the region boundary.");
+  xbt_assert(region->contain(simgrid::mc::remote(addr)), "Trying to read out of the region boundary.");
 
   switch (region->storage_type()) {
   case simgrid::mc::StorageType::NoData:
@@ -255,8 +236,7 @@ const void* MC_region_read(
   }
 }
 
-static inline __attribute__ ((always_inline))
-void* MC_region_read_pointer(mc_mem_region_t region, const void* addr)
+static XBT_ALWAYS_INLINE void* MC_region_read_pointer(mc_mem_region_t region, const void* addr)
 {
   void* res;
   return *(void**) MC_region_read(region, &res, addr, sizeof(void*));
