@@ -1,18 +1,20 @@
-/* Copyright (c) 2004-2016. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include "simgrid/s4u/Engine.hpp"
 #include "simgrid/s4u/NetZone.hpp"
-#include "simgrid/s4u/engine.hpp"
 #include "src/msg/msg_private.h"
 
-#if HAVE_LUA
+#if SIMGRID_HAVE_LUA
 #include <lua.h>
 #include <lauxlib.h>
 #include <lualib.h>
 #endif
 
+SG_BEGIN_DECL()
+
 /********************************* MSG **************************************/
 
 /** \ingroup msg_simulation
@@ -23,7 +25,7 @@
  *
  *     \include simgrid.dtd
  *
- * Here is a small example of such a platform 
+ * Here is a small example of such a platform
  *
  *     \include small_platform.xml
  *
@@ -34,49 +36,45 @@ void MSG_create_environment(const char *file)
   SIMIX_create_environment(file);
 }
 
-void MSG_post_create_environment() {
-  xbt_lib_cursor_t cursor;
-  void **data;
-  char *name;
-
-  /* Initialize MSG storages */
-  xbt_lib_foreach(storage_lib, cursor, name, data) {
-    if(data[SIMIX_STORAGE_LEVEL])
-      __MSG_storage_create(xbt_dict_cursor_get_elm(cursor));
-  }
-}
-
-msg_netzone_t MSG_environment_get_routing_root()
+msg_netzone_t MSG_zone_get_root()
 {
   return simgrid::s4u::Engine::instance()->netRoot();
 }
 
-const char* MSG_environment_as_get_name(msg_netzone_t netzone)
+const char* MSG_zone_get_name(msg_netzone_t netzone)
 {
   return netzone->name();
 }
 
-msg_netzone_t MSG_environment_as_get_by_name(const char* name)
+msg_netzone_t MSG_zone_get_by_name(const char* name)
 {
   return simgrid::s4u::Engine::instance()->netzoneByNameOrNull(name);
 }
 
-xbt_dict_t MSG_environment_as_get_routing_sons(msg_netzone_t netzone)
+void MSG_zone_get_sons(msg_netzone_t netzone, xbt_dict_t whereto)
 {
-  return netzone->children();
+  for (auto elem : *netzone->children()) {
+    xbt_dict_set(whereto, elem->name(), static_cast<void*>(elem), nullptr);
+  }
 }
 
-const char* MSG_environment_as_get_property_value(msg_netzone_t netzone, const char* name)
+const char* MSG_zone_get_property_value(msg_netzone_t netzone, const char* name)
 {
   return netzone->property(name);
 }
 
-void MSG_environment_as_set_property_value(msg_netzone_t netzone, const char* name, char* value)
+void MSG_zone_set_property_value(msg_netzone_t netzone, const char* name, char* value)
 {
   netzone->setProperty(name, value);
 }
 
-xbt_dynar_t MSG_environment_as_get_hosts(msg_netzone_t netzone)
+void MSG_zone_get_hosts(msg_netzone_t netzone, xbt_dynar_t whereto)
 {
-  return netzone->hosts();
+  /* converts vector to dynar */
+  std::vector<simgrid::s4u::Host*> hosts;
+  netzone->hosts(&hosts);
+  for (auto host : hosts)
+    xbt_dynar_push(whereto, &host);
 }
+
+SG_END_DECL()
