@@ -1,18 +1,20 @@
-/* Copyright (c) 2004-2015. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/Host.hpp"
 
 #include "instr/instr_interface.h"
 #include "mc/mc.h"
 #include "src/msg/msg_private.h"
-#include "src/surf/xml/platf_private.hpp" // FIXME: KILLME by removing MSG_post_create_environment()
 
 XBT_LOG_NEW_CATEGORY(msg, "All MSG categories");
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_kernel, msg, "Logging specific to MSG (kernel)");
 
+SG_BEGIN_DECL()
+
 MSG_Global_t msg_global = nullptr;
 static void MSG_exit();
 
@@ -23,11 +25,6 @@ static void _sg_cfg_cb_msg_debug_multiple_use(const char *name)
   msg_global->debug_multiple_use = xbt_cfg_get_boolean(name);
 }
 
-static void MSG_host_create_(sg_host_t host)
-{
-  __MSG_host_create(host);
-}
-
 /**
  * \ingroup msg_simulation
  * \brief Initialize MSG with less verifications
@@ -38,9 +35,9 @@ void MSG_init_nocheck(int *argc, char **argv) {
   TRACE_global_init(argc, argv);
 
   xbt_getpid = &MSG_process_self_PID;
-  if (!msg_global) {
+  if (not msg_global) {
 
-    msg_global = xbt_new0(s_MSG_Global_t, 1);
+    msg_global = new s_MSG_Global_t();
 
     xbt_cfg_register_boolean("msg/debug-multiple-use", "no", _sg_cfg_cb_msg_debug_multiple_use,
         "Print backtraces of both processes when there is a conflict of multiple use of a task");
@@ -54,14 +51,10 @@ void MSG_init_nocheck(int *argc, char **argv) {
     SIMIX_function_register_process_create(MSG_process_create_from_SIMIX);
     SIMIX_function_register_process_cleanup(MSG_process_cleanup_from_SIMIX);
 
-    simgrid::surf::on_postparse.connect(MSG_post_create_environment);
+    simgrid::MsgHostExt::EXTENSION_ID = simgrid::s4u::Host::extension_create<simgrid::MsgHostExt>();
     simgrid::s4u::Host::onCreation.connect([](simgrid::s4u::Host& host) {
-      MSG_host_create_(&host);
+      host.extension_set<simgrid::MsgHostExt>(new simgrid::MsgHostExt());
     });
-    MSG_HOST_LEVEL = simgrid::s4u::Host::extension_create([](void *p) {
-      __MSG_host_priv_free((msg_host_priv_t) p);
-    });
-
   }
 
   if(MC_is_active()){
@@ -69,10 +62,7 @@ void MSG_init_nocheck(int *argc, char **argv) {
     MC_ignore_heap(&(msg_global->sent_msg), sizeof(msg_global->sent_msg));
   }
 
-  XBT_DEBUG("ADD MSG LEVELS");
-  MSG_STORAGE_LEVEL = xbt_lib_add_level(storage_lib, (void_f_pvoid_t) __MSG_storage_destroy);
-  MSG_FILE_LEVEL = xbt_lib_add_level(file_lib, (void_f_pvoid_t) __MSG_file_destroy);
-  if(xbt_cfg_get_boolean("clean-atexit"))
+  if (xbt_cfg_get_boolean("clean-atexit"))
     atexit(MSG_exit);
 }
 
@@ -126,7 +116,7 @@ static void MSG_exit() {
 
   TRACE_surf_resource_utilization_release();
   TRACE_end();
-  free(msg_global);
+  delete msg_global;
   msg_global = nullptr;
 }
 
@@ -142,3 +132,5 @@ unsigned long int MSG_get_sent_msg()
 {
   return msg_global->sent_msg;
 }
+
+SG_END_DECL()
