@@ -1,21 +1,26 @@
-/* Copyright (c) 2004-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/Host.hpp"
+#include "simgrid/s4u/Storage.hpp"
 #include "src/msg/msg_private.h"
+#include "src/simix/ActorImpl.hpp"
+#include "src/simix/smx_host_private.h"
 
-#include <numeric>
 
 XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(msg);
 
+simgrid::xbt::Extension<simgrid::s4u::Host, simgrid::MsgHostExt> simgrid::MsgHostExt::EXTENSION_ID;
+
+SG_BEGIN_DECL()
+
 int sg_storage_max_file_descriptors = 1024;
 
 /** @addtogroup m_host_management
  * (#msg_host_t) and the functions for managing it.
- *  
+ *
  *  A <em>location</em> (or <em>host</em>) is any possible place where  a process may run. Thus it may be represented
  *  as a <em>physical resource with computing capabilities</em>, some <em>mailboxes</em> to enable running process to
  *  communicate with remote ones, and some <em>private data</em> that can be only accessed by local process.
@@ -23,17 +28,6 @@ int sg_storage_max_file_descriptors = 1024;
  */
 
 /********************************* Host **************************************/
-msg_host_t __MSG_host_create(sg_host_t host) // FIXME: don't return our parameter
-{
-  msg_host_priv_t priv = xbt_new0(s_msg_host_priv_t, 1);
-
-  priv->file_descriptor_table = nullptr;
-
-  sg_host_msg_set(host,priv);
-
-  return host;
-}
-
 /** \ingroup m_host_management
  * \brief Finds a msg_host_t using its name.
  *
@@ -80,7 +74,7 @@ msg_host_t MSG_host_self()
  *
  * \brief Start the host if it is off
  *
- * See also #MSG_host_is_on() and #MSG_host_is_off() to test the current state of the host and @ref SURF_plugin_energy
+ * See also #MSG_host_is_on() and #MSG_host_is_off() to test the current state of the host and @ref plugin_energy
  * for more info on DVFS.
  */
 void MSG_host_on(msg_host_t host)
@@ -92,7 +86,7 @@ void MSG_host_on(msg_host_t host)
  *
  * \brief Stop the host if it is on
  *
- * See also #MSG_host_is_on() and #MSG_host_is_off() to test the current state of the host and @ref SURF_plugin_energy
+ * See also #MSG_host_is_on() and #MSG_host_is_off() to test the current state of the host and @ref plugin_energy
  * for more info on DVFS.
  */
 void MSG_host_off(msg_host_t host)
@@ -100,17 +94,6 @@ void MSG_host_off(msg_host_t host)
   host->turnOff();
 }
 
-/*
- * \brief Frees private data of a host (internal call only)
- */
-void __MSG_host_priv_free(msg_host_priv_t priv)
-{
-  if (priv == nullptr)
-    return;
-  delete priv->file_descriptor_table;
-  free(priv);
-}
-
 /** \ingroup m_host_management
  * \brief Return the current number MSG hosts.
  */
@@ -120,7 +103,7 @@ int MSG_get_host_number()
 }
 
 /** \ingroup m_host_management
- * \brief Return a dynar containing all the hosts declared at a given point of time
+ * \brief Return a dynar containing all the hosts declared at a given point of time (including VMs)
  * \remark The host order in the returned array is generally different from the host creation/declaration order in the
  *         XML platform (we use a hash table internally)
  */
@@ -158,12 +141,16 @@ int MSG_host_get_core_number(msg_host_t host) {
  * \brief Return the list of processes attached to an host.
  *
  * \param host a host
- * \return a swag with the attached processes
+ * \param whereto a dynar in which we should push processes living on that host
  */
-xbt_swag_t MSG_host_get_process_list(msg_host_t host)
+void MSG_host_get_process_list(msg_host_t host, xbt_dynar_t whereto)
 {
   xbt_assert((host != nullptr), "Invalid parameters");
-  return host->processes();
+  smx_actor_t actor = NULL;
+  xbt_swag_foreach(actor, host->extension<simgrid::simix::Host>()->process_list) {
+    msg_process_t p = actor->ciface();
+    xbt_dynar_push(whereto, &p);
+  }
 }
 
 /** \ingroup m_host_management
@@ -205,7 +192,8 @@ void MSG_host_set_property_value(msg_host_t host, const char* name, char* value)
 /** @ingroup m_host_management
  * @brief Determine if a host is up and running.
  *
- * See also #MSG_host_on() and #MSG_host_off() to switch the host ON and OFF and @ref SURF_plugin_energy for more info on DVFS.
+ * See also #MSG_host_on() and #MSG_host_off() to switch the host ON and OFF and @ref plugin_energy for more info on
+ * DVFS.
  *
  * @param host host to test
  * @return Returns true if the host is up and running, and false if it's currently down
@@ -218,7 +206,8 @@ int MSG_host_is_on(msg_host_t host)
 /** @ingroup m_host_management
  * @brief Determine if a host is currently off.
  *
- * See also #MSG_host_on() and #MSG_host_off() to switch the host ON and OFF and @ref SURF_plugin_energy for more info on DVFS.
+ * See also #MSG_host_on() and #MSG_host_off() to switch the host ON and OFF and @ref plugin_energy for more info on
+ * DVFS.
  */
 int MSG_host_is_off(msg_host_t host)
 {
@@ -226,7 +215,7 @@ int MSG_host_is_off(msg_host_t host)
 }
 
 /** \ingroup m_host_management
- * \brief Return the speed of the processor (in flop/s) at a given pstate. See also @ref SURF_plugin_energy.
+ * \brief Return the speed of the processor (in flop/s) at a given pstate. See also @ref plugin_energy.
  *
  * \param  host host to test
  * \param pstate_index pstate to test
@@ -238,18 +227,7 @@ double MSG_host_get_power_peak_at(msg_host_t host, int pstate_index) {
 }
 
 /** \ingroup m_host_management
- * \brief Return the current speed of the processor (in flop/s)
- *
- * \param  host host to test
- * \return Returns the current processor speed
- */
-double MSG_host_get_current_power_peak(msg_host_t host) {
-  xbt_assert((host != nullptr), "Invalid parameters (host is nullptr)");
-  return host->getPstateSpeedCurrent();
-}
-
-/** \ingroup m_host_management
- * \brief Return the total count of pstates defined for a host. See also @ref SURF_plugin_energy.
+ * \brief Return the total count of pstates defined for a host. See also @ref plugin_energy.
  *
  * \param  host host to test
  */
@@ -264,8 +242,7 @@ int MSG_host_get_nb_pstates(msg_host_t host) {
  */
 xbt_dict_t MSG_host_get_mounted_storage_list(msg_host_t host)
 {
-  xbt_assert((host != nullptr), "Invalid parameters");
-  return host->mountedStoragesAsDict();
+  return sg_host_get_mounted_storage_list(host);
 }
 
 /** \ingroup m_host_management
@@ -275,8 +252,7 @@ xbt_dict_t MSG_host_get_mounted_storage_list(msg_host_t host)
  */
 xbt_dynar_t MSG_host_get_attached_storage_list(msg_host_t host)
 {
-  xbt_assert((host != nullptr), "Invalid parameters");
-  return host->attachedStorages();
+  return sg_host_get_attached_storage_list(host);
 }
 
 /** \ingroup m_host_management
@@ -288,35 +264,10 @@ xbt_dict_t MSG_host_get_storage_content(msg_host_t host)
 {
   xbt_assert((host != nullptr), "Invalid parameters");
   xbt_dict_t contents = xbt_dict_new_homogeneous(nullptr);
-  msg_storage_t storage;
-  char* storage_name;
-  char* mount_name;
-  xbt_dict_cursor_t cursor = nullptr;
+  for (auto elm : host->mountedStorages())
+    xbt_dict_set(contents, elm.first.c_str(), MSG_storage_get_content(elm.second), nullptr);
 
-  xbt_dict_t storage_list = host->mountedStoragesAsDict();
-
-  xbt_dict_foreach(storage_list,cursor,mount_name,storage_name){
-    storage = static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib,storage_name));
-    xbt_dict_t content = simcall_storage_get_content(storage);
-    xbt_dict_set(contents,mount_name, content,nullptr);
-  }
-  xbt_dict_free(&storage_list);
   return contents;
 }
 
-int __MSG_host_get_file_descriptor_id(msg_host_t host){
-  msg_host_priv_t priv = sg_host_msg(host);
-  if(!priv->file_descriptor_table){
-    priv->file_descriptor_table = new std::vector<int>(sg_storage_max_file_descriptors);
-    std::iota (priv->file_descriptor_table->rbegin(), priv->file_descriptor_table->rend(), 0); // Fill with ..., 1, 0.
-  }
-  xbt_assert(!priv->file_descriptor_table->empty(), "Too much files are opened! Some have to be closed.");
-  int desc = priv->file_descriptor_table->back();
-  priv->file_descriptor_table->pop_back();
-  return desc;
-}
-
-void __MSG_host_release_file_descriptor_id(msg_host_t host, int id){
-  msg_host_priv_t priv = sg_host_msg(host);
-  priv->file_descriptor_table->push_back(id);
-}
+SG_END_DECL()
