@@ -1,34 +1,40 @@
-/* Copyright (c) 2004-2016. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/File.hpp"
+#include "simgrid/s4u/Host.hpp"
+#include "simgrid/s4u/Storage.hpp"
 #include "src/msg/msg_private.h"
+#include <numeric>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_io, msg, "Logging specific to MSG (io)");
 
+SG_BEGIN_DECL()
+
 /** @addtogroup msg_file
  * (#msg_file_t) and the functions for managing it.
  *
  *  \see #msg_file_t
  */
 
-/********************************* File **************************************/
-void __MSG_file_get_info(msg_file_t fd){
+static int MSG_host_get_file_descriptor_id(msg_host_t host)
+{
+  simgrid::MsgHostExt* priv = host->extension<simgrid::MsgHostExt>();
+  if (priv->file_descriptor_table == nullptr) {
+    priv->file_descriptor_table = new std::vector<int>(sg_storage_max_file_descriptors);
+    std::iota(priv->file_descriptor_table->rbegin(), priv->file_descriptor_table->rend(), 0); // Fill with ..., 1, 0.
+  }
+  xbt_assert(not priv->file_descriptor_table->empty(), "Too much files are opened! Some have to be closed.");
+  int desc = priv->file_descriptor_table->back();
+  priv->file_descriptor_table->pop_back();
+  return desc;
+}
 
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  xbt_dynar_t info = simcall_file_get_info(priv->simdata->smx_file);
-  sg_size_t *psize;
-
-  priv->content_type = xbt_dynar_pop_as(info, char *);
-  priv->storage_type = xbt_dynar_pop_as(info, char *);
-  priv->storageId = xbt_dynar_pop_as(info, char *);
-  priv->mount_point = xbt_dynar_pop_as(info, char *);
-  psize = xbt_dynar_pop_as(info, sg_size_t*);
-  priv->size = *psize;
-  xbt_free(psize);
-  xbt_dynar_free_container(&info);
+static void MSG_host_release_file_descriptor_id(msg_host_t host, int id)
+{
+  host->extension<simgrid::MsgHostExt>()->file_descriptor_table->push_back(id);
 }
 
 /** \ingroup msg_file
@@ -39,8 +45,7 @@ void __MSG_file_get_info(msg_file_t fd){
  */
 msg_error_t MSG_file_set_data(msg_file_t fd, void *data)
 {
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  priv->data = data;
+  fd->setUserdata(data);
   return MSG_OK;
 }
 
@@ -50,10 +55,9 @@ msg_error_t MSG_file_set_data(msg_file_t fd, void *data)
  *
  * This functions checks whether \a file is a valid pointer and return the user data associated to \a file if possible.
  */
-void *MSG_file_get_data(msg_file_t fd)
+void* MSG_file_get_data(msg_file_t fd)
 {
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return priv->data;
+  return fd->userdata();
 }
 
 /** \ingroup msg_file
@@ -62,21 +66,14 @@ void *MSG_file_get_data(msg_file_t fd)
  * \param fd is a the file descriptor
  */
 void MSG_file_dump (msg_file_t fd){
-  /* Update the cached information first */
-  __MSG_file_get_info(fd);
-
-  msg_file_priv_t priv = MSG_file_priv(fd);
   XBT_INFO("File Descriptor information:\n"
            "\t\tFull path: '%s'\n"
            "\t\tSize: %llu\n"
            "\t\tMount point: '%s'\n"
            "\t\tStorage Id: '%s'\n"
            "\t\tStorage Type: '%s'\n"
-           "\t\tContent Type: '%s'\n"
            "\t\tFile Descriptor Id: %d",
-           priv->fullpath, priv->size, priv->mount_point,
-           priv->storageId, priv->storage_type,
-           priv->content_type, priv->desc_id);
+           fd->path(), fd->size(), fd->mount_point.c_str(), fd->storageId, fd->storage_type, fd->desc_id);
 }
 
 /** \ingroup msg_file
@@ -88,34 +85,28 @@ void MSG_file_dump (msg_file_t fd){
  */
 sg_size_t MSG_file_read(msg_file_t fd, sg_size_t size)
 {
-  msg_file_priv_t file_priv = MSG_file_priv(fd);
   sg_size_t read_size;
 
-  if (file_priv->size == 0) /* Nothing to read, return */
+  if (fd->size() == 0) /* Nothing to read, return */
     return 0;
 
   /* Find the host where the file is physically located and read it */
-  msg_storage_t storage_src = static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib, file_priv->storageId));
-  msg_storage_priv_t storage_priv_src = MSG_storage_priv(storage_src);
-  msg_host_t attached_host = MSG_host_by_name(storage_priv_src->hostname);
-  read_size = simcall_file_read(file_priv->simdata->smx_file, size, attached_host);
+  msg_storage_t storage_src           = simgrid::s4u::Storage::byName(fd->storageId);
+  msg_host_t attached_host            = storage_src->host();
+  read_size                           = fd->read(size); // TODO re-add attached_host;
 
-  if (strcmp(storage_priv_src->hostname, MSG_host_self()->cname())) {
+  if (strcmp(attached_host->cname(), MSG_host_self()->cname())) {
     /* the file is hosted on a remote host, initiate a communication between src and dest hosts for data transfer */
-    XBT_DEBUG("File is on %s remote host, initiate data transfer of %llu bytes.", storage_priv_src->hostname, read_size);
-    msg_host_t *m_host_list = nullptr;
-    m_host_list = xbt_new0(msg_host_t, 2);
-
-    m_host_list[0] = MSG_host_self();
-    m_host_list[1] = attached_host;
-    double flops_amount[] = { 0, 0};
-    double bytes_amount[] = { 0, 0, static_cast<double>(read_size), 0 };
+    XBT_DEBUG("File is on %s remote host, initiate data transfer of %llu bytes.", attached_host->cname(), read_size);
+    msg_host_t m_host_list[] = {MSG_host_self(), attached_host};
+    double flops_amount[]    = {0, 0};
+    double bytes_amount[]    = {0, 0, static_cast<double>(read_size), 0};
 
     msg_task_t task = MSG_parallel_task_create("file transfer for read", 2, m_host_list, flops_amount, bytes_amount,
                       nullptr);
     msg_error_t transfer = MSG_parallel_task_execute(task);
     MSG_task_destroy(task);
-    xbt_free(m_host_list);
+
     if(transfer != MSG_OK){
       if (transfer == MSG_HOST_FAILURE)
         XBT_WARN("Transfer error, %s remote host just turned off!", attached_host->cname());
@@ -137,32 +128,25 @@ sg_size_t MSG_file_read(msg_file_t fd, sg_size_t size)
  */
 sg_size_t MSG_file_write(msg_file_t fd, sg_size_t size)
 {
-  msg_file_priv_t file_priv = MSG_file_priv(fd);
-
   if (size == 0) /* Nothing to write, return */
     return 0;
 
   /* Find the host where the file is physically located (remote or local)*/
-  msg_storage_t storage_src = static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib, file_priv->storageId));
-  msg_storage_priv_t storage_priv_src = MSG_storage_priv(storage_src);
-  msg_host_t attached_host = MSG_host_by_name(storage_priv_src->hostname);
+  msg_storage_t storage_src = simgrid::s4u::Storage::byName(fd->storageId);
+  msg_host_t attached_host  = storage_src->host();
 
-  if (strcmp(storage_priv_src->hostname, MSG_host_self()->cname())) {
+  if (strcmp(attached_host->cname(), MSG_host_self()->cname())) {
     /* the file is hosted on a remote host, initiate a communication between src and dest hosts for data transfer */
-    XBT_DEBUG("File is on %s remote host, initiate data transfer of %llu bytes.", storage_priv_src->hostname, size);
-    msg_host_t *m_host_list = nullptr;
-    m_host_list = xbt_new0(msg_host_t, 2);
-
-    m_host_list[0] = MSG_host_self();
-    m_host_list[1] = attached_host;
-    double flops_amount[] = { 0, 0 };
-    double bytes_amount[] = { 0, static_cast<double>(size), 0, 0 };
+    XBT_DEBUG("File is on %s remote host, initiate data transfer of %llu bytes.", attached_host->cname(), size);
+    msg_host_t m_host_list[] = {MSG_host_self(), attached_host};
+    double flops_amount[]    = {0, 0};
+    double bytes_amount[]    = {0, static_cast<double>(size), 0, 0};
 
     msg_task_t task = MSG_parallel_task_create("file transfer for write", 2, m_host_list, flops_amount, bytes_amount,
                                                nullptr);
     msg_error_t transfer = MSG_parallel_task_execute(task);
     MSG_task_destroy(task);
-    free(m_host_list);
+
     if(transfer != MSG_OK){
       if (transfer == MSG_HOST_FAILURE)
         XBT_WARN("Transfer error, %s remote host just turned off!", attached_host->cname());
@@ -173,9 +157,8 @@ sg_size_t MSG_file_write(msg_file_t fd, sg_size_t size)
     }
   }
   /* Write file on local or remote host */
-  sg_size_t offset = simcall_file_tell(file_priv->simdata->smx_file);
-  sg_size_t write_size = simcall_file_write(file_priv->simdata->smx_file, size, attached_host);
-  file_priv->size = offset+write_size;
+  // sg_size_t offset     = fd->tell();
+  sg_size_t write_size = fd->write(size); // TODO readd attached_host;
 
   return write_size;
 }
@@ -190,21 +173,8 @@ sg_size_t MSG_file_write(msg_file_t fd, sg_size_t size)
  */
 msg_file_t MSG_file_open(const char* fullpath, void* data)
 {
-  char *name;
-  msg_file_priv_t priv = xbt_new(s_msg_file_priv_t, 1);
-  priv->data = data;
-  priv->fullpath = xbt_strdup(fullpath);
-  priv->simdata = xbt_new0(s_simdata_file_t,1);
-  priv->simdata->smx_file = simcall_file_open(fullpath, MSG_host_self());
-  priv->desc_id = __MSG_host_get_file_descriptor_id(MSG_host_self());
-
-  name = bprintf("%s:%s:%d", priv->fullpath, MSG_host_self()->cname(), priv->desc_id);
-
-  xbt_lib_set(file_lib, name, MSG_FILE_LEVEL, priv);
-  msg_file_t fd = static_cast<msg_file_t>(xbt_lib_get_elm_or_null(file_lib, name));
-  __MSG_file_get_info(fd);
-  xbt_free(name);
-
+  msg_file_t fd         = new simgrid::s4u::File(fullpath, MSG_host_self());
+  fd->desc_id           = MSG_host_get_file_descriptor_id(MSG_host_self());
   return fd;
 }
 
@@ -216,17 +186,10 @@ msg_file_t MSG_file_open(const char* fullpath, void* data)
  */
 int MSG_file_close(msg_file_t fd)
 {
-  char *name;
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  if (priv->data)
-    xbt_free(priv->data);
+  MSG_host_release_file_descriptor_id(MSG_host_self(), fd->desc_id);
+  delete fd;
 
-  int res = simcall_file_close(priv->simdata->smx_file, MSG_host_self());
-  name    = bprintf("%s:%s:%d", priv->fullpath, MSG_host_self()->cname(), priv->desc_id);
-  __MSG_host_release_file_descriptor_id(MSG_host_self(), priv->desc_id);
-  xbt_lib_unset(file_lib, name, MSG_FILE_LEVEL, 1);
-  xbt_free(name);
-  return res;
+  return MSG_OK;
 }
 
 /** \ingroup msg_file
@@ -237,13 +200,11 @@ int MSG_file_close(msg_file_t fd)
  */
 msg_error_t MSG_file_unlink(msg_file_t fd)
 {
-  msg_file_priv_t file_priv = MSG_file_priv(fd);
   /* Find the host where the file is physically located (remote or local)*/
-  msg_storage_t storage_src = static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib, file_priv->storageId));
-  msg_storage_priv_t storage_priv_src = MSG_storage_priv(storage_src);
-  msg_host_t attached_host = MSG_host_by_name(storage_priv_src->hostname);
-  int res = simcall_file_unlink(file_priv->simdata->smx_file, attached_host);
-  return static_cast<msg_error_t>(res);
+  msg_storage_t storage_src = simgrid::s4u::Storage::byName(fd->storageId);
+  msg_host_t attached_host  = storage_src->host();
+  fd->unlink(attached_host);
+  return MSG_OK;
 }
 
 /** \ingroup msg_file
@@ -252,9 +213,9 @@ msg_error_t MSG_file_unlink(msg_file_t fd)
  * \param fd is the file descriptor (#msg_file_t)
  * \return the size of the file (as a #sg_size_t)
  */
-sg_size_t MSG_file_get_size(msg_file_t fd){
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return simcall_file_get_size(priv->simdata->smx_file);
+sg_size_t MSG_file_get_size(msg_file_t fd)
+{
+  return fd->size();
 }
 
 /**
@@ -271,8 +232,8 @@ sg_size_t MSG_file_get_size(msg_file_t fd){
  */
 msg_error_t MSG_file_seek(msg_file_t fd, sg_offset_t offset, int origin)
 {
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return static_cast<msg_error_t>(simcall_file_seek(priv->simdata->smx_file, offset, origin));
+  fd->seek(offset); // TODO re-add origin
+  return MSG_OK;
 }
 
 /**
@@ -285,14 +246,12 @@ msg_error_t MSG_file_seek(msg_file_t fd, sg_offset_t offset, int origin)
  */
 sg_size_t MSG_file_tell(msg_file_t fd)
 {
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return simcall_file_tell(priv->simdata->smx_file);
+  return fd->tell();
 }
 
 const char *MSG_file_get_name(msg_file_t fd) {
   xbt_assert((fd != nullptr), "Invalid parameters");
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return priv->fullpath;
+  return fd->path();
 }
 
 /**
@@ -302,8 +261,8 @@ const char *MSG_file_get_name(msg_file_t fd) {
  */
 msg_error_t MSG_file_move (msg_file_t fd, const char* fullpath)
 {
-  msg_file_priv_t priv = MSG_file_priv(fd);
-  return static_cast<msg_error_t>(simcall_file_move(priv->simdata->smx_file, fullpath));
+  fd->move(fullpath);
+  return MSG_OK;
 }
 
 /**
@@ -316,78 +275,58 @@ msg_error_t MSG_file_move (msg_file_t fd, const char* fullpath)
  */
 msg_error_t MSG_file_rcopy (msg_file_t file, msg_host_t host, const char* fullpath)
 {
-  msg_file_priv_t file_priv = MSG_file_priv(file);
-  sg_size_t read_size;
-
   /* Find the host where the file is physically located and read it */
-  msg_storage_t storage_src = static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib, file_priv->storageId));
-  msg_storage_priv_t storage_priv_src = MSG_storage_priv(storage_src);
-  msg_host_t attached_host = MSG_host_by_name(storage_priv_src->hostname);
+  msg_storage_t storage_src = simgrid::s4u::Storage::byName(file->storageId);
+  msg_host_t src_host       = storage_src->host();
   MSG_file_seek(file, 0, SEEK_SET);
-  read_size = simcall_file_read(file_priv->simdata->smx_file, file_priv->size, attached_host);
+  sg_size_t read_size = file->read(file->size());
 
-  /* Find the real host destination where the file will be physically stored */
-  xbt_dict_cursor_t cursor = nullptr;
+  /* Find the host that owns the storage where the file has to be copied */
   msg_storage_t storage_dest = nullptr;
-  msg_host_t host_dest;
+  msg_host_t dst_host;
   size_t longest_prefix_length = 0;
 
-  xbt_dict_t storage_list = host->mountedStoragesAsDict();
-  char *mount_name;
-  char *storage_name;
-  xbt_dict_foreach(storage_list,cursor,mount_name,storage_name){
-    char* file_mount_name = static_cast<char *>(xbt_malloc ((strlen(mount_name)+1)));
-    strncpy(file_mount_name,fullpath,strlen(mount_name)+1);
-    file_mount_name[strlen(mount_name)] = '\0';
-
-    if(!strcmp(file_mount_name,mount_name) && strlen(mount_name)>longest_prefix_length){
+  for (auto elm : host->mountedStorages()) {
+    std::string mount_point = std::string(fullpath).substr(0, elm.first.size());
+    if (mount_point == elm.first && elm.first.length() > longest_prefix_length) {
       /* The current mount name is found in the full path and is bigger than the previous*/
-      longest_prefix_length = strlen(mount_name);
-      storage_dest = (msg_storage_t) xbt_lib_get_elm_or_null(storage_lib, storage_name);
+      longest_prefix_length = elm.first.length();
+      storage_dest          = elm.second;
     }
-    xbt_free(file_mount_name);
   }
-  xbt_dict_free(&storage_list);
 
-  char* host_name_dest = nullptr;
-  if(longest_prefix_length>0){
+  if (storage_dest != nullptr) {
     /* Mount point found, retrieve the host the storage is attached to */
-    msg_storage_priv_t storage_dest_priv = MSG_storage_priv(storage_dest);
-    host_name_dest = (char*)storage_dest_priv->hostname;
-    host_dest = MSG_host_by_name(host_name_dest);
+    dst_host = storage_dest->host();
   }else{
     XBT_WARN("Can't find mount point for '%s' on destination host '%s'", fullpath, host->cname());
     return MSG_TASK_CANCELED;
   }
 
-  XBT_DEBUG("Initiate data transfer of %llu bytes between %s and %s.", read_size, storage_priv_src->hostname,
-            host_name_dest);
-  msg_host_t *m_host_list = nullptr;
-  m_host_list = xbt_new0(msg_host_t, 2);
-
-  m_host_list[0] = attached_host;
-  m_host_list[1] = host_dest;
-  double flops_amount[] = { 0, 0 };
-  double bytes_amount[] = { 0, static_cast<double>(read_size), 0, 0 };
+  XBT_DEBUG("Initiate data transfer of %llu bytes between %s and %s.", read_size, src_host->cname(),
+            storage_dest->host()->cname());
+  msg_host_t m_host_list[] = {src_host, dst_host};
+  double flops_amount[]    = {0, 0};
+  double bytes_amount[]    = {0, static_cast<double>(read_size), 0, 0};
 
   msg_task_t task =
       MSG_parallel_task_create("file transfer for write", 2, m_host_list, flops_amount, bytes_amount, nullptr);
-  msg_error_t transfer = MSG_parallel_task_execute(task);
+  msg_error_t err = MSG_parallel_task_execute(task);
   MSG_task_destroy(task);
-  xbt_free(m_host_list);
-  if(transfer != MSG_OK){
-    if (transfer == MSG_HOST_FAILURE)
-      XBT_WARN("Transfer error, %s remote host just turned off!", host_name_dest);
-    if (transfer == MSG_TASK_CANCELED)
+
+  if (err != MSG_OK) {
+    if (err == MSG_HOST_FAILURE)
+      XBT_WARN("Transfer error, %s remote host just turned off!", storage_dest->host()->cname());
+    if (err == MSG_TASK_CANCELED)
       XBT_WARN("Transfer error, task has been canceled!");
 
-    return transfer;
+    return err;
   }
 
   /* Create file on remote host, write it and close it */
-  smx_file_t smx_file = simcall_file_open(fullpath, host_dest);
-  simcall_file_write(smx_file, read_size, host_dest);
-  simcall_file_close(smx_file, host_dest);
+  msg_file_t fd = new simgrid::s4u::File(fullpath, dst_host, nullptr);
+  fd->write(read_size, dst_host);
+  delete fd;
   return MSG_OK;
 }
 
@@ -406,46 +345,21 @@ msg_error_t MSG_file_rmove (msg_file_t file, msg_host_t host, const char* fullpa
   return res;
 }
 
-/**
- * \brief Destroys a file (internal call only)
- */
-void __MSG_file_destroy(msg_file_priv_t file) {
-  xbt_free(file->fullpath);
-  xbt_free(file->simdata);
-  xbt_free(file);
-}
-
 /********************************* Storage **************************************/
 /** @addtogroup msg_storage_management
  * (#msg_storage_t) and the functions for managing it.
  */
 
-msg_storage_t __MSG_storage_create(smx_storage_t storage)
-{
-  const char *name = SIMIX_storage_get_name(storage);
-  const char *host = SIMIX_storage_get_host(storage);
-  msg_storage_priv_t storage_private = xbt_new0(s_msg_storage_priv_t, 1);
-  storage_private->hostname = host;
-  xbt_lib_set(storage_lib,name,MSG_STORAGE_LEVEL,storage_private);
-  return xbt_lib_get_elm_or_null(storage_lib, name);
-}
-
-/**
- * \brief Destroys a storage (internal call only)
- */
-void __MSG_storage_destroy(msg_storage_priv_t storage) {
-  free(storage);
-}
-
 /** \ingroup msg_storage_management
  *
  * \brief Returns the name of the #msg_storage_t.
  *
  * This functions checks whether a storage is a valid pointer or not and return its name.
  */
-const char *MSG_storage_get_name(msg_storage_t storage) {
+const char* MSG_storage_get_name(msg_storage_t storage)
+{
   xbt_assert((storage != nullptr), "Invalid parameters");
-  return SIMIX_storage_get_name(storage);
+  return storage->name();
 }
 
 /** \ingroup msg_storage_management
@@ -453,8 +367,9 @@ const char *MSG_storage_get_name(msg_storage_t storage) {
  * \param storage a storage
  * \return the free space size of the storage element (as a #sg_size_t)
  */
-sg_size_t MSG_storage_get_free_size(msg_storage_t storage){
-  return simcall_storage_get_free_size(storage);
+sg_size_t MSG_storage_get_free_size(msg_storage_t storage)
+{
+  return storage->sizeFree();
 }
 
 /** \ingroup msg_storage_management
@@ -462,8 +377,9 @@ sg_size_t MSG_storage_get_free_size(msg_storage_t storage){
  * \param storage a storage
  * \return the used space size of the storage element (as a #sg_size_t)
  */
-sg_size_t MSG_storage_get_used_size(msg_storage_t storage){
-  return simcall_storage_get_used_size(storage);
+sg_size_t MSG_storage_get_used_size(msg_storage_t storage)
+{
+  return storage->sizeUsed();
 }
 
 /** \ingroup msg_storage_management
@@ -474,7 +390,7 @@ sg_size_t MSG_storage_get_used_size(msg_storage_t storage){
 xbt_dict_t MSG_storage_get_properties(msg_storage_t storage)
 {
   xbt_assert((storage != nullptr), "Invalid parameters (storage is nullptr)");
-  return (simcall_storage_get_properties(storage));
+  return storage->properties();
 }
 
 /** \ingroup msg_storage_management
@@ -486,7 +402,7 @@ xbt_dict_t MSG_storage_get_properties(msg_storage_t storage)
  */
 void MSG_storage_set_property_value(msg_storage_t storage, const char* name, char* value)
 {
-  xbt_dict_set(MSG_storage_get_properties(storage), name, value, nullptr);
+  storage->setProperty(name, value);
 }
 
 /** \ingroup m_storage_management
@@ -498,7 +414,7 @@ void MSG_storage_set_property_value(msg_storage_t storage, const char* name, cha
  */
 const char *MSG_storage_get_property_value(msg_storage_t storage, const char *name)
 {
-  return static_cast<char*>(xbt_dict_get_or_null(MSG_storage_get_properties(storage), name));
+  return storage->property(name);
 }
 
 /** \ingroup msg_storage_management
@@ -508,24 +424,19 @@ const char *MSG_storage_get_property_value(msg_storage_t storage, const char *na
  */
 msg_storage_t MSG_storage_get_by_name(const char *name)
 {
-  return static_cast<msg_storage_t>(xbt_lib_get_elm_or_null(storage_lib,name));
+  return simgrid::s4u::Storage::byName(name);
 }
 
 /** \ingroup msg_storage_management
  * \brief Returns a dynar containing all the storage elements declared at a given point of time
  */
-xbt_dynar_t MSG_storages_as_dynar() {
-  xbt_lib_cursor_t cursor;
-  char *key;
-  void **data;
+xbt_dynar_t MSG_storages_as_dynar()
+{
+  std::map<std::string, simgrid::s4u::Storage*>* storage_map = simgrid::s4u::allStorages();
   xbt_dynar_t res = xbt_dynar_new(sizeof(msg_storage_t),nullptr);
-
-  xbt_lib_foreach(storage_lib, cursor, key, data) {
-    if(xbt_lib_get_level(xbt_lib_get_elm_or_null(storage_lib, key), MSG_STORAGE_LEVEL) != nullptr) {
-      xbt_dictelm_t elm = xbt_dict_cursor_get_elm(cursor);
-      xbt_dynar_push(res, &elm);
-    }
-  }
+  for (auto s : *storage_map)
+    xbt_dynar_push(res, &(s.second));
+  delete storage_map;
   return res;
 }
 
@@ -536,8 +447,7 @@ xbt_dynar_t MSG_storages_as_dynar() {
  */
 msg_error_t MSG_storage_set_data(msg_storage_t storage, void *data)
 {
-  msg_storage_priv_t priv = MSG_storage_priv(storage);
-  priv->data = data;
+  storage->setUserdata(data);
   return MSG_OK;
 }
 
@@ -550,8 +460,7 @@ msg_error_t MSG_storage_set_data(msg_storage_t storage, void *data)
 void *MSG_storage_get_data(msg_storage_t storage)
 {
   xbt_assert((storage != nullptr), "Invalid parameters");
-  msg_storage_priv_t priv = MSG_storage_priv(storage);
-  return priv->data;
+  return storage->userdata();
 }
 
 /** \ingroup msg_storage_management
@@ -562,7 +471,15 @@ void *MSG_storage_get_data(msg_storage_t storage)
  */
 xbt_dict_t MSG_storage_get_content(msg_storage_t storage)
 {
-  return SIMIX_storage_get_content(storage);
+  std::map<std::string, sg_size_t>* content = storage->content();
+  xbt_dict_t content_dict = xbt_dict_new_homogeneous(&free);
+
+  for (auto entry : *content) {
+    sg_size_t* psize = static_cast<sg_size_t*>(malloc(sizeof(sg_size_t)));
+    *psize           = entry.second;
+    xbt_dict_set(content_dict, entry.first.c_str(), psize, nullptr);
+  }
+  return content_dict;
 }
 
 /** \ingroup msg_storage_management
@@ -573,7 +490,7 @@ xbt_dict_t MSG_storage_get_content(msg_storage_t storage)
  */
 sg_size_t MSG_storage_get_size(msg_storage_t storage)
 {
-  return SIMIX_storage_get_size(storage);
+  return storage->size();
 }
 
 /** \ingroup msg_storage_management
@@ -582,8 +499,10 @@ sg_size_t MSG_storage_get_size(msg_storage_t storage)
  *
  * This functions checks whether a storage is a valid pointer or not and return its name.
  */
-const char *MSG_storage_get_host(msg_storage_t storage) {
+const char* MSG_storage_get_host(msg_storage_t storage)
+{
   xbt_assert((storage != nullptr), "Invalid parameters");
-  msg_storage_priv_t priv = MSG_storage_priv(storage);
-  return priv->hostname;
+  return storage->host()->cname();
 }
+
+SG_END_DECL()
