@@ -1,5 +1,4 @@
-/* Copyright (c) 2004-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -9,24 +8,28 @@
 
 #include "simgrid/msg.h"
 
-#include "src/kernel/activity/SynchroExec.hpp"
-#include "src/kernel/activity/SynchroComm.hpp"
-
-SG_BEGIN_DECL()
+#include "src/kernel/activity/CommImpl.hpp"
+#include "src/kernel/activity/ExecImpl.hpp"
+#include "xbt/Extendable.hpp"
 
 /**************** datatypes **********************************/
-/********************************* Host **************************************/
-typedef struct s_msg_host_priv {
-  std::vector<int> *file_descriptor_table;
-} s_msg_host_priv_t;
+/**************************** Host Extension *********************************/
+namespace simgrid {
+class MsgHostExt {
+public:
+  static simgrid::xbt::Extension<s4u::Host, MsgHostExt> EXTENSION_ID;
+
+  ~MsgHostExt() {
+    delete file_descriptor_table;
+  }
+  std::vector<int>* file_descriptor_table = nullptr; // Created lazily on need
+};
+}
 /********************************* Task **************************************/
 
 typedef struct simdata_task {
   ~simdata_task()
   {
-    if (this->compute)
-      this->compute->unref();
-
     /* parallel tasks only */
     xbt_free(this->host_list);
   }
@@ -36,16 +39,17 @@ typedef struct simdata_task {
     this->isused = false;
   }
 
-  simgrid::kernel::activity::Exec *compute = nullptr; /* SIMIX modeling of computation */
-  simgrid::kernel::activity::Comm *comm = nullptr;    /* SIMIX modeling of communication */
+  simgrid::kernel::activity::ExecImplPtr compute = nullptr; /* SIMIX modeling of computation */
+  simgrid::kernel::activity::CommImplPtr comm    = nullptr; /* SIMIX modeling of communication */
   double bytes_amount = 0.0; /* Data size */
   double flops_amount = 0.0; /* Computation size */
   msg_process_t sender = nullptr;
   msg_process_t receiver = nullptr;
   msg_host_t source = nullptr;
-  double priority = 0.0;
-  double bound = 0.0; /* Capping for CPU resource */
-  double rate = 0.0;  /* Capping for network resource */
+
+  double priority = 1.0;
+  double bound    = 0.0; /* Capping for CPU resource, or 0 for no capping */
+  double rate     = -1;  /* Capping for network resource, or -1 for no capping*/
 
   bool isused = false;  /* Indicates whether the task is used in SIMIX currently */
   int host_nb = 0;      /* ==0 if sequential task; parallel task if not */
@@ -63,37 +67,30 @@ typedef struct simdata_file {
   smx_file_t smx_file;
 } s_simdata_file_t;
 
-XBT_PRIVATE int __MSG_host_get_file_descriptor_id(msg_host_t host);
-XBT_PRIVATE void __MSG_host_release_file_descriptor_id(msg_host_t host, int id);
-
 /******************************* Process *************************************/
 
-typedef struct simdata_process {
-  msg_host_t m_host;              /* the host on which the process is running */
-  msg_host_t put_host;            /* used for debugging purposes */
-  smx_activity_t waiting_action;
-  msg_task_t waiting_task;
-  msg_error_t last_errno;       /* the last value returned by a MSG_function */
+namespace simgrid {
+namespace msg {
+class ActorExt {
+public:
+  explicit ActorExt(void* d) : data(d) {}
+  msg_error_t errno_ = MSG_OK;  /* the last value returned by a MSG_function */
+  void* data = nullptr; /* user data */
+};
 
-  void* data;                   /* user data */
-} s_simdata_process_t, *simdata_process_t;
-
-typedef struct process_arg {
-  const char *name;
-  xbt_main_func_t code;
-  void *data;
-  msg_host_t m_host;
-  int argc;
-  char **argv;
-  double kill_time;
-} s_process_arg_t, *process_arg_t;
-
-typedef struct msg_comm {
-  smx_activity_t s_comm;          /* SIMIX communication object encapsulated (the same for both processes) */
+class Comm {
+public:
   msg_task_t task_sent;           /* task sent (NULL for the receiver) */
   msg_task_t *task_received;      /* where the task will be received (NULL for the sender) */
-  msg_error_t status;           /* status of the communication once finished */
-} s_msg_comm_t;
+  smx_activity_t s_comm;          /* SIMIX communication object encapsulated (the same for both processes) */
+  msg_error_t status = MSG_OK;    /* status of the communication once finished */
+  Comm(msg_task_t sent, msg_task_t* received, smx_activity_t comm)
+      : task_sent(sent), task_received(received), s_comm(std::move(comm))
+  {
+  }
+};
+}
+}
 
 /************************** Global variables ********************************/
 typedef struct MSG_Global {
@@ -101,28 +98,24 @@ typedef struct MSG_Global {
   unsigned long int sent_msg;   /* Total amount of messages sent during the simulation */
   void (*task_copy_callback) (msg_task_t task, msg_process_t src, msg_process_t dst);
   void_f_pvoid_t process_data_cleanup;
-} s_MSG_Global_t, *MSG_Global_t;
+} s_MSG_Global_t;
+typedef s_MSG_Global_t* MSG_Global_t;
+
+SG_BEGIN_DECL()
 
-/*extern MSG_Global_t msg_global;*/
 XBT_PUBLIC_DATA(MSG_Global_t) msg_global;
 
 /*************************************************************/
+
 XBT_PRIVATE msg_host_t __MSG_host_create(sg_host_t host);
-XBT_PRIVATE msg_storage_t __MSG_storage_create(smx_storage_t storage);
-XBT_PRIVATE void __MSG_host_priv_free(msg_host_priv_t priv);
-XBT_PRIVATE void __MSG_storage_destroy(msg_storage_priv_t host);
-XBT_PRIVATE void __MSG_file_destroy(msg_file_priv_t host);
+XBT_PRIVATE void __MSG_file_destroy(msg_file_t file);
 
 XBT_PRIVATE void MSG_process_cleanup_from_SIMIX(smx_actor_t smx_proc);
-XBT_PRIVATE smx_actor_t MSG_process_create_from_SIMIX(const char *name,
-                                   std::function<void()> code, void *data,
-                                   sg_host_t host, double kill_time,
-                                   xbt_dict_t properties, int auto_restart,
-                                   smx_actor_t parent_process);
+XBT_PRIVATE smx_actor_t MSG_process_create_from_SIMIX(const char* name, std::function<void()> code, void* data,
+                                                      sg_host_t host, xbt_dict_t properties,
+                                                      smx_actor_t parent_process);
 XBT_PRIVATE void MSG_comm_copy_data_from_SIMIX(smx_activity_t comm, void* buff, size_t buff_size);
 
-XBT_PRIVATE void MSG_post_create_environment();
-
 XBT_PRIVATE void MSG_host_add_task(msg_host_t host, msg_task_t task);
 XBT_PRIVATE void MSG_host_del_task(msg_host_t host, msg_task_t task);
 
@@ -152,10 +145,6 @@ XBT_PRIVATE void TRACE_msg_process_sleep_out(msg_process_t process);
 
 SG_END_DECL()
 
-XBT_PUBLIC(msg_process_t) MSG_process_create_with_environment(
-  const char *name, std::function<void()> code, void *data,
-  msg_host_t host, xbt_dict_t properties);
-
 inline void simdata_task::setUsed()
 {
   if (this->isused)
