@@ -6,6 +6,8 @@
 #include "msg_private.h"
 #include "src/simix/smx_private.h"
 
+SG_BEGIN_DECL()
+
 /** @addtogroup m_task_management
  *
  *  Since most scheduling algorithms rely on a concept of task  that can be either <em>computed</em> locally or
@@ -56,22 +58,9 @@ msg_task_t MSG_task_create(const char *name, double flop_amount, double message_
   task->data = data;
 
   /* Simulator Data */
-  simdata->compute = nullptr;
-  simdata->comm = nullptr;
   simdata->bytes_amount = message_size;
   simdata->flops_amount = flop_amount;
-  simdata->sender = nullptr;
-  simdata->receiver = nullptr;
-  simdata->source = nullptr;
-  simdata->priority = 1.0;
-  simdata->bound = 0;
-  simdata->rate = -1.0;
-  simdata->isused = 0;
 
-  simdata->host_nb = 0;
-  simdata->host_list = nullptr;
-  simdata->flops_parallel_amount = nullptr;
-  simdata->bytes_parallel_amount = nullptr;
   TRACE_msg_task_create(task);
 
   return task;
@@ -276,7 +265,7 @@ void MSG_task_set_bytes_amount(msg_task_t task, double data_size)
  */
 double MSG_task_get_remaining_communication(msg_task_t task)
 {
-  XBT_DEBUG("calling simcall_communication_get_remains(%p)", task->simdata->comm);
+  XBT_DEBUG("calling simcall_communication_get_remains(%p)", task->simdata->comm.get());
   return task->simdata->comm->remains();
 }
 
@@ -315,3 +304,5 @@ void MSG_task_set_bound(msg_task_t task, double bound)
   if (task->simdata->compute)
     simcall_execution_set_bound(task->simdata->compute, task->simdata->bound);
 }
+
+SG_END_DECL()
