@@ -1,5 +1,4 @@
-/* Copyright (c) 2006-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,33 +6,39 @@
 #include "xbt/log.h"
 #include "src/msg/msg_private.h"
 
-#include "simgrid/s4u/comm.hpp"
-#include <simgrid/s4u/Mailbox.hpp>
-
+#include "simgrid/s4u/Comm.hpp"
+#include "simgrid/s4u/Mailbox.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_comm,s4u_activity,"S4U asynchronous communications");
 
 namespace simgrid {
 namespace s4u {
-
-Comm::~Comm() {
-
+Comm::~Comm()
+{
+  if (state_ == started && not detached_ && (pimpl_ == nullptr || pimpl_->state == SIMIX_RUNNING)) {
+    XBT_INFO("Comm %p freed before its completion. Detached: %d, State: %d", this, detached_, state_);
+    if (pimpl_ != nullptr)
+      XBT_INFO("pimpl_->state: %d", pimpl_->state);
+    else
+      XBT_INFO("pimpl_ is null");
+    xbt_backtrace_display_current();
+  }
 }
 
-
-
-s4u::Comm &Comm::send_init(s4u::MailboxPtr chan) {
-  s4u::Comm *res = new s4u::Comm();
+s4u::CommPtr Comm::send_init(s4u::MailboxPtr chan)
+{
+  CommPtr res   = CommPtr(new s4u::Comm());
   res->sender_ = SIMIX_process_self();
   res->mailbox_ = chan;
-  return *res;
+  return res;
 }
 
-s4u::Comm &Comm::recv_init(s4u::MailboxPtr chan) {
-  s4u::Comm *res = new s4u::Comm();
+s4u::CommPtr Comm::recv_init(s4u::MailboxPtr chan)
+{
+  CommPtr res    = CommPtr(new s4u::Comm());
   res->receiver_ = SIMIX_process_self();
   res->mailbox_ = chan;
-  return *res;
+  return res;
 }
 
 void Comm::setRate(double rate) {
@@ -83,6 +88,7 @@ void Comm::start() {
         matchFunction_, cleanFunction_, copyDataFunction_,
         userData_, detached_);
   } else if (dstBuff_ != nullptr) { // Receiver side
+    xbt_assert(not detached_, "Receive cannot be detached");
     pimpl_ = simcall_comm_irecv(receiver_, mailbox_->getImpl(), dstBuff_, &dstBuffSize_,
         matchFunction_, copyDataFunction_,
         userData_, rate_);
@@ -97,7 +103,7 @@ void Comm::wait() {
 
   if (state_ == started)
     simcall_comm_wait(pimpl_, -1/*timeout*/);
-  else {// p_state == inited. Save a simcall and do directly a blocking send/recv
+  else { // state_ == inited. Save a simcall and do directly a blocking send/recv
     if (srcBuff_ != nullptr) {
       simcall_comm_send(sender_, mailbox_->getImpl(), remains_, rate_,
           srcBuff_, srcBuffSize_,
@@ -110,8 +116,8 @@ void Comm::wait() {
     }
   }
   state_ = finished;
-  delete this;
 }
+
 void Comm::wait(double timeout) {
   xbt_assert(state_ == started || state_ == inited);
 
@@ -133,42 +139,70 @@ void Comm::wait(double timeout) {
         userData_, timeout, rate_);
   }
   state_ = finished;
-  delete this;
 }
 
-s4u::Comm &Comm::send_async(MailboxPtr dest, void *data, int simulatedSize) {
-  s4u::Comm &res = s4u::Comm::send_init(dest);
-  res.setRemains(simulatedSize);
-  res.srcBuff_ = data;
-  res.srcBuffSize_ = sizeof(void*);
-  res.start();
+void Comm::send_detached(MailboxPtr dest, void* data, int simulatedSize)
+{
+  s4u::CommPtr res = CommPtr(s4u::Comm::send_init(dest));
+  res->setRemains(simulatedSize);
+  res->srcBuff_     = data;
+  res->srcBuffSize_ = sizeof(void*);
+  res->detached_    = true;
+  res->start();
+}
+
+s4u::CommPtr Comm::send_async(MailboxPtr dest, void* data, int simulatedSize)
+{
+  s4u::CommPtr res = CommPtr(s4u::Comm::send_init(dest));
+  res->setRemains(simulatedSize);
+  res->srcBuff_     = data;
+  res->srcBuffSize_ = sizeof(void*);
+  res->start();
   return res;
 }
 
-s4u::Comm &Comm::recv_async(MailboxPtr dest, void **data) {
-  s4u::Comm &res = s4u::Comm::recv_init(dest);
-  res.setDstData(data);
-  res.start();
+s4u::CommPtr Comm::recv_async(MailboxPtr dest, void** data)
+{
+  s4u::CommPtr res = CommPtr(s4u::Comm::recv_init(dest));
+  res->setDstData(data, sizeof(*data));
+  res->start();
   return res;
 }
 
+void Comm::cancel()
+{
+  simgrid::kernel::activity::CommImplPtr commPimpl =
+      boost::static_pointer_cast<simgrid::kernel::activity::CommImpl>(pimpl_);
+  commPimpl->cancel();
+}
+
 bool Comm::test() {
   xbt_assert(state_ == inited || state_ == started || state_ == finished);
-  
-  if (state_ == finished) 
+
+  if (state_ == finished)
     xbt_die("Don't call test on a finished comm.");
-  
+
   if (state_ == inited) {
     this->start();
   }
-  
+
   if(simcall_comm_test(pimpl_)){
     state_ = finished;
-    delete this;
     return true;
   }
   return false;
 }
 
+void intrusive_ptr_release(simgrid::s4u::Comm* c)
+{
+  if (c->refcount_.fetch_sub(1, std::memory_order_release) == 1) {
+    std::atomic_thread_fence(std::memory_order_acquire);
+    delete c;
+  }
+}
+void intrusive_ptr_add_ref(simgrid::s4u::Comm* c)
+{
+  c->refcount_.fetch_add(1, std::memory_order_relaxed);
 }
 }
+} // namespaces
