@@ -1,30 +1,31 @@
 /* s4u::Engine Simulation Engine and global functions. */
 
-/* Copyright (c) 2006-2015. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "instr/instr_interface.h"
 #include "mc/mc.h"
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/Host.hpp"
 #include "simgrid/s4u/Mailbox.hpp"
 #include "simgrid/s4u/NetZone.hpp"
-#include "simgrid/s4u/engine.hpp"
-#include "simgrid/s4u/host.hpp"
-#include "simgrid/s4u/storage.hpp"
+#include "simgrid/s4u/Storage.hpp"
 #include "simgrid/simix.h"
 #include "src/kernel/EngineImpl.hpp"
+#include "src/kernel/routing/NetPoint.hpp"
 #include "src/kernel/routing/NetZoneImpl.hpp"
-#include "src/kernel/routing/NetCard.hpp"
-
-
 #include "src/surf/network_interface.hpp"
-#include "surf/surf.h"               // routing_platf. FIXME:KILLME. SOON
+#include "surf/surf.h" // routing_platf. FIXME:KILLME. SOON
 
 XBT_LOG_NEW_CATEGORY(s4u,"Log channels of the S4U (Simgrid for you) interface");
 
 namespace simgrid {
 namespace s4u {
+xbt::signal<void()> onPlatformCreated;
+xbt::signal<void()> onSimulationEnd;
+xbt::signal<void(double)> onTimeAdvance;
 
 Engine *Engine::instance_ = nullptr; /* That singleton is awful, but I don't see no other solution right now. */
 
@@ -52,7 +53,6 @@ Engine *Engine::instance() {
 void Engine::shutdown() {
   delete s4u::Engine::instance_;
   s4u::Engine::instance_ = nullptr;
-  delete s4u::Storage::storages_;
 }
 
 double Engine::getClock()
@@ -77,6 +77,19 @@ void Engine::loadDeployment(const char *deploy)
 {
   SIMIX_launch_application(deploy);
 }
+// FIXME: The following duplicates the content of s4u::Host
+extern std::map<std::string, simgrid::s4u::Host*> host_list;
+/** @brief Returns the amount of hosts in the platform */
+size_t Engine::hostCount()
+{
+  return host_list.size();
+}
+/** @brief Fills the passed list with all hosts found in the platform */
+void Engine::hostList(std::vector<Host*>* list)
+{
+  for (auto kv : host_list)
+    list->push_back(kv.second);
+}
 
 void Engine::run() {
   if (MC_is_active()) {
@@ -93,16 +106,14 @@ s4u::NetZone* Engine::netRoot()
 
 static s4u::NetZone* netzoneByNameRecursive(s4u::NetZone* current, const char* name)
 {
-  if(!strcmp(current->name(), name))
+  if (not strcmp(current->name(), name))
     return current;
 
-  xbt_dict_cursor_t cursor = nullptr;
-  char *key;
-  NetZone_t elem;
-  xbt_dict_foreach(current->children(), cursor, key, elem) {
+  for (auto elem : *(current->children())) {
     simgrid::s4u::NetZone* tmp = netzoneByNameRecursive(elem, name);
-    if (tmp != nullptr )
-        return tmp;
+    if (tmp != nullptr) {
+      return tmp;
+    }
   }
   return nullptr;
 }
@@ -113,33 +124,38 @@ NetZone* Engine::netzoneByNameOrNull(const char* name)
   return netzoneByNameRecursive(netRoot(), name);
 }
 
-/** @brief Retrieve the netcard of the given name (or nullptr if not found) */
-simgrid::kernel::routing::NetCard* Engine::netcardByNameOrNull(const char* name)
+/** @brief Retrieve the netpoint of the given name (or nullptr if not found) */
+simgrid::kernel::routing::NetPoint* Engine::netpointByNameOrNull(const char* name)
 {
-  if (pimpl->netcards_.find(name) == pimpl->netcards_.end())
+  if (pimpl->netpoints_.find(name) == pimpl->netpoints_.end())
     return nullptr;
-  return pimpl->netcards_.at(name);
+  return pimpl->netpoints_.at(name);
 }
-/** @brief Fill the provided vector with all existing netcards */
-void Engine::netcardList(std::vector<simgrid::kernel::routing::NetCard*>* list)
+/** @brief Fill the provided vector with all existing netpoints */
+void Engine::netpointList(std::vector<simgrid::kernel::routing::NetPoint*>* list)
 {
-  for (auto kv: pimpl->netcards_)
+  for (auto kv : pimpl->netpoints_)
     list->push_back(kv.second);
 }
-/** @brief Register a new netcard to the system */
-void Engine::netcardRegister(simgrid::kernel::routing::NetCard* card)
+/** @brief Register a new netpoint to the system */
+void Engine::netpointRegister(simgrid::kernel::routing::NetPoint* point)
 {
 //  simgrid::simix::kernelImmediate([&]{ FIXME: this segfaults in set_thread
-      pimpl->netcards_[card->name()] = card;
+  pimpl->netpoints_[point->name()] = point;
 //  });
 }
-/** @brief Unregister a given netcard */
-void Engine::netcardUnregister(simgrid::kernel::routing::NetCard* card)
+/** @brief Unregister a given netpoint */
+void Engine::netpointUnregister(simgrid::kernel::routing::NetPoint* point)
 {
-  simgrid::simix::kernelImmediate([&]{
-      pimpl->netcards_.erase(card->name());
-      delete card;
+  simgrid::simix::kernelImmediate([this, point] {
+    pimpl->netpoints_.erase(point->name());
+    delete point;
   });
 }
+
+bool Engine::isInitialized()
+{
+  return Engine::instance_ != nullptr;
 }
 }
+} // namespace
