@@ -1,5 +1,4 @@
-/* Copyright (c) 2006-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,13 +7,13 @@
 #include <functional>
 #include <stdexcept>
 
-#include <unordered_map>
+#include <map>
 
-#include "simgrid/s4u/engine.hpp"
-#include "simgrid/s4u/host.hpp"
-#include "simgrid/s4u/storage.hpp"
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/Host.hpp"
+#include "simgrid/s4u/Storage.hpp"
 #include "simgrid/simix.hpp"
-#include "src/kernel/routing/NetCard.hpp"
+#include "src/kernel/routing/NetPoint.hpp"
 #include "src/msg/msg_private.h"
 #include "src/simix/ActorImpl.hpp"
 #include "src/simix/smx_private.h"
@@ -24,9 +23,6 @@
 
 XBT_LOG_EXTERNAL_CATEGORY(surf_route);
 
-std::unordered_map<std::string, simgrid::s4u::Host*> host_list; // FIXME: move it to Engine
-
-int MSG_HOST_LEVEL = -1;
 int USER_HOST_LEVEL = -1;
 
 namespace simgrid {
@@ -37,15 +33,19 @@ template class Extendable<simgrid::s4u::Host>;
 
 namespace s4u {
 
+std::map<std::string, simgrid::s4u::Host*> host_list; // FIXME: move it to Engine
+
 simgrid::xbt::signal<void(Host&)> Host::onCreation;
 simgrid::xbt::signal<void(Host&)> Host::onDestruction;
 simgrid::xbt::signal<void(Host&)> Host::onStateChange;
+simgrid::xbt::signal<void(Host&)> Host::onSpeedChange;
 
 Host::Host(const char* name)
   : name_(name)
 {
   xbt_assert(Host::by_name_or_null(name) == nullptr, "Refusing to create a second host named '%s'.", name);
   host_list[name_] = this;
+  new simgrid::surf::HostImpl(this);
 }
 
 Host::~Host()
@@ -53,8 +53,8 @@ Host::~Host()
   xbt_assert(currentlyDestroying_, "Please call h->destroy() instead of manually deleting it.");
 
   delete pimpl_;
-  if (pimpl_netcard != nullptr) // not removed yet by a children class
-    simgrid::s4u::Engine::instance()->netcardUnregister(pimpl_netcard);
+  if (pimpl_netpoint != nullptr) // not removed yet by a children class
+    simgrid::s4u::Engine::instance()->netpointUnregister(pimpl_netpoint);
   delete pimpl_cpu;
   delete mounts;
 }
@@ -69,7 +69,7 @@ Host::~Host()
  */
 void Host::destroy()
 {
-  if (!currentlyDestroying_) {
+  if (not currentlyDestroying_) {
     currentlyDestroying_ = true;
     onDestruction(*this);
     host_list.erase(name_);
@@ -101,16 +101,21 @@ Host *Host::current(){
 
 void Host::turnOn() {
   if (isOff()) {
-    simgrid::simix::kernelImmediate([&]{
+    simgrid::simix::kernelImmediate([this] {
       this->extension<simgrid::simix::Host>()->turnOn();
       this->pimpl_cpu->turnOn();
+      onStateChange(*this);
     });
   }
 }
 
 void Host::turnOff() {
   if (isOn()) {
-    simgrid::simix::kernelImmediate(std::bind(SIMIX_host_off, this, SIMIX_process_self()));
+    smx_actor_t self = SIMIX_process_self();
+    simgrid::simix::kernelImmediate([this, self] {
+      SIMIX_host_off(this, self);
+      onStateChange(*this);
+    });
   }
 }
 
@@ -122,6 +127,20 @@ int Host::pstatesCount() const {
   return this->pimpl_cpu->getNbPStates();
 }
 
+/**
+ * \brief Return the list of actors attached to an host.
+ *
+ * \param whereto a vector in which we should push actors living on that host
+ */
+void Host::actorList(std::vector<ActorPtr>* whereto)
+{
+  smx_actor_t actor = NULL;
+  xbt_swag_foreach(actor, this->extension<simgrid::simix::Host>()->process_list)
+  {
+    whereto->push_back(actor->ciface());
+  }
+}
+
 /**
  * \brief Find a route toward another host
  *
@@ -136,74 +155,64 @@ int Host::pstatesCount() const {
  */
 void Host::routeTo(Host* dest, std::vector<Link*>* links, double* latency)
 {
-  simgrid::kernel::routing::NetZoneImpl::getGlobalRoute(pimpl_netcard, dest->pimpl_netcard, links, latency);
+  std::vector<surf::LinkImpl*> linkImpls;
+  this->routeTo(dest, &linkImpls, latency);
+  for (surf::LinkImpl* l : linkImpls)
+    links->push_back(&l->piface_);
+}
+
+/** @brief Just like Host::routeTo, but filling an array of link implementations */
+void Host::routeTo(Host* dest, std::vector<surf::LinkImpl*>* links, double* latency)
+{
+  simgrid::kernel::routing::NetZoneImpl::getGlobalRoute(pimpl_netpoint, dest->pimpl_netpoint, links, latency);
   if (XBT_LOG_ISENABLED(surf_route, xbt_log_priority_debug)) {
     XBT_CDEBUG(surf_route, "Route from '%s' to '%s' (latency: %f):", cname(), dest->cname(),
                (latency == nullptr ? -1 : *latency));
     for (auto link : *links)
-      XBT_CDEBUG(surf_route, "Link %s", link->getName());
+      XBT_CDEBUG(surf_route, "Link %s", link->cname());
   }
 }
 
-boost::unordered_map<std::string, Storage*> const& Host::mountedStorages() {
-  if (mounts == nullptr) {
-    mounts = new boost::unordered_map<std::string, Storage*> ();
-
-    xbt_dict_t dict = this->mountedStoragesAsDict();
-
-    xbt_dict_cursor_t cursor;
-    char *mountname;
-    char *storagename;
-    xbt_dict_foreach(dict, cursor, mountname, storagename) {
-      mounts->insert({mountname, &Storage::byName(storagename)});
-    }
-    xbt_dict_free(&dict);
-  }
-
-  return *mounts;
-}
-
 /** Get the properties assigned to a host */
 xbt_dict_t Host::properties() {
-  return simgrid::simix::kernelImmediate([&] { return this->pimpl_->getProperties(); });
+  return simgrid::simix::kernelImmediate([this] {
+    return this->pimpl_->getProperties();
+  });
 }
 
 /** Retrieve the property value (or nullptr if not set) */
-const char*Host::property(const char*key) {
+const char* Host::property(const char* key)
+{
   return this->pimpl_->getProperty(key);
 }
-void Host::setProperty(const char*key, const char *value){
-  simgrid::simix::kernelImmediate([&] { this->pimpl_->setProperty(key, value); });
+
+void Host::setProperty(const char* key, const char* value)
+{
+  simgrid::simix::kernelImmediate([this, key, value] { this->pimpl_->setProperty(key, value); });
 }
 
 /** Get the processes attached to the host */
-xbt_swag_t Host::processes()
+void Host::processes(std::vector<ActorPtr>* list)
 {
-  return simgrid::simix::kernelImmediate([&]() {
-    return this->extension<simgrid::simix::Host>()->process_list;
-  });
+  smx_actor_t actor = NULL;
+  xbt_swag_foreach(actor, this->extension<simgrid::simix::Host>()->process_list) {
+    list->push_back(actor->iface());
+  }
 }
 
-/** Get the peak power of a host */
-double Host::getPstateSpeedCurrent()
-{
-  return simgrid::simix::kernelImmediate([&] {
-    return this->pimpl_cpu->getPstateSpeedCurrent();
-  });
-}
-
-/** Get one power peak (in flops/s) of a host at a given pstate */
+/** @brief Get the peak processor speed (in flops/s), at the specified pstate  */
 double Host::getPstateSpeed(int pstate_index)
 {
-  return simgrid::simix::kernelImmediate([&] {
+  return simgrid::simix::kernelImmediate([this, pstate_index] {
     return this->pimpl_cpu->getPstateSpeed(pstate_index);
   });
 }
 
-/** @brief Get the speed of the cpu associated to a host */
+/** @brief Get the peak processor speed (in flops/s), at the current pstate */
 double Host::speed() {
   return pimpl_cpu->getSpeed(1.0);
 }
+
 /** @brief Returns the number of core of the processor. */
 int Host::coreCount() {
   return pimpl_cpu->coreCount();
@@ -212,34 +221,37 @@ int Host::coreCount() {
 /** @brief Set the pstate at which the host should run */
 void Host::setPstate(int pstate_index)
 {
-  simgrid::simix::kernelImmediate(std::bind(
-      &simgrid::surf::Cpu::setPState, pimpl_cpu, pstate_index
-  ));
+  simgrid::simix::kernelImmediate([this, pstate_index] {
+      this->pimpl_cpu->setPState(pstate_index);
+  });
 }
 /** @brief Retrieve the pstate at which the host is currently running */
 int Host::pstate()
 {
-  return pimpl_cpu->getPState();
-}
-
-/**
- * \ingroup simix_storage_management
- * \brief Returns the list of storages mounted on an host.
- * \return a dict containing all storages mounted on the host
- */
-xbt_dict_t Host::mountedStoragesAsDict()
-{
-  return simgrid::simix::kernelImmediate([&] { return this->pimpl_->getMountedStorageList(); });
+  return this->pimpl_cpu->getPState();
 }
 
 /**
  * \ingroup simix_storage_management
  * \brief Returns the list of storages attached to an host.
- * \return a dict containing all storages attached to the host
+ * \return a vector containing all storages attached to the host
  */
-xbt_dynar_t Host::attachedStorages()
+void Host::attachedStorages(std::vector<const char*>* storages)
 {
-  return simgrid::simix::kernelImmediate([&] { return this->pimpl_->getAttachedStorageList(); });
+  simgrid::simix::kernelImmediate([this, storages] {
+     this->pimpl_->getAttachedStorageList(storages);
+  });
+}
+
+std::unordered_map<std::string, Storage*> const& Host::mountedStorages()
+{
+  if (mounts == nullptr) {
+    mounts = new std::unordered_map<std::string, Storage*>();
+    for (auto m : this->pimpl_->storage_) {
+      mounts->insert({m.first, &m.second->piface_});
+    }
+  }
+  return *mounts;
 }
 
 } // namespace simgrid
