@@ -1,12 +1,10 @@
-/* Copyright (c) 2006-2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "simdag_private.hpp"
-#include "simgrid/host.h"
-#include "simgrid/s4u/engine.hpp"
+#include "simgrid/s4u/Engine.hpp"
 #include "simgrid/sg_config.h"
 #include "src/include/instr/instr_interface.h"
 #include "src/surf/surf_interface.hpp"
@@ -40,13 +38,14 @@ std::set<SD_task_t>* simulate(double how_long){
   sd_global->return_set->clear();
 
   /* explore the runnable tasks */
-  while(!sd_global->runnable_tasks->empty())
+  while (not sd_global->runnable_tasks->empty())
     SD_task_run(*(sd_global->runnable_tasks->begin()));
 
   double elapsed_time = 0.0;
   double total_time = 0.0;
   /* main loop */
-  while (elapsed_time >= 0 && (how_long < 0 || 0.00001 < (how_long -total_time)) && !sd_global->watch_point_reached) {
+  while (elapsed_time >= 0 && (how_long < 0 || 0.00001 < (how_long - total_time)) &&
+         not sd_global->watch_point_reached) {
 
     XBT_DEBUG("Total time: %f", total_time);
 
@@ -56,7 +55,7 @@ std::set<SD_task_t>* simulate(double how_long){
       total_time += elapsed_time;
 
     /* let's see which tasks are done */
-    for (auto model : *all_existing_models) {
+    for (const auto& model : *all_existing_models) {
       surf_action_t action = surf_model_extract_done_action_set(model);
       while (action != nullptr) {
         SD_task_t task = static_cast<SD_task_t>(action->getData());
@@ -68,7 +67,7 @@ std::set<SD_task_t>* simulate(double how_long){
           sd_global->return_set->insert(task);
 
         /* remove the dependencies after this task */
-        for (auto succ : *task->successors) {
+        for (const auto& succ : *task->successors) {
           succ->predecessors->erase(task);
           succ->inputs->erase(task);
           XBT_DEBUG("Release dependency on %s: %zu remain(s). Becomes schedulable if %zu=0", SD_task_get_name(succ),
@@ -80,12 +79,12 @@ std::set<SD_task_t>* simulate(double how_long){
           if (SD_task_get_state(succ) == SD_SCHEDULED && succ->predecessors->empty() && succ->inputs->empty())
             SD_task_set_state(succ, SD_RUNNABLE);
 
-          if (SD_task_get_state(succ) == SD_RUNNABLE && !sd_global->watch_point_reached)
+          if (SD_task_get_state(succ) == SD_RUNNABLE && not sd_global->watch_point_reached)
             SD_task_run(succ);
         }
         task->successors->clear();
 
-        for (auto output : *task->outputs) {
+        for (const auto& output : *task->outputs) {
           output->start_time = task->finish_time;
           output->predecessors->erase(task);
           if (SD_task_get_state(output) == SD_SCHEDULED)
@@ -99,7 +98,7 @@ std::set<SD_task_t>* simulate(double how_long){
                 SD_task_get_name(output), SD_task_get_name(comm_dst), comm_dst->predecessors->size());
             SD_task_set_state(comm_dst, SD_SCHEDULABLE);
           }
-          if (SD_task_get_state(output) == SD_RUNNABLE && !sd_global->watch_point_reached)
+          if (SD_task_get_state(output) == SD_RUNNABLE && not sd_global->watch_point_reached)
             SD_task_run(output);
         }
         task->outputs->clear();
@@ -118,9 +117,9 @@ std::set<SD_task_t>* simulate(double how_long){
     }
   }
 
-  if (!sd_global->watch_point_reached && how_long < 0 && !sd_global->initial_tasks->empty()) {
+  if (not sd_global->watch_point_reached && how_long < 0 && not sd_global->initial_tasks->empty()) {
     XBT_WARN("Simulation is finished but %zu tasks are still not done", sd_global->initial_tasks->size());
-    for (auto t : *sd_global->initial_tasks)
+    for (const auto& t : *sd_global->initial_tasks)
       XBT_WARN("%s is in %s state", SD_task_get_name(t), __get_state_name(SD_task_get_state(t)));
   }
 
@@ -153,7 +152,7 @@ const char *__get_state_name(e_SD_task_state_t state){
  * \param argv argument list
  * \see SD_create_environment(), SD_exit()
  */
-void SD_init(int *argc, char **argv)
+void SD_init_nocheck(int *argc, char **argv)
 {
   xbt_assert(sd_global == nullptr, "SD_init() already called");
 
@@ -162,9 +161,9 @@ void SD_init(int *argc, char **argv)
   surf_init(argc, argv);
 
   xbt_cfg_setdefault_string("host/model", "ptask_L07");
-
+  if(xbt_cfg_get_boolean("clean-atexit"))
+    atexit(SD_exit);
   if (_sg_cfg_exit_asap) {
-    SD_exit();
     exit(0);
   }
 }
@@ -203,7 +202,7 @@ void SD_create_environment(const char *platform_file)
   simgrid::s4u::Engine::instance()->loadPlatform(platform_file);
 
   XBT_DEBUG("Host number: %zu, link number: %d", sg_host_count(), sg_link_count());
-#if HAVE_JEDULE
+#if SIMGRID_HAVE_JEDULE
   jedule_sd_init();
 #endif
   XBT_VERB("Starting simulation...");
@@ -224,13 +223,16 @@ void SD_create_environment(const char *platform_file)
  * \return a dynar of \ref SD_task_t whose state has changed.
  * \see SD_task_schedule(), SD_task_watch()
  */
+void SD_simulate(double how_long)
+{
+  simgrid::sd::simulate(how_long);
+}
 
-xbt_dynar_t SD_simulate(double how_long) {
+void SD_simulate_with_update(double how_long, xbt_dynar_t changed_tasks_dynar)
+{
   std::set<SD_task_t> *changed_tasks = simgrid::sd::simulate(how_long);
-  xbt_dynar_t changed_tasks_dynar = xbt_dynar_new(sizeof(SD_task_t), nullptr);
-  for (auto task: *changed_tasks)
+  for (const auto& task : *changed_tasks)
     xbt_dynar_push(changed_tasks_dynar, &task);
-  return changed_tasks_dynar;
 }
 
 /** @brief Returns the current clock, in seconds */
@@ -246,7 +248,7 @@ double SD_get_clock() {
 void SD_exit()
 {
   TRACE_end();
-#if HAVE_JEDULE
+#if SIMGRID_HAVE_JEDULE
   jedule_sd_exit();
 #endif
   delete sd_global;
