@@ -12,7 +12,6 @@
 #include "xbt/log.h"
 #include "xbt/mallocator.h"
 #include "xbt/str.h"
-#include "xbt/lib.h"
 #include "xbt/sysdep.h"
 #include "surf/surf.h"
 #include "surf/maxmin.h"
@@ -20,12 +19,10 @@
 #include "simgrid/simix.h"
 #include "simgrid/sg_config.h"
 #include "simgrid_config.h" /* what was compiled in? */
-#if HAVE_SMPI
-#include "smpi/smpi_interface.h"
-#endif
 #include "mc/mc.h"
 #include "simgrid/instr.h"
 #include "src/mc/mc_replay.h"
+#include "src/surf/surf_interface.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_config, surf, "About the configuration of SimGrid");
 
@@ -47,19 +44,20 @@ int _sg_cfg_exit_asap = 0;
 static void sg_config_cmd_line(int *argc, char **argv)
 {
   int shall_exit = 0;
-  int i, j;
+  int i;
+  int j;
 
   for (j = i = 1; i < *argc; i++) {
-    if (!strncmp(argv[i], "--cfg=", strlen("--cfg="))) {
+    if (not strncmp(argv[i], "--cfg=", strlen("--cfg="))) {
       char *opt = strchr(argv[i], '=');
       opt++;
 
       xbt_cfg_set_parse(opt);
       XBT_DEBUG("Did apply '%s' as config setting", opt);
-    } else if (!strcmp(argv[i], "--version")) {
+    } else if (not strcmp(argv[i], "--version")) {
       printf("%s\n", SIMGRID_VERSION_STRING);
       shall_exit = 1;
-    } else if (!strcmp(argv[i], "--cfg-help") || !strcmp(argv[i], "--help")) {
+    } else if (not strcmp(argv[i], "--cfg-help") || not strcmp(argv[i], "--help")) {
       printf("Description of the configuration accepted by this simulator:\n");
       xbt_cfg_help();
       printf(
@@ -77,12 +75,12 @@ static void sg_config_cmd_line(int *argc, char **argv)
           "\n"
         );
       shall_exit = 1;
-    } else if (!strcmp(argv[i], "--help-aliases")) {
+    } else if (not strcmp(argv[i], "--help-aliases")) {
       printf("Here is a list of all deprecated option names, with their replacement.\n");
       xbt_cfg_aliases();
       printf("Please consider using the recent names\n");
       shall_exit = 1;
-    } else if (!strcmp(argv[i], "--help-models")) {
+    } else if (not strcmp(argv[i], "--help-models")) {
       model_help("host", surf_host_model_description);
       printf("\n");
       model_help("CPU", surf_cpu_model_description);
@@ -95,7 +93,7 @@ static void sg_config_cmd_line(int *argc, char **argv)
                surf_optimization_mode_description[k].description);
       printf("Both network and CPU models have 'Lazy' as default optimization level\n\n");
       shall_exit = 1;
-    } else if (!strcmp(argv[i], "--help-tracing")) {
+    } else if (not strcmp(argv[i], "--help-tracing")) {
       TRACE_help (1);
       shall_exit = 1;
     } else {
@@ -119,7 +117,7 @@ static void _sg_cfg_cb__plugin(const char *name)
   if (val==nullptr || val[0] == '\0')
     return;
 
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("plugin", surf_plugin_description);
     sg_cfg_exit_early();
   }
@@ -134,7 +132,7 @@ static void _sg_cfg_cb__host_model(const char *name)
   xbt_assert(_sg_cfg_init_status < 2, "Cannot change the model after the initialization");
 
   char *val = xbt_cfg_get_string(name);
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("host", surf_host_model_description);
     sg_cfg_exit_early();
   }
@@ -149,7 +147,7 @@ static void _sg_cfg_cb__cpu_model(const char *name)
   xbt_assert(_sg_cfg_init_status < 2, "Cannot change the model after the initialization");
 
   char *val = xbt_cfg_get_string(name);
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("CPU", surf_cpu_model_description);
     sg_cfg_exit_early();
   }
@@ -164,7 +162,7 @@ static void _sg_cfg_cb__optimization_mode(const char *name)
   xbt_assert(_sg_cfg_init_status < 2, "Cannot change the model after the initialization");
 
   char *val = xbt_cfg_get_string(name);
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("optimization", surf_optimization_mode_description);
     sg_cfg_exit_early();
   }
@@ -179,7 +177,7 @@ static void _sg_cfg_cb__storage_mode(const char *name)
   xbt_assert(_sg_cfg_init_status < 2, "Cannot change the model after the initialization");
 
   char *val = xbt_cfg_get_string(name);
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("storage", surf_storage_model_description);
     sg_cfg_exit_early();
   }
@@ -193,7 +191,7 @@ static void _sg_cfg_cb__network_model(const char *name)
   xbt_assert(_sg_cfg_init_status < 2, "Cannot change the model after the initialization");
 
   char *val = xbt_cfg_get_string(name);
-  if (!strcmp(val, "help")) {
+  if (not strcmp(val, "help")) {
     model_help("network", surf_network_model_description);
     sg_cfg_exit_early();
   }
@@ -201,64 +199,6 @@ static void _sg_cfg_cb__network_model(const char *name)
   /* New Module missing */
   find_model_description(surf_network_model_description, val);
 }
-
-#if HAVE_SMPI
-/* callback of the mpi collectives: simply check that this is a valid name. It will be picked up in smpi_global.cpp */
-static void _check_coll(const char *category,
-                             s_mpi_coll_description_t * table,
-                             const char *name)
-{
-  xbt_assert(_sg_cfg_init_status < 2, "Cannot change the collective algorithm after the initialization");
-
-  char *val = xbt_cfg_get_string(name);
-  if (val && !strcmp(val, "help")) {
-    coll_help(category, table);
-    sg_cfg_exit_early();
-  }
-
-  find_coll_description(table, val, category);
-}
-static void _check_coll_gather(const char *name){
-  _check_coll("gather", mpi_coll_gather_description, name);
-}
-static void _check_coll_allgather(const char *name){
-  _check_coll("allgather", mpi_coll_allgather_description, name);
-}
-static void _check_coll_allgatherv(const char *name){
-  _check_coll("allgatherv", mpi_coll_allgatherv_description, name);
-}
-static void _check_coll_allreduce(const char *name)
-{
-  _check_coll("allreduce", mpi_coll_allreduce_description, name);
-}
-static void _check_coll_alltoall(const char *name)
-{
-  _check_coll("alltoall", mpi_coll_alltoall_description, name);
-}
-static void _check_coll_alltoallv(const char *name)
-{
-  _check_coll("alltoallv", mpi_coll_alltoallv_description, name);
-}
-static void _check_coll_bcast(const char *name)
-{
-  _check_coll("bcast", mpi_coll_bcast_description, name);
-}
-static void _check_coll_reduce(const char *name)
-{
-  _check_coll("reduce", mpi_coll_reduce_description, name);
-}
-static void _check_coll_reduce_scatter(const char *name){
-  _check_coll("reduce_scatter", mpi_coll_reduce_scatter_description, name);
-}
-static void _check_coll_scatter(const char *name){
-  _check_coll("scatter", mpi_coll_scatter_description, name);
-}
-static void _check_coll_barrier(const char *name){
-  _check_coll("barrier", mpi_coll_barrier_description, name);
-}
-
-#endif
-
 /* callback to decide if we want to use the model-checking */
 #include "src/xbt_modinter.h"
 
@@ -268,7 +208,7 @@ static void _sg_cfg_cb_model_check_replay(const char *name) {
     MC_record_path = nullptr;
 }
 
-#if HAVE_MC
+#if SIMGRID_HAVE_MC
 extern int _sg_do_model_check_record;
 static void _sg_cfg_cb_model_check_record(const char *name) {
   _sg_do_model_check_record = xbt_cfg_get_boolean(name);
@@ -312,13 +252,11 @@ static void _sg_cfg_cb_contexts_parallel_threshold(const char *name)
 static void _sg_cfg_cb_contexts_parallel_mode(const char *name)
 {
   const char* mode_name = xbt_cfg_get_string(name);
-  if (!strcmp(mode_name, "posix")) {
+  if (not strcmp(mode_name, "posix")) {
     SIMIX_context_set_parallel_mode(XBT_PARMAP_POSIX);
-  }
-  else if (!strcmp(mode_name, "futex")) {
+  } else if (not strcmp(mode_name, "futex")) {
     SIMIX_context_set_parallel_mode(XBT_PARMAP_FUTEX);
-  }
-  else if (!strcmp(mode_name, "busy_wait")) {
+  } else if (not strcmp(mode_name, "busy_wait")) {
     SIMIX_context_set_parallel_mode(XBT_PARMAP_BUSY_WAIT);
   }
   else {
@@ -356,88 +294,94 @@ void sg_config_init(int *argc, char **argv)
   char description[descsize];
 
   /* Create the configuration support */
-  if (_sg_cfg_init_status == 0) { /* Only create stuff if not already inited */
+  if (_sg_cfg_init_status != 0) { /* Only create stuff if not already inited */
+    XBT_WARN("Call to sg_config_init() after initialization ignored");
+    return;
+  }
 
-    /* Plugins configuration */
-    describe_model(description,descsize, surf_plugin_description, "plugin", "The plugins");
-    xbt_cfg_register_string("plugin", nullptr, &_sg_cfg_cb__plugin, description);
+  /* Plugins configuration */
+  describe_model(description, descsize, surf_plugin_description, "plugin", "The plugins");
+  xbt_cfg_register_string("plugin", nullptr, &_sg_cfg_cb__plugin, description);
 
-    describe_model(description,descsize, surf_cpu_model_description, "model", "The model to use for the CPU");
-    xbt_cfg_register_string("cpu/model", "Cas01", &_sg_cfg_cb__cpu_model, description);
+  describe_model(description, descsize, surf_cpu_model_description, "model", "The model to use for the CPU");
+  xbt_cfg_register_string("cpu/model", "Cas01", &_sg_cfg_cb__cpu_model, description);
 
-    describe_model(description,descsize, surf_optimization_mode_description, "optimization mode", "The optimization modes to use for the CPU");
-    xbt_cfg_register_string("cpu/optim", "Lazy", &_sg_cfg_cb__optimization_mode, description);
+  describe_model(description, descsize, surf_optimization_mode_description, "optimization mode",
+                 "The optimization modes to use for the CPU");
+  xbt_cfg_register_string("cpu/optim", "Lazy", &_sg_cfg_cb__optimization_mode, description);
 
-    describe_model(description,descsize, surf_storage_model_description, "model", "The model to use for the storage");
-    xbt_cfg_register_string("storage/model", "default", &_sg_cfg_cb__storage_mode, description);
+  describe_model(description, descsize, surf_storage_model_description, "model", "The model to use for the storage");
+  xbt_cfg_register_string("storage/model", "default", &_sg_cfg_cb__storage_mode, description);
 
-    describe_model(description,descsize, surf_network_model_description, "model", "The model to use for the network");
-    xbt_cfg_register_string("network/model", "LV08", &_sg_cfg_cb__network_model, description);
+  describe_model(description, descsize, surf_network_model_description, "model", "The model to use for the network");
+  xbt_cfg_register_string("network/model", "LV08", &_sg_cfg_cb__network_model, description);
 
-    describe_model(description,descsize, surf_optimization_mode_description, "optimization mode", "The optimization modes to use for the network");
-    xbt_cfg_register_string("network/optim", "Lazy", &_sg_cfg_cb__optimization_mode, description);
+  describe_model(description, descsize, surf_optimization_mode_description, "optimization mode",
+                 "The optimization modes to use for the network");
+  xbt_cfg_register_string("network/optim", "Lazy", &_sg_cfg_cb__optimization_mode, description);
 
-    describe_model(description,descsize, surf_host_model_description, "model", "The model to use for the host");
-    xbt_cfg_register_string("host/model", "default", &_sg_cfg_cb__host_model, description);
+  describe_model(description, descsize, surf_host_model_description, "model", "The model to use for the host");
+  xbt_cfg_register_string("host/model", "default", &_sg_cfg_cb__host_model, description);
 
-    sg_tcp_gamma = 4194304.0;
-    simgrid::config::bindFlag(sg_tcp_gamma, { "network/TCP-gamma", "network/TCP_gamma" },
-      "Size of the biggest TCP window (cat /proc/sys/net/ipv4/tcp_[rw]mem for recv/send window; Use the last given value, which is the max window size)");
+  sg_tcp_gamma = 4194304.0;
+  simgrid::config::bindFlag(sg_tcp_gamma, {"network/TCP-gamma", "network/TCP_gamma"},
+                            "Size of the biggest TCP window (cat /proc/sys/net/ipv4/tcp_[rw]mem for recv/send window; "
+                            "Use the last given value, which is the max window size)");
 
-    sg_surf_precision = 0.00001;
-    simgrid::config::bindFlag(sg_surf_precision, "surf/precision",
-      "Numerical precision used when updating simulation times (in seconds)");
+  simgrid::config::bindFlag(sg_surf_precision, "surf/precision",
+                            "Numerical precision used when updating simulation times (in seconds)");
 
-    sg_maxmin_precision = 0.00001;
-    simgrid::config::bindFlag(sg_maxmin_precision, "maxmin/precision",
-      "Numerical precision used when computing resource sharing (in ops/sec or bytes/sec)");
+  simgrid::config::bindFlag(sg_maxmin_precision, "maxmin/precision",
+                            "Numerical precision used when computing resource sharing (in flops/sec or bytes/sec)");
 
-    sg_concurrency_limit = 100;
-    simgrid::config::bindFlag(sg_concurrency_limit, "maxmin/concurrency_limit",
-      "Maximum number of concurrent variables in the maxmim system. Also limits the number of processes on each host, at higher level");
+  simgrid::config::bindFlag(sg_concurrency_limit, "maxmin/concurrency-limit",
+                            "Maximum number of concurrent variables in the maxmim system. Also limits the number of "
+                            "processes on each host, at higher level. (default: -1 means no such limitation)");
+  xbt_cfg_register_alias("maxmin/concurrency-limit", "maxmin/concurrency_limit");
 
-    /* The parameters of network models */
+  /* The parameters of network models */
 
-    // real default for "network/sender-gap" is set in network_smpi.cpp:
-    sg_sender_gap = NAN;
-    simgrid::config::bindFlag(sg_sender_gap, { "network/sender-gap", "network/sender_gap" },
-      "Minimum gap between two overlapping sends");
+  // real default for "network/sender-gap" is set in network_smpi.cpp:
+  sg_sender_gap = NAN;
+  simgrid::config::bindFlag(sg_sender_gap, {"network/sender-gap", "network/sender_gap"},
+                            "Minimum gap between two overlapping sends");
 
-    sg_latency_factor = 1.0;
-    simgrid::config::bindFlag(sg_latency_factor, { "network/latency-factor", "network/latency_factor" },
-      "Correction factor to apply to the provided latency (default value set by network model)");
+  sg_latency_factor = 1.0;
+  simgrid::config::bindFlag(sg_latency_factor, {"network/latency-factor", "network/latency_factor"},
+                            "Correction factor to apply to the provided latency (default value set by network model)");
 
-    sg_bandwidth_factor = 1.0;
-    simgrid::config::bindFlag(sg_bandwidth_factor, { "network/bandwidth-factor", "network/bandwidth_factor" },
+  sg_bandwidth_factor = 1.0;
+  simgrid::config::bindFlag(
+      sg_bandwidth_factor, {"network/bandwidth-factor", "network/bandwidth_factor"},
       "Correction factor to apply to the provided bandwidth (default value set by network model)");
 
-    // real default for "network/weight-S" is set in network_*.cpp:
-    sg_weight_S_parameter = NAN;
-    simgrid::config::bindFlag(sg_weight_S_parameter, { "network/weight-S", "network/weight_S" },
+  // real default for "network/weight-S" is set in network_*.cpp:
+  sg_weight_S_parameter = NAN;
+  simgrid::config::bindFlag(
+      sg_weight_S_parameter, {"network/weight-S", "network/weight_S"},
       "Correction factor to apply to the weight of competing streams (default value set by network model)");
 
-    /* Inclusion path */
-    simgrid::config::declareFlag<std::string>("path",
-      "Lookup path for inclusions in platform and deployment XML files",
-      "",
-      [](std::string const& path) {
-        if (path[0] != '\0') {
-          char* copy = xbt_strdup(path.c_str());
-          xbt_dynar_push(surf_path, &copy);
-        }
-      });
+  /* Inclusion path */
+  simgrid::config::declareFlag<std::string>("path", "Lookup path for inclusions in platform and deployment XML files",
+                                            "", [](std::string const& path) {
+                                              if (path[0] != '\0') {
+                                                surf_path.push_back(path);
+                                              }
+                                            });
 
-    xbt_cfg_register_boolean("cpu/maxmin-selective-update", "no", nullptr,
-        "Update the constraint set propagating recursively to others constraints (off by default when optim is set to lazy)");
-    xbt_cfg_register_alias("cpu/maxmin-selective-update","cpu/maxmin_selective_update");
-    xbt_cfg_register_boolean("network/maxmin-selective-update", "no", nullptr,
-        "Update the constraint set propagating recursively to others constraints (off by default when optim is set to lazy)");
-    xbt_cfg_register_alias("network/maxmin-selective-update","network/maxmin_selective_update");
-    /* Replay (this part is enabled even if MC it disabled) */
-    xbt_cfg_register_string("model-check/replay", nullptr, _sg_cfg_cb_model_check_replay,
-        "Model-check path to replay (as reported by SimGrid when a violation is reported)");
+  xbt_cfg_register_boolean("cpu/maxmin-selective-update", "no", nullptr, "Update the constraint set propagating "
+                                                                         "recursively to others constraints (off by "
+                                                                         "default when optim is set to lazy)");
+  xbt_cfg_register_alias("cpu/maxmin-selective-update", "cpu/maxmin_selective_update");
+  xbt_cfg_register_boolean("network/maxmin-selective-update", "no", nullptr, "Update the constraint set propagating "
+                                                                             "recursively to others constraints (off "
+                                                                             "by default when optim is set to lazy)");
+  xbt_cfg_register_alias("network/maxmin-selective-update", "network/maxmin_selective_update");
+  /* Replay (this part is enabled even if MC it disabled) */
+  xbt_cfg_register_string("model-check/replay", nullptr, _sg_cfg_cb_model_check_replay,
+                          "Model-check path to replay (as reported by SimGrid when a violation is reported)");
 
-#if HAVE_MC
+#if SIMGRID_HAVE_MC
     /* do model-checking-record */
     xbt_cfg_register_boolean("model-check/record", "no", _sg_cfg_cb_model_check_record, "Record the model-checking paths");
 
@@ -524,24 +468,31 @@ void sg_config_init(int *argc, char **argv)
     xbt_cfg_register_string("smpi/lat-factor",
         "65472:11.6436;15424:3.48845;9376:2.59299;5776:2.18796;3484:1.88101;1426:1.61075;732:1.9503;257:1.95341;0:2.01467", nullptr, "Latency factors for smpi.");
     xbt_cfg_register_alias("smpi/lat-factor","smpi/lat_factor");
-    
+
     xbt_cfg_register_string("smpi/IB-penalty-factors", "0.965;0.925;1.35", nullptr,
         "Correction factor to communications using Infiniband model with contention (default value based on Stampede cluster profiling)");
     xbt_cfg_register_alias("smpi/IB-penalty-factors","smpi/IB_penalty_factors");
-    
+
 #if HAVE_SMPI
     xbt_cfg_register_double("smpi/host-speed", 20000.0, nullptr, "Speed of the host running the simulation (in flop/s). Used to bench the operations.");
     xbt_cfg_register_alias("smpi/host-speed","smpi/running_power");
     xbt_cfg_register_alias("smpi/host-speed","smpi/running-power");
 
+    xbt_cfg_register_boolean("smpi/keep-temps", "no", nullptr, "Whether we should keep the generated temporary files.");
+
     xbt_cfg_register_boolean("smpi/display-timing", "no", nullptr, "Whether we should display the timing after simulation.");
     xbt_cfg_register_alias("smpi/display-timing", "smpi/display_timing");
 
     xbt_cfg_register_boolean("smpi/simulate-computation", "yes", nullptr, "Whether the computational part of the simulated application should be simulated.");
     xbt_cfg_register_alias("smpi/simulate-computation","smpi/simulate_computation");
 
-    xbt_cfg_register_boolean("smpi/use-shared-malloc", "yes", nullptr, "Whether SMPI_SHARED_MALLOC is enabled. Disable it for debugging purposes.");
-    xbt_cfg_register_alias("smpi/use-shared-malloc", "smpi/use_shared_malloc");
+    xbt_cfg_register_string("smpi/shared-malloc", "global", nullptr,
+                            "Whether SMPI_SHARED_MALLOC is enabled. Disable it for debugging purposes.");
+    xbt_cfg_register_alias("smpi/shared-malloc", "smpi/use-shared-malloc");
+    xbt_cfg_register_alias("smpi/shared-malloc", "smpi/use_shared_malloc");
+    xbt_cfg_register_double("smpi/shared-malloc-blocksize", 1UL << 20, nullptr, "Size of the bogus file which will be created for global shared allocations");
+    xbt_cfg_register_string("smpi/shared-malloc-hugepage", "", nullptr,
+                            "Path to a mounted hugetlbfs, to use huge pages with shared malloc.");
 
     xbt_cfg_register_double("smpi/cpu-threshold", 1e-6, nullptr, "Minimal computation time (in seconds) not discarded, or -1 for infinity.");
     xbt_cfg_register_alias("smpi/cpu-threshold", "smpi/cpu_threshold");
@@ -558,8 +509,15 @@ void sg_config_init(int *argc, char **argv)
     xbt_cfg_register_alias("smpi/send-is-detached-thresh","smpi/send_is_detached_thresh");
     xbt_cfg_register_alias("smpi/send-is-detached-thresh","smpi/send_is_detached_thres");
 
-    xbt_cfg_register_boolean("smpi/privatize-global-variables", "no", nullptr, "Whether we should privatize global variable at runtime.");
-    xbt_cfg_register_alias("smpi/privatize-global-variables", "smpi/privatize_global_variables");
+    const char* default_privatization = std::getenv("SMPI_PRIVATIZATION");
+    if (default_privatization == nullptr)
+      default_privatization = "no";
+
+    xbt_cfg_register_string("smpi/privatization", default_privatization, nullptr,
+                            "How we should privatize global variable at runtime (no, yes, mmap, dlopen).");
+
+    xbt_cfg_register_alias("smpi/privatization", "smpi/privatize-global-variables");
+    xbt_cfg_register_alias("smpi/privatization", "smpi/privatize_global_variables");
 
     xbt_cfg_register_boolean("smpi/grow-injected-times", "yes", nullptr, "Whether we want to make the injected time in MPI_Iprobe and MPI_Test grow, to allow faster simulation. This can make simulation less precise, though.");
 
@@ -571,20 +529,22 @@ void sg_config_init(int *argc, char **argv)
     xbt_cfg_register_string("smpi/ois", "0:0:0:0:0", nullptr, "Small messages timings (MPI_Isend minimum time for small messages)");
     xbt_cfg_register_string("smpi/or", "0:0:0:0:0", nullptr,  "Small messages timings (MPI_Recv minimum time for small messages)");
 
+    xbt_cfg_register_double("smpi/iprobe-cpu-usage", 1, nullptr, "Maximum usage of CPUs by MPI_Iprobe() calls. We've observed that MPI_Iprobes consume significantly less power than the maximum of a specific application. This value is then (Iprobe_Usage/Max_Application_Usage).");
+
     xbt_cfg_register_string("smpi/coll-selector", "default", nullptr, "Which collective selector to use");
     xbt_cfg_register_alias("smpi/coll-selector","smpi/coll_selector");
-    xbt_cfg_register_string("smpi/gather",        nullptr, &_check_coll_gather, "Which collective to use for gather");
-    xbt_cfg_register_string("smpi/allgather",     nullptr, &_check_coll_allgather, "Which collective to use for allgather");
-    xbt_cfg_register_string("smpi/barrier",       nullptr, &_check_coll_barrier, "Which collective to use for barrier");
-    xbt_cfg_register_string("smpi/reduce-scatter",nullptr, &_check_coll_reduce_scatter, "Which collective to use for reduce_scatter");
-    xbt_cfg_register_alias("smpi/reduce-scatter","smpi/reduce_scatter");
-    xbt_cfg_register_string("smpi/scatter",       nullptr, &_check_coll_scatter, "Which collective to use for scatter");
-    xbt_cfg_register_string("smpi/allgatherv",    nullptr, &_check_coll_allgatherv, "Which collective to use for allgatherv");
-    xbt_cfg_register_string("smpi/allreduce",     nullptr, &_check_coll_allreduce, "Which collective to use for allreduce");
-    xbt_cfg_register_string("smpi/alltoall",      nullptr, &_check_coll_alltoall, "Which collective to use for alltoall");
-    xbt_cfg_register_string("smpi/alltoallv",     nullptr, &_check_coll_alltoallv,"Which collective to use for alltoallv");
-    xbt_cfg_register_string("smpi/bcast",         nullptr, &_check_coll_bcast, "Which collective to use for bcast");
-    xbt_cfg_register_string("smpi/reduce",        nullptr, &_check_coll_reduce, "Which collective to use for reduce");
+    xbt_cfg_register_string("smpi/gather",        nullptr, nullptr, "Which collective to use for gather");
+    xbt_cfg_register_string("smpi/allgather",     nullptr, nullptr, "Which collective to use for allgather");
+    xbt_cfg_register_string("smpi/barrier",       nullptr, nullptr, "Which collective to use for barrier");
+    xbt_cfg_register_string("smpi/reduce_scatter",nullptr, nullptr, "Which collective to use for reduce_scatter");
+    xbt_cfg_register_alias("smpi/reduce_scatter","smpi/reduce-scatter");
+    xbt_cfg_register_string("smpi/scatter",       nullptr, nullptr, "Which collective to use for scatter");
+    xbt_cfg_register_string("smpi/allgatherv",    nullptr, nullptr, "Which collective to use for allgatherv");
+    xbt_cfg_register_string("smpi/allreduce",     nullptr, nullptr, "Which collective to use for allreduce");
+    xbt_cfg_register_string("smpi/alltoall",      nullptr, nullptr, "Which collective to use for alltoall");
+    xbt_cfg_register_string("smpi/alltoallv",     nullptr, nullptr,"Which collective to use for alltoallv");
+    xbt_cfg_register_string("smpi/bcast",         nullptr, nullptr, "Which collective to use for bcast");
+    xbt_cfg_register_string("smpi/reduce",        nullptr, nullptr, "Which collective to use for reduce");
 #endif // HAVE_SMPI
 
     /* Storage */
@@ -602,12 +562,11 @@ void sg_config_init(int *argc, char **argv)
         "Whether to cleanup SimGrid at exit. Disable it if your code segfaults after its end.");
     xbt_cfg_register_alias("clean-atexit","clean_atexit");
 
-    if (!surf_path) {
+    if (surf_path.empty()) {
       /* retrieves the current directory of the current process */
       const char *initial_path = __surf_get_initial_path();
       xbt_assert((initial_path), "__surf_get_initial_path() failed! Can't resolve current Windows directory");
 
-      surf_path = xbt_dynar_new(sizeof(char *), &xbt_free_ref);
       xbt_cfg_setdefault_string("path", initial_path);
     }
 
@@ -616,14 +575,11 @@ void sg_config_init(int *argc, char **argv)
     sg_config_cmd_line(argc, argv);
 
     xbt_mallocator_initialization_is_done(SIMIX_context_is_parallel());
-  } else {
-    XBT_WARN("Call to sg_config_init() after initialization ignored");
-  }
 }
 
 void sg_config_finalize()
 {
-  if (!_sg_cfg_init_status)
+  if (not _sg_cfg_init_status)
     return;                     /* Not initialized yet. Nothing to do */
 
   xbt_cfg_free(&simgrid_config);
