@@ -1,5 +1,4 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,22 +10,22 @@
 
 #include <boost/range/algorithm.hpp>
 
-#include <xbt/functional.hpp>
-#include <xbt/ex.hpp>
-#include <xbt/sysdep.h>
-#include <xbt/log.h>
-#include <xbt/dict.h>
+#include "xbt/dict.h"
+#include "xbt/ex.hpp"
+#include "xbt/functional.hpp"
+#include "xbt/log.h"
+#include "xbt/sysdep.h"
 
-#include <simgrid/s4u/host.hpp>
+#include "simgrid/s4u/Host.hpp"
 
-#include <mc/mc.h>
+#include "mc/mc.h"
 
 #include "smx_private.h"
+#include "src/kernel/activity/SleepImpl.hpp"
 #include "src/kernel/activity/SynchroIo.hpp"
 #include "src/kernel/activity/SynchroRaw.hpp"
-#include "src/kernel/activity/SynchroSleep.hpp"
-#include "src/mc/Client.hpp"
 #include "src/mc/mc_replay.h"
+#include "src/mc/remote/Client.hpp"
 #include "src/msg/msg_private.h"
 #include "src/surf/cpu_interface.hpp"
 #include "src/surf/surf_interface.hpp"
@@ -74,7 +73,7 @@ smx_actor_t SIMIX_process_self()
  */
 int SIMIX_process_has_pending_comms(smx_actor_t process) {
 
-  return xbt_fifo_size(process->comms) > 0;
+  return process->comms.size() > 0;
 }
 
 /**
@@ -82,60 +81,53 @@ int SIMIX_process_has_pending_comms(smx_actor_t process) {
  */
 void SIMIX_process_cleanup(smx_actor_t process)
 {
-  XBT_DEBUG("Cleanup process %s (%p), waiting synchro %p",
-      process->name.c_str(), process, process->waiting_synchro);
+  XBT_DEBUG("Cleanup process %s (%p), waiting synchro %p", process->name.c_str(), process,
+            process->waiting_synchro.get());
 
   process->finished = true;
   SIMIX_process_on_exit_runall(process);
 
   /* Unregister from the kill timer if any */
   if (process->kill_timer != nullptr)
-      SIMIX_timer_remove(process->kill_timer);
+    SIMIX_timer_remove(process->kill_timer);
 
   xbt_os_mutex_acquire(simix_global->mutex);
 
   /* cancel non-blocking communications */
-  smx_activity_t synchro = static_cast<smx_activity_t>(xbt_fifo_pop(process->comms));
-  while (synchro != nullptr) {
-    simgrid::kernel::activity::Comm *comm = static_cast<simgrid::kernel::activity::Comm*>(synchro);
+  smx_activity_t synchro = process->comms.front();
+  while (not process->comms.empty()) {
+    simgrid::kernel::activity::CommImplPtr comm =
+        boost::static_pointer_cast<simgrid::kernel::activity::CommImpl>(synchro);
 
     /* make sure no one will finish the comm after this process is destroyed,
      * because src_proc or dst_proc would be an invalid pointer */
-    comm->cancel();
 
     if (comm->src_proc == process) {
-      XBT_DEBUG("Found an unfinished send comm %p (detached = %d), state %d, src = %p, dst = %p",
-          comm, comm->detached, (int)comm->state, comm->src_proc, comm->dst_proc);
+      XBT_DEBUG("Found an unfinished send comm %p (detached = %d), state %d, src = %p, dst = %p", comm.get(),
+                comm->detached, (int)comm->state, comm->src_proc, comm->dst_proc);
       comm->src_proc = nullptr;
 
-      /* I'm not supposed to destroy a detached comm from the sender side, */
-      if (comm->detached)
-        XBT_DEBUG("Don't destroy it since it's a detached comm and I'm the sender");
-      else
-        comm->unref();
-
-    }
-    else if (comm->dst_proc == process){
-      XBT_DEBUG("Found an unfinished recv comm %p, state %d, src = %p, dst = %p",
-          comm, (int)comm->state, comm->src_proc, comm->dst_proc);
+    } else if (comm->dst_proc == process) {
+      XBT_DEBUG("Found an unfinished recv comm %p, state %d, src = %p, dst = %p", comm.get(), (int)comm->state,
+                comm->src_proc, comm->dst_proc);
       comm->dst_proc = nullptr;
 
       if (comm->detached && comm->src_proc != nullptr) {
         /* the comm will be freed right now, remove it from the sender */
-        xbt_fifo_remove(comm->src_proc->comms, comm);
+        comm->src_proc->comms.remove(comm);
       }
-      
-      comm->unref();
     } else {
-      xbt_die("Communication synchro %p is in my list but I'm not the sender nor the receiver", synchro);
+      xbt_die("Communication synchro %p is in my list but I'm not the sender nor the receiver", synchro.get());
     }
-    synchro = static_cast<smx_activity_t>(xbt_fifo_pop(process->comms));
+    process->comms.pop_front();
+    synchro = process->comms.front();
+    comm->cancel();
   }
 
   XBT_DEBUG("%p should not be run anymore",process);
-  xbt_swag_remove(process, simix_global->process_list);
+  simix_global->process_list.erase(process->pid);
   if (process->host)
-    xbt_swag_remove(process, sg_host_simix(process->host)->process_list);
+    xbt_swag_remove(process, process->host->extension<simgrid::simix::Host>()->process_list);
   xbt_swag_insert(process, simix_global->process_to_destroy);
   process->context->iwannadie = 0;
 
@@ -145,16 +137,16 @@ void SIMIX_process_cleanup(smx_actor_t process)
 /**
  * Garbage collection
  *
- * Should be called some time to time to free the memory allocated for processes
- * that have finished (or killed).
+ * Should be called some time to time to free the memory allocated for processes that have finished (or killed).
  */
 void SIMIX_process_empty_trash()
 {
-  smx_actor_t process = nullptr;
+  smx_actor_t process = static_cast<smx_actor_t>(xbt_swag_extract(simix_global->process_to_destroy));
 
-  while ((process = (smx_actor_t) xbt_swag_extract(simix_global->process_to_destroy))) {
+  while (process) {
     XBT_DEBUG("Getting rid of %p",process);
     intrusive_ptr_release(process);
+    process = static_cast<smx_actor_t>(xbt_swag_extract(simix_global->process_to_destroy));
   }
 }
 
@@ -164,28 +156,51 @@ namespace simix {
 ActorImpl::~ActorImpl()
 {
   delete this->context;
-  if (this->properties)
-    xbt_dict_free(&this->properties);
-  if (this->comms != nullptr)
-    xbt_fifo_free(this->comms);
-  if (this->on_exit)
-    xbt_dynar_free(&this->on_exit);
+  xbt_dict_free(&this->properties);
+}
+
+static int dying_daemon(void* exit_status, void* data)
+{
+  std::vector<ActorImpl*>* vect = &simix_global->daemons;
+
+  auto it = std::find(vect->begin(), vect->end(), static_cast<ActorImpl*>(data));
+  xbt_assert(it != vect->end(), "The dying daemon is not a daemon after all. Please report that bug.");
+
+  /* Don't move the whole content since we don't really care about the order */
+  std::swap(*it, vect->back());
+  vect->pop_back();
+
+  return 0;
+}
+/** This process will be terminated automatically when the last non-daemon process finishes */
+void ActorImpl::daemonize()
+{
+  if (not daemon) {
+    daemon = true;
+    simix_global->daemons.push_back(this);
+    SIMIX_process_on_exit(this, dying_daemon, this);
+  }
+}
+
+/** Whether this process is daemonized */
+bool ActorImpl::isDaemon()
+{
+  return daemon;
 }
 
 void create_maestro(std::function<void()> code)
 {
   smx_actor_t maestro = nullptr;
-  /* Create maestro process and intilialize it */
+  /* Create maestro process and initialize it */
   maestro = new simgrid::simix::ActorImpl();
   maestro->pid = simix_process_maxpid++;
-  maestro->ppid = -1;
   maestro->name = "";
   maestro->data = nullptr;
 
-  if (!code) {
+  if (not code) {
     maestro->context = SIMIX_context_new(std::function<void()>(), nullptr, maestro);
   } else {
-    if (!simix_global)
+    if (not simix_global)
       xbt_die("simix is not initialized, please call MSG_init first");
     maestro->context =
       simix_global->context_factory->create_maestro(code, maestro);
@@ -213,17 +228,9 @@ void SIMIX_maestro_create(void (*code)(void*), void* data)
  *
  * \return the process created
  */
-smx_actor_t SIMIX_process_create(
-                          const char *name,
-                          std::function<void()> code,
-                          void *data,
-                          sg_host_t host,
-                          double kill_time,
-                          xbt_dict_t properties,
-                          int auto_restart,
-                          smx_actor_t parent_process)
+smx_actor_t SIMIX_process_create(const char* name, std::function<void()> code, void* data, simgrid::s4u::Host* host,
+                                 xbt_dict_t properties, smx_actor_t parent_process)
 {
-  smx_actor_t process = nullptr;
 
   XBT_DEBUG("Start process %s on host '%s'", name, host->cname());
 
@@ -231,77 +238,62 @@ smx_actor_t SIMIX_process_create(
     XBT_WARN("Cannot launch process '%s' on failed host '%s'", name, host->cname());
     return nullptr;
   }
-  else {
-    process = new simgrid::simix::ActorImpl();
 
-    xbt_assert(code && host != nullptr, "Invalid parameters");
-    /* Process data */
-    process->pid = simix_process_maxpid++;
-    process->name = simgrid::xbt::string(name);
-    process->host = host;
-    process->data = data;
-    process->comms = xbt_fifo_new();
-    process->simcall.issuer = process;
-    /* Initiliaze data segment to default value */
-    SIMIX_segment_index_set(process, -1);
+  smx_actor_t process = new simgrid::simix::ActorImpl();
 
-    if (parent_process != nullptr) {
-      process->ppid = parent_process->pid;
-      /* SMPI process have their own data segment and each other inherit from their father */
+  xbt_assert(code && host != nullptr, "Invalid parameters");
+  /* Process data */
+  process->pid            = simix_process_maxpid++;
+  process->name           = simgrid::xbt::string(name);
+  process->host           = host;
+  process->data           = data;
+  process->simcall.issuer = process;
+
+  if (parent_process != nullptr) {
+    process->ppid = parent_process->pid;
+/* SMPI process have their own data segment and each other inherit from their father */
 #if HAVE_SMPI
-       if( smpi_privatize_global_variables) {
-         if (parent_process->pid != 0) {
-           SIMIX_segment_index_set(process, parent_process->segment_index);
-         } else {
-           SIMIX_segment_index_set(process, process->pid - 1);
-         }
-       }
-#endif
-     } else {
-       process->ppid = -1;
-     }
-
-    /* Process data for auto-restart */
-    process->auto_restart = auto_restart;
-    process->code = code;
-
-    XBT_VERB("Create context %s", process->name.c_str());
-    process->context = SIMIX_context_new(
-      std::move(code),
-      simix_global->cleanup_process_function, process);
-
-    /* Add properties */
-    process->properties = properties;
-
-    /* Add the process to it's host process list */
-    xbt_swag_insert(process, sg_host_simix(host)->process_list);
-
-    XBT_DEBUG("Start context '%s'", process->name.c_str());
-
-    /* Now insert it in the global process list and in the process to run list */
-    xbt_swag_insert(process, simix_global->process_list);
-    XBT_DEBUG("Inserting %s(%s) in the to_run list", process->cname(), host->cname());
-    xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, process);
-
-    if (kill_time > SIMIX_get_clock() && simix_global->kill_process_function) {
-      XBT_DEBUG("Process %s(%s) will be kill at time %f", process->cname(), process->host->cname(), kill_time);
-      process->kill_timer = SIMIX_timer_set(kill_time, [=]() {
-        simix_global->kill_process_function(process);
-      });
+    if (smpi_privatize_global_variables == SMPI_PRIVATIZE_MMAP) {
+      if (parent_process->pid != 0) {
+        SIMIX_segment_index_set(process, parent_process->segment_index);
+      } else {
+        SIMIX_segment_index_set(process, process->pid - 1);
+      }
     }
-
-    /* Tracing the process creation */
-    TRACE_msg_process_create(process->cname(), process->pid, process->host);
+#endif
   }
+
+  process->code         = code;
+
+  XBT_VERB("Create context %s", process->name.c_str());
+  process->context = SIMIX_context_new(std::move(code), simix_global->cleanup_process_function, process);
+
+  /* Add properties */
+  process->properties = properties;
+
+  /* Make sure that the process is initialized for simix, in case we are called from the Host::onCreation signal */
+  if (host->extension<simgrid::simix::Host>() == nullptr)
+    host->extension_set<simgrid::simix::Host>(new simgrid::simix::Host());
+
+  /* Add the process to its host process list */
+  xbt_swag_insert(process, host->extension<simgrid::simix::Host>()->process_list);
+
+  XBT_DEBUG("Start context '%s'", process->name.c_str());
+
+  /* Now insert it in the global process list and in the process to run list */
+  simix_global->process_list[process->pid] = process;
+  XBT_DEBUG("Inserting %s(%s) in the to_run list", process->cname(), host->cname());
+  xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, process);
+  intrusive_ptr_add_ref(process);
+
+  /* Tracing the process creation */
+  TRACE_msg_process_create(process->cname(), process->pid, process->host);
+
   return process;
 }
 
-smx_actor_t SIMIX_process_attach(
-  const char* name,
-  void *data,
-  const char* hostname,
-  xbt_dict_t properties,
-  smx_actor_t parent_process)
+smx_actor_t SIMIX_process_attach(const char* name, void* data, const char* hostname, xbt_dict_t properties,
+                                 smx_actor_t parent_process)
 {
   // This is mostly a copy/paste from SIMIX_process_new(),
   // it'd be nice to share some code between those two functions.
@@ -321,16 +313,13 @@ smx_actor_t SIMIX_process_attach(
   process->name = std::string(name);
   process->host = host;
   process->data = data;
-  process->comms = xbt_fifo_new();
   process->simcall.issuer = process;
-  process->ppid = -1;
-  /* Initiliaze data segment to default value */
-  SIMIX_segment_index_set(process, -1);
+
   if (parent_process != nullptr) {
     process->ppid = parent_process->pid;
     /* SMPI process have their own data segment and each other inherit from their father */
 #if HAVE_SMPI
-    if (smpi_privatize_global_variables) {
+    if (smpi_privatize_global_variables == SMPI_PRIVATIZE_MMAP) {
       if (parent_process->pid != 0) {
         SIMIX_segment_index_set(process, parent_process->segment_index);
       } else {
@@ -341,11 +330,10 @@ smx_actor_t SIMIX_process_attach(
   }
 
   /* Process data for auto-restart */
-  process->auto_restart = false;
   process->code = nullptr;
 
   XBT_VERB("Create context %s", process->name.c_str());
-  if (!simix_global)
+  if (not simix_global)
     xbt_die("simix is not initialized, please call MSG_init first");
   process->context = simix_global->context_factory->attach(
     simix_global->cleanup_process_function, process);
@@ -354,10 +342,10 @@ smx_actor_t SIMIX_process_attach(
   process->properties = properties;
 
   /* Add the process to it's host process list */
-  xbt_swag_insert(process, sg_host_simix(host)->process_list);
+  xbt_swag_insert(process, host->extension<simgrid::simix::Host>()->process_list);
 
   /* Now insert it in the global process list and in the process to run list */
-  xbt_swag_insert(process, simix_global->process_list);
+  simix_global->process_list[process->pid] = process;
   XBT_DEBUG("Inserting %s(%s) in the to_run list", process->cname(), host->cname());
   xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, process);
 
@@ -365,7 +353,7 @@ smx_actor_t SIMIX_process_attach(
   TRACE_msg_process_create(process->cname(), process->pid, process->host);
 
   auto context = dynamic_cast<simgrid::kernel::context::AttachContext*>(process->context);
-  if (!context)
+  if (not context)
     xbt_die("Not a suitable context");
 
   context->attach_start();
@@ -375,7 +363,7 @@ smx_actor_t SIMIX_process_attach(
 void SIMIX_process_detach()
 {
   auto context = dynamic_cast<simgrid::kernel::context::AttachContext*>(SIMIX_context_self());
-  if (!context)
+  if (not context)
     xbt_die("Not a suitable context");
 
   simix_global->cleanup_process_function(context->process());
@@ -431,39 +419,38 @@ void SIMIX_process_kill(smx_actor_t process, smx_actor_t issuer) {
   process->exception = nullptr;
 
   /* destroy the blocking synchro if any */
-  if (process->waiting_synchro) {
+  if (process->waiting_synchro != nullptr) {
 
-    simgrid::kernel::activity::Exec *exec = dynamic_cast<simgrid::kernel::activity::Exec*>(process->waiting_synchro);
-    simgrid::kernel::activity::Comm *comm = dynamic_cast<simgrid::kernel::activity::Comm*>(process->waiting_synchro);
-    simgrid::kernel::activity::Sleep *sleep = dynamic_cast<simgrid::kernel::activity::Sleep*>(process->waiting_synchro);
-    simgrid::kernel::activity::Raw *raw = dynamic_cast<simgrid::kernel::activity::Raw*>(process->waiting_synchro);
-    simgrid::kernel::activity::Io *io = dynamic_cast<simgrid::kernel::activity::Io*>(process->waiting_synchro);
+    simgrid::kernel::activity::ExecImplPtr exec =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::ExecImpl>(process->waiting_synchro);
+    simgrid::kernel::activity::CommImplPtr comm =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(process->waiting_synchro);
+    simgrid::kernel::activity::SleepImplPtr sleep =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::SleepImpl>(process->waiting_synchro);
+    simgrid::kernel::activity::RawImplPtr raw =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::RawImpl>(process->waiting_synchro);
+    simgrid::kernel::activity::IoImplPtr io =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::IoImpl>(process->waiting_synchro);
 
     if (exec != nullptr) {
-      exec->unref();
-
+      /* Nothing to do */
     } else if (comm != nullptr) {
-      xbt_fifo_remove(process->comms, process->waiting_synchro);
+      process->comms.remove(process->waiting_synchro);
       comm->cancel();
-
       // Remove first occurrence of &process->simcall:
-      auto i = boost::range::find(
-        process->waiting_synchro->simcalls,
-        &process->simcall);
+      auto i = boost::range::find(process->waiting_synchro->simcalls, &process->simcall);
       if (i != process->waiting_synchro->simcalls.end())
         process->waiting_synchro->simcalls.remove(&process->simcall);
-
-      comm->unref();
-
     } else if (sleep != nullptr) {
       SIMIX_process_sleep_destroy(process->waiting_synchro);
 
     } else if (raw != nullptr) {
       SIMIX_synchro_stop_waiting(process, &process->simcall);
-      delete process->waiting_synchro;
 
     } else if (io != nullptr) {
       SIMIX_io_destroy(process->waiting_synchro);
+    } else {
+      xbt_die("Unknown type of activity");
     }
 
     /*
@@ -475,7 +462,7 @@ void SIMIX_process_kill(smx_actor_t process, smx_actor_t issuer) {
 
     process->waiting_synchro = nullptr;
   }
-  if(!xbt_dynar_member(simix_global->process_to_run, &(process)) && process != issuer) {
+  if (not xbt_dynar_member(simix_global->process_to_run, &(process)) && process != issuer) {
     XBT_DEBUG("Inserting %s in the to_run list", process->name.c_str());
     xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, process);
   }
@@ -497,32 +484,37 @@ void SIMIX_process_throw(smx_actor_t process, xbt_errcat_t cat, int value, const
   /* cancel the blocking synchro if any */
   if (process->waiting_synchro) {
 
-    simgrid::kernel::activity::Exec *exec = dynamic_cast<simgrid::kernel::activity::Exec*>(process->waiting_synchro);
+    simgrid::kernel::activity::ExecImplPtr exec =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::ExecImpl>(process->waiting_synchro);
     if (exec != nullptr) {
       SIMIX_execution_cancel(process->waiting_synchro);
     }
 
-    simgrid::kernel::activity::Comm *comm = dynamic_cast<simgrid::kernel::activity::Comm*>(process->waiting_synchro);
+    simgrid::kernel::activity::CommImplPtr comm =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(process->waiting_synchro);
     if (comm != nullptr) {
-      xbt_fifo_remove(process->comms, comm);
+      process->comms.remove(comm);
       comm->cancel();
     }
 
-    simgrid::kernel::activity::Sleep *sleep = dynamic_cast<simgrid::kernel::activity::Sleep*>(process->waiting_synchro);
+    simgrid::kernel::activity::SleepImplPtr sleep =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::SleepImpl>(process->waiting_synchro);
     if (sleep != nullptr) {
       SIMIX_process_sleep_destroy(process->waiting_synchro);
-      if (!xbt_dynar_member(simix_global->process_to_run, &(process)) && process != SIMIX_process_self()) {
+      if (not xbt_dynar_member(simix_global->process_to_run, &(process)) && process != SIMIX_process_self()) {
         XBT_DEBUG("Inserting %s in the to_run list", process->name.c_str());
         xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, process);
       }
     }
 
-    simgrid::kernel::activity::Raw *raw = dynamic_cast<simgrid::kernel::activity::Raw*>(process->waiting_synchro);
+    simgrid::kernel::activity::RawImplPtr raw =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::RawImpl>(process->waiting_synchro);
     if (raw != nullptr) {
       SIMIX_synchro_stop_waiting(process, &process->simcall);
     }
 
-    simgrid::kernel::activity::Io *io = dynamic_cast<simgrid::kernel::activity::Io*>(process->waiting_synchro);
+    simgrid::kernel::activity::IoImplPtr io =
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::IoImpl>(process->waiting_synchro);
     if (io != nullptr) {
       SIMIX_io_destroy(process->waiting_synchro);
     }
@@ -540,13 +532,9 @@ void simcall_HANDLER_process_killall(smx_simcall_t simcall, int reset_pid) {
  */
 void SIMIX_process_killall(smx_actor_t issuer, int reset_pid)
 {
-  smx_actor_t p = nullptr;
-
-  while ((p = (smx_actor_t) xbt_swag_extract(simix_global->process_list))) {
-    if (p != issuer) {
-      SIMIX_process_kill(p,issuer);
-    }
-  }
+  for (auto kv : simix_global->process_list)
+    if (kv.second != issuer)
+      SIMIX_process_kill(kv.second, issuer);
 
   if (reset_pid > 0)
     simix_process_maxpid = reset_pid;
@@ -560,12 +548,13 @@ void simcall_HANDLER_process_set_host(smx_simcall_t simcall, smx_actor_t process
 {
   process->new_host = dest;
 }
+
 void SIMIX_process_change_host(smx_actor_t process, sg_host_t dest)
 {
   xbt_assert((process != nullptr), "Invalid parameters");
-  xbt_swag_remove(process, sg_host_simix(process->host)->process_list);
+  xbt_swag_remove(process, process->host->extension<simgrid::simix::Host>()->process_list);
   process->host = dest;
-  xbt_swag_insert(process, sg_host_simix(dest)->process_list);
+  xbt_swag_insert(process, dest->extension<simgrid::simix::Host>()->process_list);
 }
 
 
@@ -609,12 +598,13 @@ void SIMIX_process_resume(smx_actor_t process)
 {
   XBT_IN("process = %p", process);
 
-  if(process->context->iwannadie) {
+  if (process->context->iwannadie) {
     XBT_VERB("Ignoring request to suspend a process that is currently dying.");
     return;
   }
 
-  if(!process->suspended) return;
+  if (not process->suspended)
+    return;
   process->suspended = 0;
 
   /* resume the synchronization that was blocking the resumed process. */
@@ -630,7 +620,7 @@ int SIMIX_process_get_maxpid() {
 
 int SIMIX_process_count()
 {
-  return xbt_swag_size(simix_global->process_list);
+  return simix_global->process_list.size();
 }
 
 int SIMIX_process_get_PID(smx_actor_t self)
@@ -645,10 +635,10 @@ void* SIMIX_process_self_get_data()
 {
   smx_actor_t self = SIMIX_process_self();
 
-  if (!self) {
+  if (not self) {
     return nullptr;
   }
-  return SIMIX_process_get_data(self);
+  return self->data;
 }
 
 void SIMIX_process_self_set_data(void *data)
@@ -658,11 +648,6 @@ void SIMIX_process_self_set_data(void *data)
   SIMIX_process_set_data(self, data);
 }
 
-void* SIMIX_process_get_data(smx_actor_t process)
-{
-  return process->data;
-}
-
 void SIMIX_process_set_data(smx_actor_t process, void *data)
 {
   process->data = data;
@@ -681,11 +666,9 @@ const char* SIMIX_process_self_get_name() {
 
 smx_actor_t SIMIX_process_get_by_name(const char* name)
 {
-  smx_actor_t proc;
-  xbt_swag_foreach(proc, simix_global->process_list) {
-    if (proc->name == name)
-      return proc;
-  }
+  for (auto kv : simix_global->process_list)
+    if (kv.second->name == name)
+      return kv.second;
   return nullptr;
 }
 
@@ -712,13 +695,14 @@ void simcall_HANDLER_process_join(smx_simcall_t simcall, smx_actor_t process, do
   simcall->issuer->waiting_synchro = sync;
 }
 
-static int SIMIX_process_join_finish(smx_process_exit_status_t status, smx_activity_t synchro){
-  simgrid::kernel::activity::Sleep *sleep = static_cast<simgrid::kernel::activity::Sleep*>(synchro);
+static int SIMIX_process_join_finish(smx_process_exit_status_t status, void* synchro)
+{
+  simgrid::kernel::activity::SleepImpl* sleep = static_cast<simgrid::kernel::activity::SleepImpl*>(synchro);
 
   if (sleep->surf_sleep) {
     sleep->surf_sleep->cancel();
 
-    while (!sleep->simcalls.empty()) {
+    while (not sleep->simcalls.empty()) {
       smx_simcall_t simcall = sleep->simcalls.front();
       sleep->simcalls.pop_front();
       simcall_process_sleep__set__result(simcall, SIMIX_DONE);
@@ -734,15 +718,21 @@ static int SIMIX_process_join_finish(smx_process_exit_status_t status, smx_activ
     sleep->surf_sleep->unref();
     sleep->surf_sleep = nullptr;
   }
-  sleep->unref();
+  // intrusive_ptr_release(process); // FIXME: We are leaking here. See comment in SIMIX_process_join()
   return 0;
 }
 
 smx_activity_t SIMIX_process_join(smx_actor_t issuer, smx_actor_t process, double timeout)
 {
   smx_activity_t res = SIMIX_process_sleep(issuer, timeout);
-  static_cast<simgrid::kernel::activity::ActivityImpl*>(res)->ref();
-  SIMIX_process_on_exit(process, (int_f_pvoid_pvoid_t)SIMIX_process_join_finish, res);
+  intrusive_ptr_add_ref(res.get());
+  /* We are leaking the process here, but if we don't take the ref, we get a "use after free".
+   * The correct solution would be to derivate the type SynchroSleep into a SynchroProcessJoin,
+   * but the code is not clean enough for now for this.
+   * The C API should first be properly replaced with the C++ one, which is a fair amount of work.
+   */
+  intrusive_ptr_add_ref(process);
+  SIMIX_process_on_exit(process, (int_f_pvoid_pvoid_t)SIMIX_process_join_finish, &*res);
   return res;
 }
 
@@ -766,9 +756,9 @@ smx_activity_t SIMIX_process_sleep(smx_actor_t process, double duration)
   if (host->isOff())
     THROWF(host_error, 0, "Host %s failed, you cannot sleep there.", host->cname());
 
-  simgrid::kernel::activity::Sleep *synchro = new simgrid::kernel::activity::Sleep();
+  simgrid::kernel::activity::SleepImpl* synchro = new simgrid::kernel::activity::SleepImpl();
   synchro->host = host;
-  synchro->surf_sleep                       = host->pimpl_cpu->sleep(duration);
+  synchro->surf_sleep                           = host->pimpl_cpu->sleep(duration);
   synchro->surf_sleep->setData(synchro);
   XBT_DEBUG("Create sleep synchronization %p", synchro);
 
@@ -777,13 +767,13 @@ smx_activity_t SIMIX_process_sleep(smx_actor_t process, double duration)
 
 void SIMIX_process_sleep_destroy(smx_activity_t synchro)
 {
-  XBT_DEBUG("Destroy synchro %p", synchro);
-  simgrid::kernel::activity::Sleep *sleep = static_cast<simgrid::kernel::activity::Sleep*>(synchro);
+  XBT_DEBUG("Destroy sleep synchro %p", synchro.get());
+  simgrid::kernel::activity::SleepImplPtr sleep =
+      boost::dynamic_pointer_cast<simgrid::kernel::activity::SleepImpl>(synchro);
 
   if (sleep->surf_sleep) {
     sleep->surf_sleep->unref();
     sleep->surf_sleep = nullptr;
-    sleep->unref();
   }
 }
 
@@ -797,7 +787,7 @@ void SIMIX_process_sleep_destroy(smx_activity_t synchro)
  */
 void SIMIX_process_yield(smx_actor_t self)
 {
-  XBT_DEBUG("Yield process '%s'", self->name.c_str());
+  XBT_DEBUG("Yield actor '%s'", self->cname());
 
   /* Go into sleep and return control to maestro */
   self->context->suspend();
@@ -872,45 +862,38 @@ xbt_dynar_t SIMIX_process_get_runnable()
 /**
  * \brief Returns the process from PID.
  */
-smx_actor_t SIMIX_process_from_PID(int PID)
+smx_actor_t SIMIX_process_from_PID(aid_t PID)
 {
-  smx_actor_t proc;
-  xbt_swag_foreach(proc, simix_global->process_list) {
-   if (proc->pid == static_cast<unsigned long> (PID))
-    return proc;
-  }
-  return nullptr;
+  if (simix_global->process_list.find(PID) == simix_global->process_list.end())
+    return nullptr;
+  return simix_global->process_list.at(PID);
 }
 
 /** @brief returns a dynar containing all currently existing processes */
 xbt_dynar_t SIMIX_processes_as_dynar() {
-  smx_actor_t proc;
   xbt_dynar_t res = xbt_dynar_new(sizeof(smx_actor_t),nullptr);
-  xbt_swag_foreach(proc, simix_global->process_list) {
+  for (auto kv : simix_global->process_list) {
+    smx_actor_t proc = kv.second;
     xbt_dynar_push(res,&proc);
   }
   return res;
 }
 
 void SIMIX_process_on_exit_runall(smx_actor_t process) {
-  s_smx_process_exit_fun_t exit_fun;
   smx_process_exit_status_t exit_status = (process->context->iwannadie) ? SMX_EXIT_FAILURE : SMX_EXIT_SUCCESS;
-  while (!xbt_dynar_is_empty(process->on_exit)) {
-    exit_fun = xbt_dynar_pop_as(process->on_exit,s_smx_process_exit_fun_t);
+  while (not process->on_exit.empty()) {
+    s_smx_process_exit_fun_t exit_fun = process->on_exit.back();
     (exit_fun.fun)((void*)exit_status, exit_fun.arg);
+    process->on_exit.pop_back();
   }
 }
 
 void SIMIX_process_on_exit(smx_actor_t process, int_f_pvoid_pvoid_t fun, void *data) {
   xbt_assert(process, "current process not found: are you in maestro context ?");
 
-  if (!process->on_exit) {
-    process->on_exit = xbt_dynar_new(sizeof(s_smx_process_exit_fun_t), nullptr);
-  }
-
   s_smx_process_exit_fun_t exit_fun = {fun, data};
 
-  xbt_dynar_push_as(process->on_exit,s_smx_process_exit_fun_t,exit_fun);
+  process->on_exit.push_back(exit_fun);
 }
 
 /**
@@ -944,8 +927,14 @@ smx_actor_t SIMIX_process_restart(smx_actor_t process, smx_actor_t issuer) {
   SIMIX_process_kill(process, issuer);
 
   //start the new process
-  return simix_global->create_process_function(arg.name.c_str(), std::move(arg.code), arg.data, arg.host,
-      arg.kill_time, arg.properties, arg.auto_restart, nullptr);
+  smx_actor_t actor = simix_global->create_process_function(arg.name.c_str(), std::move(arg.code), arg.data, arg.host,
+                                                            arg.properties, nullptr);
+  if (arg.kill_time >= 0)
+    simcall_process_set_kill_time(actor, arg.kill_time);
+  if (arg.auto_restart)
+    simcall_process_auto_restart_set(actor, arg.auto_restart);
+
+  return actor;
 }
 
 void SIMIX_segment_index_set(smx_actor_t proc, int index){
@@ -969,14 +958,9 @@ void SIMIX_segment_index_set(smx_actor_t proc, int index){
  * \param properties the properties of the process
  * \param auto_restart either it is autorestarting or not.
  */
-smx_actor_t simcall_process_create(const char *name,
-                              xbt_main_func_t code,
-                              void *data,
-                              sg_host_t host,
-                              double kill_time,
-                              int argc, char **argv,
-                              xbt_dict_t properties,
-                              int auto_restart)
+extern "C"
+smx_actor_t simcall_process_create(const char* name, xbt_main_func_t code, void* data, sg_host_t host, int argc,
+                                   char** argv, xbt_dict_t properties)
 {
   if (name == nullptr)
     name = "";
@@ -984,21 +968,17 @@ smx_actor_t simcall_process_create(const char *name,
   for (int i = 0; i != argc; ++i)
     xbt_free(argv[i]);
   xbt_free(argv);
-  smx_actor_t res = simcall_process_create(name,
-    std::move(wrapped_code),
-    data, host, kill_time, properties, auto_restart);
+  smx_actor_t res = simcall_process_create(name, std::move(wrapped_code), data, host, properties);
   return res;
 }
 
-smx_actor_t simcall_process_create(
-  const char *name, std::function<void()> code, void *data,
-  sg_host_t host, double kill_time,
-  xbt_dict_t properties, int auto_restart)
+smx_actor_t simcall_process_create(const char* name, std::function<void()> code, void* data, sg_host_t host,
+                                   xbt_dict_t properties)
 {
   if (name == nullptr)
     name = "";
   smx_actor_t self = SIMIX_process_self();
-  return simgrid::simix::kernelImmediate([&] {
-    return SIMIX_process_create(name, std::move(code), data, host, kill_time, properties, auto_restart, self);
+  return simgrid::simix::kernelImmediate([name, code, data, host, properties, self] {
+    return SIMIX_process_create(name, std::move(code), data, host, properties, self);
   });
 }
