@@ -1,21 +1,19 @@
-/* Copyright (c) 2010-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "smx_private.h"
-#include "xbt/fifo.h"
 #include "xbt/xbt_os_thread.h"
-#if HAVE_MC
+#if SIMGRID_HAVE_MC
 #include "src/mc/mc_private.h"
 #endif
 
-#include "src/kernel/activity/SynchroExec.hpp"
-#include "src/kernel/activity/SynchroComm.hpp"
-#include "src/kernel/activity/SynchroSleep.hpp"
-#include "src/kernel/activity/SynchroRaw.hpp"
+#include "src/kernel/activity/CommImpl.hpp"
+#include "src/kernel/activity/ExecImpl.hpp"
+#include "src/kernel/activity/SleepImpl.hpp"
 #include "src/kernel/activity/SynchroIo.hpp"
+#include "src/kernel/activity/SynchroRaw.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_popping, simix,
                                 "Popping part of SIMIX (transmuting from user request into kernel handlers)");
@@ -29,7 +27,7 @@ void SIMIX_simcall_answer(smx_simcall_t simcall)
 /*    This check should be useless and slows everyone. Reactivate if you see something
  *    weird in process scheduling.
  */
-/*    if(!xbt_dynar_member(simix_global->process_to_run, &(simcall->issuer))) */
+    /*    if(not xbt_dynar_member(simix_global->process_to_run, &(simcall->issuer))) */
     xbt_dynar_push_as(simix_global->process_to_run, smx_actor_t, simcall->issuer);
 /*    else DIE_IMPOSSIBLE; */
   }
