@@ -1,5 +1,4 @@
-/* Copyright (c) 2007, 2009-2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,12 +6,9 @@
 #include <string>
 #include <vector>
 
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/Host.hpp"
 #include "smx_private.h"
 #include "src/surf/xml/platf_private.hpp" // FIXME: KILLME. There must be a better way than mimicking XML here
-#include "xbt/dict.h"
-#include "xbt/log.h"
-#include "xbt/sysdep.h"
 #include <xbt/ex.hpp>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_deployment, simix, "Logging specific to SIMIX (deployment)");
@@ -50,7 +46,7 @@ void SIMIX_launch_application(const char *file)
   try {
     parse_status = surf_parse();
     surf_parse_close();
-    xbt_assert(!parse_status, "Parse error at %s:%d", file,surf_parse_lineno);
+    xbt_assert(not parse_status, "Parse error at %s:%d", file, surf_parse_lineno);
   }
   catch (xbt_ex& e) {
     XBT_ERROR("Unrecoverable error at %s:%d. The full exception stack follows, in case it helps you to diagnose the problem.",
@@ -128,7 +124,7 @@ void SIMIX_process_set_function(const char *process_host,
   memset(&process,0,sizeof(process));
 
   sg_host_t host = sg_host_by_name(process_host);
-  if (!host)
+  if (not host)
     THROWF(arg_error, 0, "Host '%s' unknown", process_host);
   process.host = host->cname();
 
@@ -151,7 +147,7 @@ void SIMIX_process_set_function(const char *process_host,
   process.host = process_host;
   process.kill_time = process_kill_time;
   process.start_time = process_start_time;
-  process.on_failure = SURF_PROCESS_ON_FAILURE_DIE;
+  process.on_failure = SURF_ACTOR_ON_FAILURE_DIE;
   sg_platf_new_process(&process);
 }
 
