@@ -1,5 +1,4 @@
-/* Copyright (c) 2013-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2013-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,11 +10,11 @@
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * 
+ *
  * Additional copyrights may follow
  */
 
@@ -56,9 +55,7 @@
     ompi_coll_tree_t*
     ompi_coll_tuned_topo_build_bmtree( MPI_Comm comm,
                                        int root );
-    ompi_coll_tree_t*
-    ompi_coll_tuned_topo_build_in_order_bmtree( MPI_Comm comm,
-						int root );
+    ompi_coll_tree_t* ompi_coll_tuned_topo_build_in_order_bmtree(MPI_Comm comm, int root);
     ompi_coll_tree_t*
     ompi_coll_tuned_topo_build_chain( int fanout,
                                       MPI_Comm com,
