@@ -37,8 +37,8 @@ CpuTiTrace::CpuTiTrace(tmgr_trace_t speedTrace)
   for (auto val : speedTrace->event_list) {
     timePoints_[i] = time;
     integral_[i] = integral;
-    integral += val.delta * val.value;
-    time += val.delta;
+    integral += val.date_ * val.value_;
+    time += val.date_;
     i++;
   }
   timePoints_[i] = time;
@@ -69,11 +69,7 @@ CpuTiTgmr::~CpuTiTgmr()
 */
 double CpuTiTgmr::integrate(double a, double b)
 {
-  double first_chunk;
-  double middle_chunk;
-  double last_chunk;
   int a_index;
-  int b_index;
 
   if ((a < 0.0) || (a > b)) {
     xbt_die("Error, invalid integration interval [%.2f,%.2f]. "
@@ -91,15 +87,15 @@ double CpuTiTgmr::integrate(double a, double b)
   else
     a_index = static_cast<int> (ceil(a / lastTime_));
 
-  b_index = static_cast<int> (floor(b / lastTime_));
+  int b_index = static_cast<int> (floor(b / lastTime_));
 
   if (a_index > b_index) {      /* Same chunk */
     return trace_->integrateSimple(a - (a_index - 1) * lastTime_, b - (b_index) * lastTime_);
   }
 
-  first_chunk = trace_->integrateSimple(a - (a_index - 1) * lastTime_, lastTime_);
-  middle_chunk = (b_index - a_index) * total_;
-  last_chunk = trace_->integrateSimple(0.0, b - (b_index) * lastTime_);
+  double first_chunk = trace_->integrateSimple(a - (a_index - 1) * lastTime_, lastTime_);
+  double middle_chunk = (b_index - a_index) * total_;
+  double last_chunk = trace_->integrateSimple(0.0, b - (b_index) * lastTime_);
 
   XBT_DEBUG("first_chunk=%.2f  middle_chunk=%.2f  last_chunk=%.2f\n", first_chunk, middle_chunk, last_chunk);
 
@@ -124,10 +120,10 @@ double CpuTiTrace::integrateSimple(double a, double b)
 double CpuTiTrace::integrateSimplePoint(double a)
 {
   double integral = 0;
-  int ind;
   double a_aux = a;
-  ind = binarySearch(timePoints_, a, 0, nbPoints_ - 1);
+  int ind = binarySearch(timePoints_, a, 0, nbPoints_ - 1);
   integral += integral_[ind];
+
   XBT_DEBUG("a %f ind %d integral %f ind + 1 %f ind %f time +1 %f time %f",
        a, ind, integral, integral_[ind + 1], integral_[ind], timePoints_[ind + 1], timePoints_[ind]);
   double_update(&a_aux, timePoints_[ind], sg_maxmin_precision*sg_surf_precision);
@@ -241,8 +237,8 @@ double CpuTiTgmr::getPowerScale(double a)
 {
   double reduced_a = a - floor(a / lastTime_) * lastTime_;
   int point = trace_->binarySearch(trace_->timePoints_, reduced_a, 0, trace_->nbPoints_ - 1);
-  s_tmgr_event_t val = speedTrace_->event_list.at(point);
-  return val.value;
+  trace_mgr::DatedValue val = speedTrace_->event_list.at(point);
+  return val.value_;
 }
 
 /**
@@ -259,7 +255,7 @@ CpuTiTgmr::CpuTiTgmr(tmgr_trace_t speedTrace, double value) :
   trace_ = 0;
 
 /* no availability file, fixed trace */
-  if (!speedTrace) {
+  if (not speedTrace) {
     type_ = TRACE_FIXED;
     value_ = value;
     XBT_DEBUG("No availability trace. Constant value = %f", value);
@@ -268,9 +264,9 @@ CpuTiTgmr::CpuTiTgmr(tmgr_trace_t speedTrace, double value) :
 
   /* only one point available, fixed trace */
   if (speedTrace->event_list.size() == 1) {
-    s_tmgr_event_t val = speedTrace->event_list.front();
+    trace_mgr::DatedValue val = speedTrace->event_list.front();
     type_ = TRACE_FIXED;
-    value_ = val.value;
+    value_                    = val.value_;
     return;
   }
 
@@ -278,7 +274,7 @@ CpuTiTgmr::CpuTiTgmr(tmgr_trace_t speedTrace, double value) :
 
   /* count the total time of trace file */
   for (auto val : speedTrace->event_list)
-    total_time += val.delta;
+    total_time += val.date_;
 
   trace_ = new CpuTiTrace(speedTrace);
   lastTime_ = total_time;
@@ -300,9 +296,8 @@ int CpuTiTrace::binarySearch(double *array, double a, int low, int high)
 {
   xbt_assert(low < high, "Wrong parameters: low (%d) should be smaller than high (%d)", low, high);
 
-  int mid;
   do {
-    mid = low + (high - low) / 2;
+    int mid = low + (high - low) / 2;
     XBT_DEBUG("a %f low %d high %d mid %d value %f", a, low, high, mid, array[mid]);
 
     if (array[mid] > a)
@@ -324,8 +319,8 @@ int CpuTiTrace::binarySearch(double *array, double a, int low, int high)
 
 void surf_cpu_model_init_ti()
 {
-  xbt_assert(!surf_cpu_model_pm,"CPU model already initialized. This should not happen.");
-  xbt_assert(!surf_cpu_model_vm,"CPU model already initialized. This should not happen.");
+  xbt_assert(not surf_cpu_model_pm, "CPU model already initialized. This should not happen.");
+  xbt_assert(not surf_cpu_model_vm, "CPU model already initialized. This should not happen.");
 
   surf_cpu_model_pm = new simgrid::surf::CpuTiModel();
   all_existing_models->push_back(surf_cpu_model_pm);
@@ -426,13 +421,13 @@ void CpuTi::setSpeedTrace(tmgr_trace_t trace)
 
   /* add a fake trace event if periodicity == 0 */
   if (trace && trace->event_list.size() > 1) {
-    s_tmgr_event_t val = trace->event_list.back();
-    if (val.delta < 1e-12)
-      speed_.event = future_evt_set->add_trace(tmgr_empty_trace_new(), 0.0, this);
+    trace_mgr::DatedValue val = trace->event_list.back();
+    if (val.date_ < 1e-12)
+      speed_.event = future_evt_set->add_trace(new simgrid::trace_mgr::trace(), this);
   }
 }
 
-void CpuTi::apply_event(tmgr_trace_iterator_t event, double value)
+void CpuTi::apply_event(tmgr_trace_event_t event, double value)
 {
   if (event == speed_.event) {
     tmgr_trace_t speedTrace;
@@ -445,12 +440,12 @@ void CpuTi::apply_event(tmgr_trace_iterator_t event, double value)
     modified(true);
 
     speedTrace = speedIntegratedTrace_->speedTrace_;
-    s_tmgr_event_t val = speedTrace->event_list.back();
+    trace_mgr::DatedValue val = speedTrace->event_list.back();
     delete speedIntegratedTrace_;
-    speed_.scale = val.value;
+    speed_.scale = val.value_;
 
-    trace = new CpuTiTgmr(TRACE_FIXED, val.value);
-    XBT_DEBUG("value %f", val.value);
+    trace = new CpuTiTgmr(TRACE_FIXED, val.value_);
+    XBT_DEBUG("value %f", val.value_);
 
     speedIntegratedTrace_ = trace;
 
@@ -475,8 +470,8 @@ void CpuTi::apply_event(tmgr_trace_iterator_t event, double value)
           action->setFinishTime(date);
           action->setState(Action::State::failed);
           if (action->indexHeap_ >= 0) {
-            CpuTiAction *heap_act =
-                static_cast<CpuTiAction*>(xbt_heap_remove(static_cast<CpuTiModel*>(getModel())->tiActionHeap_, action->indexHeap_));
+            CpuTiAction* heap_act = static_cast<CpuTiAction*>(
+                xbt_heap_remove(static_cast<CpuTiModel*>(model())->tiActionHeap_, action->indexHeap_));
             if (heap_act != action)
               DIE_IMPOSSIBLE;
           }
@@ -495,7 +490,6 @@ void CpuTi::updateActionsFinishTime(double now)
   CpuTiAction *action;
   double sum_priority = 0.0;
   double total_area;
-  double min_finish = -1;
 
   /* update remaining amount of actions */
   updateRemainingAmount(now);
@@ -520,7 +514,7 @@ void CpuTi::updateActionsFinishTime(double now)
 
   for(ActionTiList::iterator it(actionSet_->begin()), itend(actionSet_->end()) ; it != itend ; ++it) {
     action = &*it;
-    min_finish = -1;
+    double min_finish = -1;
     /* action not running, skip it */
     if (action->getStateSet() !=  surf_cpu_model_pm->getRunningActionSet())
       continue;
@@ -547,16 +541,16 @@ void CpuTi::updateActionsFinishTime(double now)
     /* add in action heap */
     XBT_DEBUG("action(%p) index %d", action, action->indexHeap_);
     if (action->indexHeap_ >= 0) {
-      CpuTiAction *heap_act =
-          static_cast<CpuTiAction*>(xbt_heap_remove(static_cast<CpuTiModel*>(getModel())->tiActionHeap_, action->indexHeap_));
+      CpuTiAction* heap_act = static_cast<CpuTiAction*>(
+          xbt_heap_remove(static_cast<CpuTiModel*>(model())->tiActionHeap_, action->indexHeap_));
       if (heap_act != action)
         DIE_IMPOSSIBLE;
     }
     if (min_finish > NO_MAX_DURATION)
-      xbt_heap_push(static_cast<CpuTiModel*>(getModel())->tiActionHeap_, action, min_finish);
+      xbt_heap_push(static_cast<CpuTiModel*>(model())->tiActionHeap_, action, min_finish);
 
-    XBT_DEBUG("Update finish time: Cpu(%s) Action: %p, Start Time: %f Finish Time: %f Max duration %f",
-         getName(), action, action->getStartTime(), action->finishTime_, action->getMaxDuration());
+    XBT_DEBUG("Update finish time: Cpu(%s) Action: %p, Start Time: %f Finish Time: %f Max duration %f", cname(), action,
+              action->getStartTime(), action->finishTime_, action->getMaxDuration());
   }
   /* remove from modified cpu */
   modified(false);
@@ -564,7 +558,7 @@ void CpuTi::updateActionsFinishTime(double now)
 
 bool CpuTi::isUsed()
 {
-  return !actionSet_->empty();
+  return not actionSet_->empty();
 }
 
 double CpuTi::getAvailableSpeed()
@@ -588,7 +582,7 @@ void CpuTi::updateRemainingAmount(double now)
   for(ActionTiList::iterator it(actionSet_->begin()), itend(actionSet_->end()) ; it != itend ; ++it) {
     CpuTiAction *action = &*it;
     /* action not running, skip it */
-    if (action->getStateSet() != getModel()->getRunningActionSet())
+    if (action->getStateSet() != model()->getRunningActionSet())
       continue;
 
     /* bogus priority, skip it */
@@ -616,8 +610,8 @@ void CpuTi::updateRemainingAmount(double now)
 
 CpuAction *CpuTi::execution_start(double size)
 {
-  XBT_IN("(%s,%g)", getName(), size);
-  CpuTiAction *action = new CpuTiAction(static_cast<CpuTiModel*>(getModel()), size, isOff(), this);
+  XBT_IN("(%s,%g)", cname(), size);
+  CpuTiAction* action = new CpuTiAction(static_cast<CpuTiModel*>(model()), size, isOff(), this);
 
   actionSet_->push_back(*action);
 
@@ -631,8 +625,8 @@ CpuAction *CpuTi::sleep(double duration)
   if (duration > 0)
     duration = MAX(duration, sg_surf_precision);
 
-  XBT_IN("(%s,%g)", getName(), duration);
-  CpuTiAction *action = new CpuTiAction(static_cast<CpuTiModel*>(getModel()), 1.0, isOff(), this);
+  XBT_IN("(%s,%g)", cname(), duration);
+  CpuTiAction* action = new CpuTiAction(static_cast<CpuTiModel*>(model()), 1.0, isOff(), this);
 
   action->maxDuration_ = duration;
   action->suspended_ = 2;
@@ -640,8 +634,8 @@ CpuAction *CpuTi::sleep(double duration)
    /* Move to the *end* of the corresponding action set. This convention
       is used to speed up update_resource_state  */
   action->getStateSet()->erase(action->getStateSet()->iterator_to(*action));
-    action->stateSet_ = static_cast<CpuTiModel*>(getModel())->runningActionSetThatDoesNotNeedBeingChecked_;
-    action->getStateSet()->push_back(*action);
+  action->stateSet_ = static_cast<CpuTiModel*>(model())->runningActionSetThatDoesNotNeedBeingChecked_;
+  action->getStateSet()->push_back(*action);
   }
 
   actionSet_->push_back(*action);
@@ -651,9 +645,9 @@ CpuAction *CpuTi::sleep(double duration)
 }
 
 void CpuTi::modified(bool modified){
-  CpuTiList *modifiedCpu = static_cast<CpuTiModel*>(getModel())->modifiedCpu_;
+  CpuTiList* modifiedCpu = static_cast<CpuTiModel*>(model())->modifiedCpu_;
   if (modified) {
-    if (!cpu_ti_hook.is_linked()) {
+    if (not cpu_ti_hook.is_linked()) {
       modifiedCpu->push_back(*this);
     }
   } else {
@@ -688,7 +682,7 @@ void CpuTiAction::setState(Action::State state)
 int CpuTiAction::unref()
 {
   refcount_--;
-  if (!refcount_) {
+  if (not refcount_) {
     if (action_hook.is_linked())
       getStateSet()->erase(getStateSet()->iterator_to(*this));
     /* remove from action_set */
@@ -708,7 +702,6 @@ void CpuTiAction::cancel()
   this->setState(Action::State::failed);
   xbt_heap_remove(getModel()->getActionHeap(), this->indexHeap_);
   cpu_->modified(true);
-  return;
 }
 
 void CpuTiAction::suspend()
