@@ -10,7 +10,6 @@
 
 #include "src/surf/cpu_interface.hpp"
 #include "src/surf/trace_mgr.hpp"
-#include "surf/surf_routing.h"
 
 /* Epsilon */
 #define EPSILON 0.000000001
@@ -99,7 +98,7 @@ public:
   CpuTi *cpu_;
   int indexHeap_ = -1;
   int suspended_ = 0;
-public:
+
   boost::intrusive::list_member_hook<> action_ti_hook;
 };
 
@@ -116,7 +115,7 @@ public:
 
   void setSpeedTrace(tmgr_trace_t trace) override;
 
-  void apply_event(tmgr_trace_iterator_t event, double value) override;
+  void apply_event(tmgr_trace_event_t event, double value) override;
   void updateActionsFinishTime(double now);
   void updateRemainingAmount(double now);
 
@@ -134,7 +133,6 @@ public:
 
   double currentFrequency_;
 
-public:
   boost::intrusive::list_member_hook<> cpu_ti_hook;
 };
 
