@@ -1,13 +1,12 @@
-/* Copyright (c) 2010, 2012-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/instr/instr_private.h"
 
-#include "simgrid/s4u/engine.hpp"
-#include "simgrid/s4u/host.hpp"
+#include "simgrid/s4u/Engine.hpp"
+#include "simgrid/s4u/Host.hpp"
 #include "src/kernel/routing/NetZoneImpl.hpp"
 #include "src/surf/network_interface.hpp"
 #include "src/surf/xml/platf_private.hpp"
@@ -22,19 +21,18 @@ static std::vector<container_t> currentContainer; /* push and pop, used only in
 static const char *instr_node_name (xbt_node_t node)
 {
   void *data = xbt_graph_node_get_data(node);
-  char *str = (char*)data;
-  return str;
+  return static_cast<char*>(data);
 }
 
 static container_t lowestCommonAncestor (container_t a1, container_t a2)
 {
   //this is only an optimization (since most of a1 and a2 share the same parent)
-  if (a1->father == a2->father) return a1->father;
+  if (a1->father == a2->father)
+    return a1->father;
 
   //create an array with all ancestors of a1
   std::vector<container_t> ancestors_a1;
-  container_t p;
-  p = a1->father;
+  container_t p = a1->father;
   while (p){
     ancestors_a1.push_back(p);
     p = p->father;
@@ -76,13 +74,14 @@ static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
 
   //find common father
   container_t father = lowestCommonAncestor (src, dst);
-  if (!father){
+  if (not father) {
     xbt_die ("common father unknown, this is a tracing problem");
   }
 
   if (filter != nullptr){
     //check if we already register this pair (we only need one direction)
-    char aux1[INSTR_DEFAULT_STR_SIZE], aux2[INSTR_DEFAULT_STR_SIZE];
+    char aux1[INSTR_DEFAULT_STR_SIZE];
+    char aux2[INSTR_DEFAULT_STR_SIZE];
     snprintf (aux1, INSTR_DEFAULT_STR_SIZE, "%s%s", src->name, dst->name);
     snprintf (aux2, INSTR_DEFAULT_STR_SIZE, "%s%s", dst->name, src->name);
     if (xbt_dict_get_or_null (filter, aux1)){
@@ -117,58 +116,55 @@ static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
   static long long counter = 0;
 
   char key[INSTR_DEFAULT_STR_SIZE];
-  snprintf (key, INSTR_DEFAULT_STR_SIZE, "%lld", counter++);
-  new_pajeStartLink(SIMIX_get_clock(), father, link_type, src, "topology", key);
-  new_pajeEndLink(SIMIX_get_clock(), father, link_type, dst, "topology", key);
+  snprintf (key, INSTR_DEFAULT_STR_SIZE, "%lld", counter);
+  counter++;
+
+  new StartLinkEvent(SIMIX_get_clock(), father, link_type, src, "topology", key);
+  new EndLinkEvent(SIMIX_get_clock(), father, link_type, dst, "topology", key);
 
   XBT_DEBUG ("  linkContainers %s <-> %s", src->name, dst->name);
 }
 
 static void recursiveGraphExtraction(simgrid::s4u::NetZone* netzone, container_t container, xbt_dict_t filter)
 {
-  if (!TRACE_platform_topology()){
+  if (not TRACE_platform_topology()) {
     XBT_DEBUG("Graph extraction disabled by user.");
     return;
   }
   XBT_DEBUG("Graph extraction for NetZone = %s", netzone->name());
-  if (!xbt_dict_is_empty(netzone->children())) {
-    xbt_dict_cursor_t cursor = nullptr;
-    NetZone_t nz_son;
-    char *child_name;
+  if (not netzone->children()->empty()) {
     //bottom-up recursion
-    xbt_dict_foreach (netzone->children(), cursor, child_name, nz_son) {
-      container_t child_container = (container_t)xbt_dict_get(container->children, nz_son->name());
+    for (auto nz_son : *netzone->children()) {
+      container_t child_container = static_cast<container_t>(xbt_dict_get(container->children, nz_son->name()));
       recursiveGraphExtraction(nz_son, child_container, filter);
     }
   }
 
-  {
-    xbt_graph_t graph = xbt_graph_new_graph (0, nullptr);
-    xbt_dict_t nodes = xbt_dict_new_homogeneous(nullptr);
-    xbt_dict_t edges = xbt_dict_new_homogeneous(nullptr);
-    xbt_edge_t edge = nullptr;
+  xbt_graph_t graph = xbt_graph_new_graph (0, nullptr);
+  xbt_dict_t nodes = xbt_dict_new_homogeneous(nullptr);
+  xbt_dict_t edges = xbt_dict_new_homogeneous(nullptr);
+  xbt_edge_t edge = nullptr;
 
-    xbt_dict_cursor_t cursor = nullptr;
-    char *edge_name;
+  xbt_dict_cursor_t cursor = nullptr;
+  char *edge_name;
 
-    static_cast<simgrid::kernel::routing::NetZoneImpl*>(netzone)->getGraph(graph, nodes, edges);
-    xbt_dict_foreach(edges,cursor,edge_name,edge) {
-        linkContainers(
-          PJ_container_get((const char*) edge->src->data),
-          PJ_container_get((const char*) edge->dst->data), filter);
-    }
-    xbt_dict_free (&nodes);
-    xbt_dict_free (&edges);
-    xbt_graph_free_graph(graph, xbt_free_f, xbt_free_f, nullptr);
+  static_cast<simgrid::kernel::routing::NetZoneImpl*>(netzone)->getGraph(graph, nodes, edges);
+  xbt_dict_foreach(edges,cursor,edge_name,edge) {
+    linkContainers(
+          PJ_container_get(static_cast<const char*>(edge->src->data)),
+          PJ_container_get(static_cast<const char*>(edge->dst->data)), filter);
   }
+  xbt_dict_free (&nodes);
+  xbt_dict_free (&edges);
+  xbt_graph_free_graph(graph, xbt_free_f, xbt_free_f, nullptr);
 }
 
 /*
  * Callbacks
  */
-void sg_instr_AS_begin(sg_platf_AS_cbarg_t AS)
+static void sg_instr_AS_begin(simgrid::s4u::NetZone& netzone)
 {
-  const char*id = AS->id;
+  const char* id = netzone.name();
 
   if (PJ_container_get_root() == nullptr){
     PJ_container_alloc ();
@@ -180,7 +176,8 @@ void sg_instr_AS_begin(sg_platf_AS_cbarg_t AS)
       type_t mpi = PJ_type_get_or_null ("MPI", root->type);
       if (mpi == nullptr){
         mpi = PJ_type_container_new("MPI", root->type);
-        if (!TRACE_smpi_is_grouped()) PJ_type_state_new ("MPI_STATE", mpi);
+        if (not TRACE_smpi_is_grouped())
+          PJ_type_state_new ("MPI_STATE", mpi);
         PJ_type_link_new ("MPI_LINK", PJ_type_get_root(), mpi, mpi);
       }
     }
@@ -198,25 +195,25 @@ void sg_instr_AS_begin(sg_platf_AS_cbarg_t AS)
   }
 }
 
-void sg_instr_AS_end()
+static void sg_instr_AS_end(simgrid::s4u::NetZone& /*netzone*/)
 {
   if (TRACE_needs_platform()){
     currentContainer.pop_back();
   }
 }
 
-static void instr_routing_parse_start_link(simgrid::surf::Link* link)
+static void instr_routing_parse_start_link(simgrid::s4u::Link& link)
 {
   if (currentContainer.empty()) // No ongoing parsing. Are you creating the loopback?
     return;
   container_t father = currentContainer.back();
 
-  double bandwidth_value = link->bandwidth();
-  double latency_value   = link->latency();
+  double bandwidth_value = link.bandwidth();
+  double latency_value   = link.latency();
 
-  container_t container = PJ_container_new(link->getName(), INSTR_LINK, father);
+  container_t container = PJ_container_new(link.name(), INSTR_LINK, father);
 
-  if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (! TRACE_disable_link())) {
+  if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (not TRACE_disable_link())) {
     type_t bandwidth = PJ_type_get_or_null("bandwidth", container->type);
     if (bandwidth == nullptr) {
       bandwidth = PJ_type_variable_new("bandwidth", nullptr, container->type);
@@ -225,8 +222,8 @@ static void instr_routing_parse_start_link(simgrid::surf::Link* link)
     if (latency == nullptr) {
       latency = PJ_type_variable_new("latency", nullptr, container->type);
     }
-    new_pajeSetVariable(0, container, bandwidth, bandwidth_value);
-    new_pajeSetVariable(0, container, latency, latency_value);
+    new SetVariableEvent(0, container, bandwidth, bandwidth_value);
+    new SetVariableEvent(0, container, latency, latency_value);
   }
   if (TRACE_uncategorized()) {
     type_t bandwidth_used = PJ_type_get_or_null("bandwidth_used", container->type);
@@ -236,19 +233,19 @@ static void instr_routing_parse_start_link(simgrid::surf::Link* link)
   }
 }
 
-void sg_instr_new_host(simgrid::s4u::Host& host)
+static void sg_instr_new_host(simgrid::s4u::Host& host)
 {
   container_t father = currentContainer.back();
   container_t container = PJ_container_new(host.cname(), INSTR_HOST, father);
 
-  if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (! TRACE_disable_speed())) {
+  if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (not TRACE_disable_speed())) {
     type_t speed = PJ_type_get_or_null ("power", container->type);
     if (speed == nullptr){
       speed = PJ_type_variable_new ("power", nullptr, container->type);
     }
 
-    double current_speed_state = host.getPstateSpeedCurrent();
-    new_pajeSetVariable (0, container, speed, current_speed_state);
+    double current_speed_state = host.speed();
+    new SetVariableEvent (0, container, speed, current_speed_state);
   }
   if (TRACE_uncategorized()){
     type_t speed_used = PJ_type_get_or_null ("power_used", container->type);
@@ -297,10 +294,12 @@ void sg_instr_new_host(simgrid::s4u::Host& host)
 
 }
 
-void sg_instr_new_router(sg_platf_router_cbarg_t router)
+void sg_instr_new_router(const char* name)
 {
-  container_t father = currentContainer.back();
-  PJ_container_new (router->id, INSTR_ROUTER, father);
+  if (TRACE_is_enabled() && TRACE_needs_platform()) {
+    container_t father = currentContainer.back();
+    PJ_container_new(name, INSTR_ROUTER, father);
+  }
 }
 
 static void instr_routing_parse_end_platform ()
@@ -317,12 +316,17 @@ static void instr_routing_parse_end_platform ()
 
 void instr_routing_define_callbacks ()
 {
-  if (!TRACE_is_enabled()) return;
   //always need the call backs to ASes (we need only the root AS),
   //to create the rootContainer and the rootType properly
-  if (!TRACE_needs_platform()) return;
-  simgrid::surf::Link::onCreation.connect(instr_routing_parse_start_link);
-  simgrid::surf::on_postparse.connect(instr_routing_parse_end_platform);
+  if (not TRACE_is_enabled())
+    return;
+  if (TRACE_needs_platform()) {
+    simgrid::s4u::Link::onCreation.connect(instr_routing_parse_start_link);
+    simgrid::s4u::onPlatformCreated.connect(instr_routing_parse_end_platform);
+    simgrid::s4u::Host::onCreation.connect(sg_instr_new_host);
+  }
+  simgrid::s4u::NetZone::onCreation.connect(sg_instr_AS_begin);
+  simgrid::s4u::NetZone::onSeal.connect(sg_instr_AS_end);
 }
 
 /*
@@ -330,17 +334,17 @@ void instr_routing_define_callbacks ()
  */
 static void recursiveNewVariableType (const char *new_typename, const char *color, type_t root)
 {
-  if (!strcmp (root->name, "HOST")){
+  if (not strcmp(root->name, "HOST")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "p%s", new_typename);
     PJ_type_variable_new (tnstr, color, root);
   }
-  if (!strcmp (root->name, "MSG_VM")){
+  if (not strcmp(root->name, "MSG_VM")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "p%s", new_typename);
     PJ_type_variable_new (tnstr, color, root);
   }
- if (!strcmp (root->name, "LINK")){
+  if (not strcmp(root->name, "LINK")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "b%s", new_typename);
     PJ_type_variable_new (tnstr, color, root);
@@ -360,7 +364,7 @@ void instr_new_variable_type (const char *new_typename, const char *color)
 
 static void recursiveNewUserVariableType (const char *father_type, const char *new_typename, const char *color, type_t root)
 {
-  if (!strcmp (root->name, father_type)){
+  if (not strcmp(root->name, father_type)) {
     PJ_type_variable_new (new_typename, color, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
@@ -378,7 +382,7 @@ void instr_new_user_variable_type  (const char *father_type, const char *new_typ
 
 static void recursiveNewUserStateType (const char *father_type, const char *new_typename, type_t root)
 {
-  if (!strcmp (root->name, father_type)){
+  if (not strcmp(root->name, father_type)) {
     PJ_type_state_new (new_typename, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
@@ -396,7 +400,7 @@ void instr_new_user_state_type (const char *father_type, const char *new_typenam
 
 static void recursiveNewValueForUserStateType (const char *type_name, const char *value, const char *color, type_t root)
 {
-  if (!strcmp (root->name, type_name)){
+  if (not strcmp(root->name, type_name)) {
     PJ_value_new (value, color, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
@@ -419,16 +423,13 @@ int instr_platform_traced ()
 
 #define GRAPHICATOR_SUPPORT_FUNCTIONS
 
-static void recursiveXBTGraphExtraction(xbt_graph_t graph, xbt_dict_t nodes, xbt_dict_t edges, NetZone_t netzone,
+static void recursiveXBTGraphExtraction(xbt_graph_t graph, xbt_dict_t nodes, xbt_dict_t edges, sg_netzone_t netzone,
                                         container_t container)
 {
-  if (!xbt_dict_is_empty(netzone->children())) {
-    xbt_dict_cursor_t cursor = nullptr;
-    NetZone_t netzone_child;
-    char *child_name;
+  if (not netzone->children()->empty()) {
     //bottom-up recursion
-    xbt_dict_foreach (netzone->children(), cursor, child_name, netzone_child) {
-      container_t child_container = (container_t)xbt_dict_get(container->children, netzone_child->name());
+    for (auto netzone_child : *netzone->children()) {
+      container_t child_container = static_cast<container_t>(xbt_dict_get(container->children, netzone_child->name()));
       recursiveXBTGraphExtraction(graph, nodes, edges, netzone_child, child_container);
     }
   }
@@ -452,9 +453,8 @@ void instr_routing_platform_graph_export_graphviz (xbt_graph_t g, const char *fi
   unsigned int cursor = 0;
   xbt_node_t node = nullptr;
   xbt_edge_t edge = nullptr;
-  FILE *file = nullptr;
 
-  file = fopen(filename, "w");
+  FILE *file = fopen(filename, "w");
   xbt_assert(file, "Failed to open %s \n", filename);
 
   if (g->directed)
@@ -465,8 +465,7 @@ void instr_routing_platform_graph_export_graphviz (xbt_graph_t g, const char *fi
   fprintf(file, "  graph [overlap=scale]\n");
 
   fprintf(file, "  node [shape=box, style=filled]\n");
-  fprintf(file,
-          "  node [width=.3, height=.3, style=filled, color=skyblue]\n\n");
+  fprintf(file, "  node [width=.3, height=.3, style=filled, color=skyblue]\n\n");
 
   xbt_dynar_foreach(g->nodes, cursor, node) {
     fprintf(file, "  \"%s\";\n", instr_node_name(node));
@@ -481,5 +480,4 @@ void instr_routing_platform_graph_export_graphviz (xbt_graph_t g, const char *fi
   }
   fprintf(file, "}\n");
   fclose(file);
-
 }
