@@ -30,7 +30,7 @@ namespace simgrid {
       double nextOccuringEvent(double now) override;
       void updateActionsState(double now, double delta) override;
 
-      Link* createLink(const char* name, double bw, double lat, e_surf_link_sharing_policy_t policy) override;
+      LinkImpl* createLink(const char* name, double bw, double lat, e_surf_link_sharing_policy_t policy) override;
     };
 
     /**********
