@@ -1,11 +1,10 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef _NS3_SIM_H
-#define _NS3_SIM_H
+#ifndef NS3_SIM_H
+#define NS3_SIM_H
 
 #include <cstdint>
 
