@@ -58,7 +58,8 @@ class NetworkL07Model : public NetworkModel {
 public:
   NetworkL07Model(HostL07Model *hmodel, lmm_system_t sys);
   ~NetworkL07Model();
-  Link* createLink(const char* name, double bandwidth, double latency, e_surf_link_sharing_policy_t policy) override;
+  LinkImpl* createLink(const char* name, double bandwidth, double latency,
+                       e_surf_link_sharing_policy_t policy) override;
 
   Action* communicate(s4u::Host* src, s4u::Host* dst, double size, double rate) override;
 
@@ -72,22 +73,22 @@ public:
 class CpuL07 : public Cpu {
 public:
   CpuL07(CpuL07Model *model, simgrid::s4u::Host *host, std::vector<double> * speedPerPstate, int core);
-  ~CpuL07();
+  ~CpuL07() override;
   bool isUsed() override;
-  void apply_event(tmgr_trace_iterator_t event, double value) override;
+  void apply_event(tmgr_trace_event_t event, double value) override;
   Action *execution_start(double size) override;
   Action *sleep(double duration) override;
 protected:
   void onSpeedChange() override;
 };
 
-class LinkL07 : public Link {
+class LinkL07 : public LinkImpl {
 public:
   LinkL07(NetworkL07Model* model, const char* name, double bandwidth, double latency,
           e_surf_link_sharing_policy_t policy);
-  ~LinkL07(){ };
+  ~LinkL07() override;
   bool isUsed() override;
-  void apply_event(tmgr_trace_iterator_t event, double value) override;
+  void apply_event(tmgr_trace_event_t event, double value) override;
   void setBandwidth(double value) override;
   void setLatency(double value) override;
 };
