@@ -1,64 +1,36 @@
-/* Copyright (c) 2013-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2013-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "storage_n11.hpp"
-#include "src/kernel/routing/NetCard.hpp"
-#include "surf_private.h"
+#include "simgrid/s4u/Engine.hpp"
+#include "src/kernel/routing/NetPoint.hpp"
 #include <math.h> /*ceil*/
+
 XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(surf_storage);
 
 /*************
  * CallBacks *
  *************/
-
-static inline void routing_storage_type_free(void *r)
-{
-  storage_type_t stype = (storage_type_t) r;
-  free(stype->model);
-  free(stype->type_id);
-  free(stype->content);
-  free(stype->content_type);
-  xbt_dict_free(&(stype->properties));
-  xbt_dict_free(&(stype->model_properties));
-  free(stype);
-}
-
-static inline void routing_storage_host_free(void *r)
-{
-  xbt_dynar_t dyn = (xbt_dynar_t) r;
-  xbt_dynar_free(&dyn);
-}
+extern std::map<std::string, storage_type_t> storage_types;
 
 static void check_disk_attachment()
 {
-  xbt_lib_cursor_t cursor;
-  char* key;
-  void** data;
-  xbt_lib_foreach(storage_lib, cursor, key, data) {
-    if (xbt_lib_get_level(xbt_lib_get_elm_or_null(storage_lib, key), SURF_STORAGE_LEVEL) != nullptr) {
-      simgrid::surf::Storage* storage =
-          static_cast<simgrid::surf::Storage*>(xbt_lib_get_or_null(storage_lib, key, SURF_STORAGE_LEVEL));
-      simgrid::kernel::routing::NetCard* host_elm = sg_netcard_by_name_or_null(storage->attach_);
-      if (!host_elm)
-        surf_parse_error("Unable to attach storage %s: host %s does not exist.", storage->getName(), storage->attach_);
-    }
+  for (auto s : *simgrid::surf::StorageImpl::storagesMap()) {
+    simgrid::kernel::routing::NetPoint* host_elm = sg_netpoint_by_name_or_null(s.second->attach_.c_str());
+    if (not host_elm)
+      surf_parse_error("Unable to attach storage %s: host %s does not exist.", s.second->cname(),
+                       s.second->attach_.c_str());
+    else
+      s.second->piface_.attached_to_ = sg_host_by_name(s.second->attach_.c_str());
   }
 }
 
 void storage_register_callbacks()
 {
-  simgrid::surf::on_postparse.connect(check_disk_attachment);
+  simgrid::s4u::onPlatformCreated.connect(check_disk_attachment);
   instr_routing_define_callbacks();
-
-  ROUTING_STORAGE_LEVEL = xbt_lib_add_level(storage_lib, xbt_free_f);
-  ROUTING_STORAGE_HOST_LEVEL = xbt_lib_add_level(storage_lib, routing_storage_host_free);
-  ROUTING_STORAGE_TYPE_LEVEL = xbt_lib_add_level(storage_type_lib, routing_storage_type_free);
-  SURF_STORAGE_LEVEL = xbt_lib_add_level(storage_lib, [](void *self) {
-    delete static_cast<simgrid::surf::Storage*>(self);
-  });
 }
 
 /*********
@@ -74,26 +46,19 @@ void surf_storage_model_init_default()
 namespace simgrid {
 namespace surf {
 
-Storage* StorageN11Model::createStorage(const char* id, const char* type_id, const char* content_name,
-                                        const char* content_type, const char* attach)
+StorageImpl* StorageN11Model::createStorage(const char* id, const char* type_id, const char* content_name,
+                                            const char* attach)
 {
+  storage_type_t storage_type = storage_types.at(type_id);
 
-  xbt_assert(!surf_storage_resource_priv(surf_storage_resource_by_name(id)),
-      "Storage '%s' declared several times in the platform file", id);
+  double Bread =
+      surf_parse_get_bandwidth(storage_type->model_properties->at("Bread").c_str(), "property Bread, storage", type_id);
+  double Bwrite = surf_parse_get_bandwidth(storage_type->model_properties->at("Bwrite").c_str(),
+                                           "property Bwrite, storage", type_id);
 
-  storage_type_t storage_type = (storage_type_t) xbt_lib_get_or_null(storage_type_lib, type_id,ROUTING_STORAGE_TYPE_LEVEL);
-
-  double Bread  = surf_parse_get_bandwidth((char*)xbt_dict_get(storage_type->model_properties, "Bread"),
-      "property Bread, storage",type_id);
-  double Bwrite = surf_parse_get_bandwidth((char*)xbt_dict_get(storage_type->model_properties, "Bwrite"),
-      "property Bwrite, storage",type_id);
-  double Bconnection   = surf_parse_get_bandwidth((char*)xbt_dict_get(storage_type->model_properties, "Bconnection"),
-      "property Bconnection, storage",type_id);
-
-  Storage* storage = new StorageN11(this, id, maxminSystem_, Bread, Bwrite, Bconnection, type_id, (char*)content_name,
-                                    content_type, storage_type->size, (char*)attach);
+  StorageImpl* storage = new StorageN11(this, id, maxminSystem_, Bread, Bwrite, type_id, (char*)content_name,
+                                        storage_type->size, (char*)attach);
   storageCreatedCallbacks(storage);
-  xbt_lib_set(storage_lib, id, SURF_STORAGE_LEVEL, storage);
 
   XBT_DEBUG("SURF storage create resource\n\t\tid '%s'\n\t\ttype '%s'\n\t\tBread '%f'\n", id, type_id, Bread);
 
@@ -151,10 +116,8 @@ void StorageN11Model::updateActionsState(double /*now*/, double delta)
       //  which becomes the new file size
       action->file_->size = action->file_->current_position;
 
-      sg_size_t *psize = xbt_new(sg_size_t,1);
-      *psize                  = action->file_->size;
-      xbt_dict_t content_dict = action->storage_->content_;
-      xbt_dict_set(content_dict, action->file_->name, psize, nullptr);
+      action->storage_->content_->erase(action->file_->name);
+      action->storage_->content_->insert({action->file_->name, action->file_->size});
     }
 
     action->updateRemains(lmm_variable_getvalue(action->getVariable()) * delta);
@@ -179,27 +142,24 @@ void StorageN11Model::updateActionsState(double /*now*/, double delta)
  ************/
 
 StorageN11::StorageN11(StorageModel* model, const char* name, lmm_system_t maxminSystem, double bread, double bwrite,
-                       double bconnection, const char* type_id, char* content_name, const char* content_type,
-                       sg_size_t size, char* attach)
-    : Storage(model, name, maxminSystem, bread, bwrite, bconnection, type_id, content_name, content_type, size, attach)
+                       const char* type_id, char* content_name, sg_size_t size, char* attach)
+    : StorageImpl(model, name, maxminSystem, bread, bwrite, type_id, content_name, size, attach)
 {
-  XBT_DEBUG("Create resource with Bconnection '%f' Bread '%f' Bwrite '%f' and Size '%llu'", bconnection, bread, bwrite, size);
+  XBT_DEBUG("Create resource with Bread '%f' Bwrite '%f' and Size '%llu'", bread, bwrite, size);
+  simgrid::s4u::Storage::onCreation(this->piface_);
 }
 
 StorageAction *StorageN11::open(const char* mount, const char* path)
 {
   XBT_DEBUG("\tOpen file '%s'",path);
 
-  sg_size_t size, *psize;
-  psize = (sg_size_t*) xbt_dict_get_or_null(content_, path);
+  sg_size_t size;
   // if file does not exist create an empty file
-  if(psize)
-    size = *psize;
+  if (content_->find(path) != content_->end())
+    size = content_->at(path);
   else {
-    psize = xbt_new(sg_size_t,1);
     size = 0;
-    *psize = size;
-    xbt_dict_set(content_, path, psize, nullptr);
+    content_->insert({path, size});
     XBT_DEBUG("File '%s' was not found, file created.",path);
   }
   surf_file_t file = xbt_new0(s_surf_file_t,1);
@@ -208,7 +168,7 @@ StorageAction *StorageN11::open(const char* mount, const char* path)
   file->mount = xbt_strdup(mount);
   file->current_position = 0;
 
-  StorageAction *action = new StorageN11Action(getModel(), 0, isOff(), this, OPEN);
+  StorageAction* action = new StorageN11Action(model(), 0, isOff(), this, OPEN);
   action->file_         = file;
 
   return action;
@@ -230,7 +190,7 @@ StorageAction *StorageN11::close(surf_file_t fd)
   free(fd->name);
   free(fd->mount);
   xbt_free(fd);
-  StorageAction *action = new StorageN11Action(getModel(), 0, isOff(), this, CLOSE);
+  StorageAction* action = new StorageN11Action(model(), 0, isOff(), this, CLOSE);
   return action;
 }
 
@@ -247,7 +207,7 @@ StorageAction *StorageN11::read(surf_file_t fd, sg_size_t size)
   else
     fd->current_position += size;
 
-  StorageAction *action = new StorageN11Action(getModel(), size, isOff(), this, READ);
+  StorageAction* action = new StorageN11Action(model(), size, isOff(), this, READ);
   return action;
 }
 
@@ -256,7 +216,7 @@ StorageAction *StorageN11::write(surf_file_t fd, sg_size_t size)
   char *filename = fd->name;
   XBT_DEBUG("\tWrite file '%s' size '%llu/%llu'",filename,size,fd->size);
 
-  StorageAction *action = new StorageN11Action(getModel(), size, isOff(), this, WRITE);
+  StorageAction* action = new StorageN11Action(model(), size, isOff(), this, WRITE);
   action->file_         = fd;
   /* Substract the part of the file that might disappear from the used sized on the storage element */
   usedSize_ -= (fd->size - fd->current_position);
@@ -271,14 +231,14 @@ StorageAction *StorageN11::write(surf_file_t fd, sg_size_t size)
  * Action *
  **********/
 
-StorageN11Action::StorageN11Action(Model *model, double cost, bool failed, Storage *storage, e_surf_action_storage_type_t type)
-: StorageAction(model, cost, failed,
-    lmm_variable_new(model->getMaxminSystem(), this, 1.0, -1.0 , 3),
-    storage, type) {
-  XBT_IN("(%s,%g", storage->getName(), cost);
+StorageN11Action::StorageN11Action(Model* model, double cost, bool failed, StorageImpl* storage,
+                                   e_surf_action_storage_type_t type)
+    : StorageAction(model, cost, failed, lmm_variable_new(model->getMaxminSystem(), this, 1.0, -1.0, 3), storage, type)
+{
+  XBT_IN("(%s,%g", storage->cname(), cost);
 
   // Must be less than the max bandwidth for all actions
-  lmm_expand(model->getMaxminSystem(), storage->getConstraint(), getVariable(), 1.0);
+  lmm_expand(model->getMaxminSystem(), storage->constraint(), getVariable(), 1.0);
   switch(type) {
   case OPEN:
   case CLOSE:
@@ -295,6 +255,8 @@ StorageN11Action::StorageN11Action(Model *model, double cost, bool failed, Stora
     //    storage->p_writeActions->push_back(action);
     //    ref();
     break;
+  default:
+    THROW_UNIMPLEMENTED;
   }
   XBT_OUT();
 }
@@ -302,7 +264,7 @@ StorageN11Action::StorageN11Action(Model *model, double cost, bool failed, Stora
 int StorageN11Action::unref()
 {
   refcount_--;
-  if (!refcount_) {
+  if (not refcount_) {
     if (action_hook.is_linked())
       stateSet_->erase(stateSet_->iterator_to(*this));
     if (getVariable())
