@@ -1,9 +1,9 @@
-/* Copyright (c) 2013-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2013-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include "simgrid/s4u/Engine.hpp"
 #include "src/instr/instr_private.h"
 #include "src/plugins/vm/VirtualMachineImpl.hpp"
 
@@ -18,7 +18,7 @@ extern double NOW;
 void surf_presolve()
 {
   double next_event_date = -1.0;
-  tmgr_trace_iterator_t event = nullptr;
+  tmgr_trace_event_t event          = nullptr;
   double value = -1.0;
   simgrid::surf::Resource *resource = nullptr;
 
@@ -28,9 +28,8 @@ void surf_presolve()
       break;
 
     while ((event = future_evt_set->pop_leq(next_event_date, &value, &resource))) {
-      if (value >= 0){
+      if (value >= 0)
         resource->apply_event(event, value);
-      }
     }
   }
 
@@ -46,7 +45,7 @@ double surf_solve(double max_date)
   double model_next_action_end = -1.0;
   double value = -1.0;
   simgrid::surf::Resource *resource = nullptr;
-  tmgr_trace_iterator_t event = nullptr;
+  tmgr_trace_event_t event          = nullptr;
 
   if (max_date > 0.0) {
     xbt_assert(max_date > NOW,"You asked to simulate up to %f, but that's in the past already", max_date);
@@ -75,7 +74,7 @@ double surf_solve(double max_date)
     next_event_date = future_evt_set->next_date();
     XBT_DEBUG("Next TRACE event: %f", next_event_date);
 
-    if(! surf_network_model->nextOccuringEventIsIdempotent()){ // NS3, I see you
+    if (not surf_network_model->nextOccuringEventIsIdempotent()) { // NS3, I see you
       if (next_event_date!=-1.0 && time_delta!=-1.0) {
         time_delta = MIN(next_event_date - NOW, time_delta);
       } else {
@@ -102,7 +101,7 @@ double surf_solve(double max_date)
     XBT_DEBUG("Updating models (min = %g, NOW = %g, next_event_date = %g)", time_delta, NOW, next_event_date);
 
     while ((event = future_evt_set->pop_leq(next_event_date, &value, &resource))) {
-      if (resource->isUsed() || xbt_dict_get_or_null(watched_hosts_lib, resource->getName())) {
+      if (resource->isUsed() || xbt_dict_get_or_null(watched_hosts_lib, resource->cname())) {
         time_delta = next_event_date - NOW;
         XBT_DEBUG("This event invalidates the next_occuring_event() computation of models. Next event set to %f", time_delta);
       }
@@ -111,7 +110,7 @@ double surf_solve(double max_date)
       NOW = next_event_date;
       /* update state of the corresponding resource to the new value. Does not touch lmm.
          It will be modified if needed when updating actions */
-      XBT_DEBUG("Calling update_resource_state for resource %s", resource->getName());
+      XBT_DEBUG("Calling update_resource_state for resource %s", resource->cname());
       resource->apply_event(event, value);
       NOW = round_start;
     }
@@ -120,7 +119,7 @@ double surf_solve(double max_date)
   /* FIXME: Moved this test to here to avoid stopping simulation if there are actions running on cpus and all cpus are with availability = 0.
    * This may cause an infinite loop if one cpu has a trace with periodicity = 0 and the other a trace with periodicity > 0.
    * The options are: all traces with same periodicity(0 or >0) or we need to change the way how the events are managed */
-  if (time_delta == -1.0) {
+  if (time_delta < 0) {
     XBT_DEBUG("No next event at all. Bail out now.");
     return -1.0;
   }
@@ -134,6 +133,7 @@ double surf_solve(double max_date)
   for (auto model : *all_existing_models) {
     model->updateActionsState(NOW, time_delta);
   }
+  simgrid::s4u::onTimeAdvance(time_delta);
 
   TRACE_paje_dump_buffer (0);
 
@@ -143,31 +143,28 @@ double surf_solve(double max_date)
 /*********
  * MODEL *
  *********/
-
-surf_action_t surf_model_extract_done_action_set(surf_model_t model){
-  if (model->getDoneActionSet()->empty())
+static surf_action_t ActionListExtract(simgrid::surf::ActionList* list)
+{
+  if (list->empty())
     return nullptr;
-  surf_action_t res = &model->getDoneActionSet()->front();
-  model->getDoneActionSet()->pop_front();
+  surf_action_t res = &list->front();
+  list->pop_front();
   return res;
 }
 
+surf_action_t surf_model_extract_done_action_set(surf_model_t model)
+{
+  return ActionListExtract(model->getDoneActionSet());
+}
+
 surf_action_t surf_model_extract_failed_action_set(surf_model_t model){
-  if (model->getFailedActionSet()->empty())
-    return nullptr;
-  surf_action_t res = &model->getFailedActionSet()->front();
-  model->getFailedActionSet()->pop_front();
-  return res;
+  return ActionListExtract(model->getFailedActionSet());
 }
 
 int surf_model_running_action_set_size(surf_model_t model){
   return model->getRunningActionSet()->size();
 }
 
-surf_action_t surf_host_open(sg_host_t host, const char* fullpath){
-  return host->pimpl_->open(fullpath);
-}
-
 surf_action_t surf_host_close(sg_host_t host, surf_file_t fd){
   return host->pimpl_->close(fd);
 }
@@ -188,10 +185,6 @@ surf_action_t surf_host_write(sg_host_t host, surf_file_t fd, sg_size_t size){
   return host->pimpl_->write(fd, size);
 }
 
-xbt_dynar_t surf_host_get_info(sg_host_t host, surf_file_t fd){
-  return host->pimpl_->getInfo(fd);
-}
-
 size_t surf_host_file_tell(sg_host_t host, surf_file_t fd){
   return host->pimpl_->fileTell(fd);
 }
@@ -205,28 +198,34 @@ int surf_host_file_move(sg_host_t host, surf_file_t fd, const char* fullpath){
   return host->pimpl_->fileMove(fd, fullpath);
 }
 
-xbt_dict_t surf_storage_get_content(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->getContent();
+sg_size_t surf_storage_get_size(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->size_;
 }
 
-sg_size_t surf_storage_get_size(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->getSize();
+sg_size_t surf_storage_get_free_size(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->getFreeSize();
 }
 
-sg_size_t surf_storage_get_free_size(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->getFreeSize();
+sg_size_t surf_storage_get_used_size(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->getUsedSize();
 }
 
-sg_size_t surf_storage_get_used_size(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->getUsedSize();
+xbt_dict_t surf_storage_get_properties(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->getProperties();
 }
 
-xbt_dict_t surf_storage_get_properties(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->getProperties();
+const char* surf_storage_get_host(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->attach_.c_str();
 }
 
-const char* surf_storage_get_host(surf_resource_t resource){
-  return static_cast<simgrid::surf::Storage*>(surf_storage_resource_priv(resource))->attach_;
+const char* surf_storage_get_name(surf_storage_t resource)
+{
+  return static_cast<simgrid::surf::StorageImpl*>(resource)->cname();
 }
 
 void surf_cpu_action_set_bound(surf_action_t action, double bound) {
