@@ -1,21 +1,17 @@
-/* Copyright (c) 2004-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "surf_interface.hpp"
-#include "cpu_interface.hpp"
 #include "mc/mc.h"
-#include "network_interface.hpp"
-#include "simgrid/s4u/engine.hpp"
+#include "simgrid/s4u/Engine.hpp"
 #include "simgrid/sg_config.h"
 #include "src/instr/instr_private.h" // TRACE_is_enabled(). FIXME: remove by subscribing tracing to the surf signals
-#include "src/internal_config.h"
-#include "src/kernel/routing/NetCard.hpp"
-#include "src/simix/smx_host_private.h"
+#include "src/kernel/routing/NetPoint.hpp"
 #include "src/surf/HostImpl.hpp"
-#include "surf_private.h"
+
+#include <fstream>
 #include <vector>
 
 XBT_LOG_NEW_CATEGORY(surf, "All SURF categories");
@@ -25,29 +21,28 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_kernel, surf, "Logging specific to SURF (ke
  * Utils *
  *********/
 
-/* model_list_invoke contains only surf_host and surf_vm.
- * The callback functions of cpu_model and network_model will be called from those of these host models. */
 std::vector<surf_model_t> * all_existing_models = nullptr; /* to destroy models correctly */
-xbt_dynar_t model_list_invoke = nullptr;  /* to invoke callbacks */
 
 simgrid::trace_mgr::future_evt_set *future_evt_set = nullptr;
-xbt_dynar_t surf_path = nullptr;
+std::vector<std::string> surf_path;
 std::vector<simgrid::s4u::Host*> host_that_restart;
 xbt_dict_t watched_hosts_lib;
+extern std::map<std::string, storage_type_t> storage_types;
 
 namespace simgrid {
 namespace surf {
 
-simgrid::xbt::signal<void(void)> surfExitCallbacks;
-
+simgrid::xbt::signal<void()> surfExitCallbacks;
 }
 }
 
 #include <simgrid/plugins/energy.h> // FIXME: this plugin should not be linked to the core
+#include <simgrid/plugins/load.h>   // FIXME: this plugin should not be linked to the core
 
 s_surf_model_description_t surf_plugin_description[] = {
-    {"Energy", "Cpu energy consumption.", &sg_energy_plugin_init},
-     {nullptr, nullptr,  nullptr}      /* this array must be nullptr terminated */
+    {"Energy", "Cpu energy consumption.", &sg_host_energy_plugin_init},
+    {"Load", "Cpu load.", &sg_host_load_plugin_init},
+    {nullptr, nullptr, nullptr} /* this array must be nullptr terminated */
 };
 
 /* Don't forget to update the option description in smx_config when you change this */
@@ -81,7 +76,7 @@ void surf_network_model_init_IB() {
   xbt_die("Please activate SMPI support in cmake to use the IB network model.");
 }
 #endif
-#if !HAVE_NS3
+#if !SIMGRID_HAVE_NS3
 void surf_network_model_init_NS3() {
   xbt_die("Please activate NS3 support in cmake and install the dependencies to use the NS3 network model.");
 }
@@ -128,11 +123,29 @@ double surf_get_clock()
 # define FILE_DELIM "/"         /* FIXME: move to better location */
 #endif
 
+std::ifstream* surf_ifsopen(const char* name)
+{
+  std::ifstream* fs = new std::ifstream();
+  xbt_assert(name);
+  if (__surf_is_absolute_file_path(name)) { /* don't mess with absolute file names */
+    fs->open(name, std::ifstream::in);
+  }
+
+  /* search relative files in the path */
+  for (auto path_elm : surf_path) {
+    std::string buff = path_elm + FILE_DELIM + name;
+    fs->open(buff.c_str(), std::ifstream::in);
+
+    if (not fs->fail()) {
+      XBT_DEBUG("Found file at %s", buff.c_str());
+      return fs;
+    }
+  }
+
+  return fs;
+}
 FILE *surf_fopen(const char *name, const char *mode)
 {
-  unsigned int cpt;
-  char *path_elm = nullptr;
-  char *buff;
   FILE *file = nullptr;
 
   xbt_assert(name);
@@ -141,8 +154,8 @@ FILE *surf_fopen(const char *name, const char *mode)
     return fopen(name, mode);
 
   /* search relative files in the path */
-  xbt_dynar_foreach(surf_path, cpt, path_elm) {
-    buff = bprintf("%s" FILE_DELIM "%s", path_elm, name);
+  for (auto path_elm : surf_path) {
+    char* buff = bprintf("%s" FILE_DELIM "%s", path_elm.c_str(), name);
     file = fopen(buff, mode);
     free(buff);
 
@@ -177,7 +190,7 @@ const char *__surf_get_initial_path()
   unsigned int len = GetCurrentDirectory(MAX_PATH + 1, current_directory);
   char root[4] = { 0 };
 
-  if (!len)
+  if (not len)
     return nullptr;
 
   strncpy(root, current_directory, 3);
@@ -228,10 +241,10 @@ int find_model_description(s_surf_model_description_t * table,
   char *name_list = nullptr;
 
   for (i = 0; table[i].name; i++)
-    if (!strcmp(name, table[i].name)) {
+    if (not strcmp(name, table[i].name)) {
       return i;
     }
-  if (!table[0].name)
+  if (not table[0].name)
     xbt_die("No model is valid! This is a bug.");
   name_list = xbt_strdup(table[0].name);
   for (i = 1; table[i].name; i++) {
@@ -243,44 +256,82 @@ int find_model_description(s_surf_model_description_t * table,
   return -1;
 }
 
-static inline void surf_storage_free(void *r)
+void sg_version_check(int lib_version_major, int lib_version_minor, int lib_version_patch)
 {
-  delete static_cast<simgrid::surf::Storage*>(r);
-}
-
-void sg_version_check(int lib_version_major,int lib_version_minor,int lib_version_patch) {
-    if ((lib_version_major != SIMGRID_VERSION_MAJOR) || (lib_version_minor != SIMGRID_VERSION_MINOR)) {
-      fprintf(stderr,
+  if ((lib_version_major != SIMGRID_VERSION_MAJOR) || (lib_version_minor != SIMGRID_VERSION_MINOR)) {
+    fprintf(stderr, "FATAL ERROR: Your program was compiled with SimGrid version %d.%d.%d, "
+                    "and then linked against SimGrid %d.%d.%d. Please fix this.\n",
+            lib_version_major, lib_version_minor, lib_version_patch, SIMGRID_VERSION_MAJOR, SIMGRID_VERSION_MINOR,
+            SIMGRID_VERSION_PATCH);
+    abort();
+  }
+  if (lib_version_patch != SIMGRID_VERSION_PATCH) {
+    if (SIMGRID_VERSION_PATCH >= 90 || lib_version_patch >= 90) {
+      fprintf(
+          stderr,
           "FATAL ERROR: Your program was compiled with SimGrid version %d.%d.%d, "
-          "and then linked against SimGrid %d.%d.%d. Please fix this.\n",
-          lib_version_major,lib_version_minor,lib_version_patch,
-          SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH);
+          "and then linked against SimGrid %d.%d.%d. \n"
+          "One of them is a development version, and should not be mixed with the stable release. Please fix this.\n",
+          lib_version_major, lib_version_minor, lib_version_patch, SIMGRID_VERSION_MAJOR, SIMGRID_VERSION_MINOR,
+          SIMGRID_VERSION_PATCH);
       abort();
     }
-    if (lib_version_patch != SIMGRID_VERSION_PATCH) {
-      if(SIMGRID_VERSION_PATCH >= 90 || lib_version_patch >=90){
-        fprintf(stderr,
-        "FATAL ERROR: Your program was compiled with SimGrid version %d.%d.%d, "
-        "and then linked against SimGrid %d.%d.%d. \n"
-        "One of them is a development version, and should not be mixed with the stable release. Please fix this.\n",
-        lib_version_major,lib_version_minor,lib_version_patch,
-        SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH);
-        abort();
-      }
-        fprintf(stderr,
-            "Warning: Your program was compiled with SimGrid version %d.%d.%d, "
-            "and then linked against SimGrid %d.%d.%d. Proceeding anyway.\n",
-            lib_version_major,lib_version_minor,lib_version_patch,
-            SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH);
-    }
+    fprintf(stderr, "Warning: Your program was compiled with SimGrid version %d.%d.%d, "
+                    "and then linked against SimGrid %d.%d.%d. Proceeding anyway.\n",
+            lib_version_major, lib_version_minor, lib_version_patch, SIMGRID_VERSION_MAJOR, SIMGRID_VERSION_MINOR,
+            SIMGRID_VERSION_PATCH);
+  }
 }
 
-void sg_version(int *ver_major,int *ver_minor,int *ver_patch) {
+void sg_version_get(int* ver_major, int* ver_minor, int* ver_patch)
+{
   *ver_major = SIMGRID_VERSION_MAJOR;
   *ver_minor = SIMGRID_VERSION_MINOR;
   *ver_patch = SIMGRID_VERSION_PATCH;
 }
 
+void sg_version()
+{
+  std::printf("This program was linked against %s (git: %s), found in %s.\n",
+              SIMGRID_VERSION_STRING, SIMGRID_GIT_VERSION, SIMGRID_INSTALL_PREFIX);
+
+#if SIMGRID_HAVE_MC
+  std::printf("   Model-checking support compiled in.\n");
+#else
+  std::printf("   Model-checking support disabled at compilation.\n");
+#endif
+
+#if SIMGRID_HAVE_NS3
+  std::printf("   NS3 support compiled in.\n");
+#else
+  std::printf("   NS3 support disabled at compilation.\n");
+#endif
+
+#if SIMGRID_HAVE_JEDULE
+  std::printf("   Jedule support compiled in.\n");
+#else
+  std::printf("   Jedule support disabled at compilation.\n");
+#endif
+
+#if SIMGRID_HAVE_LUA
+  std::printf("   Lua support compiled in.\n");
+#else
+  std::printf("   Lua support disabled at compilation.\n");
+#endif
+
+#if SIMGRID_HAVE_MALLOCATOR
+  std::printf("   Mallocator support compiled in.\n");
+#else
+  std::printf("   Mallocator support disabled at compilation.\n");
+#endif
+
+  std::printf("\nTo cite SimGrid in a publication, please use:\n"
+              "   Henri Casanova, Arnaud Giersch, Arnaud Legrand, Martin Quinson, Frédéric Suter. \n"
+              "   Versatile, Scalable, and Accurate Simulation of Distributed Applications and Platforms. \n"
+              "   Journal of Parallel and Distributed Computing, Elsevier, 2014, 74 (10), pp.2899-2917.\n");
+  std::printf("The pdf file and a BibTeX entry for LaTeX users can be found at http://hal.inria.fr/hal-01017319\n");
+}
+
 void surf_init(int *argc, char **argv)
 {
   if (USER_HOST_LEVEL != -1) // Already initialized
@@ -289,24 +340,16 @@ void surf_init(int *argc, char **argv)
   XBT_DEBUG("Create all Libs");
   USER_HOST_LEVEL = simgrid::s4u::Host::extension_create(nullptr);
 
-  storage_lib = xbt_lib_new();
-  storage_type_lib = xbt_lib_new();
-  file_lib = xbt_lib_new();
   watched_hosts_lib = xbt_dict_new_homogeneous(nullptr);
 
-  XBT_DEBUG("Add SURF levels");
-  SURF_STORAGE_LEVEL = xbt_lib_add_level(storage_lib,surf_storage_free);
-
   xbt_init(argc, argv);
-  if (!all_existing_models)
+  if (not all_existing_models)
     all_existing_models = new std::vector<simgrid::surf::Model*>();
-  if (!model_list_invoke)
-    model_list_invoke = xbt_dynar_new(sizeof(simgrid::surf::Model*), nullptr);
-  if (!future_evt_set)
+  if (not future_evt_set)
     future_evt_set = new simgrid::trace_mgr::future_evt_set();
 
-  TRACE_add_start_function(TRACE_surf_alloc);
-  TRACE_add_end_function(TRACE_surf_release);
+  TRACE_surf_alloc();
+  simgrid::surf::surfExitCallbacks.connect(TRACE_surf_release);
 
   sg_config_init(argc, argv);
 
@@ -318,19 +361,25 @@ void surf_exit()
 {
   TRACE_end();                  /* Just in case it was not called by the upper layer (or there is no upper layer) */
 
-  xbt_dynar_free(&surf_path);
-
   sg_host_exit();
-  xbt_lib_free(&storage_lib);
   sg_link_exit();
-  xbt_lib_free(&storage_type_lib);
-  xbt_lib_free(&file_lib);
   xbt_dict_free(&watched_hosts_lib);
+  for (auto e : storage_types) {
+    storage_type_t stype = e.second;
+    free(stype->model);
+    free(stype->type_id);
+    free(stype->content);
+    xbt_dict_free(&(stype->properties));
+    delete stype->model_properties;
+    free(stype);
+  }
+  for (auto s : *simgrid::surf::StorageImpl::storages)
+    delete s.second;
+  delete simgrid::surf::StorageImpl::storages;
 
   for (auto model : *all_existing_models)
     delete model;
   delete all_existing_models;
-  xbt_dynar_free(&model_list_invoke);
 
   simgrid::surf::surfExitCallbacks();
 
@@ -395,10 +444,10 @@ double Model::nextOccuringEventLazy(double now)
   lmm_solve(maxminSystem_);
   XBT_DEBUG("After share resources, The size of modified actions set is %zd", modifiedSet_->size());
 
-  while(!modifiedSet_->empty()) {
+  while (not modifiedSet_->empty()) {
     Action *action = &(modifiedSet_->front());
     modifiedSet_->pop_front();
-    int max_dur_flag = 0;
+    bool max_dur_flag = false;
 
     if (action->getStateSet() != runningActionSet_)
       continue;
@@ -422,27 +471,24 @@ double Model::nextOccuringEventLazy(double now)
       min = now + time_to_completion; // when the task will complete if nothing changes
     }
 
-    if ((action->getMaxDuration() != NO_MAX_DURATION)
-        && (min == -1
-            || action->getStartTime() +
-            action->getMaxDuration() < min)) {
-      min = action->getStartTime() +
-          action->getMaxDuration();  // when the task will complete anyway because of the deadline if any
-      max_dur_flag = 1;
+    if ((action->getMaxDuration() > NO_MAX_DURATION) &&
+        (min <= -1 || action->getStartTime() + action->getMaxDuration() < min)) {
+      // when the task will complete anyway because of the deadline if any
+      min          = action->getStartTime() + action->getMaxDuration();
+      max_dur_flag = true;
     }
 
-
     XBT_DEBUG("Action(%p) corresponds to variable %d", action, action->getVariable()->id_int);
 
     XBT_DEBUG("Action(%p) Start %f. May finish at %f (got a share of %f). Max_duration %f", action,
         action->getStartTime(), min, share,
         action->getMaxDuration());
 
-    if (min != -1) {
+    if (min > -1) {
       action->heapUpdate(actionHeap_, min, max_dur_flag ? MAX_DURATION : NORMAL);
-      XBT_DEBUG("Insert at heap action(%p) min %f now %f", action, min,
-                now);
-    } else DIE_IMPOSSIBLE;
+      XBT_DEBUG("Insert at heap action(%p) min %f now %f", action, min, now);
+    } else
+      DIE_IMPOSSIBLE;
   }
 
   //hereafter must have already the min value for this resource model
@@ -523,7 +569,7 @@ bool Resource::isOn() const {
   return isOn_;
 }
 bool Resource::isOff() const {
-  return ! isOn_;
+  return not isOn_;
 }
 
 void Resource::turnOn()
@@ -536,11 +582,13 @@ void Resource::turnOff()
   isOn_ = false;
 }
 
-Model *Resource::getModel() const {
+Model* Resource::model() const
+{
   return model_;
 }
 
-const char *Resource::getName() const {
+const char* Resource::cname() const
+{
   return name_.c_str();
 }
 
@@ -548,7 +596,8 @@ bool Resource::operator==(const Resource &other) const {
   return name_ == other.name_;
 }
 
-lmm_constraint_t Resource::getConstraint() const {
+lmm_constraint_t Resource::constraint() const
+{
   return constraint_;
 }
 
@@ -601,13 +650,13 @@ void Action::finish() {
 
 Action::State Action::getState()
 {
-  if (stateSet_ ==  getModel()->getReadyActionSet())
+  if (stateSet_ == model_->getReadyActionSet())
     return Action::State::ready;
-  if (stateSet_ ==  getModel()->getRunningActionSet())
+  if (stateSet_ == model_->getRunningActionSet())
     return Action::State::running;
-  if (stateSet_ ==  getModel()->getFailedActionSet())
+  if (stateSet_ == model_->getFailedActionSet())
     return Action::State::failed;
-  if (stateSet_ ==  getModel()->getDoneActionSet())
+  if (stateSet_ == model_->getDoneActionSet())
     return Action::State::done;
   return Action::State::not_in_the_system;
 }
@@ -617,16 +666,16 @@ void Action::setState(Action::State state)
   stateSet_->erase(stateSet_->iterator_to(*this));
   switch (state) {
   case Action::State::ready:
-    stateSet_ = getModel()->getReadyActionSet();
+    stateSet_ = model_->getReadyActionSet();
     break;
   case Action::State::running:
-    stateSet_ = getModel()->getRunningActionSet();
+    stateSet_ = model_->getRunningActionSet();
     break;
   case Action::State::failed:
-    stateSet_ = getModel()->getFailedActionSet();
+    stateSet_ = model_->getFailedActionSet();
     break;
   case Action::State::done:
-    stateSet_ = getModel()->getDoneActionSet();
+    stateSet_ = model_->getDoneActionSet();
     break;
   default:
     stateSet_ = nullptr;
@@ -647,7 +696,7 @@ void Action::setBound(double bound)
   if (variable_)
     lmm_update_variable_bound(getModel()->getMaxminSystem(), variable_, bound);
 
-  if (getModel()->getUpdateMechanism() == UM_LAZY && getLastUpdate()!=surf_get_clock())
+  if (getModel()->getUpdateMechanism() == UM_LAZY && getLastUpdate() != surf_get_clock())
     heapRemove(getModel()->getActionHeap());
   XBT_OUT();
 }
@@ -660,7 +709,7 @@ double Action::getStartTime()
 double Action::getFinishTime()
 {
   /* keep the function behavior, some models (cpu_ti) change the finish time before the action end */
-  return remains_ == 0 ? finishTime_ : -1;
+  return remains_ <= 0 ? finishTime_ : -1;
 }
 
 void Action::setData(void* data)
@@ -708,7 +757,7 @@ void Action::cancel(){
 
 int Action::unref(){
   refcount_--;
-  if (!refcount_) {
+  if (not refcount_) {
     if (action_hook.is_linked())
       stateSet_->erase(stateSet_->iterator_to(*this));
     if (getVariable())
@@ -833,7 +882,7 @@ void Action::updateRemainingLazy(double now)
     if (getModel() == surf_cpu_model_pm && TRACE_is_enabled()) {
       simgrid::surf::Resource *cpu = static_cast<simgrid::surf::Resource*>(
         lmm_constraint_id(lmm_get_cnst_from_var(getModel()->getMaxminSystem(), getVariable(), 0)));
-      TRACE_surf_host_set_utilization(cpu->getName(), getCategory(), lastValue_, lastUpdate_, now - lastUpdate_);
+      TRACE_surf_host_set_utilization(cpu->cname(), getCategory(), lastValue_, lastUpdate_, now - lastUpdate_);
     }
     XBT_DEBUG("Updating action(%p): remains is now %f", this, remains_);
   }
