@@ -1,11 +1,10 @@
-/* Copyright (c) 2006-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2006-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef _SURF_SURFXML_PARSE_H
-#define _SURF_SURFXML_PARSE_H
+#ifndef SURF_SURFXML_PARSE_H
+#define SURF_SURFXML_PARSE_H
 
 #include <xbt/dict.h>
 #include <xbt/function_types.h>
@@ -22,6 +21,7 @@ XBT_PUBLIC(void) surf_parse_open(const char *file);
 XBT_PUBLIC(void) surf_parse_close();
 XBT_PUBLIC(void) surf_parse_assert(bool cond, const char *fmt, ...) XBT_ATTRIB_PRINTF(2,3);
 XBT_PUBLIC(void) XBT_ATTRIB_NORETURN surf_parse_error(const char *msg,...) XBT_ATTRIB_PRINTF(1,2);
+XBT_PUBLIC(void) surf_parse_assert_netpoint(char* hostname, const char* pre, const char* post);
 XBT_PUBLIC(void) surf_parse_warn(const char *msg,...) XBT_ATTRIB_PRINTF(1,2);
 
 XBT_PUBLIC(double) surf_parse_get_double(const char *string);
@@ -35,12 +35,4 @@ XBT_PUBLIC_DATA(int_f_void_t) surf_parse;       /* Entry-point to the parser. Se
 
 SG_END_DECL()
 
-namespace simgrid {
-namespace surf {
-
-extern XBT_PRIVATE xbt::signal<void(void)> on_postparse;
-
-}
-}
-
 #endif
