@@ -11,6 +11,8 @@
 
 #include "simgrid/host.h"
 #include "src/surf/xml/platf.hpp"
+#include <map>
+#include <string>
 #include <vector>
 
 SG_BEGIN_DECL()
@@ -48,29 +50,27 @@ typedef struct {
   tmgr_trace_t state_trace;
   const char* coord;
   xbt_dict_t properties;
-} s_sg_platf_host_cbarg_t, *sg_platf_host_cbarg_t;
+} s_sg_platf_host_cbarg_t;
+typedef s_sg_platf_host_cbarg_t* sg_platf_host_cbarg_t;
 
 typedef struct {
   const char* id;
   const char* link_up;
   const char* link_down;
-} s_sg_platf_host_link_cbarg_t, *sg_platf_host_link_cbarg_t;
+} s_sg_platf_host_link_cbarg_t;
+typedef s_sg_platf_host_link_cbarg_t* sg_platf_host_link_cbarg_t;
 
-typedef struct {
-  const char* id;
-  const char* coord;
-} s_sg_platf_router_cbarg_t, *sg_platf_router_cbarg_t;
-
-typedef struct {
-  const char* id;
-  double bandwidth;
-  tmgr_trace_t bandwidth_trace;
-  double latency;
-  tmgr_trace_t latency_trace;
-  tmgr_trace_t state_trace;
-  e_surf_link_sharing_policy_t policy;
-  xbt_dict_t properties;
-} s_sg_platf_link_cbarg_t, *sg_platf_link_cbarg_t;
+class LinkCreationArgs {
+public:
+  std::string id;
+  double bandwidth                    = 0;
+  tmgr_trace_t bandwidth_trace        = nullptr;
+  double latency                      = 0;
+  tmgr_trace_t latency_trace          = nullptr;
+  tmgr_trace_t state_trace            = nullptr;
+  e_surf_link_sharing_policy_t policy = SURF_LINK_FATPIPE;
+  xbt_dict_t properties               = nullptr;
+};
 
 typedef struct s_sg_platf_peer_cbarg *sg_platf_peer_cbarg_t;
 typedef struct s_sg_platf_peer_cbarg {
@@ -78,7 +78,6 @@ typedef struct s_sg_platf_peer_cbarg {
   double speed;
   double bw_in;
   double bw_out;
-  double lat;
   const char* coord;
   tmgr_trace_t speed_trace;
   tmgr_trace_t state_trace;
@@ -87,11 +86,11 @@ typedef struct s_sg_platf_peer_cbarg {
 typedef struct s_sg_platf_route_cbarg *sg_platf_route_cbarg_t;
 typedef struct s_sg_platf_route_cbarg {
   bool symmetrical;
-  sg_netcard_t src;
-  sg_netcard_t dst;
-  sg_netcard_t gw_src;
-  sg_netcard_t gw_dst;
-  std::vector<Link*> *link_list;
+  sg_netpoint_t src;
+  sg_netpoint_t dst;
+  sg_netpoint_t gw_src;
+  sg_netpoint_t gw_dst;
+  std::vector<simgrid::surf::LinkImpl*>* link_list;
 } s_sg_platf_route_cbarg_t;
 
 typedef struct s_sg_platf_cluster_cbarg *sg_platf_cluster_cbarg_t;
@@ -100,7 +99,7 @@ typedef struct s_sg_platf_cluster_cbarg {
   const char* prefix;
   const char* suffix;
   std::vector<int>* radicals;
-  double speed;
+  std::vector<double> speeds;
   int core_amount;
   double bw;
   double lat;
@@ -117,7 +116,7 @@ typedef struct s_sg_platf_cluster_cbarg {
   e_surf_link_sharing_policy_t bb_sharing_policy;
 } s_sg_platf_cluster_cbarg_t;
 
-typedef struct s_sg_platf_cabinet_cbarg *sg_platf_cabinet_cbarg_t;
+typedef struct s_sg_platf_cabinet_cbarg* sg_platf_cabinet_cbarg_t;
 typedef struct s_sg_platf_cabinet_cbarg {
   const char* id;
   const char* prefix;
@@ -128,29 +127,30 @@ typedef struct s_sg_platf_cabinet_cbarg {
   double lat;
 } s_sg_platf_cabinet_cbarg_t;
 
-typedef struct {
+typedef struct s_sg_platf_storage_cbarg* sg_platf_storage_cbarg_t;
+typedef struct s_sg_platf_storage_cbarg {
   const char* id;
   const char* type_id;
   const char* content;
-  const char* content_type;
   xbt_dict_t properties;
   const char* attach;
-} s_sg_platf_storage_cbarg_t, *sg_platf_storage_cbarg_t;
+} s_sg_platf_storage_cbarg_t;
 
-typedef struct {
+typedef struct s_sg_platf_storage_type_cbarg* sg_platf_storage_type_cbarg_t;
+typedef struct s_sg_platf_storage_type_cbarg {
   const char* id;
   const char* model;
   const char* content;
-  const char* content_type;
   xbt_dict_t properties;
-  xbt_dict_t model_properties;
+  std::map<std::string, std::string>* model_properties;
   sg_size_t size;
-} s_sg_platf_storage_type_cbarg_t, *sg_platf_storage_type_cbarg_t;
+} s_sg_platf_storage_type_cbarg_t;
 
-typedef struct {
+typedef struct s_sg_platf_mount_cbarg* sg_platf_mount_cbarg_t;
+typedef struct s_sg_platf_mount_cbarg {
   const char* storageId;
   const char* name;
-} s_sg_platf_mount_cbarg_t, *sg_platf_mount_cbarg_t;
+} s_sg_platf_mount_cbarg_t;
 
 typedef struct s_sg_platf_prop_cbarg *sg_platf_prop_cbarg_t;
 typedef struct s_sg_platf_prop_cbarg {
@@ -194,7 +194,7 @@ typedef struct s_sg_platf_AS_cbarg {
 #define SG_PLATF_AS_INITIALIZER {nullptr,0}
 
 /********** Routing **********/
-void routing_cluster_add_backbone(Link* bb);
+void routing_cluster_add_backbone(simgrid::surf::LinkImpl* bb);
 /*** END of the parsing cruft ***/
 
 XBT_PUBLIC(void) sg_platf_begin();  // Start a new platform
@@ -205,8 +205,9 @@ XBT_PUBLIC(void) sg_platf_new_AS_seal();                     // That AS is fully
 
 XBT_PUBLIC(void) sg_platf_new_host   (sg_platf_host_cbarg_t   host);   // Add an host   to the currently described AS
 XBT_PUBLIC(void) sg_platf_new_hostlink(sg_platf_host_link_cbarg_t h); // Add an host_link to the currently described AS
-XBT_PUBLIC(void) sg_platf_new_router (sg_platf_router_cbarg_t router); // Add a router  to the currently described AS
-XBT_PUBLIC(void) sg_platf_new_link   (sg_platf_link_cbarg_t link);     // Add a link    to the currently described AS
+XBT_PUBLIC(simgrid::kernel::routing::NetPoint*)
+sg_platf_new_router(const char* name, const char* coords);             // Add a router  to the currently described AS
+XBT_PUBLIC(void) sg_platf_new_link(LinkCreationArgs* link);            // Add a link    to the currently described AS
 XBT_PUBLIC(void) sg_platf_new_peer   (sg_platf_peer_cbarg_t peer);     // Add a peer    to the currently described AS
 XBT_PUBLIC(void) sg_platf_new_cluster(sg_platf_cluster_cbarg_t clust); // Add a cluster to the currently described AS
 XBT_PUBLIC(void) sg_platf_new_cabinet(sg_platf_cabinet_cbarg_t cabinet); // Add a cabinet to the currently described AS
@@ -228,7 +229,7 @@ XBT_PUBLIC(int) surf_parse_lex();
 XBT_PUBLIC(int) surf_parse_get_lineno();
 XBT_PUBLIC(FILE *) surf_parse_get_in();
 XBT_PUBLIC(FILE *) surf_parse_get_out();
-XBT_PUBLIC(yy_size_t) surf_parse_get_leng();
+XBT_PUBLIC(int) surf_parse_get_leng();
 XBT_PUBLIC(char *) surf_parse_get_text();
 XBT_PUBLIC(void) surf_parse_set_lineno(int line_number);
 XBT_PUBLIC(void) surf_parse_set_in(FILE * in_str);
@@ -237,17 +238,9 @@ XBT_PUBLIC(int) surf_parse_get_debug();
 XBT_PUBLIC(void) surf_parse_set_debug(int bdebug);
 XBT_PUBLIC(int) surf_parse_lex_destroy();
 
-/* To include files (?) */
-XBT_PRIVATE void surfxml_bufferstack_push(int _new);
-XBT_PRIVATE void surfxml_bufferstack_pop(int _new);
-XBT_PUBLIC_DATA(int) surfxml_bufferstack_size;
-
 XBT_PUBLIC(void) routing_route_free(sg_platf_route_cbarg_t route);
 /********** Instr. **********/
-XBT_PRIVATE void sg_instr_AS_begin(sg_platf_AS_cbarg_t AS);
-XBT_PRIVATE void sg_instr_new_router(sg_platf_router_cbarg_t router);
-XBT_PRIVATE void sg_instr_new_host(simgrid::s4u::Host& host);
-XBT_PRIVATE void sg_instr_AS_end();
+XBT_PRIVATE void sg_instr_new_router(const char* name);
 
 SG_END_DECL()
 
