@@ -1,12 +1,11 @@
 /* dict - a generic dictionary, variation over hash table                   */
 
-/* Copyright (c) 2004-2015. The SimGrid Team.
+/* Copyright (c) 2004-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-
 #include <string.h>
 #include <stdio.h>
 
@@ -73,8 +72,8 @@ xbt_dict_t xbt_dict_new_homogeneous(void_f_pvoid_t free_ctn)
  */
 void xbt_dict_free(xbt_dict_t * dict)
 {
-  int i;
-  xbt_dictelm_t current, previous;
+  xbt_dictelm_t current;
+  xbt_dictelm_t previous;
   int table_size;
   xbt_dictelm_t *table;
 
@@ -85,7 +84,7 @@ void xbt_dict_free(xbt_dict_t * dict)
     table = (*dict)->table;
     /* Warning: the size of the table is 'table_size+1'...
      * This is because table_size is used as a binary mask in xbt_dict_rehash */
-    for (i = 0; (*dict)->count && i <= table_size; i++) {
+    for (int i = 0; (*dict)->count && i <= table_size; i++) {
       current = table[i];
       while (current != nullptr) {
         previous = current;
@@ -103,7 +102,7 @@ void xbt_dict_free(xbt_dict_t * dict)
 /** Returns the amount of elements in the dict */
 unsigned int xbt_dict_size(xbt_dict_t dict)
 {
-  return (dict ? (unsigned int) dict->count : (unsigned int) 0);
+  return (dict != nullptr ? static_cast<unsigned int>(dict->count) : static_cast<unsigned int>(0));
 }
 
 /* Expend the size of the dict */
@@ -114,12 +113,13 @@ static void xbt_dict_rehash(xbt_dict_t dict)
 
   xbt_dictelm_t *currcell = (xbt_dictelm_t *) xbt_realloc((char *) dict->table, newsize * sizeof(xbt_dictelm_t));
   memset(&currcell[oldsize], 0, oldsize * sizeof(xbt_dictelm_t));       /* zero second half */
-  dict->table_size = --newsize;
+  newsize--;
+  dict->table_size = newsize;
   dict->table = currcell;
   XBT_DEBUG("REHASH (%d->%d)", oldsize, newsize);
 
   for (unsigned i = 0; i < oldsize; i++, currcell++) {
-    if (!*currcell)             /* empty cell */
+    if (*currcell == nullptr) /* empty cell */
       continue;
 
     xbt_dictelm_t *twincell = currcell + oldsize;
@@ -132,16 +132,15 @@ static void xbt_dict_rehash(xbt_dict_t dict)
       if ((bucklet->hash_code & newsize) != i) {        /* Move to b */
         *pprev = bucklet->next;
         bucklet->next = *twincell;
-        if (!*twincell)
+        if (*twincell == nullptr)
           dict->fill++;
         *twincell = bucklet;
-        continue;
       } else {
         pprev = &bucklet->next;
       }
     }
 
-    if (!*currcell)             /* everything moved */
+    if (*currcell == nullptr) /* everything moved */
       dict->fill--;
   }
 }
@@ -162,8 +161,10 @@ void xbt_dict_set_ext(xbt_dict_t dict, const char *key, int key_len, void *data,
 {
   unsigned int hash_code = xbt_str_hash_ext(key, key_len);
 
-  xbt_dictelm_t current, previous = nullptr;
+  xbt_dictelm_t current;
+  xbt_dictelm_t previous = nullptr;
 
+  xbt_assert(not free_ctn, "Cannot set an individual free function in homogeneous dicts.");
   XBT_CDEBUG(xbt_dict, "ADD %.*s hash = %u, size = %d, & = %u", key_len, key, hash_code,
              dict->table_size, hash_code & dict->table_size);
   current = dict->table[hash_code & dict->table_size];
@@ -175,7 +176,7 @@ void xbt_dict_set_ext(xbt_dict_t dict, const char *key, int key_len, void *data,
 
   if (current == nullptr) {
     /* this key doesn't exist yet */
-    current = xbt_dictelm_new(dict, key, key_len, hash_code, data, free_ctn);
+    current = xbt_dictelm_new(key, key_len, hash_code, data);
     dict->count++;
     if (previous == nullptr) {
       dict->table[hash_code & dict->table_size] = current;
@@ -360,14 +361,15 @@ void xbt_dict_remove_ext(xbt_dict_t dict, const char *key, int key_len)
 
   if (current == nullptr)
     THROWF(not_found_error, 0, "key %.*s not found", key_len, key);
-
-  if (previous != nullptr) {
-    previous->next = current->next;
-  } else {
-    dict->table[hash_code & dict->table_size] = current->next;
+  else {
+    if (previous != nullptr) {
+      previous->next = current->next;
+    } else {
+      dict->table[hash_code & dict->table_size] = current->next;
+    }
   }
 
-  if (!dict->table[hash_code & dict->table_size])
+  if (not dict->table[hash_code & dict->table_size])
     dict->fill--;
 
   xbt_dictelm_free(dict, current);
@@ -428,7 +430,7 @@ void xbt_dict_dump_output_string(void *s)
  */
 int xbt_dict_is_empty(xbt_dict_t dict)
 {
-  return !dict || (xbt_dict_length(dict) == 0);
+  return not dict || (xbt_dict_length(dict) == 0);
 }
 
 /**
@@ -475,7 +477,7 @@ void xbt_dict_dump_sizes(xbt_dict_t dict)
 
   printf("Dict %p: %d bucklets, %d used cells (of %d) ", dict, dict->count, dict->fill, dict->table_size);
 
-  if (!dict) {
+  if (not dict) {
     printf("\n");
     return;
   }
@@ -500,7 +502,7 @@ void xbt_dict_dump_sizes(xbt_dict_t dict)
       xbt_dynar_set(sizes, size, &prevsize);
     }
   }
-  if (!all_sizes)
+  if (not all_sizes)
     all_sizes = xbt_dynar_new(sizeof(int), nullptr);
 
   xbt_dynar_foreach(sizes, count, size) {
@@ -516,11 +518,8 @@ void xbt_dict_dump_sizes(xbt_dict_t dict)
     }
 
     /* Report current sizes */
-    if (count == 0)
-      continue;
-    if (size == 0)
-      continue;
-    printf("%uelm x %u cells; ", count, size);
+    if (count != 0 && size != 0)
+      printf("%uelm x %u cells; ", count, size);
   }
   printf("\n");
   xbt_dynar_free(&sizes);
@@ -536,9 +535,6 @@ void xbt_dict_preinit()
   if (dict_elm_mallocator == nullptr)
     dict_elm_mallocator = xbt_mallocator_new(256, dict_elm_mallocator_new_f, dict_elm_mallocator_free_f,
       dict_elm_mallocator_reset_f);
-  if (dict_het_elm_mallocator == nullptr)
-    dict_het_elm_mallocator = xbt_mallocator_new(256, dict_het_elm_mallocator_new_f, dict_het_elm_mallocator_free_f,
-      dict_het_elm_mallocator_reset_f);
 }
 
 /**
@@ -550,8 +546,6 @@ void xbt_dict_postexit()
   if (dict_elm_mallocator != nullptr) {
     xbt_mallocator_free(dict_elm_mallocator);
     dict_elm_mallocator = nullptr;
-    xbt_mallocator_free(dict_het_elm_mallocator);
-    dict_het_elm_mallocator = nullptr;
   }
   if (all_sizes) {
     unsigned int count;
@@ -560,15 +554,16 @@ void xbt_dict_postexit()
     int total_count = 0;
     printf("Overall stats:");
     xbt_dynar_foreach(all_sizes, count, size) {
-      if (count == 0)
-        continue;
-      if (size == 0)
-        continue;
-      printf("%uelm x %d cells; ", count, size);
-      avg += count * size;
-      total_count += size;
+      if (count != 0 && size != 0) {
+        printf("%uelm x %d cells; ", count, size);
+        avg += count * size;
+        total_count += size;
+      }
     }
-    printf("; %f elm per cell\n", avg / (double) total_count);
+    if (total_count > 0)
+      printf("; %f elm per cell\n", avg / (double)total_count);
+    else
+      printf("; 0 elm per cell\n");
   }
 }
 
@@ -601,7 +596,7 @@ static void debugged_add(xbt_dict_t head, const char* key)
   debugged_add_ext(head, key, key);
 }
 
-static xbt_dict_t new_fixture(void)
+static xbt_dict_t new_fixture()
 {
   xbt_test_add("Fill in the dictionnary");
 
@@ -625,10 +620,10 @@ static void search_ext(xbt_dict_t head, const char *key, const char *data)
   if (data) {
     xbt_test_assert(found, "data do not match expectations: found nullptr while searching for %s", data);
     if (found)
-      xbt_test_assert(!strcmp(data, found), "data do not match expectations: found %s while searching for %s",
-                      found, data);
+      xbt_test_assert(not strcmp(data, found), "data do not match expectations: found %s while searching for %s", found,
+                      data);
   } else {
-    xbt_test_assert(!found, "data do not match expectations: found %s while searching for nullptr", found);
+    xbt_test_assert(not found, "data do not match expectations: found %s while searching for nullptr", found);
   }
 }
 
@@ -652,12 +647,12 @@ static void traverse(xbt_dict_t head)
   int i = 0;
 
   xbt_dict_foreach(head, cursor, key, data) {
-    if (!key || !data || strcmp(key, data)) {
+    if (not key || not data || strcmp(key, data)) {
       xbt_test_log("Seen #%d:  %s->%s", ++i, key, data);
     } else {
       xbt_test_log("Seen #%d:  %s", ++i, key);
     }
-    xbt_test_assert(!data || !strcmp(key, data), "Key(%s) != value(%s). Aborting", key, data);
+    xbt_test_assert(not data || not strcmp(key, data), "Key(%s) != value(%s). Aborting", key, data);
   }
 }
 
@@ -706,7 +701,7 @@ static void count_check_get_key(xbt_dict_t dict, int length)
   xbt_dict_foreach(dict, cursor, key, data) {
     effective++;
     char* key2 = xbt_dict_get_key(dict, data);
-    xbt_assert(!strcmp(key, key2), "The data was registered under %s instead of %s as expected", key2, key);
+    xbt_assert(not strcmp(key, key2), "The data was registered under %s instead of %s as expected", key2, key);
   }
 
   xbt_test_assert(effective == length, "Effective length(%d) != %d.", effective, length);
@@ -770,7 +765,7 @@ XBT_TEST_UNIT("basic", test_dict_basic, "Basic usage: change, retrieve and trave
   xbt_test_add("Search 123");
   char* data = (char*)xbt_dict_get(head, "123");
   xbt_test_assert(data);
-  xbt_test_assert(!strcmp("123", data));
+  xbt_test_assert(not strcmp("123", data));
 
   search_not_found(head, "Can't be found");
   search_not_found(head, "123 Can't be found");
@@ -877,13 +872,13 @@ XBT_TEST_UNIT("nulldata", test_dict_nulldata, "nullptr data management")
     char* data;
 
     xbt_dict_foreach(head, cursor, key, data) {
-      if (!key || !data || strcmp(key, data)) {
+      if (not key || not data || strcmp(key, data)) {
         xbt_test_log("Seen:  %s->%s", key, data);
       } else {
         xbt_test_log("Seen:  %s", key);
       }
 
-      if (!strcmp(key, "null"))
+      if (not strcmp(key, "null"))
         found = 1;
     }
     xbt_test_assert(found, "the key 'null', associated to nullptr is not found");
@@ -930,7 +925,7 @@ XBT_TEST_UNIT("crash", test_dict_crash, "Crash test")
 
       xbt_dict_set(head, key, key, nullptr);
       data = (char*) xbt_dict_get(head, key);
-      xbt_test_assert(!strcmp(key, data), "Retrieved value (%s) != Injected value (%s)", key, data);
+      xbt_test_assert(not strcmp(key, data), "Retrieved value (%s) != Injected value (%s)", key, data);
 
       count(head, j + 1);
     }
@@ -943,7 +938,6 @@ XBT_TEST_UNIT("crash", test_dict_crash, "Crash test")
   xbt_dict_t head = xbt_dict_new_homogeneous(&free);
   xbt_test_add("Fill %d elements, with keys being the number of element", NB_ELM);
   for (int j = 0; j < NB_ELM; j++) {
-    /* if (!(j%1000)) { printf("."); fflush(stdout); } */
     char* key = (char*)xbt_malloc(10);
 
     snprintf(key,10, "%d", j);
@@ -961,9 +955,9 @@ XBT_TEST_UNIT("crash", test_dict_crash, "Crash test")
     for (int j = 0; j < NB_ELM; j++) {
       snprintf(key,10, "%d", j);
       void* data = xbt_dict_get(head, key);
-      xbt_test_assert(!strcmp(key, (char *) data), "with get, key=%s != data=%s", key, (char *) data);
+      xbt_test_assert(not strcmp(key, (char*)data), "with get, key=%s != data=%s", key, (char*)data);
       data = xbt_dict_get_ext(head, key, strlen(key));
-      xbt_test_assert(!strcmp(key, (char *) data), "with get_ext, key=%s != data=%s", key, (char *) data);
+      xbt_test_assert(not strcmp(key, (char*)data), "with get_ext, key=%s != data=%s", key, (char*)data);
     }
   }
   free(key);
@@ -971,7 +965,6 @@ XBT_TEST_UNIT("crash", test_dict_crash, "Crash test")
   xbt_test_add("Remove my %d elements", NB_ELM);
   key = (char*) xbt_malloc(10);
   for (int j = 0; j < NB_ELM; j++) {
-    /* if (!(j%10000)) printf("."); fflush(stdout); */
     snprintf(key,10, "%d", j);
     xbt_dict_remove(head, key);
   }
