@@ -23,14 +23,14 @@ static inline void _sanity_check_dynar(xbt_dynar_t dynar)
 
 static inline void _sanity_check_idx(int idx)
 {
-  xbt_assert(idx >= 0, "dynar idx(=%d) < 0", (int) (idx));
+  xbt_assert(idx >= 0, "dynar idx(=%d) < 0", idx);
 }
 
 static inline void _check_inbound_idx(xbt_dynar_t dynar, int idx)
 {
-  if (idx < 0 || idx >= (int)dynar->used) {
+  if (idx < 0 || idx >= static_cast<int>(dynar->used)) {
     THROWF(bound_error, idx, "dynar is not that long. You asked %d, but it's only %lu long",
-           (int) (idx), (unsigned long) dynar->used);
+           idx, static_cast<unsigned long>(dynar->used));
   }
 }
 
@@ -75,7 +75,7 @@ static inline void _xbt_dynar_get_elm(void *const dst, const xbt_dynar_t dynar,
   memcpy(dst, elm, dynar->elmsize);
 }
 
-void xbt_dynar_dump(xbt_dynar_t dynar)
+extern "C" void xbt_dynar_dump(xbt_dynar_t dynar)
 {
   XBT_INFO("Dynar dump: size=%lu; used=%lu; elmsize=%lu; data=%p; free_f=%p",
         dynar->size, dynar->used, dynar->elmsize, dynar->data, dynar->free_f);
@@ -89,7 +89,7 @@ void xbt_dynar_dump(xbt_dynar_t dynar)
  * Creates a new dynar. If a free_func is provided, the elements have to be pointer of pointer. That is to say that
  * dynars can contain either base types (int, char, double, etc) or pointer of pointers (struct **).
  */
-xbt_dynar_t xbt_dynar_new(const unsigned long elmsize, void_f_pvoid_t const free_f)
+extern "C" xbt_dynar_t xbt_dynar_new(const unsigned long elmsize, void_f_pvoid_t const free_f)
 {
   xbt_dynar_t dynar = xbt_new0(s_xbt_dynar_t, 1);
 
@@ -102,6 +102,26 @@ xbt_dynar_t xbt_dynar_new(const unsigned long elmsize, void_f_pvoid_t const free
   return dynar;
 }
 
+/** @brief Initialize a dynar structure that was not malloc'ed
+ * This can be useful to keep temporary dynars on the stack
+ */
+extern "C" void xbt_dynar_init(xbt_dynar_t dynar, const unsigned long elmsize, void_f_pvoid_t const free_f)
+{
+  dynar->size    = 0;
+  dynar->used    = 0;
+  dynar->elmsize = elmsize;
+  dynar->data    = nullptr;
+  dynar->free_f  = free_f;
+}
+
+/** @brief Destroy a dynar that was created with xbt_dynar_init */
+extern "C" void xbt_dynar_free_data(xbt_dynar_t dynar)
+{
+  xbt_dynar_reset(dynar);
+  if (dynar)
+    free(dynar->data);
+}
+
 /** @brief Destructor of the structure not touching to the content
  *
  * \param dynar poor victim
@@ -109,7 +129,7 @@ xbt_dynar_t xbt_dynar_new(const unsigned long elmsize, void_f_pvoid_t const free
  * kilkil a dynar BUT NOT its content. Ie, the array is freed, but the content is not touched (the \a free_f function
  * is not used)
  */
-void xbt_dynar_free_container(xbt_dynar_t * dynar)
+extern "C" void xbt_dynar_free_container(xbt_dynar_t* dynar)
 {
   if (dynar && *dynar) {
     xbt_dynar_t d = *dynar;
@@ -123,7 +143,7 @@ void xbt_dynar_free_container(xbt_dynar_t * dynar)
  *
  * \param dynar who to squeeze
  */
-void xbt_dynar_reset(xbt_dynar_t const dynar)
+extern "C" void xbt_dynar_reset(xbt_dynar_t const dynar)
 {
   _sanity_check_dynar(dynar);
 
@@ -139,7 +159,7 @@ void xbt_dynar_reset(xbt_dynar_t const dynar)
  * \param d1 dynar to keep
  * \param d2 dynar to merge into d1. This dynar is free at end.
  */
-void xbt_dynar_merge(xbt_dynar_t *d1, xbt_dynar_t *d2)
+extern "C" void xbt_dynar_merge(xbt_dynar_t* d1, xbt_dynar_t* d2)
 {
   if((*d1)->elmsize != (*d2)->elmsize)
     xbt_die("Element size must are not equal");
@@ -167,7 +187,7 @@ void xbt_dynar_merge(xbt_dynar_t *d1, xbt_dynar_t *d2)
  * Set \a empty_slots_wanted to zero to reduce the dynar internal array as much as possible.
  * Note that if \a empty_slots_wanted is greater than the array size, the internal array is expanded instead of shrunk.
  */
-void xbt_dynar_shrink(xbt_dynar_t dynar, int empty_slots_wanted)
+extern "C" void xbt_dynar_shrink(xbt_dynar_t dynar, int empty_slots_wanted)
 {
   _xbt_dynar_resize(dynar, dynar->used + empty_slots_wanted);
 }
@@ -178,7 +198,7 @@ void xbt_dynar_shrink(xbt_dynar_t dynar, int empty_slots_wanted)
  *
  * kilkil a dynar and its content
  */
-void xbt_dynar_free(xbt_dynar_t * dynar)
+extern "C" void xbt_dynar_free(xbt_dynar_t* dynar)
 {
   if (dynar && *dynar) {
     xbt_dynar_reset(*dynar);
@@ -187,7 +207,7 @@ void xbt_dynar_free(xbt_dynar_t * dynar)
 }
 
 /** \brief free a dynar passed as void* (handy to store dynar in dynars or dict) */
-void xbt_dynar_free_voidp(void *d)
+extern "C" void xbt_dynar_free_voidp(void* d)
 {
   xbt_dynar_t dynar = (xbt_dynar_t)d;
   xbt_dynar_free(&dynar);
@@ -197,7 +217,7 @@ void xbt_dynar_free_voidp(void *d)
  *
  * \param dynar the dynar we want to mesure
  */
-unsigned long xbt_dynar_length(const xbt_dynar_t dynar)
+extern "C" unsigned long xbt_dynar_length(const xbt_dynar_t dynar)
 {
   return (dynar ? (unsigned long) dynar->used : (unsigned long) 0);
 }
@@ -206,8 +226,7 @@ unsigned long xbt_dynar_length(const xbt_dynar_t dynar)
  *
  *\param dynar the dynat we want to check
  */
-
-int xbt_dynar_is_empty(const xbt_dynar_t dynar)
+extern "C" int xbt_dynar_is_empty(const xbt_dynar_t dynar)
 {
   return (xbt_dynar_length(dynar) == 0);
 }
@@ -218,7 +237,7 @@ int xbt_dynar_is_empty(const xbt_dynar_t dynar)
  * \param idx index of the slot we want to retrieve
  * \param[out] dst where to put the result to.
  */
-void xbt_dynar_get_cpy(const xbt_dynar_t dynar, const unsigned long idx, void *const dst)
+extern "C" void xbt_dynar_get_cpy(const xbt_dynar_t dynar, const unsigned long idx, void* const dst)
 {
   _sanity_check_dynar(dynar);
   _check_inbound_idx(dynar, idx);
@@ -235,7 +254,7 @@ void xbt_dynar_get_cpy(const xbt_dynar_t dynar, const unsigned long idx, void *c
  * \warning The returned value is the actual content of the dynar.
  * Make a copy before fooling with it.
  */
-void *xbt_dynar_get_ptr(const xbt_dynar_t dynar, const unsigned long idx)
+extern "C" void* xbt_dynar_get_ptr(const xbt_dynar_t dynar, const unsigned long idx)
 {
   void *res;
   _sanity_check_dynar(dynar);
@@ -245,7 +264,7 @@ void *xbt_dynar_get_ptr(const xbt_dynar_t dynar, const unsigned long idx)
   return res;
 }
 
-void *xbt_dynar_set_at_ptr(const xbt_dynar_t dynar, const unsigned long idx)
+extern "C" void* xbt_dynar_set_at_ptr(const xbt_dynar_t dynar, const unsigned long idx)
 {
   _sanity_check_dynar(dynar);
 
@@ -267,7 +286,7 @@ void *xbt_dynar_set_at_ptr(const xbt_dynar_t dynar, const unsigned long idx)
  *
  * If you want to free the previous content, use xbt_dynar_replace().
  */
-void xbt_dynar_set(xbt_dynar_t dynar, const int idx, const void *const src)
+extern "C" void xbt_dynar_set(xbt_dynar_t dynar, const int idx, const void* const src)
 {
   memcpy(xbt_dynar_set_at_ptr(dynar, idx), src, dynar->elmsize);
 }
@@ -281,7 +300,7 @@ void xbt_dynar_set(xbt_dynar_t dynar, const int idx, const void *const src)
  * Set the Nth element of a dynar, expanding the dynar if needed, AND DO free the previous value at this position. If
  * you don't want to free the previous content, use xbt_dynar_set().
  */
-void xbt_dynar_replace(xbt_dynar_t dynar, const unsigned long idx, const void *const object)
+extern "C" void xbt_dynar_replace(xbt_dynar_t dynar, const unsigned long idx, const void* const object)
 {
   _sanity_check_dynar(dynar);
 
@@ -299,7 +318,7 @@ void xbt_dynar_replace(xbt_dynar_t dynar, const unsigned long idx, const void *c
  * You can then use regular affectation to set its value instead of relying on the slow memcpy. This is what
  * xbt_dynar_insert_at_as() does.
  */
-void *xbt_dynar_insert_at_ptr(xbt_dynar_t const dynar, const int idx)
+extern "C" void* xbt_dynar_insert_at_ptr(xbt_dynar_t const dynar, const int idx)
 {
   void *res;
   unsigned long old_used;
@@ -330,7 +349,7 @@ void *xbt_dynar_insert_at_ptr(xbt_dynar_t const dynar, const int idx)
  * Set the Nth element of a dynar, expanding the dynar if needed, and moving the previously existing value and all
  * subsequent ones to one position right in the dynar.
  */
-void xbt_dynar_insert_at(xbt_dynar_t const dynar, const int idx, const void *const src)
+extern "C" void xbt_dynar_insert_at(xbt_dynar_t const dynar, const int idx, const void* const src)
 {
   /* checks done in xbt_dynar_insert_at_ptr */
   memcpy(xbt_dynar_insert_at_ptr(dynar, idx), src, dynar->elmsize);
@@ -344,11 +363,8 @@ void xbt_dynar_insert_at(xbt_dynar_t const dynar, const int idx, const void *con
  * If the object argument of this function is a non-null pointer, the removed element is copied to this address. If not,
  * the element is freed using the free_f function passed at dynar creation.
  */
-void xbt_dynar_remove_at(xbt_dynar_t const dynar, const int idx, void *const object)
+extern "C" void xbt_dynar_remove_at(xbt_dynar_t const dynar, const int idx, void* const object)
 {
-  unsigned long nb_shift;
-  unsigned long offset;
-
   _sanity_check_dynar(dynar);
   _check_inbound_idx(dynar, idx);
 
@@ -358,10 +374,10 @@ void xbt_dynar_remove_at(xbt_dynar_t const dynar, const int idx, void *const obj
     dynar->free_f(_xbt_dynar_elm(dynar, idx));
   }
 
-  nb_shift = dynar->used - 1 - idx;
+  unsigned long nb_shift = dynar->used - 1 - idx;
 
   if (nb_shift) {
-    offset = nb_shift * dynar->elmsize;
+    unsigned long offset = nb_shift * dynar->elmsize;
     memmove(_xbt_dynar_elm(dynar, idx), _xbt_dynar_elm(dynar, idx + 1), offset);
   }
 
@@ -375,20 +391,20 @@ void xbt_dynar_remove_at(xbt_dynar_t const dynar, const int idx, void *const obj
  *
  * Each of the removed elements is freed using the free_f function passed at dynar creation.
  */
-void xbt_dynar_remove_n_at(xbt_dynar_t const dynar, const unsigned int n, const int idx)
+extern "C" void xbt_dynar_remove_n_at(xbt_dynar_t const dynar, const unsigned int n, const int idx)
 {
   unsigned long nb_shift;
   unsigned long offset;
-  unsigned long cur;
 
-  if (!n) return;
+  if (not n)
+    return;
 
   _sanity_check_dynar(dynar);
   _check_inbound_idx(dynar, idx);
   _check_inbound_idx(dynar, idx + n - 1);
 
   if (dynar->free_f) {
-    for (cur = idx; cur < idx + n; cur++) {
+    for (unsigned long cur = idx; cur < idx + n; cur++) {
       dynar->free_f(_xbt_dynar_elm(dynar, cur));
     }
   }
@@ -411,22 +427,22 @@ void xbt_dynar_remove_n_at(xbt_dynar_t const dynar, const unsigned int n, const
  * \code
  * signed int position = -1;
  * xbt_dynar_foreach(dynar, iter, elem) {
- *    if (!memcmp(elem, searched_element, sizeof(*elem))) {
+ *    if (not memcmp(elem, searched_element, sizeof(*elem))) {
  *        position = iter;
  *        break;
  *    }
  * }
  * \endcode
- * 
+ *
  * Raises not_found_error if not found. If you have less than 2 millions elements, you probably want to use
  * #xbt_dynar_search_or_negative() instead, so that you don't have to TRY/CATCH on element not found.
  */
-unsigned int xbt_dynar_search(xbt_dynar_t const dynar, void *const elem)
+extern "C" unsigned int xbt_dynar_search(xbt_dynar_t const dynar, void* const elem)
 {
   unsigned long it;
 
   for (it = 0; it < dynar->used; it++)
-    if (!memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
+    if (not memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
       return it;
     }
 
@@ -438,33 +454,33 @@ unsigned int xbt_dynar_search(xbt_dynar_t const dynar, void *const elem)
  *
  * Beware that if your dynar contains pointed values (such as strings) instead of scalar, this function is probably not
  * what you want. Check the documentation of xbt_dynar_search() for more info.
- * 
+ *
  * Note that usually, the dynar indices are unsigned integers. If you have more than 2 million elements in your dynar,
  * this very function will not work (but the other will).
  */
-signed int xbt_dynar_search_or_negative(xbt_dynar_t const dynar, void *const elem)
+extern "C" signed int xbt_dynar_search_or_negative(xbt_dynar_t const dynar, void* const elem)
 {
   unsigned long it;
 
   for (it = 0; it < dynar->used; it++)
-    if (!memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
+    if (not memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
       return it;
     }
 
   return -1;
 }
 
-/** @brief Returns a boolean indicating whether the element is part of the dynar 
+/** @brief Returns a boolean indicating whether the element is part of the dynar
  *
  * Beware that if your dynar contains pointed values (such as strings) instead of scalar, this function is probably not
  * what you want. Check the documentation of xbt_dynar_search() for more info.
  */
-int xbt_dynar_member(xbt_dynar_t const dynar, void *const elem)
+extern "C" int xbt_dynar_member(xbt_dynar_t const dynar, void* const elem)
 {
   unsigned long it;
 
   for (it = 0; it < dynar->used; it++)
-    if (!memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
+    if (not memcmp(_xbt_dynar_elm(dynar, it), elem, dynar->elmsize)) {
       return 1;
     }
 
@@ -476,13 +492,13 @@ int xbt_dynar_member(xbt_dynar_t const dynar, void *const elem)
  * You can then use regular affectation to set its value instead of relying on the slow memcpy. This is what
  * xbt_dynar_push_as() does.
  */
-void *xbt_dynar_push_ptr(xbt_dynar_t const dynar)
+extern "C" void* xbt_dynar_push_ptr(xbt_dynar_t const dynar)
 {
   return xbt_dynar_insert_at_ptr(dynar, dynar->used);
 }
 
 /** @brief Add an element at the end of the dynar */
-void xbt_dynar_push(xbt_dynar_t const dynar, const void *const src)
+extern "C" void xbt_dynar_push(xbt_dynar_t const dynar, const void* const src)
 {
   /* checks done in xbt_dynar_insert_at_ptr */
   memcpy(xbt_dynar_insert_at_ptr(dynar, dynar->used), src, dynar->elmsize);
@@ -493,7 +509,7 @@ void xbt_dynar_push(xbt_dynar_t const dynar, const void *const src)
  * You can then use regular affectation to set its value instead of relying on the slow memcpy. This is what
  * xbt_dynar_pop_as() does.
  */
-void *xbt_dynar_pop_ptr(xbt_dynar_t const dynar)
+extern "C" void* xbt_dynar_pop_ptr(xbt_dynar_t const dynar)
 {
   _check_populated_dynar(dynar);
   XBT_CDEBUG(xbt_dyn, "Pop %p", (void *) dynar);
@@ -502,7 +518,7 @@ void *xbt_dynar_pop_ptr(xbt_dynar_t const dynar)
 }
 
 /** @brief Get and remove the last element of the dynar */
-void xbt_dynar_pop(xbt_dynar_t const dynar, void *const dst)
+extern "C" void xbt_dynar_pop(xbt_dynar_t const dynar, void* const dst)
 {
   /* sanity checks done by remove_at */
   XBT_CDEBUG(xbt_dyn, "Pop %p", (void *) dynar);
@@ -513,7 +529,7 @@ void xbt_dynar_pop(xbt_dynar_t const dynar, void *const dst)
  *
  * This is less efficient than xbt_dynar_push()
  */
-void xbt_dynar_unshift(xbt_dynar_t const dynar, const void *const src)
+extern "C" void xbt_dynar_unshift(xbt_dynar_t const dynar, const void* const src)
 {
   /* sanity checks done by insert_at */
   xbt_dynar_insert_at(dynar, 0, src);
@@ -523,7 +539,7 @@ void xbt_dynar_unshift(xbt_dynar_t const dynar, const void *const src)
  *
  * This is less efficient than xbt_dynar_pop()
  */
-void xbt_dynar_shift(xbt_dynar_t const dynar, void *const dst)
+extern "C" void xbt_dynar_shift(xbt_dynar_t const dynar, void* const dst)
 {
   /* sanity checks done by remove_at */
   xbt_dynar_remove_at(dynar, 0, dst);
@@ -533,7 +549,7 @@ void xbt_dynar_shift(xbt_dynar_t const dynar, void *const dst)
  *
  * The mapped function may change the value of the element itself, but should not mess with the structure of the dynar.
  */
-void xbt_dynar_map(const xbt_dynar_t dynar, void_f_pvoid_t const op)
+extern "C" void xbt_dynar_map(const xbt_dynar_t dynar, void_f_pvoid_t const op)
 {
   char *const data = (char *) dynar->data;
   const unsigned long elmsize = dynar->elmsize;
@@ -552,9 +568,10 @@ void xbt_dynar_map(const xbt_dynar_t dynar, void_f_pvoid_t const op)
  *
  * This function can be used while traversing without problem.
  */
-void xbt_dynar_cursor_rm(xbt_dynar_t dynar, unsigned int *const cursor)
+extern "C" void xbt_dynar_cursor_rm(xbt_dynar_t dynar, unsigned int* const cursor)
 {
-  xbt_dynar_remove_at(dynar, (*cursor)--, nullptr);
+  xbt_dynar_remove_at(dynar, *cursor, nullptr);
+  *cursor -= 1;
 }
 
 /** @brief Sorts a dynar according to the function <tt>compar_fn</tt>
@@ -583,7 +600,7 @@ void xbt_dynar_cursor_rm(xbt_dynar_t dynar, unsigned int *const cursor)
  * \param dynar the dynar to sort
  * \param compar_fn comparison function of type (int (compar_fn*) (const void*) (const void*)).
  */
-void xbt_dynar_sort(xbt_dynar_t dynar, int_f_cpvoid_cpvoid_t compar_fn)
+extern "C" void xbt_dynar_sort(xbt_dynar_t dynar, int_f_cpvoid_cpvoid_t compar_fn)
 {
   if (dynar->data != nullptr)
     qsort(dynar->data, dynar->used, dynar->elmsize, compar_fn);
@@ -594,7 +611,7 @@ static int strcmp_voidp(const void *pa, const void *pb) {
 }
 
 /** @brief Sorts a dynar of strings (ie, char* data) */
-xbt_dynar_t xbt_dynar_sort_strings(xbt_dynar_t dynar)
+extern "C" xbt_dynar_t xbt_dynar_sort_strings(xbt_dynar_t dynar)
 {
   xbt_dynar_sort(dynar, strcmp_voidp);
   return dynar; // to enable functional uses
@@ -614,13 +631,13 @@ xbt_dynar_t xbt_dynar_sort_strings(xbt_dynar_t dynar)
  * Remark: if the elements stored in the dynar are structures, the color function has to retrieve the field to sort
  * first.
  */
-XBT_PUBLIC(void) xbt_dynar_three_way_partition(xbt_dynar_t const dynar, int_f_pvoid_t color)
+extern "C" void xbt_dynar_three_way_partition(xbt_dynar_t const dynar, int_f_pvoid_t color)
 {
   unsigned long int i;
   unsigned long int p = -1;
   unsigned long int q = dynar->used;
   const unsigned long elmsize = dynar->elmsize;
-  void *tmp = xbt_malloc(elmsize);
+  char* tmp[elmsize];
   void *elm;
 
   for (i = 0; i < q;) {
@@ -631,10 +648,12 @@ XBT_PUBLIC(void) xbt_dynar_three_way_partition(xbt_dynar_t const dynar, int_f_pv
       ++i;
     } else {
       if (colori == 0) {
-        elm = _xbt_dynar_elm(dynar, ++p);
+        ++p;
+        elm = _xbt_dynar_elm(dynar, p);
         ++i;
       } else {                  /* colori == 2 */
-        elm = _xbt_dynar_elm(dynar, --q);
+        --q;
+        elm = _xbt_dynar_elm(dynar, q);
       }
       if (elm != elmi) {
         memcpy(tmp,  elm,  elmsize);
@@ -643,17 +662,16 @@ XBT_PUBLIC(void) xbt_dynar_three_way_partition(xbt_dynar_t const dynar, int_f_pv
       }
     }
   }
-  xbt_free(tmp);
 }
 
-/** @brief Transform a dynar into a nullptr terminated array. 
+/** @brief Transform a dynar into a nullptr terminated array.
  *
  *  \param dynar the dynar to transform
  *  \return pointer to the first element of the array
  *
  *  Note: The dynar won't be usable afterwards.
  */
-void *xbt_dynar_to_array(xbt_dynar_t dynar)
+extern "C" void* xbt_dynar_to_array(xbt_dynar_t dynar)
 {
   void *res;
   xbt_dynar_shrink(dynar, 1);
@@ -674,13 +692,13 @@ void *xbt_dynar_to_array(xbt_dynar_t dynar)
  *  considered equal, and a value different of zero when they are considered different. Finally, d2 is destroyed
  *  afterwards.
  */
-int xbt_dynar_compare(xbt_dynar_t d1, xbt_dynar_t d2, int(*compar)(const void *, const void *))
+extern "C" int xbt_dynar_compare(xbt_dynar_t d1, xbt_dynar_t d2, int (*compar)(const void*, const void*))
 {
   int i ;
   int size;
-  if((!d1) && (!d2)) return 0;
-  if((!d1) || (!d2))
-  {
+  if ((not d1) && (not d2))
+    return 0;
+  if ((not d1) || (not d2)) {
     XBT_DEBUG("nullptr dynar d1=%p d2=%p",d1,d2);
     xbt_dynar_free(&d2);
     return 1;
@@ -722,7 +740,6 @@ XBT_TEST_UNIT("int", test_dynar_int, "Dynars of integers")
   /* Vars_decl [doxygen cruft] */
   int i;
   unsigned int cursor;
-  int *iptr;
 
   xbt_test_add("==== Traverse the empty dynar");
   xbt_dynar_t d = xbt_dynar_new(sizeof(int), nullptr);
@@ -745,7 +762,7 @@ XBT_TEST_UNIT("int", test_dynar_int, "Dynars of integers")
 
   /* 2. Traverse manually the dynar */
   for (cursor = 0; cursor < NB_ELEM; cursor++) {
-    iptr = (int*) xbt_dynar_get_ptr(d, cursor);
+    int* iptr = (int*)xbt_dynar_get_ptr(d, cursor);
     xbt_test_assert(cursor == (unsigned int)*iptr, "The retrieved value is not the same than the injected one (%u!=%d)",
                     cursor, *iptr);
   }
@@ -1048,25 +1065,17 @@ XBT_TEST_UNIT("string", test_dynar_string, "Dynars of strings")
     s1 = xbt_strdup(buf);
     xbt_dynar_push(d, &s1);
   }
-  for (int cpt = 0; cpt < NB_ELEM; cpt++) {
-    snprintf(buf,1023, "%d", cpt);
-    s1 = xbt_strdup(buf);
-    xbt_dynar_replace(d, cpt, &s1);
-  }
-  for (int cpt = 0; cpt < NB_ELEM; cpt++) {
-    snprintf(buf,1023, "%d", cpt);
-    s1 = xbt_strdup(buf);
-    xbt_dynar_replace(d, cpt, &s1);
-  }
-  for (int cpt = 0; cpt < NB_ELEM; cpt++) {
-    snprintf(buf,1023, "%d", cpt);
-    s1 = xbt_strdup(buf);
-    xbt_dynar_replace(d, cpt, &s1);
+  for (int i = 0 ; i < 3 ; i++) {
+    for (int cpt = 0; cpt < NB_ELEM; cpt++) {
+      snprintf(buf,1023, "%d", cpt);
+      s1 = xbt_strdup(buf);
+      xbt_dynar_replace(d, cpt, &s1);
+    }
   }
   for (int cpt = 0; cpt < NB_ELEM; cpt++) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_shift(d, &s2);
-    xbt_test_assert(!strcmp(buf, s2), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s2);
+    xbt_test_assert(not strcmp(buf, s2), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s2);
     free(s2);
   }
   xbt_dynar_free(&d);           /* This code is used both as example and as regression test, so we try to */
@@ -1083,13 +1092,13 @@ XBT_TEST_UNIT("string", test_dynar_string, "Dynars of strings")
   /* 2. Traverse the dynar with the macro */
   xbt_dynar_foreach(d, iter, s1) {
     snprintf(buf,1023, "%u", NB_ELEM - iter - 1);
-    xbt_test_assert(!strcmp(buf, s1), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s1);
+    xbt_test_assert(not strcmp(buf, s1), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s1);
   }
   /* 3. Traverse the dynar with the macro */
   for (int cpt = 0; cpt < NB_ELEM; cpt++) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_pop(d, &s2);
-    xbt_test_assert(!strcmp(buf, s2), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s2);
+    xbt_test_assert(not strcmp(buf, s2), "The retrieved value is not the same than the injected one (%s!=%s)", buf, s2);
     free(s2);
   }
   /* 4. Free the resources */
@@ -1113,22 +1122,22 @@ XBT_TEST_UNIT("string", test_dynar_string, "Dynars of strings")
   for (int cpt = 0; cpt < NB_ELEM / 2; cpt++) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_shift(d, &s2);
-    xbt_test_assert(!strcmp(buf, s2),
-                     "The retrieved value is not the same than the injected one at the begining (%s!=%s)", buf, s2);
+    xbt_test_assert(not strcmp(buf, s2),
+                    "The retrieved value is not the same than the injected one at the begining (%s!=%s)", buf, s2);
     free(s2);
   }
   for (int cpt = (NB_ELEM / 5) - 1; cpt >= 0; cpt--) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_shift(d, &s2);
-    xbt_test_assert(!strcmp(buf, s2),
-                     "The retrieved value is not the same than the injected one in the middle (%s!=%s)", buf, s2);
+    xbt_test_assert(not strcmp(buf, s2),
+                    "The retrieved value is not the same than the injected one in the middle (%s!=%s)", buf, s2);
     free(s2);
   }
   for (int cpt = NB_ELEM / 2; cpt < NB_ELEM; cpt++) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_shift(d, &s2);
-    xbt_test_assert(!strcmp(buf, s2), "The retrieved value is not the same than the injected one at the end (%s!=%s)",
-                     buf, s2);
+    xbt_test_assert(not strcmp(buf, s2),
+                    "The retrieved value is not the same than the injected one at the end (%s!=%s)", buf, s2);
     free(s2);
   }
   xbt_dynar_free(&d);           /* This code is used both as example and as regression test, so we try to */
@@ -1145,7 +1154,7 @@ XBT_TEST_UNIT("string", test_dynar_string, "Dynars of strings")
   for (int cpt = 2 * (NB_ELEM / 5); cpt < 4 * (NB_ELEM / 5); cpt++) {
     snprintf(buf,1023, "%d", cpt);
     xbt_dynar_remove_at(d, 2 * (NB_ELEM / 5), &s2);
-    xbt_test_assert(!strcmp(buf, s2), "Remove a bad value. Got %s, expected %s", s2, buf);
+    xbt_test_assert(not strcmp(buf, s2), "Remove a bad value. Got %s, expected %s", s2, buf);
     free(s2);
   }
   xbt_dynar_free(&d);           /* end_of_doxygen */
