@@ -1,5 +1,4 @@
-/* Copyright (c) 2008-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2008-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -9,9 +8,31 @@
 #include <cstring>
 
 #include <sys/types.h>
-#ifdef __linux__
+
+#if defined __APPLE__
+# include <mach/mach_init.h>
+# include <mach/mach_traps.h>
+# include <mach/mach_port.h>
+# include <mach/mach_vm.h>
 # include <sys/mman.h>
-#elif defined __FreeBSD__
+# include <sys/param.h>
+# include <libproc.h>
+# if __MAC_OS_X_VERSION_MIN_REQUIRED < 1050
+#  define mach_vm_address_t vm_address_t
+#  define mach_vm_size_t vm_size_t
+#  if defined __ppc64__ || defined __x86_64__
+#    define mach_vm_region vm_region64
+#  else
+#    define mach_vm_region vm_region
+#  endif
+# endif
+#endif
+
+#if defined __linux__
+# include <sys/mman.h>
+#endif
+
+#if defined __FreeBSD__
 # include <sys/types.h>
 # include <sys/mman.h>
 # include <sys/param.h>
@@ -45,7 +66,106 @@ namespace xbt {
 XBT_PRIVATE std::vector<VmMap> get_memory_map(pid_t pid)
 {
   std::vector<VmMap> ret;
-#ifdef __linux__
+#if defined __APPLE__
+  vm_map_t map;
+
+  /* Request authorization to read mappings */
+  if (task_for_pid(mach_task_self(), pid, &map) != KERN_SUCCESS) {
+    std::perror("task_for_pid failed");
+    xbt_die("Cannot request authorization for kernel information access");
+  }
+
+  /*
+   * Darwin do not give us the number of mappings, so we read entries until
+   * we get an KERN_INVALID_ADDRESS return.
+   */
+  mach_vm_address_t address = VM_MIN_ADDRESS;
+  while (true) {
+    kern_return_t kr;
+    memory_object_name_t object;
+    mach_vm_size_t size;
+#if defined __ppc64__ || defined __x86_64__
+    vm_region_flavor_t flavor = VM_REGION_BASIC_INFO_64;
+    struct vm_region_basic_info_64 info;
+    mach_msg_type_number_t info_count = VM_REGION_BASIC_INFO_COUNT_64;
+#else
+    vm_region_flavor_t flavor = VM_REGION_BASIC_INFO;
+    struct vm_region_basic_info info;
+    mach_msg_type_number_t info_count = VM_REGION_BASIC_INFO_COUNT;
+#endif
+
+    kr =
+      mach_vm_region(
+          map,
+          &address,
+          &size,
+          flavor,
+          (vm_region_info_t)&info,
+          &info_count,
+          &object);
+    if (kr == KERN_INVALID_ADDRESS) {
+      break;
+    }
+    else if (kr != KERN_SUCCESS) {
+      std::perror("mach_vm_region failed");
+      xbt_die("Cannot request authorization for kernel information access");
+    }
+
+    VmMap memreg;
+
+    /* Addresses */
+    memreg.start_addr = address;
+    memreg.end_addr = address + size;
+
+    /* Permissions */
+    memreg.prot = PROT_NONE;
+    if (info.protection & VM_PROT_READ)
+      memreg.prot |= PROT_READ;
+    if (info.protection & VM_PROT_WRITE)
+      memreg.prot |= PROT_WRITE;
+    if (info.protection & VM_PROT_EXECUTE)
+      memreg.prot |= PROT_EXEC;
+
+    /* Private (copy-on-write) or shared? */
+    memreg.flags = 0;
+    if (info.shared)
+      memreg.flags |= MAP_SHARED;
+    else
+      memreg.flags |= MAP_PRIVATE;
+
+    /* Offset */
+    memreg.offset = info.offset;
+
+    /* Device : not sure this can be mapped to something outside of Linux? */
+    memreg.dev_major = 0;
+    memreg.dev_minor = 0;
+
+    /* Inode */
+    memreg.inode = 0;
+
+    /* Path */
+    char path[MAXPATHLEN];
+    int pathlen;
+    pathlen = proc_regionfilename(pid, address, path, sizeof(path));
+    path[pathlen]   = '\0';
+    memreg.pathname = path;
+
+#if 0 /* Display mappings for debug */
+    fprintf(stderr,
+        "%#014llx - %#014llx | %c%c%c | %s\n",
+        memreg.start_addr, memreg.end_addr,
+        (memreg.prot & PROT_READ) ? 'r' : '-',
+        (memreg.prot & PROT_WRITE) ? 'w' : '-',
+        (memreg.prot & PROT_EXEC) ? 'x' : '-',
+        memreg.pathname.c_str());
+#endif
+
+    ret.push_back(std::move(memreg));
+    address += size;
+  }
+
+  mach_port_deallocate(mach_task_self(), map);
+#elif defined __linux__
   /* Open the actual process's proc maps file and create the memory_map_t */
   /* to be returned. */
   char* path = bprintf("/proc/%i/maps", (int) pid);
@@ -136,8 +256,9 @@ XBT_PRIVATE std::vector<VmMap> get_memory_map(pid_t pid)
     } else {
       memreg.flags |= MAP_SHARED;
       if (lfields[1][3] != 's')
-	XBT_WARN("The protection is neither 'p' (private) nor 's' (shared) but '%s'. Let's assume shared, as on b0rken win-ubuntu systems.\nFull line: %s\n",
-		 lfields[1], line);
+        XBT_WARN("The protection is neither 'p' (private) nor 's' (shared) but '%s'. Let's assume shared, as on b0rken "
+                 "win-ubuntu systems.\nFull line: %s\n",
+                 lfields[1], line);
     }
 
     /* Get the offset value */
@@ -176,7 +297,7 @@ XBT_PRIVATE std::vector<VmMap> get_memory_map(pid_t pid)
 
     /* Create space for a new map region in the region's array and copy the */
     /* parsed stuff from the temporal memreg variable */
-    XBT_DEBUG("Found region for %s", !memreg.pathname.empty() ? memreg.pathname.c_str() : "(null)");
+    XBT_DEBUG("Found region for %s", not memreg.pathname.empty() ? memreg.pathname.c_str() : "(null)");
 
     ret.push_back(std::move(memreg));
   }
@@ -240,9 +361,8 @@ XBT_PRIVATE std::vector<VmMap> get_memory_map(pid_t pid)
       */
     if (vmentries[i].kve_path[0] != '\0')
       memreg.pathname = vmentries[i].kve_path;
-    else if (vmentries[i].kve_type == KVME_TYPE_DEFAULT
-	    && vmentries[i-1].kve_type == KVME_TYPE_VNODE
-        && vmentries[i-1].kve_path[0] != '\0')
+    else if (vmentries[i].kve_type == KVME_TYPE_DEFAULT && vmentries[i - 1].kve_type == KVME_TYPE_VNODE &&
+             vmentries[i - 1].kve_path[0] != '\0')
       memreg.pathname = vmentries[i-1].kve_path;
     else if (vmentries[i].kve_type == KVME_TYPE_DEFAULT
         && vmentries[i].kve_flags & KVME_FLAG_GROWS_DOWN)
@@ -254,8 +374,7 @@ XBT_PRIVATE std::vector<VmMap> get_memory_map(pid_t pid)
      * later identifies mappings based on the permissions that are expected
      * when running the Linux kernel.
      */
-    if (vmentries[i].kve_type == KVME_TYPE_VNODE
-        && ! (vmentries[i].kve_flags & KVME_FLAG_NEEDS_COPY))
+    if (vmentries[i].kve_type == KVME_TYPE_VNODE && not(vmentries[i].kve_flags & KVME_FLAG_NEEDS_COPY))
       memreg.prot &= ~PROT_WRITE;
 
     ret.push_back(std::move(memreg));
