@@ -7,11 +7,9 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include <xbt/ex.hpp>
-#include "src/internal_config.h"
 #include "xbt/misc.h"
 #include "xbt/sysdep.h"
 #include "xbt/str.h"            /* headers of these functions */
-#include "xbt/strbuff.h"
 
 /**  @brief Strip whitespace (or other characters) from the end of a string.
  *
@@ -34,10 +32,10 @@ void xbt_str_rtrim(char *s, const char *char_list)
   const char *__char_list = " \t\n\r\x0B";
   char white_char[256] = { 1, 0 };
 
-  if (!s)
+  if (not s)
     return;
 
-  if (!char_list) {
+  if (not char_list) {
     while (*__char_list) {
       white_char[(unsigned char) *__char_list++] = 1;
     }
@@ -77,10 +75,10 @@ void xbt_str_ltrim(char *s, const char *char_list)
   const char *__char_list = " \t\n\r\x0B";
   char white_char[256] = { 1, 0 };
 
-  if (!s)
+  if (not s)
     return;
 
-  if (!char_list) {
+  if (not char_list) {
     while (*__char_list) {
       white_char[(unsigned char) *__char_list++] = 1;
     }
@@ -113,7 +111,7 @@ void xbt_str_ltrim(char *s, const char *char_list)
  */
 void xbt_str_trim(char *s, const char *char_list)
 {
-  if (!s)
+  if (not s)
     return;
 
   xbt_str_rtrim(s, char_list);
@@ -141,31 +139,6 @@ void xbt_str_subst(char *str, char from, char to, int occurence)
   }
 }
 
-/** @brief Replaces a set of variables by their values
- *
- * @param str The input of the replacement process
- * @param patterns The changes to apply
- * @return The string modified
- *
- * Both '$toto' and '${toto}' are valid (and the two writing are equivalent).
- *
- * If the variable name contains spaces, use the brace version (ie, ${toto tutu})
- *
- * You can provide a default value to use if the variable is not set in the dict by using '${var:=default}' or
- * '${var:-default}'. These two forms are equivalent, even if they shouldn't to respect the shell standard (:= form
- * should set the value in the dict, but does not) (BUG).
- */
-char *xbt_str_varsubst(const char *str, xbt_dict_t patterns)
-{
-  xbt_strbuff_t buff = xbt_strbuff_new_from(str);
-  char *res;
-  xbt_strbuff_varsubst(buff, patterns);
-  res = buff->data;
-  xbt_strbuff_free_container(buff);
-  return res;
-}
-
-
 /** @brief Splits a string into a dynar of strings
  *
  * @param s: the string to split
@@ -183,33 +156,31 @@ char *xbt_str_varsubst(const char *str, xbt_dict_t patterns)
 xbt_dynar_t xbt_str_split(const char *s, const char *sep)
 {
   xbt_dynar_t res = xbt_dynar_new(sizeof(char *), &xbt_free_ref);
-  const char *p, *q;
-  int done;
   const char *sep_dflt = " \t\n\r\x0B";
   char is_sep[256] = { 1, 0 };
 
   /* check what are the separators */
   memset(is_sep, 0, sizeof(is_sep));
-  if (!sep) {
+  if (not sep) {
     while (*sep_dflt)
       is_sep[(unsigned char) *sep_dflt++] = 1;
   } else {
     while (*sep)
       is_sep[(unsigned char) *sep++] = 1;
   }
-  is_sep[0] = 1;                /* End of string is also separator */
+  is_sep[0] = 1; /* End of string is also separator */
 
   /* Do the job */
-  p = s;
-  q = s;
-  done = 0;
+  const char* p = s;
+  const char* q = s;
+  int done      = 0;
 
   if (s[0] == '\0')
     return res;
 
-  while (!done) {
+  while (not done) {
     char *topush;
-    while (!is_sep[(unsigned char) *q]) {
+    while (not is_sep[(unsigned char)*q]) {
       q++;
     }
     if (*q == '\0')
@@ -227,18 +198,16 @@ xbt_dynar_t xbt_str_split(const char *s, const char *sep)
 
 /**
  * \brief This functions splits a string after using another string as separator
- * For example A!!B!!C splitted after !! will return the dynar {A,B,C}
+ * For example Anot not B!not C split after !! will return the dynar {A,B,C}
  * \return An array of dynars containing the string tokens
  */
 xbt_dynar_t xbt_str_split_str(const char *s, const char *sep)
 {
   xbt_dynar_t res = xbt_dynar_new(sizeof(char *), &xbt_free_ref);
-  int done;
-  const char *p, *q;
 
-  p = s;
-  q = s;
-  done = 0;
+  const char* p = s;
+  const char* q = s;
+  int done      = 0;
 
   if (s[0] == '\0')
     return res;
@@ -248,14 +217,13 @@ xbt_dynar_t xbt_str_split_str(const char *s, const char *sep)
     return res;
   }
 
-  while (!done) {
+  while (not done) {
     char *to_push;
-    int v = 0;
-    //get the start of the first occurence of the substring
+    // get the start of the first occurrence of the substring
     q = strstr(p, sep);
     //if substring was not found add the entire string
     if (nullptr == q) {
-      v = strlen(p);
+      int v   = strlen(p);
       to_push = (char*) xbt_malloc(v + 1);
       memcpy(to_push, p, v);
       to_push[v] = '\0';
@@ -287,10 +255,12 @@ xbt_dynar_t xbt_str_split_str(const char *s, const char *sep)
  */
 xbt_dynar_t xbt_str_split_quoted_in_place(char *s) {
   xbt_dynar_t res = xbt_dynar_new(sizeof(char *), nullptr);
-  char *beg, *end;              /* pointers around the parsed chunk */
-  int in_simple_quote = 0, in_double_quote = 0;
-  int done = 0;
-  int ctn = 0;                  /* Got something in this block */
+  char* beg;
+  char* end; /* pointers around the parsed chunk */
+  int in_simple_quote = 0;
+  int in_double_quote = 0;
+  int done            = 0;
+  int ctn             = 0; /* Got something in this block */
 
   if (s[0] == '\0')
     return res;
@@ -300,7 +270,7 @@ xbt_dynar_t xbt_str_split_quoted_in_place(char *s) {
   /* do not trim leading spaces: caller responsibility to clean his cruft */
   end = beg;
 
-  while (!done) {
+  while (not done) {
     switch (*end) {
     case '\\':
       ctn = 1;
@@ -312,8 +282,8 @@ xbt_dynar_t xbt_str_split_quoted_in_place(char *s) {
       break;
     case '\'':
       ctn = 1;
-      if (!in_double_quote) {
-        in_simple_quote = !in_simple_quote;
+      if (not in_double_quote) {
+        in_simple_quote = not in_simple_quote;
         memmove(end, end + 1, strlen(end));
       } else {
         /* simple quote protected by double ones */
@@ -322,8 +292,8 @@ xbt_dynar_t xbt_str_split_quoted_in_place(char *s) {
       break;
     case '"':
       ctn = 1;
-      if (!in_simple_quote) {
-        in_double_quote = !in_double_quote;
+      if (not in_simple_quote) {
+        in_double_quote = not in_double_quote;
         memmove(end, end + 1, strlen(end));
       } else {
         /* double quote protected by simple ones */
@@ -403,10 +373,9 @@ char *xbt_str_join(xbt_dynar_t dyn, const char *sep)
 {
   int len = 1, dyn_len = xbt_dynar_length(dyn);
   unsigned int cpt;
-  char *cursor;
-  char *res, *p;
+  char* cursor;
 
-  if (!dyn_len)
+  if (not dyn_len)
     return xbt_strdup("");
 
   /* compute the length */
@@ -415,8 +384,8 @@ char *xbt_str_join(xbt_dynar_t dyn, const char *sep)
   }
   len += strlen(sep) * dyn_len;
   /* Do the job */
-  res = (char*) xbt_malloc(len);
-  p = res;
+  char* res = (char*)xbt_malloc(len);
+  char* p   = res;
   xbt_dynar_foreach(dyn, cpt, cursor) {
     if ((int) cpt < dyn_len - 1)
       p += snprintf(p,len, "%s%s", cursor, sep);
@@ -433,26 +402,24 @@ char *xbt_str_join(xbt_dynar_t dyn, const char *sep)
  */
 char *xbt_str_join_array(const char *const *strs, const char *sep)
 {
-  char *res,*q;
   int amount_strings=0;
   int len=0;
-  int i;
 
-  if ((!strs) || (!strs[0]))
+  if ((not strs) || (not strs[0]))
     return xbt_strdup("");
 
   /* compute the length before malloc */
-  for (i=0;strs[i];i++) {
+  for (int i = 0; strs[i]; i++) {
     len += strlen(strs[i]);
     amount_strings++;
   }
   len += strlen(sep) * amount_strings;
 
   /* Do the job */
-  res = (char*) xbt_malloc(len);
-  q = res;
-  for (i=0;strs[i];i++) {
-    if (i!=0) { // not first loop
+  char* res = (char*)xbt_malloc(len);
+  char* q   = res;
+  for (int i = 0; strs[i]; i++) {
+    if (i != 0) { // not first loop
       q += snprintf(q,len, "%s%s", sep, strs[i]);
     } else {
       q += snprintf(q,len, "%s",strs[i]);
@@ -461,25 +428,6 @@ char *xbt_str_join_array(const char *const *strs, const char *sep)
   return res;
 }
 
-/** @brief creates a new string containing what can be read on a fd */
-char *xbt_str_from_file(FILE * file)
-{
-  xbt_strbuff_t buff = xbt_strbuff_new();
-  char *res;
-  char bread[1024];
-  memset(bread, 0, 1024);
-
-  while (!feof(file)) {
-    int got = fread(bread, 1, 1023, file);
-    bread[got] = '\0';
-    xbt_strbuff_append(buff, bread);
-  }
-
-  res = buff->data;
-  xbt_strbuff_free_container(buff);
-  return res;
-}
-
 /** @brief Parse an integer out of a string, or raise an error
  *
  * The @a str is passed as argument to your @a error_msg, as follows:
@@ -487,7 +435,7 @@ char *xbt_str_from_file(FILE * file)
  */
 long int xbt_str_parse_int(const char* str, const char* error_msg)
 {
-  char *endptr;
+  char* endptr;
   if (str == nullptr || str[0] == '\0')
     THROWF(arg_error, 0, error_msg, str);
 
@@ -522,15 +470,13 @@ double xbt_str_parse_double(const char* str, const char* error_msg)
 
 XBT_TEST_SUITE("xbt_str", "String Handling");
 
-#define mytest(name, input, expected) \
-  xbt_test_add(name); \
-  d=xbt_str_split_quoted(input); \
-  s=xbt_str_join(d,"XXX"); \
-  xbt_test_assert(!strcmp(s,expected),\
-                   "Input (%s) leads to (%s) instead of (%s)", \
-                   input,s,expected);\
-                   free(s); \
-                   xbt_dynar_free(&d);
+#define mytest(name, input, expected)                                                                                  \
+  xbt_test_add(name);                                                                                                  \
+  d = xbt_str_split_quoted(input);                                                                                     \
+  s = xbt_str_join(d, "XXX");                                                                                          \
+  xbt_test_assert(not strcmp(s, expected), "Input (%s) leads to (%s) instead of (%s)", input, s, expected);            \
+  free(s);                                                                                                             \
+  xbt_dynar_free(&d);
 XBT_TEST_UNIT("xbt_str_split_quoted", test_split_quoted, "test the function xbt_str_split_quoted")
 {
   xbt_dynar_t d;
@@ -550,15 +496,13 @@ XBT_TEST_UNIT("xbt_str_split_quoted", test_split_quoted, "test the function xbt_
   mytest("Backslashed quotes + quotes", "'toto \\'tutu' tata", "toto 'tutuXXXtata");
 }
 
-#define mytest_str(name, input, separator, expected) \
-  xbt_test_add(name); \
-  d=xbt_str_split_str(input, separator); \
-  s=xbt_str_join(d,"XXX"); \
-  xbt_test_assert(!strcmp(s,expected),\
-                   "Input (%s) leads to (%s) instead of (%s)", \
-                   input,s,expected);\
-                   free(s); \
-                   xbt_dynar_free(&d);
+#define mytest_str(name, input, separator, expected)                                                                   \
+  xbt_test_add(name);                                                                                                  \
+  d = xbt_str_split_str(input, separator);                                                                             \
+  s = xbt_str_join(d, "XXX");                                                                                          \
+  xbt_test_assert(not strcmp(s, expected), "Input (%s) leads to (%s) instead of (%s)", input, s, expected);            \
+  free(s);                                                                                                             \
+  xbt_dynar_free(&d);
 
 XBT_TEST_UNIT("xbt_str_split_str", test_split_str, "test the function xbt_str_split_str")
 {
