@@ -30,7 +30,7 @@ static int master(int argc, char *argv[])
 {
   XBT_INFO("Launching our nice bugged recursive function...");
   unsigned i = 1;
-  while (i <= 0x80000000u) {
+  while (i <= 0x80000000U) {
     i *= 2;
     unsigned res = collatz(i, i);
     XBT_VERB("collatz(%u, %u) returned %u", i, i, res);
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
 
   SIMIX_function_register("master", master);
   SIMIX_create_environment(argv[1]);
-  simcall_process_create("master", master, NULL, sg_host_by_name("Tremblay"), -1, 0, NULL, NULL, 0);
+  simcall_process_create("master", master, NULL, sg_host_by_name("Tremblay"), 0, NULL, NULL);
   SIMIX_run();
 
   return 0;
