@@ -17,10 +17,8 @@
 
 int main(int argc, char *argv[])
 {
-  int rank, size;
-  int i;
-  int *sb;
-  int *rb;
+  int rank;
+  int size;
   int status;
 
   MPI_Init(&argc, &argv);
@@ -28,23 +26,23 @@ int main(int argc, char *argv[])
   MPI_Comm_size(MPI_COMM_WORLD, &size);
 
   int count = 2;
-  sb = (int *) xbt_malloc(count * sizeof(int));
-  rb = (int *) xbt_malloc(count * size * sizeof(int));
-  
-  for (i = 0; i < count; ++i)
+  int* sb = (int *) xbt_malloc(count * sizeof(int));
+  int* rb = (int *) xbt_malloc(count * size * sizeof(int));
+
+  for (int i = 0; i < count; ++i)
     sb[i] = rank * count + i;
-  for (i = 0; i < count * size; ++i)  
+  for (int i = 0; i < count * size; ++i)
     rb[i] = 0;
 
   printf("[%d] sndbuf=[", rank);
-  for (i = 0; i < count; i++)
+  for (int i = 0; i < count; i++)
     printf("%d ", sb[i]);
   printf("]\n");
 
   status = MPI_Allgather(sb, count, MPI_INT, rb, count, MPI_INT, MPI_COMM_WORLD);
 
   printf("[%d] rcvbuf=[", rank);
-  for (i = 0; i < count * size; i++)
+  for (int i = 0; i < count * size; i++)
     printf("%d ", rb[i]);
   printf("]\n");
 
@@ -54,8 +52,8 @@ int main(int argc, char *argv[])
       fflush(stdout);
     }
   }
-  free(sb);
-  free(rb);
+  xbt_free(sb);
+  xbt_free(rb);
   MPI_Finalize();
   return (EXIT_SUCCESS);
 }
