@@ -9,7 +9,9 @@
 
 int main(int argc, char **argv)
 {
-  int i, size, rank;
+  int i;
+  int size;
+  int rank;
   int count = 2048;
 
   MPI_Init(&argc, &argv);
@@ -32,7 +34,7 @@ int main(int argc, char **argv)
   xbt_free(values);
 
   count = 4096;
-  values = (int *) xbt_malloc(count * sizeof(int));  
+  values = (int *) xbt_malloc(count * sizeof(int));
 
   for (i = 0; i < count; i++)
     values[i] = (size -1 == rank) ? 17 : 3;
