@@ -259,7 +259,7 @@ static void test3(method_t method)
 
   /* Creates the constraints */
   lmm_constraint_t *tmp_cnst = xbt_new0(lmm_constraint_t, 15);
-  for (int i = 0; i < 15; i++) 
+  for (int i = 0; i < 15; i++)
     tmp_cnst[i] = lmm_constraint_new(Sys, nullptr, B[i]);
 
   /* Creates the variables */
@@ -298,10 +298,8 @@ static void test3(method_t method)
   xbt_free(A);
 }
 
-int main(int argc, char **argv)
+int main()
 {
-  surf_init(&argc, argv);
-
   XBT_INFO("***** Test 1 (Max-Min)");
   test1(MAXMIN);
   XBT_INFO("***** Test 1 (Lagrange - Vegas)");
@@ -323,6 +321,5 @@ int main(int argc, char **argv)
   XBT_INFO("***** Test 3 (Lagrange - Reno)");
   test3(LAGRANGE_RENO);
 
-  surf_exit();
   return 0;
 }
