@@ -1,20 +1,14 @@
 /* A few basic tests for the surf library                                   */
 
-/* Copyright (c) 2004-2015. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "surf/surf.h"
 #include "simgrid/host.h"
-#include "simgrid/s4u/host.hpp"
-#include "simgrid/sg_config.h"
 #include "src/surf/cpu_interface.hpp"
 #include "src/surf/network_interface.hpp"
-#include "src/surf/surf_interface.hpp"
-#include <stdio.h>
 
-#include "xbt/log.h"
 XBT_LOG_NEW_DEFAULT_CATEGORY(surf_test, "Messages specific for surf example");
 
 static const char *string_action(simgrid::surf::Action::State state)
@@ -37,7 +31,6 @@ static const char *string_action(simgrid::surf::Action::State state)
 
 int main(int argc, char **argv)
 {
-  double now = -1.0;
   surf_init(&argc, argv);       /* Initialize some common structures */
   xbt_cfg_set_parse("cpu/model:Cas01");
   xbt_cfg_set_parse("network/model:CM02");
@@ -71,8 +64,7 @@ int main(int argc, char **argv)
   surf_solve(-1.0);
   do {
     simgrid::surf::ActionList *action_list = nullptr;
-    now = surf_get_clock();
-    XBT_INFO("Next Event : %g", now);
+    XBT_INFO("Next Event : %g", surf_get_clock());
     XBT_DEBUG("\t CPU actions");
 
     action_list = surf_cpu_model_pm->getFailedActionSet();
